#include <nexus-rest-api.h>

/**
 * Enunciate-specific C functions.
 */
#ifndef ENUNCIATE_C_UTILITIES
#define ENUNCIATE_C_UTILITIES

/*******************xml utilities************************************/

static int xmlTextReaderAdvanceToNextStartOrEndElement(xmlTextReaderPtr reader) {
  int status = xmlTextReaderRead(reader);
  while (status && xmlTextReaderNodeType(reader) != XML_READER_TYPE_ELEMENT && xmlTextReaderNodeType(reader) != XML_READER_TYPE_END_ELEMENT) {
    status = xmlTextReaderRead(reader);
  }
  return status;
}

static int xmlTextReaderSkipElement(xmlTextReaderPtr reader) {
  int status = xmlTextReaderNext(reader);
  while (status && xmlTextReaderNodeType(reader) != XML_READER_TYPE_ELEMENT && xmlTextReaderNodeType(reader) != XML_READER_TYPE_END_ELEMENT) {
    status = xmlTextReaderRead(reader);
  }
  return status;
}

static xmlChar *xmlTextReaderReadEntireNodeValue(xmlTextReaderPtr reader) {
  xmlChar *buffer = calloc(1, sizeof(xmlChar));
  const xmlChar *snippet;
  int status;
  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ATTRIBUTE) {
    return xmlTextReaderValue(reader);
  }
  else if (xmlTextReaderIsEmptyElement(reader) == 0) {
    status = xmlTextReaderRead(reader);
    while (status && (xmlTextReaderNodeType(reader) == XML_READER_TYPE_TEXT || xmlTextReaderNodeType(reader) == XML_READER_TYPE_CDATA || xmlTextReaderNodeType(reader) == XML_READER_TYPE_ENTITY_REFERENCE)) {
      snippet = xmlTextReaderConstValue(reader);
      buffer = realloc(buffer, (xmlStrlen(buffer) + xmlStrlen(snippet) + 1) * sizeof(xmlChar));
      xmlStrcat(buffer, snippet);
      status = xmlTextReaderRead(reader);
    }
  }
  return buffer;
}

/*******************base 64 utilities************************************/

/*
 * Base64 Translation Table as described in RFC1113.
 *
 * This code was graciously ripped from http://base64.sourceforge.net
 */
static const char cb64[]="ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/";

/*
 * Base64 Translation Table to decode (created by author)
 *
 * This code was graciously ripped from http://base64.sourceforge.net
 */
static const char cd64[]="|$$$}rstuvwxyz{$$$$$$$>?@ABCDEFGHIJKLMNOPQRSTUVW$$$$$$XYZ[\\]^_`abcdefghijklmnopq";

/*
 * encode 3 8-bit binary bytes as 4 '6-bit' characters
 *
 * This code was graciously ripped from http://base64.sourceforge.net
 *
 * @param in the block to encode
 * @param out the block to encode to
 * @param len the length of the 'in' block.
 */
static void _encode_base64_block(unsigned char in[3], unsigned char out[4], int len) {
  out[0] = cb64[ in[0] >> 2 ];
  out[1] = cb64[ ((in[0] & 0x03) << 4) | ((in[1] & 0xf0) >> 4) ];
  out[2] = (unsigned char) (len > 1 ? cb64[ ((in[1] & 0x0f) << 2) | ((in[2] & 0xc0) >> 6) ] : '=');
  out[3] = (unsigned char) (len > 2 ? cb64[ in[2] & 0x3f ] : '=');
}

/*
 * decode 4 '6-bit' characters into 3 8-bit binary bytes
 *
 * This code was graciously ripped from http://base64.sourceforge.net
 */
static void _decode_base64_block( unsigned char in[4], unsigned char out[3] )
{
    out[ 0 ] = (unsigned char ) (in[0] << 2 | in[1] >> 4);
    out[ 1 ] = (unsigned char ) (in[1] << 4 | in[2] >> 2);
    out[ 2 ] = (unsigned char ) (((in[2] << 6) & 0xc0) | in[3]);
}

/*
 * base64 encode a stream adding padding and line breaks as per spec.
 *
 * This code was graciously ripped from http://base64.sourceforge.net
 *
 * @param instream The stream to encode.
 * @param insize The size of the stream to encode.
 * @return The encoded string.
 */
xmlChar *_encode_base64(unsigned char *instream, int insize) {
  unsigned char in[3];
  unsigned char out[4];
  xmlChar *encoded;
  int i, in_index = 0, out_index = 0, blocklen;

  if (insize == 0) {
    return BAD_CAST "\0";
  }

  encoded = calloc(((insize / 3) * 4) + 10, sizeof(xmlChar));
  while (in_index <= insize) {
    blocklen = 0;
    for (i = 0; i < 3; i++) {
      in[i] = instream[in_index++];
      if (in_index <= insize) {
        blocklen++;
      }
      else {
        in[i] = 0;
      }
    }
    if (blocklen) {
      _encode_base64_block(in, out, blocklen);
      for( i = 0; i < 4; i++ ) {
        encoded[out_index++] = out[i];
      }
    }
  }

  return encoded;
}

/*
 * Decode a base64 encoded stream discarding padding, line breaks and noise
 *
 * This code was graciously ripped from http://base64.sourceforge.net
 *
 * @param invalue The string to decode.
 * @param outsize Holder for the length of the returned data.
 * @return The decoded data.
 */
unsigned char *_decode_base64( const xmlChar *invalue, int *outsize ) {
  xmlChar in[4];
  unsigned char out[3], v;
  int i, in_index = 0, out_index = 0, blocklen;
  unsigned char *outstream;

  if (invalue == NULL) {
    return NULL;
  }

  outstream = calloc(((xmlStrlen(invalue) / 4) * 3) + 1, sizeof(unsigned char));
  while (invalue[in_index] != '\0') {
    for (blocklen = 0, i = 0; i < 4 && invalue[in_index]; i++) {
      v = 0;
      while (invalue[in_index] != '\0' && v == 0) {
        v = (unsigned char) invalue[in_index++];
        v = (unsigned char) ((v < 43 || v > 122) ? 0 : cd64[ v - 43 ]);
        if (v) {
          v = (unsigned char) ((v == '$') ? 0 : v - 61);
        }
      }

      if (invalue[in_index] != '\0') {
        blocklen++;
        if (v) {
          in[i] = (unsigned char) (v - 1);
        }
      }
      else {
        in[i] = 0;
      }
    }

    if (blocklen) {
      _decode_base64_block( in, out );
      for( i = 0; i < blocklen - 1; i++ ) {
        outstream[out_index++] = out[i];
      }
    }
  }

  if (outsize != NULL) {
    *outsize = out_index;
  }

  return outstream;
}

#endif /* ENUNCIATE_C_UTILITIES */

#ifndef ENUNCIATE_OBJC_CLASSES
#define ENUNCIATE_OBJC_CLASSES

/**
 * Protocol defining a JAXB (see https://jaxb.dev.java.net/) type.
 */
@protocol JAXBType

/**
 * Read an XML type from an XML reader.
 *
 * @param reader The reader.
 * @return An instance of the object defining the JAXB type.
 */
+ (id<JAXBType>) readXMLType: (xmlTextReaderPtr) reader;

/**
 * Initialize the object with an XML reader.
 *
 * @param reader The XML reader from which to initialize the values of this type.
 */
- (id) initWithReader: (xmlTextReaderPtr) reader;

/**
 * Write this instance of a JAXB type to a writer.
 *
 * @param writer The writer.
 */
- (void) writeXMLType: (xmlTextWriterPtr) writer;

@end /*protocol JAXBType*/


/**
 * Protocol defining a JAXB (see https://jaxb.dev.java.net/) element.
 */
@protocol JAXBElement

/**
 * Read the XML element from an XML reader. It is assumed
 * that the reader is pointing at the start element (be careful
 * that it's not still pointing to the XML document).
 *
 * @param reader The reader.
 * @return An instance of the object defining the JAXB element.
 */
+ (id<JAXBElement>) readXMLElement: (xmlTextReaderPtr) reader;

/**
 * Write this instance of a JAXB element to a writer.
 *
 * @param writer The writer.
 */
- (void) writeXMLElement: (xmlTextWriterPtr) writer;

/**
 * Write this instance of a JAXB element to a writer.
 *
 * @param writer The writer.
 * @param writeNs Whether to write the namespaces for this element to the xml writer.
 */
- (void) writeXMLElement: (xmlTextWriterPtr) writer writeNamespaces: (BOOL) writeNs;

@end /*protocol JAXBElement*/


/**
 * Protocol defining methods for events that occur
 * when reading/parsing XML. Intended for internal
 * use only.
 */
@protocol JAXBReading

/**
 * Method for reading an attribute.
 *
 * @param reader The reader pointing to the attribute.
 * @return Whether the attribute was read.
 */
- (BOOL) readJAXBAttribute: (xmlTextReaderPtr) reader;

/**
 * Method for reading the value of an element.
 *
 * @param reader The reader pointing to the element containing a value.
 * @return Whether the value was read.
 */
- (BOOL) readJAXBValue: (xmlTextReaderPtr) reader;

/**
 * Method for reading a child element. If (and only if) the child
 * element was handled, the element in the reader should be
 * "consumed" and the reader will be pointing to the end element.
 *
 * @param reader The reader pointing to the child element.
 * @return Whether the child element was read.
 */
- (BOOL) readJAXBChildElement: (xmlTextReaderPtr) reader;

/**
 * Method for reading an unknown attribute.
 *
 * @param reader The reader pointing to the unknown attribute.
 * @return Whether the attribute was read.
 */
- (void) readUnknownJAXBAttribute: (xmlTextReaderPtr) reader;

/**
 * Method for reading an unknown child element. Implementations
 * must be responsible for "consuming" the child element.
 *
 * @param reader The reader pointing to the unknown child element.
 * @return The status of the reader after having consumed the unknown child element.
 */
- (int) readUnknownJAXBChildElement: (xmlTextReaderPtr) reader;

@end /*protocol JAXBReading*/

/**
 * Protocol defining methods for events that occur
 * when writing XML. Intended for internal
 * use only.
 */
@protocol JAXBWriting

/**
 * Method for writing the attributes.
 *
 * @param writer The writer.
 */
- (void) writeJAXBAttributes: (xmlTextWriterPtr) writer;

/**
 * Method for writing the element value.
 *
 * @param writer The writer.
 */
- (void) writeJAXBValue: (xmlTextWriterPtr) writer;

/**
 * Method for writing the child elements.
 *
 * @param writer The writer.
 */
- (void) writeJAXBChildElements: (xmlTextWriterPtr) writer;

@end /*protocol JAXBWriting*/

/**
 * Declaration of the JAXB type, element, events for a base object.
 */
@interface NSObject (JAXB) <JAXBType, JAXBElement, JAXBReading, JAXBWriting>

@end

/**
 * Implementation of the JAXB type, element, events for a base object.
 */
@implementation NSObject (JAXB)

/**
 * Read the XML type from the reader; an instance of NSXMLElement.
 *
 * @param reader The reader.
 * @return An instance of NSXMLElement
 */
+ (id<JAXBType>) readXMLType: (xmlTextReaderPtr) reader
{
  return [JAXBBasicXMLNode readXMLType: reader];
}

/**
 * Read an XML type from an XML reader into an existing instance.
 *
 * @param reader The reader.
 * @param existing The existing instance into which to read values.
 */
- (id) initWithReader: (xmlTextReaderPtr) reader
{
  int status, depth;
  if ((self = [self init])) {
    if (xmlTextReaderHasAttributes(reader)) {
      while (xmlTextReaderMoveToNextAttribute(reader)) {
        if ([self readJAXBAttribute: reader] == NO) {
          [self readUnknownJAXBAttribute: reader];
        }
      }

      status = xmlTextReaderMoveToElement(reader);
      if (!status) {
        //panic: unable to return to the element node.
        [NSException raise: @"XMLReadError"
                     format: @"Error moving back to element position from attributes."];
      }
    }

    if ([self readJAXBValue: reader] == NO) {
      //no value handled; attempt to process child elements
      if (xmlTextReaderIsEmptyElement(reader) == 0) {
        depth = xmlTextReaderDepth(reader);//track the depth.
        status = xmlTextReaderAdvanceToNextStartOrEndElement(reader);
        while (xmlTextReaderDepth(reader) > depth) {
          if (status < 1) {
            //panic: XML read error.
            [NSException raise: @"XMLReadError"
                         format: @"Error handling a child element."];
          }
          else if ([self readJAXBChildElement: reader]) {
            status = xmlTextReaderAdvanceToNextStartOrEndElement(reader);
          }
          else {
            status = [self readUnknownJAXBChildElement: reader];
          }
        }
      }
    }
  }
  return self;
}

/**
 * Write the XML type value of this object to the writer.
 *
 * @param writer The writer.
 */
- (void) writeXMLType: (xmlTextWriterPtr) writer
{
  [self writeJAXBAttributes: writer];
  [self writeJAXBValue: writer];
  [self writeJAXBChildElements: writer];
}

/**
 * Read the XML element from the reader; an instance of NSXMLElement.
 *
 * @param reader The reader.
 * @return An instance of NSXMLElement
 */
+ (id<JAXBElement>) readXMLElement: (xmlTextReaderPtr) reader
{
  return (id<JAXBElement>) [JAXBBasicXMLNode readXMLType: reader];
}

/**
 * No op; root objects don't have an element name/namespace. Subclasses must override.
 *
 * @param writer The writer.
 */
- (void) writeXMLElement: (xmlTextWriterPtr) writer
{
  //no-op
}

/**
 * No op; root objects don't have an element name/namespace. Subclasses must override.
 *
 * @param writer The writer.
 * @param writeNs Ignored.
 */
- (void) writeXMLElement: (xmlTextWriterPtr) writer writeNamespaces: (BOOL) writeNs
{
  //no-op
}

/**
 * No-op; base objects do not handle any attributes.
 *
 * @param reader The reader pointing to the attribute.
 * @return NO
 */
- (BOOL) readJAXBAttribute: (xmlTextReaderPtr) reader
{
  return NO;
}

/**
 * No-op; base objects do not handle any values.
 *
 * @param reader The reader pointing to the element containing a value.
 * @return NO
 */
- (BOOL) readJAXBValue: (xmlTextReaderPtr) reader
{
  return NO;
}

/**
 * No-op; base objects do not handle any child elements.
 *
 * @param reader The reader pointing to the child element.
 * @return NO
 */
- (BOOL) readJAXBChildElement: (xmlTextReaderPtr) reader
{
  return NO;
}

/**
 * No-op; base objects do not handle any attributes.
 *
 * @param reader The reader pointing to the unknown attribute.
 */
- (void) readUnknownJAXBAttribute: (xmlTextReaderPtr) reader
{
}

/**
 * Just skips the unknown element; base objects do not handle any child elements.
 *
 * @param reader The reader pointing to the unknown child element.
 * @return The status of the reader after skipping the unknown child element.
 */
- (int) readUnknownJAXBChildElement: (xmlTextReaderPtr) reader
{
  return xmlTextReaderSkipElement(reader);
}

/**
 * No-op; base objects have no attributes.
 *
 * @param writer The writer.
 */
- (void) writeJAXBAttributes: (xmlTextWriterPtr) writer
{
  //no-op.
}

/**
 * No-op; base objects have no element value.
 *
 * @param writer The writer.
 */
- (void) writeJAXBValue: (xmlTextWriterPtr) writer
{
  //no-op.
}

/**
 * No-op; base objects have no child elements.
 *
 * @param writer The writer.
 */
- (void) writeJAXBChildElements: (xmlTextWriterPtr) writer
{
  //no-op.
}

@end /*NSObject (JAXB)*/

/**
 * Implementation of the JAXB type, element for an xml element.
 */
@implementation JAXBBasicXMLNode

/**
 * Accessor for the (local) name of the XML node.
 *
 * @return The (local) name of the XML node.
 */
- (NSString *) name
{
  return _name;
}

/**
 * Accessor for the (local) name of the XML node.
 *
 * @param newName The (local) name of the XML node.
 */
- (void) setName: (NSString *) newName
{
  [newName retain];
  [_name release];
  _name = newName;
}

/**
 * Accessor for the namespace of the XML node.
 *
 * @return The namespace of the XML node.
 */
- (NSString *) ns
{
  return _ns;
}

/**
 * Accessor for the namespace of the XML node.
 *
 * @param newNs The namespace of the XML node.
 */
- (void) setNs: (NSString *) newNs
{
  [newNs retain];
  [_ns release];
  _ns = newNs;
}

/**
 * Accessor for the namespace prefix of the XML node.
 *
 * @return The namespace prefix of the XML node.
 */
- (NSString *) prefix
{
  return _prefix;
}

/**
 * Accessor for the namespace prefix of the XML node.
 *
 * @param newPrefix The namespace prefix of the XML node.
 */
- (void) setPrefix: (NSString *) newPrefix
{
  [newPrefix retain];
  [_prefix release];
  _prefix = newPrefix;
}

/**
 * Accessor for the value of the XML node.
 *
 * @return The value of the XML node.
 */
- (NSString *) value
{
  return _value;
}

/**
 * Accessor for the value of the XML node.
 *
 * @param newValue The value of the XML node.
 */
- (void) setValue: (NSString *) newValue
{
  [newValue retain];
  [_value release];
  _value = newValue;
}

/**
 * Accessor for the child elements of the XML node.
 *
 * @return The child elements of the XML node.
 */
- (NSArray *) childElements
{
  return _childElements;
}

/**
 * Accessor for the child elements of the XML node.
 *
 * @param newValue The child elements of the XML node.
 */
- (void) setChildElements: (NSArray *) newChildElements
{
  [newChildElements retain];
  [_childElements release];
  _childElements = newChildElements;
}

/**
 * Accessor for the attributes of the XML node.
 *
 * @return The attributes of the XML node.
 */
- (NSArray *) attributes
{
  return _attributes;
}

/**
 * Accessor for the attributes of the XML node.
 *
 * @param newAttributes The attributes of the XML node.
 */
- (void) setAttributes: (NSArray *) newAttributes
{
  [newAttributes retain];
  [_attributes release];
  _attributes = newAttributes;
}

- (void) dealloc {
  [self setName: nil];
  [self setNs: nil];
  [self setPrefix: nil];
  [self setValue: nil];
  [self setChildElements: nil];
  [self setAttributes: nil];
  [super dealloc];
}
@end /*implementation JAXBBasicXMLNode*/

/**
 * Internal, private interface for JAXB reading and writing.
 */
@interface JAXBBasicXMLNode (JAXB) <JAXBType, JAXBElement>

@end /*interface JAXBBasicXMLNode (JAXB)*/

@implementation JAXBBasicXMLNode (JAXB)

/**
 * Read the XML type from the reader; an instance of JAXBBasicXMLNode.
 *
 * @param reader The reader.
 * @return An instance of JAXBBasicXMLNode
 */
+ (id<JAXBType>) readXMLType: (xmlTextReaderPtr) reader
{
  JAXBBasicXMLNode *node = [[JAXBBasicXMLNode alloc] init];
  NS_DURING
  {
    [node initWithReader: reader];
  }
  NS_HANDLER
  {
    [node dealloc];
    node = nil;
    [localException raise];
  }
  NS_ENDHANDLER

  [node autorelease];
  return node;
}

/**
 * Read an XML type from an XML reader into an existing instance of JAXBBasicXMLNode.
 *
 * @param reader The reader.
 * @param existing The existing instance into which to read values.
 */
- (id) initWithReader: (xmlTextReaderPtr) reader
{
  int status, depth;
  JAXBBasicXMLNode *child;
  xmlChar *value = NULL;
  const xmlChar *text;
  NSMutableArray *children;

  if ((self = [self init])) {
    depth = xmlTextReaderDepth(reader);
    [self setName: [NSString stringWithUTF8String: (const char *) xmlTextReaderLocalName(reader)]];
    [self setNs: [NSString stringWithUTF8String: (const char *) xmlTextReaderNamespaceUri(reader)]];
    [self setPrefix: [NSString stringWithUTF8String: (const char *)xmlTextReaderPrefix(reader)]];

    if (xmlTextReaderHasAttributes(reader)) {
      child = nil;
      children = [[NSMutableArray alloc] init];
      while (xmlTextReaderMoveToNextAttribute(reader)) {
        child = [[JAXBBasicXMLNode alloc] init];
        [child setName: [NSString stringWithUTF8String: (const char *) xmlTextReaderLocalName(reader)]];
        [child setNs: [NSString stringWithUTF8String: (const char *)xmlTextReaderNamespaceUri(reader)]];
        [child setPrefix: [NSString stringWithUTF8String: (const char *) xmlTextReaderPrefix(reader)]];
        [child setValue: [NSString stringWithUTF8String: (const char *) xmlTextReaderValue(reader)]];
        [children addObject: child];
      }
      [self setAttributes: children];

      status = xmlTextReaderMoveToElement(reader);
      if (status < 1) {
        //panic: unable to return to the element node.
        [NSException raise: @"XMLReadError"
                     format: @"Error moving to element from attributes."];
      }
    }

    if (xmlTextReaderIsEmptyElement(reader) == 0) {
      children = [[NSMutableArray alloc] init];
      status = xmlTextReaderRead(reader);
      while (status == 1 && xmlTextReaderDepth(reader) > depth) {
        switch (xmlTextReaderNodeType(reader)) {
          case XML_READER_TYPE_ELEMENT:
            child = (JAXBBasicXMLNode *) [JAXBBasicXMLNode readXMLType: reader];
            [children addObject: child];
            break;
          case XML_READER_TYPE_TEXT:
          case XML_READER_TYPE_CDATA:
            text = xmlTextReaderConstValue(reader);
            value = xmlStrncat(value, text, xmlStrlen(text));
            break;
          default:
            //skip anything else.
            break;
        }

        status = xmlTextReaderRead(reader);
      }

      if (status < 1) {
        //panic: xml read error
        [NSException raise: @"XMLReadError"
                     format: @"Error reading child elements."];
      }

      if ([children count] > 0) {
        [self setChildElements: children];
      }

      if (value != NULL) {
        [self setValue: [NSString stringWithUTF8String: (const char *) value]];
      }

    }
  }

  return self;
}

/**
 * Read the XML element from the reader; an instance of NSXMLElement.
 *
 * @param reader The reader.
 * @return An instance of NSXMLElement
 */
+ (id<JAXBElement>) readXMLElement: (xmlTextReaderPtr) reader
{
  return (id<JAXBElement>) [JAXBBasicXMLNode readXMLType: reader];
}

/**
 * Write the basic node to an xml writer.
 *
 * @param writer The writer.
 */
- (void) writeXMLType: (xmlTextWriterPtr) writer
{
  int status;
  NSEnumerator *enumerator;
  JAXBBasicXMLNode *child;
  xmlChar *childns, *childname, *childprefix, *childvalue;

  status = xmlTextWriterStartElementNS(writer, _prefix ? BAD_CAST [_prefix UTF8String] : NULL, _name ? BAD_CAST [_name UTF8String] : NULL, _ns ? BAD_CAST [_ns UTF8String] : NULL);
  if (status < 0) {
    childns = BAD_CAST "";
    if (_ns) {
      childns = BAD_CAST [_ns UTF8String];
    }

    childname = BAD_CAST "";
    if (_name) {
      childname = BAD_CAST [_name UTF8String];
    }

    [NSException raise: @"XMLWriteError"
                 format: @"Error writing start element {%s}%s for JAXBBasicXMLNode.", childns, childname];
  }

  if (_attributes) {
    enumerator = [_attributes objectEnumerator];
    while ( (child = (JAXBBasicXMLNode *)[enumerator nextObject]) ) {
      childns = NULL;
      if ([child ns]) {
        childns = BAD_CAST [[child ns] UTF8String];
      }

      childprefix = NULL;
      if ([child prefix]) {
        childprefix = BAD_CAST [[child prefix] UTF8String];
      }

      childname = NULL;
      if ([child name]) {
        childname = BAD_CAST [[child name] UTF8String];
      }

      childvalue = NULL;
      if ([child value]) {
        childvalue = BAD_CAST [[child value] UTF8String];
      }

      status = xmlTextWriterWriteAttributeNS(writer, childprefix, childname, childns, childvalue);
      if (status < 0) {
        [NSException raise: @"XMLWriteError"
                     format: @"Error writing attribute {%s}%s for JAXBBasicXMLNode.", childns, childname];
      }
    }
  }

  if (_value) {
    status = xmlTextWriterWriteString(writer, BAD_CAST [_value UTF8String]);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing value of JAXBBasicXMLNode."];
    }
  }

  if (_childElements) {
    enumerator = [_childElements objectEnumerator];
    while ( (child = [enumerator nextObject]) ) {
      [child writeXMLType: writer];
    }
  }

  status = xmlTextWriterEndElement(writer);
  if (status < 0) {
    childns = BAD_CAST "";
    if (_ns) {
      childns = BAD_CAST [_ns UTF8String];
    }

    childname = BAD_CAST "";
    if (_name) {
      childname = BAD_CAST [_name UTF8String];
    }

    [NSException raise: @"XMLWriteError"
                 format: @"Error writing end element {%s}%s for JAXBBasicXMLNode.", childns, childname];
  }
}

/**
 * Writes this node to a writer.
 *
 * @param writer The writer.
 */
- (void) writeXMLElement: (xmlTextWriterPtr) writer
{
  [self writeXMLType: writer];
}

/**
 * Writes this node to a writer.
 *
 * @param writer The writer.
 * @param writeNs Whether to write the namespaces for this element to the xml writer.
 */
- (void) writeXMLElement: (xmlTextWriterPtr) writer writeNamespaces: (BOOL) writeNs
{
  [self writeXMLType: writer];
}

@end /* implementation JAXBBasicXMLNode (JAXB) */

/**
 * Declaration of the JAXB type for a string.
 */
@interface NSString (JAXBType) <JAXBType>
@end

/**
 * Implementation of the JAXB type for a string.
 */
@implementation NSString (JAXBType)

/**
 * Read the XML type from the reader.
 *
 * @param reader The reader.
 * @return The NSString that was read from the reader.
 */
+ (id<JAXBType>) readXMLType: (xmlTextReaderPtr) reader
{
  return [NSString stringWithUTF8String: (const char *) xmlTextReaderReadEntireNodeValue(reader)];
}

/**
 * Read an XML type from an XML reader into an existing instance.
 *
 * @param reader The reader.
 * @param existing The existing instance into which to read values.
 */
- (id) initWithReader: (xmlTextReaderPtr) reader
{
  [NSException raise: @"XMLReadError"
               format: @"An existing string cannot be modified."];
  return nil;
}

/**
 * Write the NSString to the writer.
 *
 * @param writer The writer.
 */
- (void) writeXMLType: (xmlTextWriterPtr) writer
{
  xmlTextWriterWriteString(writer, BAD_CAST [self UTF8String]);
}

@end /*NSString (JAXBType)*/



/**
 * Declaration of the JAXB type for a big number.
 */
@interface NSNumber (JAXBType) <JAXBType>
@end

/**
 * Implementation of the JAXB type for a big number.
 */
@implementation NSNumber (JAXBType)

/**
 * Read the XML type from the reader.
 *
 * @param reader The reader.
 * @return The NSNumber that was read from the reader.
 */
+ (id<JAXBType>) readXMLType: (xmlTextReaderPtr) reader
{
  return [NSNumber numberWithLongLong: [[NSString stringWithUTF8String: (const char *) xmlTextReaderReadEntireNodeValue(reader)] longLongValue]];
}

/**
 * Read an XML type from an XML reader into an existing instance.
 *
 * @param reader The reader.
 * @param existing The existing instance into which to read values.
 */
- (id) initWithReader: (xmlTextReaderPtr) reader
{
  [NSException raise: @"XMLReadError"
               format: @"An existing number cannot be modified."];
  return nil;
}

/**
 * Write the NSNumber to the writer.
 *
 * @param writer The writer.
 */
- (void) writeXMLType: (xmlTextWriterPtr) writer
{
  xmlTextWriterWriteString(writer, BAD_CAST [[self description] UTF8String]);
}

@end /*NSNumber (JAXBType)*/



/**
 * Declaration of the JAXB type for a big number.
 */
@interface NSDecimalNumber (JAXBType) <JAXBType>
@end

/**
 * Implementation of the JAXB type for a big number.
 */
@implementation NSDecimalNumber (JAXBType)

/**
 * Read the XML type from the reader.
 *
 * @param reader The reader.
 * @return The NSDecimalNumber that was read from the reader.
 */
+ (id<JAXBType>) readXMLType: (xmlTextReaderPtr) reader
{
  return [NSDecimalNumber decimalNumberWithString: [NSString stringWithUTF8String: (const char *) xmlTextReaderReadEntireNodeValue(reader)]];
}

/**
 * Read an XML type from an XML reader into an existing instance.
 *
 * @param reader The reader.
 * @param existing The existing instance into which to read values.
 */
- (id) initWithReader: (xmlTextReaderPtr) reader
{
  [NSException raise: @"XMLReadError"
               format: @"An existing decimal number cannot be modified."];
  return nil;
}

/**
 * Write the NSDecimalNumber to the writer.
 *
 * @param writer The writer.
 */
- (void) writeXMLType: (xmlTextWriterPtr) writer
{
  xmlTextWriterWriteString(writer, BAD_CAST [[self description] UTF8String]);
}

@end /*NSDecimalNumber (JAXBType)*/



/**
 * Declaration of the JAXB type for a url.
 */
@interface NSURL (JAXBType) <JAXBType>
@end

/**
 * Implementation of the JAXB type for a url.
 */
@implementation NSURL (JAXBType)

/**
 * Read the XML type from the reader.
 *
 * @param reader The reader.
 * @return The NSURL that was read from the reader.
 */
+ (id<JAXBType>) readXMLType: (xmlTextReaderPtr) reader
{
  return [NSURL URLWithString: [NSString stringWithUTF8String: (const char *) xmlTextReaderReadEntireNodeValue(reader)]];
}

/**
 * Read an XML type from an XML reader into an existing instance.
 *
 * @param reader The reader.
 * @param existing The existing instance into which to read values.
 */
- (id) initWithReader: (xmlTextReaderPtr) reader
{
  [NSException raise: @"XMLReadError"
               format: @"An existing url cannot be modified."];
  return nil;
}

/**
 * Write the NSURL to the writer.
 *
 * @param writer The writer.
 */
- (void) writeXMLType: (xmlTextWriterPtr) writer
{
  xmlTextWriterWriteString(writer, BAD_CAST [[self absoluteString] UTF8String]);
}

@end /*NSURL (JAXBType)*/



/**
 * Declaration of the JAXB type for binary data.
 */
@interface NSData (JAXBType) <JAXBType>
@end

/**
 * Implementation of the JAXB type for a binary data.
 */
@implementation NSData (JAXBType)

/**
 * Read the XML type from the reader.
 *
 * @param reader The reader.
 * @return The NSData that was read from the reader.
 */
+ (id<JAXBType>) readXMLType: (xmlTextReaderPtr) reader
{
  xmlChar *base64data = xmlTextReaderReadEntireNodeValue(reader);
  int len;
  unsigned char *data = _decode_base64(base64data, &len);
  NSData *wrappedData = [NSData dataWithBytesNoCopy: data length: len];
  free(base64data);
  return wrappedData;
}

/**
 * Read an XML type from an XML reader into an existing instance.
 *
 * @param reader The reader.
 * @param existing The existing instance into which to read values.
 */
- (id) initWithReader: (xmlTextReaderPtr) reader
{
  [NSException raise: @"XMLReadError"
               format: @"An existing NSData cannot be modified."];
  return nil;
}

/**
 * Write the NSData to the writer.
 *
 * @param writer The writer.
 */
- (void) writeXMLType: (xmlTextWriterPtr) writer
{
  xmlChar *out = _encode_base64((unsigned char *)[self bytes], [self length]);
  xmlTextWriterWriteString(writer, out);
  free(out);
}

@end /*NSData (JAXBType)*/



/**
 * Declaration of the JAXB type for a big number.
 */
@interface NSDate (JAXBType) <JAXBType>
@end

/**
 * Implementation of the JAXB type for a big number.
 */
@implementation NSDate (JAXBType)

/**
 * Read the XML type from the reader.
 *
 * @param reader The reader.
 * @return The NSDate that was read from the reader.
 */
+ (id<JAXBType>) readXMLType: (xmlTextReaderPtr) reader
{
  xmlChar *timevalue = xmlTextReaderReadEntireNodeValue(reader);
  NSInteger year = 0;
  NSUInteger month = 1, day = 1, hour = 0, minute = 0, second = 0;
  BOOL skip_time = NO;
  int index = 0, token_index = 0, len = xmlStrlen(timevalue), offset_hour = 0, offset_minute = 0;
  char token[len];

  if (len > (index + 5) && timevalue[index + 4] == '-') {
    //assume we're at yyyy-MM-dd
    token_index = 0;
    while (index < len && timevalue[index] != '-') {
      token[token_index++] = timevalue[index++];
    }
    token[token_index] = '\0';
    if (token_index != 4) {
      [NSException raise: @"XMLReadError"
                   format: @"Unable to read dateTime %s; invalid year: %s", timevalue, token];
    }
    year = atoi(token);
    index++;

    //go to next '-' character.
    token_index = 0;
    while (index < len && timevalue[index] != '-') {
      token[token_index++] = timevalue[index++];
    }
    token[token_index] = '\0';
    if (token_index != 2) {
      [NSException raise: @"XMLReadError"
                   format: @"Unable to read dateTime %s; invalid month: %s", timevalue, token];
    }
    month = atoi(token);
    index++;

    //go to 'T', 'Z', '+', or '-' character.
    token_index = 0;
    while (index < len && timevalue[index] != 'T' && timevalue[index] != 'Z' && timevalue[index] != '-' && timevalue[index] != '+') {
      token[token_index++] = timevalue[index++];
    }
    token[token_index] = '\0';
    if (token_index != 2) {
      [NSException raise: @"XMLReadError"
                   format: @"Unable to read dateTime %s; invalid day of month: %s", timevalue, token];
    }
    day = atoi(token);
    if (timevalue[index] != 'T') {
      skip_time = YES;
    }
    if (timevalue[index] != '-') {
      index++;
    }
  }

  if (skip_time == NO || (len > (index + 3) && timevalue[index + 2] == ':')) {
    //assume we're at HH:mm:ss

    //go to ':' character.
    token_index = 0;
    while (index < len && timevalue[index] != ':') {
      token[token_index++] = timevalue[index++];
    }
    token[token_index] = '\0';
    if (token_index != 2) {
      [NSException raise: @"XMLReadError"
                   format: @"Unable to read dateTime %s; invalid hour: %s", timevalue, token];
    }
    hour = atoi(token);
    index++;

    //go to ':' character.
    token_index = 0;
    while (index < len && timevalue[index] != ':') {
      token[token_index++] = timevalue[index++];
    }
    token[token_index] = '\0';
    if (token_index != 2) {
      [NSException raise: @"XMLReadError"
                   format: @"Unable to read dateTime %s; invalid minute: %s", timevalue, token];
    }
    minute = atoi(token);
    index++;

    //go to '+' or '-' or 'Z' character.
    token_index = 0;
    while (index < len && timevalue[index] != '+' && timevalue[index] != '-' && timevalue[index] != 'Z') {
      token[token_index++] = timevalue[index++];
    }
    token[token_index] = '\0';
    if (token_index == 0) {
      [NSException raise: @"XMLReadError"
                   format: @"Unable to read dateTime %s; invalid seconds: %s", timevalue, token];
    }
    second = (NSUInteger) atof(token);
    if (timevalue[index] != '-') {
      index++;
    }
  }

  //go to ':' character.
  token_index = 0;
  while (index < len && timevalue[index] != ':') {
    token[token_index++] = timevalue[index++];
  }
  token[token_index] = '\0';
  offset_hour += atoi(token);
  index++;

  //go to end.
  token_index = 0;
  while (index < len) {
    token[token_index++] = timevalue[index++];
  }
  token[token_index] = '\0';
  offset_minute += atoi(token);

  //YYYY-MM-DD HH:MM:SS -HHHMM
  free(timevalue);
  return [NSDate dateWithString: [NSString stringWithFormat: @"%04i-%02i-%02i %02i:%02i:%02i %+03i%02i", year, month, day, hour, minute, second, offset_hour, offset_minute]];
}

/**
 * Read an XML type from an XML reader into an existing instance.
 *
 * @param reader The reader.
 * @param existing The existing instance into which to read values.
 */
- (id) initWithReader: (xmlTextReaderPtr) reader
{
  [NSException raise: @"XMLReadError"
               format: @"An existing date cannot be modified."];
  return nil;
}

/**
 * Write the NSDate to the writer.
 *
 * @param writer The writer.
 */
- (void) writeXMLType: (xmlTextWriterPtr) writer
{
  NSDateFormatter *formatter = [[NSDateFormatter alloc] initWithDateFormat: @"%Y-%m-%dT%H:%M:%S %z" allowNaturalLanguage: NO];
  xmlChar *timevalue = BAD_CAST [[formatter stringForObjectValue: self] UTF8String];
  timevalue[19] = timevalue[20];
  timevalue[20] = timevalue[21];
  timevalue[21] = timevalue[22];
  timevalue[22] = ':';
  xmlTextWriterWriteString(writer, timevalue);
  [formatter release];
}
@end /*NSDate (JAXBType)*/

#endif /* ENUNCIATE_OBJC_CLASSES */

#ifndef ENUNCIATE_XML_OBJC_PRIMITIVE_FUNCTIONS
#define ENUNCIATE_XML_OBJC_PRIMITIVE_FUNCTIONS

/*******************boolean************************************/

/**
 * Read a boolean value from the reader.
 *
 * @param reader The reader (pointing at a node with a value).
 * @return YES if "true" was read. NO otherwise.
 */
static BOOL *xmlTextReaderReadBooleanType(xmlTextReaderPtr reader) {
  xmlChar *nodeValue = xmlTextReaderReadEntireNodeValue(reader);
  BOOL *value = malloc(sizeof(BOOL));
  *value = (xmlStrcmp(BAD_CAST "true", nodeValue) == 0) ? YES : NO;
  free(nodeValue);
  return value;
}

/**
 * Write a boolean value to the writer.
 *
 * @param writer The writer.
 * @param value The value to be written.
 * @return the bytes written (may be 0 because of buffering) or -1 in case of error.
 */
static int xmlTextWriterWriteBooleanType(xmlTextWriterPtr writer, BOOL *value) {
  if (*value) {
    return xmlTextWriterWriteString(writer, BAD_CAST "false");
  }
  else {
    return xmlTextWriterWriteString(writer, BAD_CAST "true");
  }
}

/*******************byte************************************/

/**
 * Read a byte value from the reader.
 *
 * @param reader The reader (pointing at a node with a value).
 * @return the byte.
 */
static unsigned char *xmlTextReaderReadByteType(xmlTextReaderPtr reader) {
  xmlChar *nodeValue = xmlTextReaderReadEntireNodeValue(reader);
  unsigned char *value = malloc(sizeof(unsigned char));
  *value = (unsigned char) atoi((char *) nodeValue);
  free(nodeValue);
  return value;
}

/**
 * Write a byte value to the writer.
 *
 * @param writer The writer.
 * @param value The value to be written.
 * @return the bytes written (may be 0 because of buffering) or -1 in case of error.
 */
static int xmlTextWriterWriteByteType(xmlTextWriterPtr writer, unsigned char *value) {
  return xmlTextWriterWriteFormatString(writer, "%i", *value);
}

/*******************double************************************/

/**
 * Read a double value from the reader.
 *
 * @param reader The reader (pointing at a node with a value).
 * @return the double.
 */
static double *xmlTextReaderReadDoubleType(xmlTextReaderPtr reader) {
  xmlChar *nodeValue = xmlTextReaderReadEntireNodeValue(reader);
  double *value = malloc(sizeof(double));
  *value = atof((char *) nodeValue);
  free(nodeValue);
  return value;
}

/**
 * Write a double value to the writer.
 *
 * @param writer The writer.
 * @param value The value to be written.
 * @return the bytes written (may be 0 because of buffering) or -1 in case of error.
 */
static int xmlTextWriterWriteDoubleType(xmlTextWriterPtr writer, double *value) {
  return xmlTextWriterWriteFormatString(writer, "%f", *value);
}

/*******************float************************************/

/**
 * Read a float value from the reader.
 *
 * @param reader The reader (pointing at a node with a value).
 * @return the float.
 */
static float *xmlTextReaderReadFloatType(xmlTextReaderPtr reader) {
  xmlChar *nodeValue = xmlTextReaderReadEntireNodeValue(reader);
  float *value = malloc(sizeof(float));
  *value = atof((char *)nodeValue);
  free(nodeValue);
  return value;
}

/**
 * Write a float value to the writer.
 *
 * @param writer The writer.
 * @param value The value to be written.
 * @return the bytes written (may be 0 because of buffering) or -1 in case of error.
 */
static int xmlTextWriterWriteFloatType(xmlTextWriterPtr writer, float *value) {
  return xmlTextWriterWriteFormatString(writer, "%f", *value);
}

/*******************int************************************/

/**
 * Read a int value from the reader.
 *
 * @param reader The reader (pointing at a node with a value).
 * @param value The value to be written.
 * @return the int.
 */
static int *xmlTextReaderReadIntType(xmlTextReaderPtr reader) {
  xmlChar *nodeValue = xmlTextReaderReadEntireNodeValue(reader);
  int *value = malloc(sizeof(int));
  *value = atoi((char *)nodeValue);
  free(nodeValue);
  return value;
}

/**
 * Write a int value to the writer.
 *
 * @param writer The writer.
 * @param value The value to be written.
 * @return the bytes written (may be 0 because of buffering) or -1 in case of error.
 */
static int xmlTextWriterWriteIntType(xmlTextWriterPtr writer, int *value) {
  return xmlTextWriterWriteFormatString(writer, "%i", *value);
}

/*******************long************************************/

/**
 * Read a long value from the reader.
 *
 * @param reader The reader (pointing at a node with a value).
 * @return the long.
 */
static long *xmlTextReaderReadLongType(xmlTextReaderPtr reader) {
  xmlChar *nodeValue = xmlTextReaderReadEntireNodeValue(reader);
  long *value = malloc(sizeof(long));
  *value = atol((char *)nodeValue);
  free(nodeValue);
  return value;
}

/**
 * Write a long value to the writer.
 *
 * @param writer The writer.
 * @param value The value to be written.
 * @return the bytes written (may be 0 because of buffering) or -1 in case of error.
 */
static int xmlTextWriterWriteLongType(xmlTextWriterPtr writer, long *value) {
  return xmlTextWriterWriteFormatString(writer, "%ld", *value);
}

/*******************short************************************/

/**
 * Read a short value from the reader.
 *
 * @param reader The reader (pointing at a node with a value).
 * @return the short.
 */
static short *xmlTextReaderReadShortType(xmlTextReaderPtr reader) {
  xmlChar *nodeValue = xmlTextReaderReadEntireNodeValue(reader);
  short *value = malloc(sizeof(short));
  *value = atoi((char *)nodeValue);
  free(nodeValue);
  return value;
}

/**
 * Write a short value to the writer.
 *
 * @param writer The writer.
 * @param value The value to be written.
 * @return the bytes written (may be 0 because of buffering) or -1 in case of error.
 */
static int xmlTextWriterWriteShortType(xmlTextWriterPtr writer, short *value) {
  return xmlTextWriterWriteFormatString(writer, "%hi", *value);
}

/*******************char************************************/

/**
 * Read a character value from the reader.
 *
 * @param reader The reader (pointing at a node with a value).
 * @return the character.
 */
static xmlChar *xmlTextReaderReadCharacterType(xmlTextReaderPtr reader) {
  return xmlTextReaderReadEntireNodeValue(reader);
}

/**
 * Write a character value to the writer.
 *
 * @param writer The writer.
 * @param value The value to be written.
 * @return the bytes written (may be 0 because of buffering) or -1 in case of error.
 */
static int xmlTextWriterWriteCharacterType(xmlTextWriterPtr writer, xmlChar *value) {
  return xmlTextWriterWriteString(writer, value);
}

#endif /* ENUNCIATE_XML_OBJC_PRIMITIVE_FUNCTIONS */

#ifndef DEF_NEXUS_REST_APINS0AuthenticationSettings_M
#define DEF_NEXUS_REST_APINS0AuthenticationSettings_M

/**
 *  Remote authentication tokens used in remote authentications
 against HTTP Proxies and/or protected remote repositories.
 
 @version $Revision$ $Date$

 */
@implementation NEXUS_REST_APINS0AuthenticationSettings

/**
 * A username to be used in authentication.
 */
- (NSString *) username
{
  return _username;
}

/**
 * A username to be used in authentication.
 */
- (void) setUsername: (NSString *) newUsername
{
  [newUsername retain];
  [_username release];
  _username = newUsername;
}

/**
 * A password to be used in authentication.
 */
- (NSString *) password
{
  return _password;
}

/**
 * A password to be used in authentication.
 */
- (void) setPassword: (NSString *) newPassword
{
  [newPassword retain];
  [_password release];
  _password = newPassword;
}

/**
 * The Windows NT Lan Manager to use for authentication.
 */
- (NSString *) ntlmHost
{
  return _ntlmHost;
}

/**
 * The Windows NT Lan Manager to use for authentication.
 */
- (void) setNtlmHost: (NSString *) newNtlmHost
{
  [newNtlmHost retain];
  [_ntlmHost release];
  _ntlmHost = newNtlmHost;
}

/**
 * The Windows NT Lan Manager Domain to use for authentication.
 */
- (NSString *) ntlmDomain
{
  return _ntlmDomain;
}

/**
 * The Windows NT Lan Manager Domain to use for authentication.
 */
- (void) setNtlmDomain: (NSString *) newNtlmDomain
{
  [newNtlmDomain retain];
  [_ntlmDomain release];
  _ntlmDomain = newNtlmDomain;
}

- (void) dealloc
{
  [self setUsername: nil];
  [self setPassword: nil];
  [self setNtlmHost: nil];
  [self setNtlmDomain: nil];
  [super dealloc];
}
@end /* implementation NEXUS_REST_APINS0AuthenticationSettings */

/**
 * Internal, private interface for JAXB reading and writing.
 */
@interface NEXUS_REST_APINS0AuthenticationSettings (JAXB) <JAXBReading, JAXBWriting, JAXBType>

@end /*interface NEXUS_REST_APINS0AuthenticationSettings (JAXB)*/

/**
 * Internal, private implementation for JAXB reading and writing.
 */
@implementation NEXUS_REST_APINS0AuthenticationSettings (JAXB)

/**
 * Read an instance of NEXUS_REST_APINS0AuthenticationSettings from an XML reader.
 *
 * @param reader The reader.
 * @return An instance of NEXUS_REST_APINS0AuthenticationSettings defined by the XML reader.
 */
+ (id<JAXBType>) readXMLType: (xmlTextReaderPtr) reader
{
  NEXUS_REST_APINS0AuthenticationSettings *_nEXUS_REST_APINS0AuthenticationSettings = [[NEXUS_REST_APINS0AuthenticationSettings alloc] init];
  NS_DURING
  {
    [_nEXUS_REST_APINS0AuthenticationSettings initWithReader: reader];
  }
  NS_HANDLER
  {
    [_nEXUS_REST_APINS0AuthenticationSettings dealloc];
    _nEXUS_REST_APINS0AuthenticationSettings = nil;
    [localException raise];
  }
  NS_ENDHANDLER

  [_nEXUS_REST_APINS0AuthenticationSettings autorelease];
  return _nEXUS_REST_APINS0AuthenticationSettings;
}

/**
 * Initialize this instance of NEXUS_REST_APINS0AuthenticationSettings according to
 * the XML being read from the reader.
 *
 * @param reader The reader.
 */
- (id) initWithReader: (xmlTextReaderPtr) reader
{
  return [super initWithReader: reader];
}

/**
 * Write the XML for this instance of NEXUS_REST_APINS0AuthenticationSettings to the writer.
 * Note that since we're only writing the XML type,
 * No start/end element will be written.
 *
 * @param reader The reader.
 */
- (void) writeXMLType: (xmlTextWriterPtr) writer
{
  [super writeXMLType:writer];
}

//documentation inherited.
- (BOOL) readJAXBAttribute: (xmlTextReaderPtr) reader
{
  void *_child_accessor;

  if ([super readJAXBAttribute: reader]) {
    return YES;
  }

  return NO;
}

//documentation inherited.
- (BOOL) readJAXBValue: (xmlTextReaderPtr) reader
{
  return [super readJAXBValue: reader];
}

//documentation inherited.
- (BOOL) readJAXBChildElement: (xmlTextReaderPtr) reader
{
  id __child;
  void *_child_accessor;
  int status, depth;

  if ([super readJAXBChildElement: reader]) {
    return YES;
  }
  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "username", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}username of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}username of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setUsername: __child];
    return YES;
  } //end "if choice"

  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "password", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}password of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}password of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setPassword: __child];
    return YES;
  } //end "if choice"

  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "ntlmHost", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}ntlmHost of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}ntlmHost of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setNtlmHost: __child];
    return YES;
  } //end "if choice"

  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "ntlmDomain", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}ntlmDomain of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}ntlmDomain of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setNtlmDomain: __child];
    return YES;
  } //end "if choice"


  return NO;
}

//documentation inherited.
- (int) readUnknownJAXBChildElement: (xmlTextReaderPtr) reader
{
  return [super readUnknownJAXBChildElement: reader];
}

//documentation inherited.
- (void) readUnknownJAXBAttribute: (xmlTextReaderPtr) reader
{
  [super readUnknownJAXBAttribute: reader];
}

//documentation inherited.
- (void) writeJAXBAttributes: (xmlTextWriterPtr) writer
{
  int status;

  [super writeJAXBAttributes: writer];

}

//documentation inherited.
- (void) writeJAXBValue: (xmlTextWriterPtr) writer
{
  [super writeJAXBValue: writer];
}

/**
 * Method for writing the child elements.
 *
 * @param writer The writer.
 */
- (void) writeJAXBChildElements: (xmlTextWriterPtr) writer
{
  int status;
  id __item;
  NSEnumerator *__enumerator;

  [super writeJAXBChildElements: writer];

  if ([self username]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "username", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}username."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}username...");
#endif
    [[self username] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}username...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}username."];
    }
  }
  if ([self password]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "password", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}password."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}password...");
#endif
    [[self password] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}password...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}password."];
    }
  }
  if ([self ntlmHost]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "ntlmHost", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}ntlmHost."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}ntlmHost...");
#endif
    [[self ntlmHost] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}ntlmHost...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}ntlmHost."];
    }
  }
  if ([self ntlmDomain]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "ntlmDomain", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}ntlmDomain."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}ntlmDomain...");
#endif
    [[self ntlmDomain] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}ntlmDomain...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}ntlmDomain."];
    }
  }
}
@end /* implementation NEXUS_REST_APINS0AuthenticationSettings (JAXB) */

#endif /* DEF_NEXUS_REST_APINS0AuthenticationSettings_M */
#ifndef DEF_NEXUS_REST_APINS0ConfigurationsListResource_M
#define DEF_NEXUS_REST_APINS0ConfigurationsListResource_M

/**
 *  A Nexus configuration item, and the url needed to retrieve the
 configuration details.
 
 @version $Revision$ $Date$

 */
@implementation NEXUS_REST_APINS0ConfigurationsListResource

/**
 * The url that can be accessed to retrieve details about the
configuration.
 */
- (NSString *) resourceURI
{
  return _resourceURI;
}

/**
 * The url that can be accessed to retrieve details about the
configuration.
 */
- (void) setResourceURI: (NSString *) newResourceURI
{
  [newResourceURI retain];
  [_resourceURI release];
  _resourceURI = newResourceURI;
}

/**
 * The name of the configuration item.
 */
- (NSString *) name
{
  return _name;
}

/**
 * The name of the configuration item.
 */
- (void) setName: (NSString *) newName
{
  [newName retain];
  [_name release];
  _name = newName;
}

- (void) dealloc
{
  [self setResourceURI: nil];
  [self setName: nil];
  [super dealloc];
}
@end /* implementation NEXUS_REST_APINS0ConfigurationsListResource */

/**
 * Internal, private interface for JAXB reading and writing.
 */
@interface NEXUS_REST_APINS0ConfigurationsListResource (JAXB) <JAXBReading, JAXBWriting, JAXBType>

@end /*interface NEXUS_REST_APINS0ConfigurationsListResource (JAXB)*/

/**
 * Internal, private implementation for JAXB reading and writing.
 */
@implementation NEXUS_REST_APINS0ConfigurationsListResource (JAXB)

/**
 * Read an instance of NEXUS_REST_APINS0ConfigurationsListResource from an XML reader.
 *
 * @param reader The reader.
 * @return An instance of NEXUS_REST_APINS0ConfigurationsListResource defined by the XML reader.
 */
+ (id<JAXBType>) readXMLType: (xmlTextReaderPtr) reader
{
  NEXUS_REST_APINS0ConfigurationsListResource *_nEXUS_REST_APINS0ConfigurationsListResource = [[NEXUS_REST_APINS0ConfigurationsListResource alloc] init];
  NS_DURING
  {
    [_nEXUS_REST_APINS0ConfigurationsListResource initWithReader: reader];
  }
  NS_HANDLER
  {
    [_nEXUS_REST_APINS0ConfigurationsListResource dealloc];
    _nEXUS_REST_APINS0ConfigurationsListResource = nil;
    [localException raise];
  }
  NS_ENDHANDLER

  [_nEXUS_REST_APINS0ConfigurationsListResource autorelease];
  return _nEXUS_REST_APINS0ConfigurationsListResource;
}

/**
 * Initialize this instance of NEXUS_REST_APINS0ConfigurationsListResource according to
 * the XML being read from the reader.
 *
 * @param reader The reader.
 */
- (id) initWithReader: (xmlTextReaderPtr) reader
{
  return [super initWithReader: reader];
}

/**
 * Write the XML for this instance of NEXUS_REST_APINS0ConfigurationsListResource to the writer.
 * Note that since we're only writing the XML type,
 * No start/end element will be written.
 *
 * @param reader The reader.
 */
- (void) writeXMLType: (xmlTextWriterPtr) writer
{
  [super writeXMLType:writer];
}

//documentation inherited.
- (BOOL) readJAXBAttribute: (xmlTextReaderPtr) reader
{
  void *_child_accessor;

  if ([super readJAXBAttribute: reader]) {
    return YES;
  }

  return NO;
}

//documentation inherited.
- (BOOL) readJAXBValue: (xmlTextReaderPtr) reader
{
  return [super readJAXBValue: reader];
}

//documentation inherited.
- (BOOL) readJAXBChildElement: (xmlTextReaderPtr) reader
{
  id __child;
  void *_child_accessor;
  int status, depth;

  if ([super readJAXBChildElement: reader]) {
    return YES;
  }
  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "resourceURI", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}resourceURI of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}resourceURI of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setResourceURI: __child];
    return YES;
  } //end "if choice"

  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "name", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}name of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}name of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setName: __child];
    return YES;
  } //end "if choice"


  return NO;
}

//documentation inherited.
- (int) readUnknownJAXBChildElement: (xmlTextReaderPtr) reader
{
  return [super readUnknownJAXBChildElement: reader];
}

//documentation inherited.
- (void) readUnknownJAXBAttribute: (xmlTextReaderPtr) reader
{
  [super readUnknownJAXBAttribute: reader];
}

//documentation inherited.
- (void) writeJAXBAttributes: (xmlTextWriterPtr) writer
{
  int status;

  [super writeJAXBAttributes: writer];

}

//documentation inherited.
- (void) writeJAXBValue: (xmlTextWriterPtr) writer
{
  [super writeJAXBValue: writer];
}

/**
 * Method for writing the child elements.
 *
 * @param writer The writer.
 */
- (void) writeJAXBChildElements: (xmlTextWriterPtr) writer
{
  int status;
  id __item;
  NSEnumerator *__enumerator;

  [super writeJAXBChildElements: writer];

  if ([self resourceURI]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "resourceURI", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}resourceURI."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}resourceURI...");
#endif
    [[self resourceURI] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}resourceURI...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}resourceURI."];
    }
  }
  if ([self name]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "name", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}name."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}name...");
#endif
    [[self name] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}name...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}name."];
    }
  }
}
@end /* implementation NEXUS_REST_APINS0ConfigurationsListResource (JAXB) */

#endif /* DEF_NEXUS_REST_APINS0ConfigurationsListResource_M */
#ifndef DEF_NEXUS_REST_APINS0ContentListDescribeResource_M
#define DEF_NEXUS_REST_APINS0ContentListDescribeResource_M

/**
 *  Details about the requested item, that should be useful in
 finding how the item was retrieved.
 
 @version $Revision$ $Date$

 */
@implementation NEXUS_REST_APINS0ContentListDescribeResource

/**
 * The original request url used to access the resource.
 */
- (NSString *) requestUrl
{
  return _requestUrl;
}

/**
 * The original request url used to access the resource.
 */
- (void) setRequestUrl: (NSString *) newRequestUrl
{
  [newRequestUrl retain];
  [_requestUrl release];
  _requestUrl = newRequestUrl;
}

/**
 * The number of milliseconds that passed while retrieving the
item.
 */
- (long) processingTimeMillis
{
  return _processingTimeMillis;
}

/**
 * The number of milliseconds that passed while retrieving the
item.
 */
- (void) setProcessingTimeMillis: (long) newProcessingTimeMillis
{
  _processingTimeMillis = newProcessingTimeMillis;
}

/**
 * A set of request parameters for the item.
 */
- (NEXUS_REST_APINS0ContentListDescribeRequestResource *) request
{
  return _request;
}

/**
 * A set of request parameters for the item.
 */
- (void) setRequest: (NEXUS_REST_APINS0ContentListDescribeRequestResource *) newRequest
{
  [newRequest retain];
  [_request release];
  _request = newRequest;
}

/**
 * A set of response parameters for the item.
 */
- (NEXUS_REST_APINS0ContentListDescribeResponseResource *) response
{
  return _response;
}

/**
 * A set of response parameters for the item.
 */
- (void) setResponse: (NEXUS_REST_APINS0ContentListDescribeResponseResource *) newResponse
{
  [newResponse retain];
  [_response release];
  _response = newResponse;
}

- (void) dealloc
{
  [self setRequestUrl: nil];
  [self setRequest: nil];
  [self setResponse: nil];
  [super dealloc];
}
@end /* implementation NEXUS_REST_APINS0ContentListDescribeResource */

/**
 * Internal, private interface for JAXB reading and writing.
 */
@interface NEXUS_REST_APINS0ContentListDescribeResource (JAXB) <JAXBReading, JAXBWriting, JAXBType>

@end /*interface NEXUS_REST_APINS0ContentListDescribeResource (JAXB)*/

/**
 * Internal, private implementation for JAXB reading and writing.
 */
@implementation NEXUS_REST_APINS0ContentListDescribeResource (JAXB)

/**
 * Read an instance of NEXUS_REST_APINS0ContentListDescribeResource from an XML reader.
 *
 * @param reader The reader.
 * @return An instance of NEXUS_REST_APINS0ContentListDescribeResource defined by the XML reader.
 */
+ (id<JAXBType>) readXMLType: (xmlTextReaderPtr) reader
{
  NEXUS_REST_APINS0ContentListDescribeResource *_nEXUS_REST_APINS0ContentListDescribeResource = [[NEXUS_REST_APINS0ContentListDescribeResource alloc] init];
  NS_DURING
  {
    [_nEXUS_REST_APINS0ContentListDescribeResource initWithReader: reader];
  }
  NS_HANDLER
  {
    [_nEXUS_REST_APINS0ContentListDescribeResource dealloc];
    _nEXUS_REST_APINS0ContentListDescribeResource = nil;
    [localException raise];
  }
  NS_ENDHANDLER

  [_nEXUS_REST_APINS0ContentListDescribeResource autorelease];
  return _nEXUS_REST_APINS0ContentListDescribeResource;
}

/**
 * Initialize this instance of NEXUS_REST_APINS0ContentListDescribeResource according to
 * the XML being read from the reader.
 *
 * @param reader The reader.
 */
- (id) initWithReader: (xmlTextReaderPtr) reader
{
  return [super initWithReader: reader];
}

/**
 * Write the XML for this instance of NEXUS_REST_APINS0ContentListDescribeResource to the writer.
 * Note that since we're only writing the XML type,
 * No start/end element will be written.
 *
 * @param reader The reader.
 */
- (void) writeXMLType: (xmlTextWriterPtr) writer
{
  [super writeXMLType:writer];
}

//documentation inherited.
- (BOOL) readJAXBAttribute: (xmlTextReaderPtr) reader
{
  void *_child_accessor;

  if ([super readJAXBAttribute: reader]) {
    return YES;
  }

  return NO;
}

//documentation inherited.
- (BOOL) readJAXBValue: (xmlTextReaderPtr) reader
{
  return [super readJAXBValue: reader];
}

//documentation inherited.
- (BOOL) readJAXBChildElement: (xmlTextReaderPtr) reader
{
  id __child;
  void *_child_accessor;
  int status, depth;

  if ([super readJAXBChildElement: reader]) {
    return YES;
  }
  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "requestUrl", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}requestUrl of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}requestUrl of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setRequestUrl: __child];
    return YES;
  } //end "if choice"


  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "processingTimeMillis", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

    _child_accessor = xmlTextReaderReadLongType(reader);
    if (_child_accessor == NULL) {
      //panic: unable to return the value for some reason.
      [self dealloc];
      [NSException raise: @"XMLReadError"
                   format: @"Error reading element value."];
    }
    [self setProcessingTimeMillis: *((long*) _child_accessor)];
    free(_child_accessor);
    return YES;
  }
  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "request", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}request of type {}content-list-describe-request-resource.");
#endif
    __child = [NEXUS_REST_APINS0ContentListDescribeRequestResource readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}request of type {}content-list-describe-request-resource.");
#endif

    [self setRequest: __child];
    return YES;
  } //end "if choice"

  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "response", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}response of type {}content-list-describe-response-resource.");
#endif
    __child = [NEXUS_REST_APINS0ContentListDescribeResponseResource readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}response of type {}content-list-describe-response-resource.");
#endif

    [self setResponse: __child];
    return YES;
  } //end "if choice"


  return NO;
}

//documentation inherited.
- (int) readUnknownJAXBChildElement: (xmlTextReaderPtr) reader
{
  return [super readUnknownJAXBChildElement: reader];
}

//documentation inherited.
- (void) readUnknownJAXBAttribute: (xmlTextReaderPtr) reader
{
  [super readUnknownJAXBAttribute: reader];
}

//documentation inherited.
- (void) writeJAXBAttributes: (xmlTextWriterPtr) writer
{
  int status;

  [super writeJAXBAttributes: writer];

}

//documentation inherited.
- (void) writeJAXBValue: (xmlTextWriterPtr) writer
{
  [super writeJAXBValue: writer];
}

/**
 * Method for writing the child elements.
 *
 * @param writer The writer.
 */
- (void) writeJAXBChildElements: (xmlTextWriterPtr) writer
{
  int status;
  id __item;
  NSEnumerator *__enumerator;

  [super writeJAXBChildElements: writer];

  if ([self requestUrl]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "requestUrl", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}requestUrl."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}requestUrl...");
#endif
    [[self requestUrl] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}requestUrl...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}requestUrl."];
    }
  }
  if (YES) { //always write the primitive element...
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "processingTimeMillis", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}processingTimeMillis."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}processingTimeMillis...");
#endif
    status = xmlTextWriterWriteLongType(writer, &_processingTimeMillis);
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}processingTimeMillis...");
#endif
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing child element {}processingTimeMillis."];
    }

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}processingTimeMillis."];
    }
  }
  if ([self request]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "request", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}request."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}request...");
#endif
    [[self request] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}request...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}request."];
    }
  }
  if ([self response]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "response", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}response."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}response...");
#endif
    [[self response] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}response...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}response."];
    }
  }
}
@end /* implementation NEXUS_REST_APINS0ContentListDescribeResource (JAXB) */

#endif /* DEF_NEXUS_REST_APINS0ContentListDescribeResource_M */
#ifndef DEF_NEXUS_REST_APINS0ContentListDescribeResponseResource_M
#define DEF_NEXUS_REST_APINS0ContentListDescribeResponseResource_M

/**
 *  A set of response parameters that were sent back with response.
 
 @version $Revision$ $Date$

 */
@implementation NEXUS_REST_APINS0ContentListDescribeResponseResource

/**
 * States the type of item that was returned (or NONE if not
found).
 */
- (NSString *) responseType
{
  return _responseType;
}

/**
 * States the type of item that was returned (or NONE if not
found).
 */
- (void) setResponseType: (NSString *) newResponseType
{
  [newResponseType retain];
  [_responseType release];
  _responseType = newResponseType;
}

/**
 * The classname of the returned item.
 */
- (NSString *) responseActualClass
{
  return _responseActualClass;
}

/**
 * The classname of the returned item.
 */
- (void) setResponseActualClass: (NSString *) newResponseActualClass
{
  [newResponseActualClass retain];
  [_responseActualClass release];
  _responseActualClass = newResponseActualClass;
}

/**
 * The path of the item in the repository.
 */
- (NSString *) responsePath
{
  return _responsePath;
}

/**
 * The path of the item in the repository.
 */
- (void) setResponsePath: (NSString *) newResponsePath
{
  [newResponsePath retain];
  [_responsePath release];
  _responsePath = newResponsePath;
}

/**
 * A string that uniquely defines this item in the system (or
'virtual' if this is an item from a virtual repository).
 */
- (NSString *) responseUid
{
  return _responseUid;
}

/**
 * A string that uniquely defines this item in the system (or
'virtual' if this is an item from a virtual repository).
 */
- (void) setResponseUid: (NSString *) newResponseUid
{
  [newResponseUid retain];
  [_responseUid release];
  _responseUid = newResponseUid;
}

/**
 * The id of the repository this item was retrieved from (or
null if this is an item from a virtual repository).
 */
- (NSString *) originatingRepositoryId
{
  return _originatingRepositoryId;
}

/**
 * The id of the repository this item was retrieved from (or
null if this is an item from a virtual repository).
 */
- (void) setOriginatingRepositoryId: (NSString *) newOriginatingRepositoryId
{
  [newOriginatingRepositoryId retain];
  [_originatingRepositoryId release];
  _originatingRepositoryId = newOriginatingRepositoryId;
}

/**
 * The name of the repository this item was retrieved from (or
null if this is an item from a virtual repository).
 */
- (NSString *) originatingRepositoryName
{
  return _originatingRepositoryName;
}

/**
 * The name of the repository this item was retrieved from (or
null if this is an item from a virtual repository).
 */
- (void) setOriginatingRepositoryName: (NSString *) newOriginatingRepositoryName
{
  [newOriginatingRepositoryName retain];
  [_originatingRepositoryName release];
  _originatingRepositoryName = newOriginatingRepositoryName;
}

/**
 * The main facet (Repository implementation) of the repository
this item was retrieved from (or null if this is an item
from a virtual repository).
 */
- (NSString *) originatingRepositoryMainFacet
{
  return _originatingRepositoryMainFacet;
}

/**
 * The main facet (Repository implementation) of the repository
this item was retrieved from (or null if this is an item
from a virtual repository).
 */
- (void) setOriginatingRepositoryMainFacet: (NSString *) newOriginatingRepositoryMainFacet
{
  [newOriginatingRepositoryMainFacet retain];
  [_originatingRepositoryMainFacet release];
  _originatingRepositoryMainFacet = newOriginatingRepositoryMainFacet;
}

/**
 * Field processedRepositoriesList.
 */
- (NSArray *) processedRepositoriesList
{
  return _processedRepositoriesList;
}

/**
 * Field processedRepositoriesList.
 */
- (void) setProcessedRepositoriesList: (NSArray *) newProcessedRepositoriesList
{
  [newProcessedRepositoriesList retain];
  [_processedRepositoriesList release];
  _processedRepositoriesList = newProcessedRepositoriesList;
}

/**
 * Field appliedMappings.
 */
- (NSArray *) appliedMappings
{
  return _appliedMappings;
}

/**
 * Field appliedMappings.
 */
- (void) setAppliedMappings: (NSArray *) newAppliedMappings
{
  [newAppliedMappings retain];
  [_appliedMappings release];
  _appliedMappings = newAppliedMappings;
}

/**
 * Field properties.
 */
- (NSArray *) properties
{
  return _properties;
}

/**
 * Field properties.
 */
- (void) setProperties: (NSArray *) newProperties
{
  [newProperties retain];
  [_properties release];
  _properties = newProperties;
}

/**
 * Field attributes.
 */
- (NSArray *) attributes
{
  return _attributes;
}

/**
 * Field attributes.
 */
- (void) setAttributes: (NSArray *) newAttributes
{
  [newAttributes retain];
  [_attributes release];
  _attributes = newAttributes;
}

/**
 * Field sources.
 */
- (NSArray *) sources
{
  return _sources;
}

/**
 * Field sources.
 */
- (void) setSources: (NSArray *) newSources
{
  [newSources retain];
  [_sources release];
  _sources = newSources;
}

- (void) dealloc
{
  [self setResponseType: nil];
  [self setResponseActualClass: nil];
  [self setResponsePath: nil];
  [self setResponseUid: nil];
  [self setOriginatingRepositoryId: nil];
  [self setOriginatingRepositoryName: nil];
  [self setOriginatingRepositoryMainFacet: nil];
  [self setProcessedRepositoriesList: nil];
  [self setAppliedMappings: nil];
  [self setProperties: nil];
  [self setAttributes: nil];
  [self setSources: nil];
  [super dealloc];
}
@end /* implementation NEXUS_REST_APINS0ContentListDescribeResponseResource */

/**
 * Internal, private interface for JAXB reading and writing.
 */
@interface NEXUS_REST_APINS0ContentListDescribeResponseResource (JAXB) <JAXBReading, JAXBWriting, JAXBType>

@end /*interface NEXUS_REST_APINS0ContentListDescribeResponseResource (JAXB)*/

/**
 * Internal, private implementation for JAXB reading and writing.
 */
@implementation NEXUS_REST_APINS0ContentListDescribeResponseResource (JAXB)

/**
 * Read an instance of NEXUS_REST_APINS0ContentListDescribeResponseResource from an XML reader.
 *
 * @param reader The reader.
 * @return An instance of NEXUS_REST_APINS0ContentListDescribeResponseResource defined by the XML reader.
 */
+ (id<JAXBType>) readXMLType: (xmlTextReaderPtr) reader
{
  NEXUS_REST_APINS0ContentListDescribeResponseResource *_nEXUS_REST_APINS0ContentListDescribeResponseResource = [[NEXUS_REST_APINS0ContentListDescribeResponseResource alloc] init];
  NS_DURING
  {
    [_nEXUS_REST_APINS0ContentListDescribeResponseResource initWithReader: reader];
  }
  NS_HANDLER
  {
    [_nEXUS_REST_APINS0ContentListDescribeResponseResource dealloc];
    _nEXUS_REST_APINS0ContentListDescribeResponseResource = nil;
    [localException raise];
  }
  NS_ENDHANDLER

  [_nEXUS_REST_APINS0ContentListDescribeResponseResource autorelease];
  return _nEXUS_REST_APINS0ContentListDescribeResponseResource;
}

/**
 * Initialize this instance of NEXUS_REST_APINS0ContentListDescribeResponseResource according to
 * the XML being read from the reader.
 *
 * @param reader The reader.
 */
- (id) initWithReader: (xmlTextReaderPtr) reader
{
  return [super initWithReader: reader];
}

/**
 * Write the XML for this instance of NEXUS_REST_APINS0ContentListDescribeResponseResource to the writer.
 * Note that since we're only writing the XML type,
 * No start/end element will be written.
 *
 * @param reader The reader.
 */
- (void) writeXMLType: (xmlTextWriterPtr) writer
{
  [super writeXMLType:writer];
}

//documentation inherited.
- (BOOL) readJAXBAttribute: (xmlTextReaderPtr) reader
{
  void *_child_accessor;

  if ([super readJAXBAttribute: reader]) {
    return YES;
  }

  return NO;
}

//documentation inherited.
- (BOOL) readJAXBValue: (xmlTextReaderPtr) reader
{
  return [super readJAXBValue: reader];
}

//documentation inherited.
- (BOOL) readJAXBChildElement: (xmlTextReaderPtr) reader
{
  id __child;
  void *_child_accessor;
  int status, depth;

  if ([super readJAXBChildElement: reader]) {
    return YES;
  }
  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "responseType", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}responseType of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}responseType of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setResponseType: __child];
    return YES;
  } //end "if choice"

  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "responseActualClass", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}responseActualClass of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}responseActualClass of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setResponseActualClass: __child];
    return YES;
  } //end "if choice"

  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "responsePath", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}responsePath of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}responsePath of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setResponsePath: __child];
    return YES;
  } //end "if choice"

  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "responseUid", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}responseUid of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}responseUid of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setResponseUid: __child];
    return YES;
  } //end "if choice"

  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "originatingRepositoryId", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}originatingRepositoryId of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}originatingRepositoryId of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setOriginatingRepositoryId: __child];
    return YES;
  } //end "if choice"

  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "originatingRepositoryName", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}originatingRepositoryName of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}originatingRepositoryName of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setOriginatingRepositoryName: __child];
    return YES;
  } //end "if choice"

  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "originatingRepositoryMainFacet", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}originatingRepositoryMainFacet of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}originatingRepositoryMainFacet of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setOriginatingRepositoryMainFacet: __child];
    return YES;
  } //end "if choice"

  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "processedRepositoriesList", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

    if (xmlTextReaderIsEmptyElement(reader) == 0) {
#if DEBUG_ENUNCIATE > 1
      NSLog(@"Unwrapping wrapper element {}processedRepositoriesList...");
#endif
      //start wrapper element "{}processedRepositoriesList"
      depth = xmlTextReaderDepth(reader);
      status = xmlTextReaderAdvanceToNextStartOrEndElement(reader);
      while (xmlTextReaderDepth(reader) > depth) {
        if (status < 1) {
          //panic: XML read error.
          [self dealloc];
          [NSException raise: @"XMLReadError"
                       format: @"Failure to advance to next wrapped child element."];
        }
  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "processedRepositoriesListItem", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}processedRepositoriesListItem of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}processedRepositoriesListItem of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    if ([self processedRepositoriesList]) {
      [self setProcessedRepositoriesList: [[self processedRepositoriesList] arrayByAddingObject: __child]];
    }
    else {
      [self setProcessedRepositoriesList: [NSArray arrayWithObject: __child]];
    }
    continue; //continue "while in wrapper element" loop
  } //end "if choice"

        status = xmlTextReaderAdvanceToNextStartOrEndElement(reader);
#if DEBUG_ENUNCIATE > 1
        NSLog(@"successfully unwrapped wrapper element {}processedRepositoriesList...");
#endif
      } // end "while in wrapper element" loop

      if (status < 1) {
        //panic: XML read error.
        [self dealloc];
        [NSException raise: @"XMLReadError"
                     format: @"Failure to advance to end wrapper element."];
      }
      else {
        //end wrapper element "{}processedRepositoriesList"
        status = xmlTextReaderAdvanceToNextStartOrEndElement(reader);
      }
    } //end "if empty element" clause
    else {
      __child = [NSArray array];
      [self setProcessedRepositoriesList: (NSArray*) __child];
    }

    return YES;
  } // end "if wrapper element" clause
  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "appliedMappings", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

    if (xmlTextReaderIsEmptyElement(reader) == 0) {
#if DEBUG_ENUNCIATE > 1
      NSLog(@"Unwrapping wrapper element {}appliedMappings...");
#endif
      //start wrapper element "{}appliedMappings"
      depth = xmlTextReaderDepth(reader);
      status = xmlTextReaderAdvanceToNextStartOrEndElement(reader);
      while (xmlTextReaderDepth(reader) > depth) {
        if (status < 1) {
          //panic: XML read error.
          [self dealloc];
          [NSException raise: @"XMLReadError"
                       format: @"Failure to advance to next wrapped child element."];
        }
  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "appliedMappingItem", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}appliedMappingItem of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}appliedMappingItem of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    if ([self appliedMappings]) {
      [self setAppliedMappings: [[self appliedMappings] arrayByAddingObject: __child]];
    }
    else {
      [self setAppliedMappings: [NSArray arrayWithObject: __child]];
    }
    continue; //continue "while in wrapper element" loop
  } //end "if choice"

        status = xmlTextReaderAdvanceToNextStartOrEndElement(reader);
#if DEBUG_ENUNCIATE > 1
        NSLog(@"successfully unwrapped wrapper element {}appliedMappings...");
#endif
      } // end "while in wrapper element" loop

      if (status < 1) {
        //panic: XML read error.
        [self dealloc];
        [NSException raise: @"XMLReadError"
                     format: @"Failure to advance to end wrapper element."];
      }
      else {
        //end wrapper element "{}appliedMappings"
        status = xmlTextReaderAdvanceToNextStartOrEndElement(reader);
      }
    } //end "if empty element" clause
    else {
      __child = [NSArray array];
      [self setAppliedMappings: (NSArray*) __child];
    }

    return YES;
  } // end "if wrapper element" clause
  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "properties", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

    if (xmlTextReaderIsEmptyElement(reader) == 0) {
#if DEBUG_ENUNCIATE > 1
      NSLog(@"Unwrapping wrapper element {}properties...");
#endif
      //start wrapper element "{}properties"
      depth = xmlTextReaderDepth(reader);
      status = xmlTextReaderAdvanceToNextStartOrEndElement(reader);
      while (xmlTextReaderDepth(reader) > depth) {
        if (status < 1) {
          //panic: XML read error.
          [self dealloc];
          [NSException raise: @"XMLReadError"
                       format: @"Failure to advance to next wrapped child element."];
        }
  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "propertyItem", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}propertyItem of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}propertyItem of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    if ([self properties]) {
      [self setProperties: [[self properties] arrayByAddingObject: __child]];
    }
    else {
      [self setProperties: [NSArray arrayWithObject: __child]];
    }
    continue; //continue "while in wrapper element" loop
  } //end "if choice"

        status = xmlTextReaderAdvanceToNextStartOrEndElement(reader);
#if DEBUG_ENUNCIATE > 1
        NSLog(@"successfully unwrapped wrapper element {}properties...");
#endif
      } // end "while in wrapper element" loop

      if (status < 1) {
        //panic: XML read error.
        [self dealloc];
        [NSException raise: @"XMLReadError"
                     format: @"Failure to advance to end wrapper element."];
      }
      else {
        //end wrapper element "{}properties"
        status = xmlTextReaderAdvanceToNextStartOrEndElement(reader);
      }
    } //end "if empty element" clause
    else {
      __child = [NSArray array];
      [self setProperties: (NSArray*) __child];
    }

    return YES;
  } // end "if wrapper element" clause
  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "attributes", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

    if (xmlTextReaderIsEmptyElement(reader) == 0) {
#if DEBUG_ENUNCIATE > 1
      NSLog(@"Unwrapping wrapper element {}attributes...");
#endif
      //start wrapper element "{}attributes"
      depth = xmlTextReaderDepth(reader);
      status = xmlTextReaderAdvanceToNextStartOrEndElement(reader);
      while (xmlTextReaderDepth(reader) > depth) {
        if (status < 1) {
          //panic: XML read error.
          [self dealloc];
          [NSException raise: @"XMLReadError"
                       format: @"Failure to advance to next wrapped child element."];
        }
  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "attributeItem", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}attributeItem of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}attributeItem of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    if ([self attributes]) {
      [self setAttributes: [[self attributes] arrayByAddingObject: __child]];
    }
    else {
      [self setAttributes: [NSArray arrayWithObject: __child]];
    }
    continue; //continue "while in wrapper element" loop
  } //end "if choice"

        status = xmlTextReaderAdvanceToNextStartOrEndElement(reader);
#if DEBUG_ENUNCIATE > 1
        NSLog(@"successfully unwrapped wrapper element {}attributes...");
#endif
      } // end "while in wrapper element" loop

      if (status < 1) {
        //panic: XML read error.
        [self dealloc];
        [NSException raise: @"XMLReadError"
                     format: @"Failure to advance to end wrapper element."];
      }
      else {
        //end wrapper element "{}attributes"
        status = xmlTextReaderAdvanceToNextStartOrEndElement(reader);
      }
    } //end "if empty element" clause
    else {
      __child = [NSArray array];
      [self setAttributes: (NSArray*) __child];
    }

    return YES;
  } // end "if wrapper element" clause
  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "sources", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

    if (xmlTextReaderIsEmptyElement(reader) == 0) {
#if DEBUG_ENUNCIATE > 1
      NSLog(@"Unwrapping wrapper element {}sources...");
#endif
      //start wrapper element "{}sources"
      depth = xmlTextReaderDepth(reader);
      status = xmlTextReaderAdvanceToNextStartOrEndElement(reader);
      while (xmlTextReaderDepth(reader) > depth) {
        if (status < 1) {
          //panic: XML read error.
          [self dealloc];
          [NSException raise: @"XMLReadError"
                       format: @"Failure to advance to next wrapped child element."];
        }
  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "sourceItem", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}sourceItem of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}sourceItem of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    if ([self sources]) {
      [self setSources: [[self sources] arrayByAddingObject: __child]];
    }
    else {
      [self setSources: [NSArray arrayWithObject: __child]];
    }
    continue; //continue "while in wrapper element" loop
  } //end "if choice"

        status = xmlTextReaderAdvanceToNextStartOrEndElement(reader);
#if DEBUG_ENUNCIATE > 1
        NSLog(@"successfully unwrapped wrapper element {}sources...");
#endif
      } // end "while in wrapper element" loop

      if (status < 1) {
        //panic: XML read error.
        [self dealloc];
        [NSException raise: @"XMLReadError"
                     format: @"Failure to advance to end wrapper element."];
      }
      else {
        //end wrapper element "{}sources"
        status = xmlTextReaderAdvanceToNextStartOrEndElement(reader);
      }
    } //end "if empty element" clause
    else {
      __child = [NSArray array];
      [self setSources: (NSArray*) __child];
    }

    return YES;
  } // end "if wrapper element" clause

  return NO;
}

//documentation inherited.
- (int) readUnknownJAXBChildElement: (xmlTextReaderPtr) reader
{
  return [super readUnknownJAXBChildElement: reader];
}

//documentation inherited.
- (void) readUnknownJAXBAttribute: (xmlTextReaderPtr) reader
{
  [super readUnknownJAXBAttribute: reader];
}

//documentation inherited.
- (void) writeJAXBAttributes: (xmlTextWriterPtr) writer
{
  int status;

  [super writeJAXBAttributes: writer];

}

//documentation inherited.
- (void) writeJAXBValue: (xmlTextWriterPtr) writer
{
  [super writeJAXBValue: writer];
}

/**
 * Method for writing the child elements.
 *
 * @param writer The writer.
 */
- (void) writeJAXBChildElements: (xmlTextWriterPtr) writer
{
  int status;
  id __item;
  NSEnumerator *__enumerator;

  [super writeJAXBChildElements: writer];

  if ([self responseType]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "responseType", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}responseType."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}responseType...");
#endif
    [[self responseType] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}responseType...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}responseType."];
    }
  }
  if ([self responseActualClass]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "responseActualClass", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}responseActualClass."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}responseActualClass...");
#endif
    [[self responseActualClass] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}responseActualClass...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}responseActualClass."];
    }
  }
  if ([self responsePath]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "responsePath", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}responsePath."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}responsePath...");
#endif
    [[self responsePath] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}responsePath...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}responsePath."];
    }
  }
  if ([self responseUid]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "responseUid", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}responseUid."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}responseUid...");
#endif
    [[self responseUid] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}responseUid...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}responseUid."];
    }
  }
  if ([self originatingRepositoryId]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "originatingRepositoryId", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}originatingRepositoryId."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}originatingRepositoryId...");
#endif
    [[self originatingRepositoryId] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}originatingRepositoryId...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}originatingRepositoryId."];
    }
  }
  if ([self originatingRepositoryName]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "originatingRepositoryName", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}originatingRepositoryName."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}originatingRepositoryName...");
#endif
    [[self originatingRepositoryName] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}originatingRepositoryName...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}originatingRepositoryName."];
    }
  }
  if ([self originatingRepositoryMainFacet]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "originatingRepositoryMainFacet", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}originatingRepositoryMainFacet."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}originatingRepositoryMainFacet...");
#endif
    [[self originatingRepositoryMainFacet] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}originatingRepositoryMainFacet...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}originatingRepositoryMainFacet."];
    }
  }
  if ([self processedRepositoriesList]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "processedRepositoriesList", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start wrapper element {}processedRepositoriesList."];
    }
    __enumerator = [[self processedRepositoriesList] objectEnumerator];

    while ( (__item = [__enumerator nextObject]) ) {
      status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "processedRepositoriesListItem", NULL);
      if (status < 0) {
        [NSException raise: @"XMLWriteError"
                     format: @"Error writing start child element {}processedRepositoriesListItem."];
      }

#if DEBUG_ENUNCIATE > 1
      NSLog(@"writing element {}processedRepositoriesListItem...");
#endif
      [__item writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
      NSLog(@"successfully wrote element {}processedRepositoriesListItem...");
#endif

      status = xmlTextWriterEndElement(writer);
      if (status < 0) {
        [NSException raise: @"XMLWriteError"
                     format: @"Error writing end child element {}processedRepositoriesListItem."];
      }
    } //end item iterator.

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end wrapper element {}processedRepositoriesList."];
    }
  }
  if ([self appliedMappings]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "appliedMappings", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start wrapper element {}appliedMappings."];
    }
    __enumerator = [[self appliedMappings] objectEnumerator];

    while ( (__item = [__enumerator nextObject]) ) {
      status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "appliedMappingItem", NULL);
      if (status < 0) {
        [NSException raise: @"XMLWriteError"
                     format: @"Error writing start child element {}appliedMappingItem."];
      }

#if DEBUG_ENUNCIATE > 1
      NSLog(@"writing element {}appliedMappingItem...");
#endif
      [__item writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
      NSLog(@"successfully wrote element {}appliedMappingItem...");
#endif

      status = xmlTextWriterEndElement(writer);
      if (status < 0) {
        [NSException raise: @"XMLWriteError"
                     format: @"Error writing end child element {}appliedMappingItem."];
      }
    } //end item iterator.

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end wrapper element {}appliedMappings."];
    }
  }
  if ([self properties]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "properties", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start wrapper element {}properties."];
    }
    __enumerator = [[self properties] objectEnumerator];

    while ( (__item = [__enumerator nextObject]) ) {
      status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "propertyItem", NULL);
      if (status < 0) {
        [NSException raise: @"XMLWriteError"
                     format: @"Error writing start child element {}propertyItem."];
      }

#if DEBUG_ENUNCIATE > 1
      NSLog(@"writing element {}propertyItem...");
#endif
      [__item writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
      NSLog(@"successfully wrote element {}propertyItem...");
#endif

      status = xmlTextWriterEndElement(writer);
      if (status < 0) {
        [NSException raise: @"XMLWriteError"
                     format: @"Error writing end child element {}propertyItem."];
      }
    } //end item iterator.

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end wrapper element {}properties."];
    }
  }
  if ([self attributes]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "attributes", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start wrapper element {}attributes."];
    }
    __enumerator = [[self attributes] objectEnumerator];

    while ( (__item = [__enumerator nextObject]) ) {
      status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "attributeItem", NULL);
      if (status < 0) {
        [NSException raise: @"XMLWriteError"
                     format: @"Error writing start child element {}attributeItem."];
      }

#if DEBUG_ENUNCIATE > 1
      NSLog(@"writing element {}attributeItem...");
#endif
      [__item writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
      NSLog(@"successfully wrote element {}attributeItem...");
#endif

      status = xmlTextWriterEndElement(writer);
      if (status < 0) {
        [NSException raise: @"XMLWriteError"
                     format: @"Error writing end child element {}attributeItem."];
      }
    } //end item iterator.

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end wrapper element {}attributes."];
    }
  }
  if ([self sources]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "sources", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start wrapper element {}sources."];
    }
    __enumerator = [[self sources] objectEnumerator];

    while ( (__item = [__enumerator nextObject]) ) {
      status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "sourceItem", NULL);
      if (status < 0) {
        [NSException raise: @"XMLWriteError"
                     format: @"Error writing start child element {}sourceItem."];
      }

#if DEBUG_ENUNCIATE > 1
      NSLog(@"writing element {}sourceItem...");
#endif
      [__item writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
      NSLog(@"successfully wrote element {}sourceItem...");
#endif

      status = xmlTextWriterEndElement(writer);
      if (status < 0) {
        [NSException raise: @"XMLWriteError"
                     format: @"Error writing end child element {}sourceItem."];
      }
    } //end item iterator.

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end wrapper element {}sources."];
    }
  }
}
@end /* implementation NEXUS_REST_APINS0ContentListDescribeResponseResource (JAXB) */

#endif /* DEF_NEXUS_REST_APINS0ContentListDescribeResponseResource_M */
#ifndef DEF_NEXUS_REST_APINS0ContentListResource_M
#define DEF_NEXUS_REST_APINS0ContentListResource_M

/**
 *  A Content Item definition, including all data needed to properly
 access the item, and understand the item.
 
 @version $Revision$ $Date$

 */
@implementation NEXUS_REST_APINS0ContentListResource

/**
 * The URI that can be used to directly access this item in the
future.
 */
- (NSString *) resourceURI
{
  return _resourceURI;
}

/**
 * The URI that can be used to directly access this item in the
future.
 */
- (void) setResourceURI: (NSString *) newResourceURI
{
  [newResourceURI retain];
  [_resourceURI release];
  _resourceURI = newResourceURI;
}

/**
 * The relative path in relation to the root of the repository.
 */
- (NSString *) relativePath
{
  return _relativePath;
}

/**
 * The relative path in relation to the root of the repository.
 */
- (void) setRelativePath: (NSString *) newRelativePath
{
  [newRelativePath retain];
  [_relativePath release];
  _relativePath = newRelativePath;
}

/**
 * A name of the content item.
 */
- (NSString *) text
{
  return _text;
}

/**
 * A name of the content item.
 */
- (void) setText: (NSString *) newText
{
  [newText retain];
  [_text release];
  _text = newText;
}

/**
 * Flag that states whether the content item is a file item (if
true), otherwise it is a folder item, and can use the
resourceURI to retrieve the contained content.
 */
- (BOOL) leaf
{
  return _leaf;
}

/**
 * Flag that states whether the content item is a file item (if
true), otherwise it is a folder item, and can use the
resourceURI to retrieve the contained content.
 */
- (void) setLeaf: (BOOL) newLeaf
{
  _leaf = newLeaf;
}

/**
 * Timestamp the item was last modified.
 */
- (NSDate *) lastModified
{
  return _lastModified;
}

/**
 * Timestamp the item was last modified.
 */
- (void) setLastModified: (NSDate *) newLastModified
{
  [newLastModified retain];
  [_lastModified release];
  _lastModified = newLastModified;
}

/**
 * Size of the item on the disk.
 */
- (long) sizeOnDisk
{
  return _sizeOnDisk;
}

/**
 * Size of the item on the disk.
 */
- (void) setSizeOnDisk: (long) newSizeOnDisk
{
  _sizeOnDisk = newSizeOnDisk;
}

- (void) dealloc
{
  [self setResourceURI: nil];
  [self setRelativePath: nil];
  [self setText: nil];
  [self setLastModified: nil];
  [super dealloc];
}
@end /* implementation NEXUS_REST_APINS0ContentListResource */

/**
 * Internal, private interface for JAXB reading and writing.
 */
@interface NEXUS_REST_APINS0ContentListResource (JAXB) <JAXBReading, JAXBWriting, JAXBType>

@end /*interface NEXUS_REST_APINS0ContentListResource (JAXB)*/

/**
 * Internal, private implementation for JAXB reading and writing.
 */
@implementation NEXUS_REST_APINS0ContentListResource (JAXB)

/**
 * Read an instance of NEXUS_REST_APINS0ContentListResource from an XML reader.
 *
 * @param reader The reader.
 * @return An instance of NEXUS_REST_APINS0ContentListResource defined by the XML reader.
 */
+ (id<JAXBType>) readXMLType: (xmlTextReaderPtr) reader
{
  NEXUS_REST_APINS0ContentListResource *_nEXUS_REST_APINS0ContentListResource = [[NEXUS_REST_APINS0ContentListResource alloc] init];
  NS_DURING
  {
    [_nEXUS_REST_APINS0ContentListResource initWithReader: reader];
  }
  NS_HANDLER
  {
    [_nEXUS_REST_APINS0ContentListResource dealloc];
    _nEXUS_REST_APINS0ContentListResource = nil;
    [localException raise];
  }
  NS_ENDHANDLER

  [_nEXUS_REST_APINS0ContentListResource autorelease];
  return _nEXUS_REST_APINS0ContentListResource;
}

/**
 * Initialize this instance of NEXUS_REST_APINS0ContentListResource according to
 * the XML being read from the reader.
 *
 * @param reader The reader.
 */
- (id) initWithReader: (xmlTextReaderPtr) reader
{
  return [super initWithReader: reader];
}

/**
 * Write the XML for this instance of NEXUS_REST_APINS0ContentListResource to the writer.
 * Note that since we're only writing the XML type,
 * No start/end element will be written.
 *
 * @param reader The reader.
 */
- (void) writeXMLType: (xmlTextWriterPtr) writer
{
  [super writeXMLType:writer];
}

//documentation inherited.
- (BOOL) readJAXBAttribute: (xmlTextReaderPtr) reader
{
  void *_child_accessor;

  if ([super readJAXBAttribute: reader]) {
    return YES;
  }

  return NO;
}

//documentation inherited.
- (BOOL) readJAXBValue: (xmlTextReaderPtr) reader
{
  return [super readJAXBValue: reader];
}

//documentation inherited.
- (BOOL) readJAXBChildElement: (xmlTextReaderPtr) reader
{
  id __child;
  void *_child_accessor;
  int status, depth;

  if ([super readJAXBChildElement: reader]) {
    return YES;
  }
  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "resourceURI", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}resourceURI of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}resourceURI of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setResourceURI: __child];
    return YES;
  } //end "if choice"

  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "relativePath", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}relativePath of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}relativePath of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setRelativePath: __child];
    return YES;
  } //end "if choice"

  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "text", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}text of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}text of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setText: __child];
    return YES;
  } //end "if choice"


  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "leaf", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

    _child_accessor = xmlTextReaderReadBooleanType(reader);
    if (_child_accessor == NULL) {
      //panic: unable to return the value for some reason.
      [self dealloc];
      [NSException raise: @"XMLReadError"
                   format: @"Error reading element value."];
    }
    [self setLeaf: *((BOOL*) _child_accessor)];
    free(_child_accessor);
    return YES;
  }
  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "lastModified", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}lastModified of type {http://www.w3.org/2001/XMLSchema}dateTime.");
#endif
    __child = [NSDate readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}lastModified of type {http://www.w3.org/2001/XMLSchema}dateTime.");
#endif

    [self setLastModified: __child];
    return YES;
  } //end "if choice"


  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "sizeOnDisk", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

    _child_accessor = xmlTextReaderReadLongType(reader);
    if (_child_accessor == NULL) {
      //panic: unable to return the value for some reason.
      [self dealloc];
      [NSException raise: @"XMLReadError"
                   format: @"Error reading element value."];
    }
    [self setSizeOnDisk: *((long*) _child_accessor)];
    free(_child_accessor);
    return YES;
  }

  return NO;
}

//documentation inherited.
- (int) readUnknownJAXBChildElement: (xmlTextReaderPtr) reader
{
  return [super readUnknownJAXBChildElement: reader];
}

//documentation inherited.
- (void) readUnknownJAXBAttribute: (xmlTextReaderPtr) reader
{
  [super readUnknownJAXBAttribute: reader];
}

//documentation inherited.
- (void) writeJAXBAttributes: (xmlTextWriterPtr) writer
{
  int status;

  [super writeJAXBAttributes: writer];

}

//documentation inherited.
- (void) writeJAXBValue: (xmlTextWriterPtr) writer
{
  [super writeJAXBValue: writer];
}

/**
 * Method for writing the child elements.
 *
 * @param writer The writer.
 */
- (void) writeJAXBChildElements: (xmlTextWriterPtr) writer
{
  int status;
  id __item;
  NSEnumerator *__enumerator;

  [super writeJAXBChildElements: writer];

  if ([self resourceURI]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "resourceURI", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}resourceURI."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}resourceURI...");
#endif
    [[self resourceURI] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}resourceURI...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}resourceURI."];
    }
  }
  if ([self relativePath]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "relativePath", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}relativePath."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}relativePath...");
#endif
    [[self relativePath] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}relativePath...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}relativePath."];
    }
  }
  if ([self text]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "text", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}text."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}text...");
#endif
    [[self text] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}text...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}text."];
    }
  }
  if (YES) { //always write the primitive element...
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "leaf", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}leaf."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}leaf...");
#endif
    status = xmlTextWriterWriteBooleanType(writer, &_leaf);
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}leaf...");
#endif
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing child element {}leaf."];
    }

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}leaf."];
    }
  }
  if ([self lastModified]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "lastModified", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}lastModified."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}lastModified...");
#endif
    [[self lastModified] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}lastModified...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}lastModified."];
    }
  }
  if (YES) { //always write the primitive element...
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "sizeOnDisk", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}sizeOnDisk."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}sizeOnDisk...");
#endif
    status = xmlTextWriterWriteLongType(writer, &_sizeOnDisk);
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}sizeOnDisk...");
#endif
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing child element {}sizeOnDisk."];
    }

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}sizeOnDisk."];
    }
  }
}
@end /* implementation NEXUS_REST_APINS0ContentListResource (JAXB) */

#endif /* DEF_NEXUS_REST_APINS0ContentListResource_M */
#ifndef DEF_NEXUS_REST_APINS0ErrorReportRequestDTO_M
#define DEF_NEXUS_REST_APINS0ErrorReportRequestDTO_M

/**
 *  Details required to generate an error report.
 
 @version $Revision$ $Date$

 */
@implementation NEXUS_REST_APINS0ErrorReportRequestDTO

/**
 * The title of the error report.
 */
- (NSString *) title
{
  return _title;
}

/**
 * The title of the error report.
 */
- (void) setTitle: (NSString *) newTitle
{
  [newTitle retain];
  [_title release];
  _title = newTitle;
}

/**
 * A detailed explanation of the error report.
 */
- (NSString *) description
{
  return _description;
}

/**
 * A detailed explanation of the error report.
 */
- (void) setDescription: (NSString *) newDescription
{
  [newDescription retain];
  [_description release];
  _description = newDescription;
}

/**
 * If true will overwrite currect error report settings with
the credentials provided.
 */
- (BOOL) saveErrorReportingSettings
{
  return _saveErrorReportingSettings;
}

/**
 * If true will overwrite currect error report settings with
the credentials provided.
 */
- (void) setSaveErrorReportingSettings: (BOOL) newSaveErrorReportingSettings
{
  _saveErrorReportingSettings = newSaveErrorReportingSettings;
}

/**
 * The error report settings.
 */
- (NEXUS_REST_APINS0ErrorReportingSettings *) errorReportingSettings
{
  return _errorReportingSettings;
}

/**
 * The error report settings.
 */
- (void) setErrorReportingSettings: (NEXUS_REST_APINS0ErrorReportingSettings *) newErrorReportingSettings
{
  [newErrorReportingSettings retain];
  [_errorReportingSettings release];
  _errorReportingSettings = newErrorReportingSettings;
}

- (void) dealloc
{
  [self setTitle: nil];
  [self setDescription: nil];
  [self setErrorReportingSettings: nil];
  [super dealloc];
}
@end /* implementation NEXUS_REST_APINS0ErrorReportRequestDTO */

/**
 * Internal, private interface for JAXB reading and writing.
 */
@interface NEXUS_REST_APINS0ErrorReportRequestDTO (JAXB) <JAXBReading, JAXBWriting, JAXBType>

@end /*interface NEXUS_REST_APINS0ErrorReportRequestDTO (JAXB)*/

/**
 * Internal, private implementation for JAXB reading and writing.
 */
@implementation NEXUS_REST_APINS0ErrorReportRequestDTO (JAXB)

/**
 * Read an instance of NEXUS_REST_APINS0ErrorReportRequestDTO from an XML reader.
 *
 * @param reader The reader.
 * @return An instance of NEXUS_REST_APINS0ErrorReportRequestDTO defined by the XML reader.
 */
+ (id<JAXBType>) readXMLType: (xmlTextReaderPtr) reader
{
  NEXUS_REST_APINS0ErrorReportRequestDTO *_nEXUS_REST_APINS0ErrorReportRequestDTO = [[NEXUS_REST_APINS0ErrorReportRequestDTO alloc] init];
  NS_DURING
  {
    [_nEXUS_REST_APINS0ErrorReportRequestDTO initWithReader: reader];
  }
  NS_HANDLER
  {
    [_nEXUS_REST_APINS0ErrorReportRequestDTO dealloc];
    _nEXUS_REST_APINS0ErrorReportRequestDTO = nil;
    [localException raise];
  }
  NS_ENDHANDLER

  [_nEXUS_REST_APINS0ErrorReportRequestDTO autorelease];
  return _nEXUS_REST_APINS0ErrorReportRequestDTO;
}

/**
 * Initialize this instance of NEXUS_REST_APINS0ErrorReportRequestDTO according to
 * the XML being read from the reader.
 *
 * @param reader The reader.
 */
- (id) initWithReader: (xmlTextReaderPtr) reader
{
  return [super initWithReader: reader];
}

/**
 * Write the XML for this instance of NEXUS_REST_APINS0ErrorReportRequestDTO to the writer.
 * Note that since we're only writing the XML type,
 * No start/end element will be written.
 *
 * @param reader The reader.
 */
- (void) writeXMLType: (xmlTextWriterPtr) writer
{
  [super writeXMLType:writer];
}

//documentation inherited.
- (BOOL) readJAXBAttribute: (xmlTextReaderPtr) reader
{
  void *_child_accessor;

  if ([super readJAXBAttribute: reader]) {
    return YES;
  }

  return NO;
}

//documentation inherited.
- (BOOL) readJAXBValue: (xmlTextReaderPtr) reader
{
  return [super readJAXBValue: reader];
}

//documentation inherited.
- (BOOL) readJAXBChildElement: (xmlTextReaderPtr) reader
{
  id __child;
  void *_child_accessor;
  int status, depth;

  if ([super readJAXBChildElement: reader]) {
    return YES;
  }
  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "title", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}title of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}title of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setTitle: __child];
    return YES;
  } //end "if choice"

  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "description", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}description of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}description of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setDescription: __child];
    return YES;
  } //end "if choice"


  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "saveErrorReportingSettings", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

    _child_accessor = xmlTextReaderReadBooleanType(reader);
    if (_child_accessor == NULL) {
      //panic: unable to return the value for some reason.
      [self dealloc];
      [NSException raise: @"XMLReadError"
                   format: @"Error reading element value."];
    }
    [self setSaveErrorReportingSettings: *((BOOL*) _child_accessor)];
    free(_child_accessor);
    return YES;
  }
  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "errorReportingSettings", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}errorReportingSettings of type {}error-reporting-settings.");
#endif
    __child = [NEXUS_REST_APINS0ErrorReportingSettings readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}errorReportingSettings of type {}error-reporting-settings.");
#endif

    [self setErrorReportingSettings: __child];
    return YES;
  } //end "if choice"


  return NO;
}

//documentation inherited.
- (int) readUnknownJAXBChildElement: (xmlTextReaderPtr) reader
{
  return [super readUnknownJAXBChildElement: reader];
}

//documentation inherited.
- (void) readUnknownJAXBAttribute: (xmlTextReaderPtr) reader
{
  [super readUnknownJAXBAttribute: reader];
}

//documentation inherited.
- (void) writeJAXBAttributes: (xmlTextWriterPtr) writer
{
  int status;

  [super writeJAXBAttributes: writer];

}

//documentation inherited.
- (void) writeJAXBValue: (xmlTextWriterPtr) writer
{
  [super writeJAXBValue: writer];
}

/**
 * Method for writing the child elements.
 *
 * @param writer The writer.
 */
- (void) writeJAXBChildElements: (xmlTextWriterPtr) writer
{
  int status;
  id __item;
  NSEnumerator *__enumerator;

  [super writeJAXBChildElements: writer];

  if ([self title]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "title", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}title."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}title...");
#endif
    [[self title] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}title...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}title."];
    }
  }
  if ([self description]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "description", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}description."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}description...");
#endif
    [[self description] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}description...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}description."];
    }
  }
  if (YES) { //always write the primitive element...
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "saveErrorReportingSettings", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}saveErrorReportingSettings."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}saveErrorReportingSettings...");
#endif
    status = xmlTextWriterWriteBooleanType(writer, &_saveErrorReportingSettings);
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}saveErrorReportingSettings...");
#endif
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing child element {}saveErrorReportingSettings."];
    }

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}saveErrorReportingSettings."];
    }
  }
  if ([self errorReportingSettings]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "errorReportingSettings", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}errorReportingSettings."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}errorReportingSettings...");
#endif
    [[self errorReportingSettings] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}errorReportingSettings...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}errorReportingSettings."];
    }
  }
}
@end /* implementation NEXUS_REST_APINS0ErrorReportRequestDTO (JAXB) */

#endif /* DEF_NEXUS_REST_APINS0ErrorReportRequestDTO_M */
#ifndef DEF_NEXUS_REST_APINS0ErrorReportResponseDTO_M
#define DEF_NEXUS_REST_APINS0ErrorReportResponseDTO_M

/**
 *  The response data that is returned after generating an error
 report.
 
 @version $Revision$ $Date$

 */
@implementation NEXUS_REST_APINS0ErrorReportResponseDTO

/**
 * The JIRA server URL for the error report that was created.
 */
- (NSString *) jiraUrl
{
  return _jiraUrl;
}

/**
 * The JIRA server URL for the error report that was created.
 */
- (void) setJiraUrl: (NSString *) newJiraUrl
{
  [newJiraUrl retain];
  [_jiraUrl release];
  _jiraUrl = newJiraUrl;
}

- (void) dealloc
{
  [self setJiraUrl: nil];
  [super dealloc];
}
@end /* implementation NEXUS_REST_APINS0ErrorReportResponseDTO */

/**
 * Internal, private interface for JAXB reading and writing.
 */
@interface NEXUS_REST_APINS0ErrorReportResponseDTO (JAXB) <JAXBReading, JAXBWriting, JAXBType>

@end /*interface NEXUS_REST_APINS0ErrorReportResponseDTO (JAXB)*/

/**
 * Internal, private implementation for JAXB reading and writing.
 */
@implementation NEXUS_REST_APINS0ErrorReportResponseDTO (JAXB)

/**
 * Read an instance of NEXUS_REST_APINS0ErrorReportResponseDTO from an XML reader.
 *
 * @param reader The reader.
 * @return An instance of NEXUS_REST_APINS0ErrorReportResponseDTO defined by the XML reader.
 */
+ (id<JAXBType>) readXMLType: (xmlTextReaderPtr) reader
{
  NEXUS_REST_APINS0ErrorReportResponseDTO *_nEXUS_REST_APINS0ErrorReportResponseDTO = [[NEXUS_REST_APINS0ErrorReportResponseDTO alloc] init];
  NS_DURING
  {
    [_nEXUS_REST_APINS0ErrorReportResponseDTO initWithReader: reader];
  }
  NS_HANDLER
  {
    [_nEXUS_REST_APINS0ErrorReportResponseDTO dealloc];
    _nEXUS_REST_APINS0ErrorReportResponseDTO = nil;
    [localException raise];
  }
  NS_ENDHANDLER

  [_nEXUS_REST_APINS0ErrorReportResponseDTO autorelease];
  return _nEXUS_REST_APINS0ErrorReportResponseDTO;
}

/**
 * Initialize this instance of NEXUS_REST_APINS0ErrorReportResponseDTO according to
 * the XML being read from the reader.
 *
 * @param reader The reader.
 */
- (id) initWithReader: (xmlTextReaderPtr) reader
{
  return [super initWithReader: reader];
}

/**
 * Write the XML for this instance of NEXUS_REST_APINS0ErrorReportResponseDTO to the writer.
 * Note that since we're only writing the XML type,
 * No start/end element will be written.
 *
 * @param reader The reader.
 */
- (void) writeXMLType: (xmlTextWriterPtr) writer
{
  [super writeXMLType:writer];
}

//documentation inherited.
- (BOOL) readJAXBAttribute: (xmlTextReaderPtr) reader
{
  void *_child_accessor;

  if ([super readJAXBAttribute: reader]) {
    return YES;
  }

  return NO;
}

//documentation inherited.
- (BOOL) readJAXBValue: (xmlTextReaderPtr) reader
{
  return [super readJAXBValue: reader];
}

//documentation inherited.
- (BOOL) readJAXBChildElement: (xmlTextReaderPtr) reader
{
  id __child;
  void *_child_accessor;
  int status, depth;

  if ([super readJAXBChildElement: reader]) {
    return YES;
  }
  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "jiraUrl", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}jiraUrl of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}jiraUrl of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setJiraUrl: __child];
    return YES;
  } //end "if choice"


  return NO;
}

//documentation inherited.
- (int) readUnknownJAXBChildElement: (xmlTextReaderPtr) reader
{
  return [super readUnknownJAXBChildElement: reader];
}

//documentation inherited.
- (void) readUnknownJAXBAttribute: (xmlTextReaderPtr) reader
{
  [super readUnknownJAXBAttribute: reader];
}

//documentation inherited.
- (void) writeJAXBAttributes: (xmlTextWriterPtr) writer
{
  int status;

  [super writeJAXBAttributes: writer];

}

//documentation inherited.
- (void) writeJAXBValue: (xmlTextWriterPtr) writer
{
  [super writeJAXBValue: writer];
}

/**
 * Method for writing the child elements.
 *
 * @param writer The writer.
 */
- (void) writeJAXBChildElements: (xmlTextWriterPtr) writer
{
  int status;
  id __item;
  NSEnumerator *__enumerator;

  [super writeJAXBChildElements: writer];

  if ([self jiraUrl]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "jiraUrl", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}jiraUrl."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}jiraUrl...");
#endif
    [[self jiraUrl] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}jiraUrl...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}jiraUrl."];
    }
  }
}
@end /* implementation NEXUS_REST_APINS0ErrorReportResponseDTO (JAXB) */

#endif /* DEF_NEXUS_REST_APINS0ErrorReportResponseDTO_M */
#ifndef DEF_NEXUS_REST_APINS0FeedListResource_M
#define DEF_NEXUS_REST_APINS0FeedListResource_M

/**
 *  Details about an RSS Feed that Nexus supplies.
 
 @version $Revision$ $Date$

 */
@implementation NEXUS_REST_APINS0FeedListResource

/**
 * The URL that must be used to retrieve the feed data.
 */
- (NSString *) resourceURI
{
  return _resourceURI;
}

/**
 * The URL that must be used to retrieve the feed data.
 */
- (void) setResourceURI: (NSString *) newResourceURI
{
  [newResourceURI retain];
  [_resourceURI release];
  _resourceURI = newResourceURI;
}

/**
 * The name of the feed.
 */
- (NSString *) name
{
  return _name;
}

/**
 * The name of the feed.
 */
- (void) setName: (NSString *) newName
{
  [newName retain];
  [_name release];
  _name = newName;
}

- (void) dealloc
{
  [self setResourceURI: nil];
  [self setName: nil];
  [super dealloc];
}
@end /* implementation NEXUS_REST_APINS0FeedListResource */

/**
 * Internal, private interface for JAXB reading and writing.
 */
@interface NEXUS_REST_APINS0FeedListResource (JAXB) <JAXBReading, JAXBWriting, JAXBType>

@end /*interface NEXUS_REST_APINS0FeedListResource (JAXB)*/

/**
 * Internal, private implementation for JAXB reading and writing.
 */
@implementation NEXUS_REST_APINS0FeedListResource (JAXB)

/**
 * Read an instance of NEXUS_REST_APINS0FeedListResource from an XML reader.
 *
 * @param reader The reader.
 * @return An instance of NEXUS_REST_APINS0FeedListResource defined by the XML reader.
 */
+ (id<JAXBType>) readXMLType: (xmlTextReaderPtr) reader
{
  NEXUS_REST_APINS0FeedListResource *_nEXUS_REST_APINS0FeedListResource = [[NEXUS_REST_APINS0FeedListResource alloc] init];
  NS_DURING
  {
    [_nEXUS_REST_APINS0FeedListResource initWithReader: reader];
  }
  NS_HANDLER
  {
    [_nEXUS_REST_APINS0FeedListResource dealloc];
    _nEXUS_REST_APINS0FeedListResource = nil;
    [localException raise];
  }
  NS_ENDHANDLER

  [_nEXUS_REST_APINS0FeedListResource autorelease];
  return _nEXUS_REST_APINS0FeedListResource;
}

/**
 * Initialize this instance of NEXUS_REST_APINS0FeedListResource according to
 * the XML being read from the reader.
 *
 * @param reader The reader.
 */
- (id) initWithReader: (xmlTextReaderPtr) reader
{
  return [super initWithReader: reader];
}

/**
 * Write the XML for this instance of NEXUS_REST_APINS0FeedListResource to the writer.
 * Note that since we're only writing the XML type,
 * No start/end element will be written.
 *
 * @param reader The reader.
 */
- (void) writeXMLType: (xmlTextWriterPtr) writer
{
  [super writeXMLType:writer];
}

//documentation inherited.
- (BOOL) readJAXBAttribute: (xmlTextReaderPtr) reader
{
  void *_child_accessor;

  if ([super readJAXBAttribute: reader]) {
    return YES;
  }

  return NO;
}

//documentation inherited.
- (BOOL) readJAXBValue: (xmlTextReaderPtr) reader
{
  return [super readJAXBValue: reader];
}

//documentation inherited.
- (BOOL) readJAXBChildElement: (xmlTextReaderPtr) reader
{
  id __child;
  void *_child_accessor;
  int status, depth;

  if ([super readJAXBChildElement: reader]) {
    return YES;
  }
  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "resourceURI", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}resourceURI of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}resourceURI of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setResourceURI: __child];
    return YES;
  } //end "if choice"

  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "name", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}name of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}name of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setName: __child];
    return YES;
  } //end "if choice"


  return NO;
}

//documentation inherited.
- (int) readUnknownJAXBChildElement: (xmlTextReaderPtr) reader
{
  return [super readUnknownJAXBChildElement: reader];
}

//documentation inherited.
- (void) readUnknownJAXBAttribute: (xmlTextReaderPtr) reader
{
  [super readUnknownJAXBAttribute: reader];
}

//documentation inherited.
- (void) writeJAXBAttributes: (xmlTextWriterPtr) writer
{
  int status;

  [super writeJAXBAttributes: writer];

}

//documentation inherited.
- (void) writeJAXBValue: (xmlTextWriterPtr) writer
{
  [super writeJAXBValue: writer];
}

/**
 * Method for writing the child elements.
 *
 * @param writer The writer.
 */
- (void) writeJAXBChildElements: (xmlTextWriterPtr) writer
{
  int status;
  id __item;
  NSEnumerator *__enumerator;

  [super writeJAXBChildElements: writer];

  if ([self resourceURI]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "resourceURI", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}resourceURI."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}resourceURI...");
#endif
    [[self resourceURI] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}resourceURI...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}resourceURI."];
    }
  }
  if ([self name]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "name", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}name."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}name...");
#endif
    [[self name] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}name...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}name."];
    }
  }
}
@end /* implementation NEXUS_REST_APINS0FeedListResource (JAXB) */

#endif /* DEF_NEXUS_REST_APINS0FeedListResource_M */
#ifndef DEF_NEXUS_REST_APINS0FormFieldResource_M
#define DEF_NEXUS_REST_APINS0FormFieldResource_M

/**
 *  Form Field definition.
 
 @version $Revision$ $Date$

 */
@implementation NEXUS_REST_APINS0FormFieldResource

/**
 * The id of the field.
 */
- (NSString *) id
{
  return _id;
}

/**
 * The id of the field.
 */
- (void) setId: (NSString *) newId
{
  [newId retain];
  [_id release];
  _id = newId;
}

/**
 * The type of the field.
 */
- (NSString *) type
{
  return _type;
}

/**
 * The type of the field.
 */
- (void) setType: (NSString *) newType
{
  [newType retain];
  [_type release];
  _type = newType;
}

/**
 * The label of the field.
 */
- (NSString *) label
{
  return _label;
}

/**
 * The label of the field.
 */
- (void) setLabel: (NSString *) newLabel
{
  [newLabel retain];
  [_label release];
  _label = newLabel;
}

/**
 * The help text of the field.
 */
- (NSString *) helpText
{
  return _helpText;
}

/**
 * The help text of the field.
 */
- (void) setHelpText: (NSString *) newHelpText
{
  [newHelpText retain];
  [_helpText release];
  _helpText = newHelpText;
}

/**
 * flag that states if the field is required.
 */
- (BOOL) required
{
  return _required;
}

/**
 * flag that states if the field is required.
 */
- (void) setRequired: (BOOL) newRequired
{
  _required = newRequired;
}

/**
 * regex validation that will validate the field.
 */
- (NSString *) regexValidation
{
  return _regexValidation;
}

/**
 * regex validation that will validate the field.
 */
- (void) setRegexValidation: (NSString *) newRegexValidation
{
  [newRegexValidation retain];
  [_regexValidation release];
  _regexValidation = newRegexValidation;
}

- (void) dealloc
{
  [self setId: nil];
  [self setType: nil];
  [self setLabel: nil];
  [self setHelpText: nil];
  [self setRegexValidation: nil];
  [super dealloc];
}
@end /* implementation NEXUS_REST_APINS0FormFieldResource */

/**
 * Internal, private interface for JAXB reading and writing.
 */
@interface NEXUS_REST_APINS0FormFieldResource (JAXB) <JAXBReading, JAXBWriting, JAXBType>

@end /*interface NEXUS_REST_APINS0FormFieldResource (JAXB)*/

/**
 * Internal, private implementation for JAXB reading and writing.
 */
@implementation NEXUS_REST_APINS0FormFieldResource (JAXB)

/**
 * Read an instance of NEXUS_REST_APINS0FormFieldResource from an XML reader.
 *
 * @param reader The reader.
 * @return An instance of NEXUS_REST_APINS0FormFieldResource defined by the XML reader.
 */
+ (id<JAXBType>) readXMLType: (xmlTextReaderPtr) reader
{
  NEXUS_REST_APINS0FormFieldResource *_nEXUS_REST_APINS0FormFieldResource = [[NEXUS_REST_APINS0FormFieldResource alloc] init];
  NS_DURING
  {
    [_nEXUS_REST_APINS0FormFieldResource initWithReader: reader];
  }
  NS_HANDLER
  {
    [_nEXUS_REST_APINS0FormFieldResource dealloc];
    _nEXUS_REST_APINS0FormFieldResource = nil;
    [localException raise];
  }
  NS_ENDHANDLER

  [_nEXUS_REST_APINS0FormFieldResource autorelease];
  return _nEXUS_REST_APINS0FormFieldResource;
}

/**
 * Initialize this instance of NEXUS_REST_APINS0FormFieldResource according to
 * the XML being read from the reader.
 *
 * @param reader The reader.
 */
- (id) initWithReader: (xmlTextReaderPtr) reader
{
  return [super initWithReader: reader];
}

/**
 * Write the XML for this instance of NEXUS_REST_APINS0FormFieldResource to the writer.
 * Note that since we're only writing the XML type,
 * No start/end element will be written.
 *
 * @param reader The reader.
 */
- (void) writeXMLType: (xmlTextWriterPtr) writer
{
  [super writeXMLType:writer];
}

//documentation inherited.
- (BOOL) readJAXBAttribute: (xmlTextReaderPtr) reader
{
  void *_child_accessor;

  if ([super readJAXBAttribute: reader]) {
    return YES;
  }

  return NO;
}

//documentation inherited.
- (BOOL) readJAXBValue: (xmlTextReaderPtr) reader
{
  return [super readJAXBValue: reader];
}

//documentation inherited.
- (BOOL) readJAXBChildElement: (xmlTextReaderPtr) reader
{
  id __child;
  void *_child_accessor;
  int status, depth;

  if ([super readJAXBChildElement: reader]) {
    return YES;
  }
  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "id", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}id of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}id of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setId: __child];
    return YES;
  } //end "if choice"

  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "type", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}type of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}type of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setType: __child];
    return YES;
  } //end "if choice"

  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "label", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}label of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}label of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setLabel: __child];
    return YES;
  } //end "if choice"

  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "helpText", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}helpText of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}helpText of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setHelpText: __child];
    return YES;
  } //end "if choice"


  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "required", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

    _child_accessor = xmlTextReaderReadBooleanType(reader);
    if (_child_accessor == NULL) {
      //panic: unable to return the value for some reason.
      [self dealloc];
      [NSException raise: @"XMLReadError"
                   format: @"Error reading element value."];
    }
    [self setRequired: *((BOOL*) _child_accessor)];
    free(_child_accessor);
    return YES;
  }
  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "regexValidation", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}regexValidation of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}regexValidation of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setRegexValidation: __child];
    return YES;
  } //end "if choice"


  return NO;
}

//documentation inherited.
- (int) readUnknownJAXBChildElement: (xmlTextReaderPtr) reader
{
  return [super readUnknownJAXBChildElement: reader];
}

//documentation inherited.
- (void) readUnknownJAXBAttribute: (xmlTextReaderPtr) reader
{
  [super readUnknownJAXBAttribute: reader];
}

//documentation inherited.
- (void) writeJAXBAttributes: (xmlTextWriterPtr) writer
{
  int status;

  [super writeJAXBAttributes: writer];

}

//documentation inherited.
- (void) writeJAXBValue: (xmlTextWriterPtr) writer
{
  [super writeJAXBValue: writer];
}

/**
 * Method for writing the child elements.
 *
 * @param writer The writer.
 */
- (void) writeJAXBChildElements: (xmlTextWriterPtr) writer
{
  int status;
  id __item;
  NSEnumerator *__enumerator;

  [super writeJAXBChildElements: writer];

  if ([self id]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "id", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}id."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}id...");
#endif
    [[self id] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}id...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}id."];
    }
  }
  if ([self type]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "type", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}type."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}type...");
#endif
    [[self type] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}type...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}type."];
    }
  }
  if ([self label]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "label", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}label."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}label...");
#endif
    [[self label] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}label...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}label."];
    }
  }
  if ([self helpText]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "helpText", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}helpText."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}helpText...");
#endif
    [[self helpText] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}helpText...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}helpText."];
    }
  }
  if (YES) { //always write the primitive element...
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "required", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}required."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}required...");
#endif
    status = xmlTextWriterWriteBooleanType(writer, &_required);
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}required...");
#endif
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing child element {}required."];
    }

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}required."];
    }
  }
  if ([self regexValidation]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "regexValidation", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}regexValidation."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}regexValidation...");
#endif
    [[self regexValidation] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}regexValidation...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}regexValidation."];
    }
  }
}
@end /* implementation NEXUS_REST_APINS0FormFieldResource (JAXB) */

#endif /* DEF_NEXUS_REST_APINS0FormFieldResource_M */
#ifndef DEF_NEXUS_REST_APINS0GlobalConfigurationListResource_M
#define DEF_NEXUS_REST_APINS0GlobalConfigurationListResource_M

/**
 *  An item that contains details about a global configuration item,
 including the url required to retrieve the configuration
 details.
 
 @version $Revision$ $Date$

 */
@implementation NEXUS_REST_APINS0GlobalConfigurationListResource

/**
 * The url that can be GET requested to retrieve the details of
the global configuration.
 */
- (NSString *) resourceURI
{
  return _resourceURI;
}

/**
 * The url that can be GET requested to retrieve the details of
the global configuration.
 */
- (void) setResourceURI: (NSString *) newResourceURI
{
  [newResourceURI retain];
  [_resourceURI release];
  _resourceURI = newResourceURI;
}

/**
 * The name of the global configuration.
 */
- (NSString *) name
{
  return _name;
}

/**
 * The name of the global configuration.
 */
- (void) setName: (NSString *) newName
{
  [newName retain];
  [_name release];
  _name = newName;
}

- (void) dealloc
{
  [self setResourceURI: nil];
  [self setName: nil];
  [super dealloc];
}
@end /* implementation NEXUS_REST_APINS0GlobalConfigurationListResource */

/**
 * Internal, private interface for JAXB reading and writing.
 */
@interface NEXUS_REST_APINS0GlobalConfigurationListResource (JAXB) <JAXBReading, JAXBWriting, JAXBType>

@end /*interface NEXUS_REST_APINS0GlobalConfigurationListResource (JAXB)*/

/**
 * Internal, private implementation for JAXB reading and writing.
 */
@implementation NEXUS_REST_APINS0GlobalConfigurationListResource (JAXB)

/**
 * Read an instance of NEXUS_REST_APINS0GlobalConfigurationListResource from an XML reader.
 *
 * @param reader The reader.
 * @return An instance of NEXUS_REST_APINS0GlobalConfigurationListResource defined by the XML reader.
 */
+ (id<JAXBType>) readXMLType: (xmlTextReaderPtr) reader
{
  NEXUS_REST_APINS0GlobalConfigurationListResource *_nEXUS_REST_APINS0GlobalConfigurationListResource = [[NEXUS_REST_APINS0GlobalConfigurationListResource alloc] init];
  NS_DURING
  {
    [_nEXUS_REST_APINS0GlobalConfigurationListResource initWithReader: reader];
  }
  NS_HANDLER
  {
    [_nEXUS_REST_APINS0GlobalConfigurationListResource dealloc];
    _nEXUS_REST_APINS0GlobalConfigurationListResource = nil;
    [localException raise];
  }
  NS_ENDHANDLER

  [_nEXUS_REST_APINS0GlobalConfigurationListResource autorelease];
  return _nEXUS_REST_APINS0GlobalConfigurationListResource;
}

/**
 * Initialize this instance of NEXUS_REST_APINS0GlobalConfigurationListResource according to
 * the XML being read from the reader.
 *
 * @param reader The reader.
 */
- (id) initWithReader: (xmlTextReaderPtr) reader
{
  return [super initWithReader: reader];
}

/**
 * Write the XML for this instance of NEXUS_REST_APINS0GlobalConfigurationListResource to the writer.
 * Note that since we're only writing the XML type,
 * No start/end element will be written.
 *
 * @param reader The reader.
 */
- (void) writeXMLType: (xmlTextWriterPtr) writer
{
  [super writeXMLType:writer];
}

//documentation inherited.
- (BOOL) readJAXBAttribute: (xmlTextReaderPtr) reader
{
  void *_child_accessor;

  if ([super readJAXBAttribute: reader]) {
    return YES;
  }

  return NO;
}

//documentation inherited.
- (BOOL) readJAXBValue: (xmlTextReaderPtr) reader
{
  return [super readJAXBValue: reader];
}

//documentation inherited.
- (BOOL) readJAXBChildElement: (xmlTextReaderPtr) reader
{
  id __child;
  void *_child_accessor;
  int status, depth;

  if ([super readJAXBChildElement: reader]) {
    return YES;
  }
  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "resourceURI", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}resourceURI of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}resourceURI of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setResourceURI: __child];
    return YES;
  } //end "if choice"

  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "name", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}name of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}name of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setName: __child];
    return YES;
  } //end "if choice"


  return NO;
}

//documentation inherited.
- (int) readUnknownJAXBChildElement: (xmlTextReaderPtr) reader
{
  return [super readUnknownJAXBChildElement: reader];
}

//documentation inherited.
- (void) readUnknownJAXBAttribute: (xmlTextReaderPtr) reader
{
  [super readUnknownJAXBAttribute: reader];
}

//documentation inherited.
- (void) writeJAXBAttributes: (xmlTextWriterPtr) writer
{
  int status;

  [super writeJAXBAttributes: writer];

}

//documentation inherited.
- (void) writeJAXBValue: (xmlTextWriterPtr) writer
{
  [super writeJAXBValue: writer];
}

/**
 * Method for writing the child elements.
 *
 * @param writer The writer.
 */
- (void) writeJAXBChildElements: (xmlTextWriterPtr) writer
{
  int status;
  id __item;
  NSEnumerator *__enumerator;

  [super writeJAXBChildElements: writer];

  if ([self resourceURI]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "resourceURI", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}resourceURI."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}resourceURI...");
#endif
    [[self resourceURI] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}resourceURI...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}resourceURI."];
    }
  }
  if ([self name]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "name", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}name."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}name...");
#endif
    [[self name] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}name...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}name."];
    }
  }
}
@end /* implementation NEXUS_REST_APINS0GlobalConfigurationListResource (JAXB) */

#endif /* DEF_NEXUS_REST_APINS0GlobalConfigurationListResource_M */
#ifndef DEF_NEXUS_REST_APINS0GlobalConfigurationResource_M
#define DEF_NEXUS_REST_APINS0GlobalConfigurationResource_M

/**
 *  List of all global configuration items in Nexus.
 
 @version $Revision$ $Date$

 */
@implementation NEXUS_REST_APINS0GlobalConfigurationResource

/**
 * Flag that determines if security is enabled, if false, there
will be no authc/authz checks performed on any requests to
the systme.
 */
- (BOOL) securityEnabled
{
  return _securityEnabled;
}

/**
 * Flag that determines if security is enabled, if false, there
will be no authc/authz checks performed on any requests to
the systme.
 */
- (void) setSecurityEnabled: (BOOL) newSecurityEnabled
{
  _securityEnabled = newSecurityEnabled;
}

/**
 * Flag that, if true, will allow anonymous access while
security is enabled.
 */
- (BOOL) securityAnonymousAccessEnabled
{
  return _securityAnonymousAccessEnabled;
}

/**
 * Flag that, if true, will allow anonymous access while
security is enabled.
 */
- (void) setSecurityAnonymousAccessEnabled: (BOOL) newSecurityAnonymousAccessEnabled
{
  _securityAnonymousAccessEnabled = newSecurityAnonymousAccessEnabled;
}

/**
 * The username to use for anonymous access (so that
roles/privileges can be applied to the anonymous access
users).
 */
- (NSString *) securityAnonymousUsername
{
  return _securityAnonymousUsername;
}

/**
 * The username to use for anonymous access (so that
roles/privileges can be applied to the anonymous access
users).
 */
- (void) setSecurityAnonymousUsername: (NSString *) newSecurityAnonymousUsername
{
  [newSecurityAnonymousUsername retain];
  [_securityAnonymousUsername release];
  _securityAnonymousUsername = newSecurityAnonymousUsername;
}

/**
 * The password to use for anonymous access.
 */
- (NSString *) securityAnonymousPassword
{
  return _securityAnonymousPassword;
}

/**
 * The password to use for anonymous access.
 */
- (void) setSecurityAnonymousPassword: (NSString *) newSecurityAnonymousPassword
{
  [newSecurityAnonymousPassword retain];
  [_securityAnonymousPassword release];
  _securityAnonymousPassword = newSecurityAnonymousPassword;
}

/**
 * Field securityRealms.
 */
- (NSArray *) securityRealms
{
  return _securityRealms;
}

/**
 * Field securityRealms.
 */
- (void) setSecurityRealms: (NSArray *) newSecurityRealms
{
  [newSecurityRealms retain];
  [_securityRealms release];
  _securityRealms = newSecurityRealms;
}

/**
 * Global remote connection settings.
 */
- (NEXUS_REST_APINS0RemoteConnectionSettings *) globalConnectionSettings
{
  return _globalConnectionSettings;
}

/**
 * Global remote connection settings.
 */
- (void) setGlobalConnectionSettings: (NEXUS_REST_APINS0RemoteConnectionSettings *) newGlobalConnectionSettings
{
  [newGlobalConnectionSettings retain];
  [_globalConnectionSettings release];
  _globalConnectionSettings = newGlobalConnectionSettings;
}

/**
 * System notification settings.
 */
- (NEXUS_REST_APINS0SystemNotificationSettings *) systemNotificationSettings
{
  return _systemNotificationSettings;
}

/**
 * System notification settings.
 */
- (void) setSystemNotificationSettings: (NEXUS_REST_APINS0SystemNotificationSettings *) newSystemNotificationSettings
{
  [newSystemNotificationSettings retain];
  [_systemNotificationSettings release];
  _systemNotificationSettings = newSystemNotificationSettings;
}

/**
 * SMTP settings for email notifications that Nexus generates.
 */
- (NEXUS_REST_APINS0SmtpSettings *) smtpSettings
{
  return _smtpSettings;
}

/**
 * SMTP settings for email notifications that Nexus generates.
 */
- (void) setSmtpSettings: (NEXUS_REST_APINS0SmtpSettings *) newSmtpSettings
{
  [newSmtpSettings retain];
  [_smtpSettings release];
  _smtpSettings = newSmtpSettings;
}

/**
 * Global HTTP Proxy Settings (will be applied to all
repositories by default).
 */
- (NEXUS_REST_APINS0RemoteHttpProxySettings *) globalHttpProxySettings
{
  return _globalHttpProxySettings;
}

/**
 * Global HTTP Proxy Settings (will be applied to all
repositories by default).
 */
- (void) setGlobalHttpProxySettings: (NEXUS_REST_APINS0RemoteHttpProxySettings *) newGlobalHttpProxySettings
{
  [newGlobalHttpProxySettings retain];
  [_globalHttpProxySettings release];
  _globalHttpProxySettings = newGlobalHttpProxySettings;
}

/**
 * Rest API configuration parameters.
 */
- (NEXUS_REST_APINS0RestApiSettings *) globalRestApiSettings
{
  return _globalRestApiSettings;
}

/**
 * Rest API configuration parameters.
 */
- (void) setGlobalRestApiSettings: (NEXUS_REST_APINS0RestApiSettings *) newGlobalRestApiSettings
{
  [newGlobalRestApiSettings retain];
  [_globalRestApiSettings release];
  _globalRestApiSettings = newGlobalRestApiSettings;
}

/**
 * Error reporting configuration parameters.
 */
- (NEXUS_REST_APINS0ErrorReportingSettings *) errorReportingSettings
{
  return _errorReportingSettings;
}

/**
 * Error reporting configuration parameters.
 */
- (void) setErrorReportingSettings: (NEXUS_REST_APINS0ErrorReportingSettings *) newErrorReportingSettings
{
  [newErrorReportingSettings retain];
  [_errorReportingSettings release];
  _errorReportingSettings = newErrorReportingSettings;
}

- (void) dealloc
{
  [self setSecurityAnonymousUsername: nil];
  [self setSecurityAnonymousPassword: nil];
  [self setSecurityRealms: nil];
  [self setGlobalConnectionSettings: nil];
  [self setSystemNotificationSettings: nil];
  [self setSmtpSettings: nil];
  [self setGlobalHttpProxySettings: nil];
  [self setGlobalRestApiSettings: nil];
  [self setErrorReportingSettings: nil];
  [super dealloc];
}
@end /* implementation NEXUS_REST_APINS0GlobalConfigurationResource */

/**
 * Internal, private interface for JAXB reading and writing.
 */
@interface NEXUS_REST_APINS0GlobalConfigurationResource (JAXB) <JAXBReading, JAXBWriting, JAXBType>

@end /*interface NEXUS_REST_APINS0GlobalConfigurationResource (JAXB)*/

/**
 * Internal, private implementation for JAXB reading and writing.
 */
@implementation NEXUS_REST_APINS0GlobalConfigurationResource (JAXB)

/**
 * Read an instance of NEXUS_REST_APINS0GlobalConfigurationResource from an XML reader.
 *
 * @param reader The reader.
 * @return An instance of NEXUS_REST_APINS0GlobalConfigurationResource defined by the XML reader.
 */
+ (id<JAXBType>) readXMLType: (xmlTextReaderPtr) reader
{
  NEXUS_REST_APINS0GlobalConfigurationResource *_nEXUS_REST_APINS0GlobalConfigurationResource = [[NEXUS_REST_APINS0GlobalConfigurationResource alloc] init];
  NS_DURING
  {
    [_nEXUS_REST_APINS0GlobalConfigurationResource initWithReader: reader];
  }
  NS_HANDLER
  {
    [_nEXUS_REST_APINS0GlobalConfigurationResource dealloc];
    _nEXUS_REST_APINS0GlobalConfigurationResource = nil;
    [localException raise];
  }
  NS_ENDHANDLER

  [_nEXUS_REST_APINS0GlobalConfigurationResource autorelease];
  return _nEXUS_REST_APINS0GlobalConfigurationResource;
}

/**
 * Initialize this instance of NEXUS_REST_APINS0GlobalConfigurationResource according to
 * the XML being read from the reader.
 *
 * @param reader The reader.
 */
- (id) initWithReader: (xmlTextReaderPtr) reader
{
  return [super initWithReader: reader];
}

/**
 * Write the XML for this instance of NEXUS_REST_APINS0GlobalConfigurationResource to the writer.
 * Note that since we're only writing the XML type,
 * No start/end element will be written.
 *
 * @param reader The reader.
 */
- (void) writeXMLType: (xmlTextWriterPtr) writer
{
  [super writeXMLType:writer];
}

//documentation inherited.
- (BOOL) readJAXBAttribute: (xmlTextReaderPtr) reader
{
  void *_child_accessor;

  if ([super readJAXBAttribute: reader]) {
    return YES;
  }

  return NO;
}

//documentation inherited.
- (BOOL) readJAXBValue: (xmlTextReaderPtr) reader
{
  return [super readJAXBValue: reader];
}

//documentation inherited.
- (BOOL) readJAXBChildElement: (xmlTextReaderPtr) reader
{
  id __child;
  void *_child_accessor;
  int status, depth;

  if ([super readJAXBChildElement: reader]) {
    return YES;
  }

  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "securityEnabled", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

    _child_accessor = xmlTextReaderReadBooleanType(reader);
    if (_child_accessor == NULL) {
      //panic: unable to return the value for some reason.
      [self dealloc];
      [NSException raise: @"XMLReadError"
                   format: @"Error reading element value."];
    }
    [self setSecurityEnabled: *((BOOL*) _child_accessor)];
    free(_child_accessor);
    return YES;
  }

  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "securityAnonymousAccessEnabled", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

    _child_accessor = xmlTextReaderReadBooleanType(reader);
    if (_child_accessor == NULL) {
      //panic: unable to return the value for some reason.
      [self dealloc];
      [NSException raise: @"XMLReadError"
                   format: @"Error reading element value."];
    }
    [self setSecurityAnonymousAccessEnabled: *((BOOL*) _child_accessor)];
    free(_child_accessor);
    return YES;
  }
  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "securityAnonymousUsername", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}securityAnonymousUsername of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}securityAnonymousUsername of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setSecurityAnonymousUsername: __child];
    return YES;
  } //end "if choice"

  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "securityAnonymousPassword", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}securityAnonymousPassword of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}securityAnonymousPassword of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setSecurityAnonymousPassword: __child];
    return YES;
  } //end "if choice"

  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "securityRealms", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

    if (xmlTextReaderIsEmptyElement(reader) == 0) {
#if DEBUG_ENUNCIATE > 1
      NSLog(@"Unwrapping wrapper element {}securityRealms...");
#endif
      //start wrapper element "{}securityRealms"
      depth = xmlTextReaderDepth(reader);
      status = xmlTextReaderAdvanceToNextStartOrEndElement(reader);
      while (xmlTextReaderDepth(reader) > depth) {
        if (status < 1) {
          //panic: XML read error.
          [self dealloc];
          [NSException raise: @"XMLReadError"
                       format: @"Failure to advance to next wrapped child element."];
        }
  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "securityRealmItem", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}securityRealmItem of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}securityRealmItem of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    if ([self securityRealms]) {
      [self setSecurityRealms: [[self securityRealms] arrayByAddingObject: __child]];
    }
    else {
      [self setSecurityRealms: [NSArray arrayWithObject: __child]];
    }
    continue; //continue "while in wrapper element" loop
  } //end "if choice"

        status = xmlTextReaderAdvanceToNextStartOrEndElement(reader);
#if DEBUG_ENUNCIATE > 1
        NSLog(@"successfully unwrapped wrapper element {}securityRealms...");
#endif
      } // end "while in wrapper element" loop

      if (status < 1) {
        //panic: XML read error.
        [self dealloc];
        [NSException raise: @"XMLReadError"
                     format: @"Failure to advance to end wrapper element."];
      }
      else {
        //end wrapper element "{}securityRealms"
        status = xmlTextReaderAdvanceToNextStartOrEndElement(reader);
      }
    } //end "if empty element" clause
    else {
      __child = [NSArray array];
      [self setSecurityRealms: (NSArray*) __child];
    }

    return YES;
  } // end "if wrapper element" clause
  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "globalConnectionSettings", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}globalConnectionSettings of type {}remote-connection-settings.");
#endif
    __child = [NEXUS_REST_APINS0RemoteConnectionSettings readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}globalConnectionSettings of type {}remote-connection-settings.");
#endif

    [self setGlobalConnectionSettings: __child];
    return YES;
  } //end "if choice"

  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "systemNotificationSettings", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}systemNotificationSettings of type {}system-notification-settings.");
#endif
    __child = [NEXUS_REST_APINS0SystemNotificationSettings readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}systemNotificationSettings of type {}system-notification-settings.");
#endif

    [self setSystemNotificationSettings: __child];
    return YES;
  } //end "if choice"

  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "smtpSettings", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}smtpSettings of type {}smtp-settings.");
#endif
    __child = [NEXUS_REST_APINS0SmtpSettings readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}smtpSettings of type {}smtp-settings.");
#endif

    [self setSmtpSettings: __child];
    return YES;
  } //end "if choice"

  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "globalHttpProxySettings", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}globalHttpProxySettings of type {}remote-http-proxy-settings.");
#endif
    __child = [NEXUS_REST_APINS0RemoteHttpProxySettings readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}globalHttpProxySettings of type {}remote-http-proxy-settings.");
#endif

    [self setGlobalHttpProxySettings: __child];
    return YES;
  } //end "if choice"

  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "globalRestApiSettings", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}globalRestApiSettings of type {}rest-api-settings.");
#endif
    __child = [NEXUS_REST_APINS0RestApiSettings readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}globalRestApiSettings of type {}rest-api-settings.");
#endif

    [self setGlobalRestApiSettings: __child];
    return YES;
  } //end "if choice"

  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "errorReportingSettings", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}errorReportingSettings of type {}error-reporting-settings.");
#endif
    __child = [NEXUS_REST_APINS0ErrorReportingSettings readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}errorReportingSettings of type {}error-reporting-settings.");
#endif

    [self setErrorReportingSettings: __child];
    return YES;
  } //end "if choice"


  return NO;
}

//documentation inherited.
- (int) readUnknownJAXBChildElement: (xmlTextReaderPtr) reader
{
  return [super readUnknownJAXBChildElement: reader];
}

//documentation inherited.
- (void) readUnknownJAXBAttribute: (xmlTextReaderPtr) reader
{
  [super readUnknownJAXBAttribute: reader];
}

//documentation inherited.
- (void) writeJAXBAttributes: (xmlTextWriterPtr) writer
{
  int status;

  [super writeJAXBAttributes: writer];

}

//documentation inherited.
- (void) writeJAXBValue: (xmlTextWriterPtr) writer
{
  [super writeJAXBValue: writer];
}

/**
 * Method for writing the child elements.
 *
 * @param writer The writer.
 */
- (void) writeJAXBChildElements: (xmlTextWriterPtr) writer
{
  int status;
  id __item;
  NSEnumerator *__enumerator;

  [super writeJAXBChildElements: writer];

  if (YES) { //always write the primitive element...
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "securityEnabled", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}securityEnabled."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}securityEnabled...");
#endif
    status = xmlTextWriterWriteBooleanType(writer, &_securityEnabled);
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}securityEnabled...");
#endif
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing child element {}securityEnabled."];
    }

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}securityEnabled."];
    }
  }
  if (YES) { //always write the primitive element...
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "securityAnonymousAccessEnabled", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}securityAnonymousAccessEnabled."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}securityAnonymousAccessEnabled...");
#endif
    status = xmlTextWriterWriteBooleanType(writer, &_securityAnonymousAccessEnabled);
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}securityAnonymousAccessEnabled...");
#endif
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing child element {}securityAnonymousAccessEnabled."];
    }

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}securityAnonymousAccessEnabled."];
    }
  }
  if ([self securityAnonymousUsername]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "securityAnonymousUsername", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}securityAnonymousUsername."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}securityAnonymousUsername...");
#endif
    [[self securityAnonymousUsername] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}securityAnonymousUsername...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}securityAnonymousUsername."];
    }
  }
  if ([self securityAnonymousPassword]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "securityAnonymousPassword", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}securityAnonymousPassword."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}securityAnonymousPassword...");
#endif
    [[self securityAnonymousPassword] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}securityAnonymousPassword...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}securityAnonymousPassword."];
    }
  }
  if ([self securityRealms]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "securityRealms", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start wrapper element {}securityRealms."];
    }
    __enumerator = [[self securityRealms] objectEnumerator];

    while ( (__item = [__enumerator nextObject]) ) {
      status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "securityRealmItem", NULL);
      if (status < 0) {
        [NSException raise: @"XMLWriteError"
                     format: @"Error writing start child element {}securityRealmItem."];
      }

#if DEBUG_ENUNCIATE > 1
      NSLog(@"writing element {}securityRealmItem...");
#endif
      [__item writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
      NSLog(@"successfully wrote element {}securityRealmItem...");
#endif

      status = xmlTextWriterEndElement(writer);
      if (status < 0) {
        [NSException raise: @"XMLWriteError"
                     format: @"Error writing end child element {}securityRealmItem."];
      }
    } //end item iterator.

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end wrapper element {}securityRealms."];
    }
  }
  if ([self globalConnectionSettings]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "globalConnectionSettings", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}globalConnectionSettings."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}globalConnectionSettings...");
#endif
    [[self globalConnectionSettings] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}globalConnectionSettings...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}globalConnectionSettings."];
    }
  }
  if ([self systemNotificationSettings]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "systemNotificationSettings", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}systemNotificationSettings."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}systemNotificationSettings...");
#endif
    [[self systemNotificationSettings] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}systemNotificationSettings...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}systemNotificationSettings."];
    }
  }
  if ([self smtpSettings]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "smtpSettings", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}smtpSettings."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}smtpSettings...");
#endif
    [[self smtpSettings] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}smtpSettings...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}smtpSettings."];
    }
  }
  if ([self globalHttpProxySettings]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "globalHttpProxySettings", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}globalHttpProxySettings."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}globalHttpProxySettings...");
#endif
    [[self globalHttpProxySettings] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}globalHttpProxySettings...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}globalHttpProxySettings."];
    }
  }
  if ([self globalRestApiSettings]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "globalRestApiSettings", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}globalRestApiSettings."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}globalRestApiSettings...");
#endif
    [[self globalRestApiSettings] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}globalRestApiSettings...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}globalRestApiSettings."];
    }
  }
  if ([self errorReportingSettings]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "errorReportingSettings", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}errorReportingSettings."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}errorReportingSettings...");
#endif
    [[self errorReportingSettings] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}errorReportingSettings...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}errorReportingSettings."];
    }
  }
}
@end /* implementation NEXUS_REST_APINS0GlobalConfigurationResource (JAXB) */

#endif /* DEF_NEXUS_REST_APINS0GlobalConfigurationResource_M */
#ifndef DEF_NEXUS_REST_APINS0LogConfigResource_M
#define DEF_NEXUS_REST_APINS0LogConfigResource_M

/**
 *  Set of parameters that describe how logging is configured.
 
 @version $Revision$ $Date$

 */
@implementation NEXUS_REST_APINS0LogConfigResource

/**
 * The root logger level (i.e. DEBUG, INFO, etc.).
 */
- (NSString *) rootLoggerLevel
{
  return _rootLoggerLevel;
}

/**
 * The root logger level (i.e. DEBUG, INFO, etc.).
 */
- (void) setRootLoggerLevel: (NSString *) newRootLoggerLevel
{
  [newRootLoggerLevel retain];
  [_rootLoggerLevel release];
  _rootLoggerLevel = newRootLoggerLevel;
}

/**
 * The appenders that the root logger will use.
 */
- (NSString *) rootLoggerAppenders
{
  return _rootLoggerAppenders;
}

/**
 * The appenders that the root logger will use.
 */
- (void) setRootLoggerAppenders: (NSString *) newRootLoggerAppenders
{
  [newRootLoggerAppenders retain];
  [_rootLoggerAppenders release];
  _rootLoggerAppenders = newRootLoggerAppenders;
}

/**
 * Where the file will be stored.
 */
- (NSString *) fileAppenderLocation
{
  return _fileAppenderLocation;
}

/**
 * Where the file will be stored.
 */
- (void) setFileAppenderLocation: (NSString *) newFileAppenderLocation
{
  [newFileAppenderLocation retain];
  [_fileAppenderLocation release];
  _fileAppenderLocation = newFileAppenderLocation;
}

/**
 * The pattern used to write to the file.
 */
- (NSString *) fileAppenderPattern
{
  return _fileAppenderPattern;
}

/**
 * The pattern used to write to the file.
 */
- (void) setFileAppenderPattern: (NSString *) newFileAppenderPattern
{
  [newFileAppenderPattern retain];
  [_fileAppenderPattern release];
  _fileAppenderPattern = newFileAppenderPattern;
}

- (void) dealloc
{
  [self setRootLoggerLevel: nil];
  [self setRootLoggerAppenders: nil];
  [self setFileAppenderLocation: nil];
  [self setFileAppenderPattern: nil];
  [super dealloc];
}
@end /* implementation NEXUS_REST_APINS0LogConfigResource */

/**
 * Internal, private interface for JAXB reading and writing.
 */
@interface NEXUS_REST_APINS0LogConfigResource (JAXB) <JAXBReading, JAXBWriting, JAXBType>

@end /*interface NEXUS_REST_APINS0LogConfigResource (JAXB)*/

/**
 * Internal, private implementation for JAXB reading and writing.
 */
@implementation NEXUS_REST_APINS0LogConfigResource (JAXB)

/**
 * Read an instance of NEXUS_REST_APINS0LogConfigResource from an XML reader.
 *
 * @param reader The reader.
 * @return An instance of NEXUS_REST_APINS0LogConfigResource defined by the XML reader.
 */
+ (id<JAXBType>) readXMLType: (xmlTextReaderPtr) reader
{
  NEXUS_REST_APINS0LogConfigResource *_nEXUS_REST_APINS0LogConfigResource = [[NEXUS_REST_APINS0LogConfigResource alloc] init];
  NS_DURING
  {
    [_nEXUS_REST_APINS0LogConfigResource initWithReader: reader];
  }
  NS_HANDLER
  {
    [_nEXUS_REST_APINS0LogConfigResource dealloc];
    _nEXUS_REST_APINS0LogConfigResource = nil;
    [localException raise];
  }
  NS_ENDHANDLER

  [_nEXUS_REST_APINS0LogConfigResource autorelease];
  return _nEXUS_REST_APINS0LogConfigResource;
}

/**
 * Initialize this instance of NEXUS_REST_APINS0LogConfigResource according to
 * the XML being read from the reader.
 *
 * @param reader The reader.
 */
- (id) initWithReader: (xmlTextReaderPtr) reader
{
  return [super initWithReader: reader];
}

/**
 * Write the XML for this instance of NEXUS_REST_APINS0LogConfigResource to the writer.
 * Note that since we're only writing the XML type,
 * No start/end element will be written.
 *
 * @param reader The reader.
 */
- (void) writeXMLType: (xmlTextWriterPtr) writer
{
  [super writeXMLType:writer];
}

//documentation inherited.
- (BOOL) readJAXBAttribute: (xmlTextReaderPtr) reader
{
  void *_child_accessor;

  if ([super readJAXBAttribute: reader]) {
    return YES;
  }

  return NO;
}

//documentation inherited.
- (BOOL) readJAXBValue: (xmlTextReaderPtr) reader
{
  return [super readJAXBValue: reader];
}

//documentation inherited.
- (BOOL) readJAXBChildElement: (xmlTextReaderPtr) reader
{
  id __child;
  void *_child_accessor;
  int status, depth;

  if ([super readJAXBChildElement: reader]) {
    return YES;
  }
  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "rootLoggerLevel", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}rootLoggerLevel of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}rootLoggerLevel of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setRootLoggerLevel: __child];
    return YES;
  } //end "if choice"

  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "rootLoggerAppenders", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}rootLoggerAppenders of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}rootLoggerAppenders of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setRootLoggerAppenders: __child];
    return YES;
  } //end "if choice"

  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "fileAppenderLocation", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}fileAppenderLocation of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}fileAppenderLocation of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setFileAppenderLocation: __child];
    return YES;
  } //end "if choice"

  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "fileAppenderPattern", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}fileAppenderPattern of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}fileAppenderPattern of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setFileAppenderPattern: __child];
    return YES;
  } //end "if choice"


  return NO;
}

//documentation inherited.
- (int) readUnknownJAXBChildElement: (xmlTextReaderPtr) reader
{
  return [super readUnknownJAXBChildElement: reader];
}

//documentation inherited.
- (void) readUnknownJAXBAttribute: (xmlTextReaderPtr) reader
{
  [super readUnknownJAXBAttribute: reader];
}

//documentation inherited.
- (void) writeJAXBAttributes: (xmlTextWriterPtr) writer
{
  int status;

  [super writeJAXBAttributes: writer];

}

//documentation inherited.
- (void) writeJAXBValue: (xmlTextWriterPtr) writer
{
  [super writeJAXBValue: writer];
}

/**
 * Method for writing the child elements.
 *
 * @param writer The writer.
 */
- (void) writeJAXBChildElements: (xmlTextWriterPtr) writer
{
  int status;
  id __item;
  NSEnumerator *__enumerator;

  [super writeJAXBChildElements: writer];

  if ([self rootLoggerLevel]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "rootLoggerLevel", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}rootLoggerLevel."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}rootLoggerLevel...");
#endif
    [[self rootLoggerLevel] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}rootLoggerLevel...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}rootLoggerLevel."];
    }
  }
  if ([self rootLoggerAppenders]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "rootLoggerAppenders", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}rootLoggerAppenders."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}rootLoggerAppenders...");
#endif
    [[self rootLoggerAppenders] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}rootLoggerAppenders...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}rootLoggerAppenders."];
    }
  }
  if ([self fileAppenderLocation]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "fileAppenderLocation", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}fileAppenderLocation."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}fileAppenderLocation...");
#endif
    [[self fileAppenderLocation] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}fileAppenderLocation...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}fileAppenderLocation."];
    }
  }
  if ([self fileAppenderPattern]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "fileAppenderPattern", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}fileAppenderPattern."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}fileAppenderPattern...");
#endif
    [[self fileAppenderPattern] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}fileAppenderPattern...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}fileAppenderPattern."];
    }
  }
}
@end /* implementation NEXUS_REST_APINS0LogConfigResource (JAXB) */

#endif /* DEF_NEXUS_REST_APINS0LogConfigResource_M */
#ifndef DEF_NEXUS_REST_APINS0LogsListResource_M
#define DEF_NEXUS_REST_APINS0LogsListResource_M

/**
 *  Details to retrieve a log file from the Nexus server.
 
 @version $Revision$ $Date$

 */
@implementation NEXUS_REST_APINS0LogsListResource

/**
 * The url that can be GET requested to retrieve the log file
content.
 */
- (NSString *) resourceURI
{
  return _resourceURI;
}

/**
 * The url that can be GET requested to retrieve the log file
content.
 */
- (void) setResourceURI: (NSString *) newResourceURI
{
  [newResourceURI retain];
  [_resourceURI release];
  _resourceURI = newResourceURI;
}

/**
 * The name of the file.
 */
- (NSString *) name
{
  return _name;
}

/**
 * The name of the file.
 */
- (void) setName: (NSString *) newName
{
  [newName retain];
  [_name release];
  _name = newName;
}

/**
 * The size of the file.
 */
- (long) size
{
  return _size;
}

/**
 * The size of the file.
 */
- (void) setSize: (long) newSize
{
  _size = newSize;
}

/**
 * MIME type of the file.
 */
- (NSString *) mimeType
{
  return _mimeType;
}

/**
 * MIME type of the file.
 */
- (void) setMimeType: (NSString *) newMimeType
{
  [newMimeType retain];
  [_mimeType release];
  _mimeType = newMimeType;
}

- (void) dealloc
{
  [self setResourceURI: nil];
  [self setName: nil];
  [self setMimeType: nil];
  [super dealloc];
}
@end /* implementation NEXUS_REST_APINS0LogsListResource */

/**
 * Internal, private interface for JAXB reading and writing.
 */
@interface NEXUS_REST_APINS0LogsListResource (JAXB) <JAXBReading, JAXBWriting, JAXBType>

@end /*interface NEXUS_REST_APINS0LogsListResource (JAXB)*/

/**
 * Internal, private implementation for JAXB reading and writing.
 */
@implementation NEXUS_REST_APINS0LogsListResource (JAXB)

/**
 * Read an instance of NEXUS_REST_APINS0LogsListResource from an XML reader.
 *
 * @param reader The reader.
 * @return An instance of NEXUS_REST_APINS0LogsListResource defined by the XML reader.
 */
+ (id<JAXBType>) readXMLType: (xmlTextReaderPtr) reader
{
  NEXUS_REST_APINS0LogsListResource *_nEXUS_REST_APINS0LogsListResource = [[NEXUS_REST_APINS0LogsListResource alloc] init];
  NS_DURING
  {
    [_nEXUS_REST_APINS0LogsListResource initWithReader: reader];
  }
  NS_HANDLER
  {
    [_nEXUS_REST_APINS0LogsListResource dealloc];
    _nEXUS_REST_APINS0LogsListResource = nil;
    [localException raise];
  }
  NS_ENDHANDLER

  [_nEXUS_REST_APINS0LogsListResource autorelease];
  return _nEXUS_REST_APINS0LogsListResource;
}

/**
 * Initialize this instance of NEXUS_REST_APINS0LogsListResource according to
 * the XML being read from the reader.
 *
 * @param reader The reader.
 */
- (id) initWithReader: (xmlTextReaderPtr) reader
{
  return [super initWithReader: reader];
}

/**
 * Write the XML for this instance of NEXUS_REST_APINS0LogsListResource to the writer.
 * Note that since we're only writing the XML type,
 * No start/end element will be written.
 *
 * @param reader The reader.
 */
- (void) writeXMLType: (xmlTextWriterPtr) writer
{
  [super writeXMLType:writer];
}

//documentation inherited.
- (BOOL) readJAXBAttribute: (xmlTextReaderPtr) reader
{
  void *_child_accessor;

  if ([super readJAXBAttribute: reader]) {
    return YES;
  }

  return NO;
}

//documentation inherited.
- (BOOL) readJAXBValue: (xmlTextReaderPtr) reader
{
  return [super readJAXBValue: reader];
}

//documentation inherited.
- (BOOL) readJAXBChildElement: (xmlTextReaderPtr) reader
{
  id __child;
  void *_child_accessor;
  int status, depth;

  if ([super readJAXBChildElement: reader]) {
    return YES;
  }
  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "resourceURI", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}resourceURI of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}resourceURI of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setResourceURI: __child];
    return YES;
  } //end "if choice"

  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "name", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}name of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}name of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setName: __child];
    return YES;
  } //end "if choice"


  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "size", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

    _child_accessor = xmlTextReaderReadLongType(reader);
    if (_child_accessor == NULL) {
      //panic: unable to return the value for some reason.
      [self dealloc];
      [NSException raise: @"XMLReadError"
                   format: @"Error reading element value."];
    }
    [self setSize: *((long*) _child_accessor)];
    free(_child_accessor);
    return YES;
  }
  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "mimeType", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}mimeType of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}mimeType of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setMimeType: __child];
    return YES;
  } //end "if choice"


  return NO;
}

//documentation inherited.
- (int) readUnknownJAXBChildElement: (xmlTextReaderPtr) reader
{
  return [super readUnknownJAXBChildElement: reader];
}

//documentation inherited.
- (void) readUnknownJAXBAttribute: (xmlTextReaderPtr) reader
{
  [super readUnknownJAXBAttribute: reader];
}

//documentation inherited.
- (void) writeJAXBAttributes: (xmlTextWriterPtr) writer
{
  int status;

  [super writeJAXBAttributes: writer];

}

//documentation inherited.
- (void) writeJAXBValue: (xmlTextWriterPtr) writer
{
  [super writeJAXBValue: writer];
}

/**
 * Method for writing the child elements.
 *
 * @param writer The writer.
 */
- (void) writeJAXBChildElements: (xmlTextWriterPtr) writer
{
  int status;
  id __item;
  NSEnumerator *__enumerator;

  [super writeJAXBChildElements: writer];

  if ([self resourceURI]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "resourceURI", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}resourceURI."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}resourceURI...");
#endif
    [[self resourceURI] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}resourceURI...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}resourceURI."];
    }
  }
  if ([self name]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "name", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}name."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}name...");
#endif
    [[self name] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}name...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}name."];
    }
  }
  if (YES) { //always write the primitive element...
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "size", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}size."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}size...");
#endif
    status = xmlTextWriterWriteLongType(writer, &_size);
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}size...");
#endif
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing child element {}size."];
    }

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}size."];
    }
  }
  if ([self mimeType]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "mimeType", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}mimeType."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}mimeType...");
#endif
    [[self mimeType] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}mimeType...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}mimeType."];
    }
  }
}
@end /* implementation NEXUS_REST_APINS0LogsListResource (JAXB) */

#endif /* DEF_NEXUS_REST_APINS0LogsListResource_M */
#ifndef DEF_NEXUS_REST_APINS0Maven2ArtifactInfoResourceRespose_M
#define DEF_NEXUS_REST_APINS0Maven2ArtifactInfoResourceRespose_M

/**
 *  REST Response object for maven 2 artifact info view.
 
 @version $Revision$ $Date$

 */
@implementation NEXUS_REST_APINS0Maven2ArtifactInfoResourceRespose

/**
 * Maven 2 info.
 */
- (NEXUS_REST_APINS0Maven2ArtifactInfoResource *) data
{
  return _data;
}

/**
 * Maven 2 info.
 */
- (void) setData: (NEXUS_REST_APINS0Maven2ArtifactInfoResource *) newData
{
  [newData retain];
  [_data release];
  _data = newData;
}

- (void) dealloc
{
  [self setData: nil];
  [super dealloc];
}

//documentation inherited.
+ (id<EnunciateXML>) readFromXML: (NSData *) xml
{
  NEXUS_REST_APINS0Maven2ArtifactInfoResourceRespose *_nEXUS_REST_APINS0Maven2ArtifactInfoResourceRespose;
  xmlTextReaderPtr reader = xmlReaderForMemory([xml bytes], [xml length], NULL, NULL, 0);
  if (reader == NULL) {
    [NSException raise: @"XMLReadError"
                 format: @"Error instantiating an XML reader."];
    return nil;
  }

  _nEXUS_REST_APINS0Maven2ArtifactInfoResourceRespose = (NEXUS_REST_APINS0Maven2ArtifactInfoResourceRespose *) [NEXUS_REST_APINS0Maven2ArtifactInfoResourceRespose readXMLElement: reader];
  xmlFreeTextReader(reader); //free the reader
  return _nEXUS_REST_APINS0Maven2ArtifactInfoResourceRespose;
}

//documentation inherited.
- (NSData *) writeToXML
{
  xmlBufferPtr buf;
  xmlTextWriterPtr writer;
  int rc;
  NSData *data;

  buf = xmlBufferCreate();
  if (buf == NULL) {
    [NSException raise: @"XMLWriteError"
                 format: @"Error creating an XML buffer."];
    return nil;
  }

  writer = xmlNewTextWriterMemory(buf, 0);
  if (writer == NULL) {
    xmlBufferFree(buf);
    [NSException raise: @"XMLWriteError"
                 format: @"Error creating an XML writer."];
    return nil;
  }

  rc = xmlTextWriterStartDocument(writer, NULL, "utf-8", NULL);
  if (rc < 0) {
    xmlFreeTextWriter(writer);
    xmlBufferFree(buf);
    [NSException raise: @"XMLWriteError"
                 format: @"Error writing XML start document."];
    return nil;
  }

  NS_DURING
  {
    [self writeXMLElement: writer];
  }
  NS_HANDLER
  {
    xmlFreeTextWriter(writer);
    xmlBufferFree(buf);
    [localException raise];
  }
  NS_ENDHANDLER

  rc = xmlTextWriterEndDocument(writer);
  if (rc < 0) {
    xmlFreeTextWriter(writer);
    xmlBufferFree(buf);
    [NSException raise: @"XMLWriteError"
                 format: @"Error writing XML end document."];
    return nil;
  }

  xmlFreeTextWriter(writer);
  data = [NSData dataWithBytes: buf->content length: buf->use];
  xmlBufferFree(buf);
  return data;
}
@end /* implementation NEXUS_REST_APINS0Maven2ArtifactInfoResourceRespose */

/**
 * Internal, private interface for JAXB reading and writing.
 */
@interface NEXUS_REST_APINS0Maven2ArtifactInfoResourceRespose (JAXB) <JAXBReading, JAXBWriting, JAXBType, JAXBElement>

@end /*interface NEXUS_REST_APINS0Maven2ArtifactInfoResourceRespose (JAXB)*/

/**
 * Internal, private implementation for JAXB reading and writing.
 */
@implementation NEXUS_REST_APINS0Maven2ArtifactInfoResourceRespose (JAXB)

/**
 * Read an instance of NEXUS_REST_APINS0Maven2ArtifactInfoResourceRespose from an XML reader.
 *
 * @param reader The reader.
 * @return An instance of NEXUS_REST_APINS0Maven2ArtifactInfoResourceRespose defined by the XML reader.
 */
+ (id<JAXBType>) readXMLType: (xmlTextReaderPtr) reader
{
  NEXUS_REST_APINS0Maven2ArtifactInfoResourceRespose *_nEXUS_REST_APINS0Maven2ArtifactInfoResourceRespose = [[NEXUS_REST_APINS0Maven2ArtifactInfoResourceRespose alloc] init];
  NS_DURING
  {
    [_nEXUS_REST_APINS0Maven2ArtifactInfoResourceRespose initWithReader: reader];
  }
  NS_HANDLER
  {
    [_nEXUS_REST_APINS0Maven2ArtifactInfoResourceRespose dealloc];
    _nEXUS_REST_APINS0Maven2ArtifactInfoResourceRespose = nil;
    [localException raise];
  }
  NS_ENDHANDLER

  [_nEXUS_REST_APINS0Maven2ArtifactInfoResourceRespose autorelease];
  return _nEXUS_REST_APINS0Maven2ArtifactInfoResourceRespose;
}

/**
 * Initialize this instance of NEXUS_REST_APINS0Maven2ArtifactInfoResourceRespose according to
 * the XML being read from the reader.
 *
 * @param reader The reader.
 */
- (id) initWithReader: (xmlTextReaderPtr) reader
{
  return [super initWithReader: reader];
}

/**
 * Write the XML for this instance of NEXUS_REST_APINS0Maven2ArtifactInfoResourceRespose to the writer.
 * Note that since we're only writing the XML type,
 * No start/end element will be written.
 *
 * @param reader The reader.
 */
- (void) writeXMLType: (xmlTextWriterPtr) writer
{
  [super writeXMLType:writer];
}

/**
 * Reads a NEXUS_REST_APINS0Maven2ArtifactInfoResourceRespose from an XML reader. The element to be read is
 * "maven2-info".
 *
 * @param reader The XML reader.
 * @return The NEXUS_REST_APINS0Maven2ArtifactInfoResourceRespose.
 */
+ (id<JAXBElement>) readXMLElement: (xmlTextReaderPtr) reader {
  int status;
  NEXUS_REST_APINS0Maven2ArtifactInfoResourceRespose *_maven2ArtifactInfoResourceRespose = nil;

  if (xmlTextReaderNodeType(reader) != XML_READER_TYPE_ELEMENT) {
    status = xmlTextReaderAdvanceToNextStartOrEndElement(reader);
    if (status < 1) {
      [NSException raise: @"XMLReadError"
                   format: @"Error advancing the reader to start element maven2-info."];
    }
  }

  if (xmlStrcmp(BAD_CAST "maven2-info", xmlTextReaderConstLocalName(reader)) == 0
      && xmlTextReaderConstNamespaceUri(reader) == NULL) {
#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read root element {}maven2-info.");
#endif
    _maven2ArtifactInfoResourceRespose = (NEXUS_REST_APINS0Maven2ArtifactInfoResourceRespose *)[NEXUS_REST_APINS0Maven2ArtifactInfoResourceRespose readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"Successfully read root element {}maven2-info.");
#endif
  }
  else {
    if (xmlTextReaderConstNamespaceUri(reader) == NULL) {
      [NSException raise: @"XMLReadError"
                   format: @"Unable to read NEXUS_REST_APINS0Maven2ArtifactInfoResourceRespose. Expected element maven2-info. Current element: {}%s", xmlTextReaderConstLocalName(reader)];
    }
    else {
      [NSException raise: @"XMLReadError"
                   format: @"Unable to read NEXUS_REST_APINS0Maven2ArtifactInfoResourceRespose. Expected element maven2-info. Current element: {%s}%s\n", xmlTextReaderConstNamespaceUri(reader), xmlTextReaderConstLocalName(reader)];
    }
  }

  return _maven2ArtifactInfoResourceRespose;
}

/**
 * Writes this NEXUS_REST_APINS0Maven2ArtifactInfoResourceRespose to XML under element name "maven2-info".
 * The namespace declarations for the element will be written.
 *
 * @param writer The XML writer.
 * @param _maven2ArtifactInfoResourceRespose The Maven2ArtifactInfoResourceRespose to write.
 * @return 1 if successful, 0 otherwise.
 */
- (void) writeXMLElement: (xmlTextWriterPtr) writer
{
  [self writeXMLElement: writer writeNamespaces: YES];
}

/**
 * Writes this NEXUS_REST_APINS0Maven2ArtifactInfoResourceRespose to an XML writer.
 *
 * @param writer The writer.
 * @param writeNs Whether to write the namespaces for this element to the xml writer.
 */
- (void) writeXMLElement: (xmlTextWriterPtr) writer writeNamespaces: (BOOL) writeNs
{
  int rc = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "maven2-info", NULL);
  if (rc < 0) {
    [NSException raise: @"XMLWriteError"
                 format: @"Error writing start element {}maven2-info. XML writer status: %i\n", rc];
  }

#if DEBUG_ENUNCIATE > 1
  NSLog(@"writing type {}maven2ArtifactInfoResourceRespose for root element {}maven2-info...");
#endif
  [self writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
  NSLog(@"successfully wrote type {}maven2ArtifactInfoResourceRespose for root element {}maven2-info...");
#endif
  rc = xmlTextWriterEndElement(writer);
  if (rc < 0) {
    [NSException raise: @"XMLWriteError"
                 format: @"Error writing end element {}maven2-info. XML writer status: %i\n", rc];
  }
}

//documentation inherited.
- (BOOL) readJAXBAttribute: (xmlTextReaderPtr) reader
{
  void *_child_accessor;

  if ([super readJAXBAttribute: reader]) {
    return YES;
  }

  return NO;
}

//documentation inherited.
- (BOOL) readJAXBValue: (xmlTextReaderPtr) reader
{
  return [super readJAXBValue: reader];
}

//documentation inherited.
- (BOOL) readJAXBChildElement: (xmlTextReaderPtr) reader
{
  id __child;
  void *_child_accessor;
  int status, depth;

  if ([super readJAXBChildElement: reader]) {
    return YES;
  }
  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "data", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}data of type {}maven2-info.");
#endif
    __child = [NEXUS_REST_APINS0Maven2ArtifactInfoResource readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}data of type {}maven2-info.");
#endif

    [self setData: __child];
    return YES;
  } //end "if choice"


  return NO;
}

//documentation inherited.
- (int) readUnknownJAXBChildElement: (xmlTextReaderPtr) reader
{
  return [super readUnknownJAXBChildElement: reader];
}

//documentation inherited.
- (void) readUnknownJAXBAttribute: (xmlTextReaderPtr) reader
{
  [super readUnknownJAXBAttribute: reader];
}

//documentation inherited.
- (void) writeJAXBAttributes: (xmlTextWriterPtr) writer
{
  int status;

  [super writeJAXBAttributes: writer];

}

//documentation inherited.
- (void) writeJAXBValue: (xmlTextWriterPtr) writer
{
  [super writeJAXBValue: writer];
}

/**
 * Method for writing the child elements.
 *
 * @param writer The writer.
 */
- (void) writeJAXBChildElements: (xmlTextWriterPtr) writer
{
  int status;
  id __item;
  NSEnumerator *__enumerator;

  [super writeJAXBChildElements: writer];

  if ([self data]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "data", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}data."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}data...");
#endif
    [[self data] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}data...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}data."];
    }
  }
}
@end /* implementation NEXUS_REST_APINS0Maven2ArtifactInfoResourceRespose (JAXB) */

#endif /* DEF_NEXUS_REST_APINS0Maven2ArtifactInfoResourceRespose_M */
#ifndef DEF_NEXUS_REST_APINS0MirrorResource_M
#define DEF_NEXUS_REST_APINS0MirrorResource_M

/**
 *  Repository mirror configuration.
 
 @version $Revision$ $Date$

 */
@implementation NEXUS_REST_APINS0MirrorResource

/**
 * The id of the repository mirror.
 */
- (NSString *) id
{
  return _id;
}

/**
 * The id of the repository mirror.
 */
- (void) setId: (NSString *) newId
{
  [newId retain];
  [_id release];
  _id = newId;
}

/**
 * The url of the repository mirror.
 */
- (NSString *) url
{
  return _url;
}

/**
 * The url of the repository mirror.
 */
- (void) setUrl: (NSString *) newUrl
{
  [newUrl retain];
  [_url release];
  _url = newUrl;
}

- (void) dealloc
{
  [self setId: nil];
  [self setUrl: nil];
  [super dealloc];
}
@end /* implementation NEXUS_REST_APINS0MirrorResource */

/**
 * Internal, private interface for JAXB reading and writing.
 */
@interface NEXUS_REST_APINS0MirrorResource (JAXB) <JAXBReading, JAXBWriting, JAXBType>

@end /*interface NEXUS_REST_APINS0MirrorResource (JAXB)*/

/**
 * Internal, private implementation for JAXB reading and writing.
 */
@implementation NEXUS_REST_APINS0MirrorResource (JAXB)

/**
 * Read an instance of NEXUS_REST_APINS0MirrorResource from an XML reader.
 *
 * @param reader The reader.
 * @return An instance of NEXUS_REST_APINS0MirrorResource defined by the XML reader.
 */
+ (id<JAXBType>) readXMLType: (xmlTextReaderPtr) reader
{
  NEXUS_REST_APINS0MirrorResource *_nEXUS_REST_APINS0MirrorResource = [[NEXUS_REST_APINS0MirrorResource alloc] init];
  NS_DURING
  {
    [_nEXUS_REST_APINS0MirrorResource initWithReader: reader];
  }
  NS_HANDLER
  {
    [_nEXUS_REST_APINS0MirrorResource dealloc];
    _nEXUS_REST_APINS0MirrorResource = nil;
    [localException raise];
  }
  NS_ENDHANDLER

  [_nEXUS_REST_APINS0MirrorResource autorelease];
  return _nEXUS_REST_APINS0MirrorResource;
}

/**
 * Initialize this instance of NEXUS_REST_APINS0MirrorResource according to
 * the XML being read from the reader.
 *
 * @param reader The reader.
 */
- (id) initWithReader: (xmlTextReaderPtr) reader
{
  return [super initWithReader: reader];
}

/**
 * Write the XML for this instance of NEXUS_REST_APINS0MirrorResource to the writer.
 * Note that since we're only writing the XML type,
 * No start/end element will be written.
 *
 * @param reader The reader.
 */
- (void) writeXMLType: (xmlTextWriterPtr) writer
{
  [super writeXMLType:writer];
}

//documentation inherited.
- (BOOL) readJAXBAttribute: (xmlTextReaderPtr) reader
{
  void *_child_accessor;

  if ([super readJAXBAttribute: reader]) {
    return YES;
  }

  return NO;
}

//documentation inherited.
- (BOOL) readJAXBValue: (xmlTextReaderPtr) reader
{
  return [super readJAXBValue: reader];
}

//documentation inherited.
- (BOOL) readJAXBChildElement: (xmlTextReaderPtr) reader
{
  id __child;
  void *_child_accessor;
  int status, depth;

  if ([super readJAXBChildElement: reader]) {
    return YES;
  }
  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "id", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}id of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}id of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setId: __child];
    return YES;
  } //end "if choice"

  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "url", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}url of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}url of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setUrl: __child];
    return YES;
  } //end "if choice"


  return NO;
}

//documentation inherited.
- (int) readUnknownJAXBChildElement: (xmlTextReaderPtr) reader
{
  return [super readUnknownJAXBChildElement: reader];
}

//documentation inherited.
- (void) readUnknownJAXBAttribute: (xmlTextReaderPtr) reader
{
  [super readUnknownJAXBAttribute: reader];
}

//documentation inherited.
- (void) writeJAXBAttributes: (xmlTextWriterPtr) writer
{
  int status;

  [super writeJAXBAttributes: writer];

}

//documentation inherited.
- (void) writeJAXBValue: (xmlTextWriterPtr) writer
{
  [super writeJAXBValue: writer];
}

/**
 * Method for writing the child elements.
 *
 * @param writer The writer.
 */
- (void) writeJAXBChildElements: (xmlTextWriterPtr) writer
{
  int status;
  id __item;
  NSEnumerator *__enumerator;

  [super writeJAXBChildElements: writer];

  if ([self id]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "id", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}id."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}id...");
#endif
    [[self id] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}id...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}id."];
    }
  }
  if ([self url]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "url", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}url."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}url...");
#endif
    [[self url] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}url...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}url."];
    }
  }
}
@end /* implementation NEXUS_REST_APINS0MirrorResource (JAXB) */

#endif /* DEF_NEXUS_REST_APINS0MirrorResource_M */
#ifndef DEF_NEXUS_REST_APINS0Maven2ArtifactInfoResource_M
#define DEF_NEXUS_REST_APINS0Maven2ArtifactInfoResource_M

/**
 *  Maven 2 Artifact Information.
 
 @version $Revision$ $Date$

 */
@implementation NEXUS_REST_APINS0Maven2ArtifactInfoResource

/**
 * Maven Group Id.
 */
- (NSString *) groupId
{
  return _groupId;
}

/**
 * Maven Group Id.
 */
- (void) setGroupId: (NSString *) newGroupId
{
  [newGroupId retain];
  [_groupId release];
  _groupId = newGroupId;
}

/**
 * Maven artifact Id.
 */
- (NSString *) artifactId
{
  return _artifactId;
}

/**
 * Maven artifact Id.
 */
- (void) setArtifactId: (NSString *) newArtifactId
{
  [newArtifactId retain];
  [_artifactId release];
  _artifactId = newArtifactId;
}

/**
 * Maven version.
 */
- (NSString *) version
{
  return _version;
}

/**
 * Maven version.
 */
- (void) setVersion: (NSString *) newVersion
{
  [newVersion retain];
  [_version release];
  _version = newVersion;
}

/**
 * Maven base version, i.e. the -SNAPSHOT version for snapshots.
 */
- (NSString *) baseVersion
{
  return _baseVersion;
}

/**
 * Maven base version, i.e. the -SNAPSHOT version for snapshots.
 */
- (void) setBaseVersion: (NSString *) newBaseVersion
{
  [newBaseVersion retain];
  [_baseVersion release];
  _baseVersion = newBaseVersion;
}

/**
 * Maven classifier.
 */
- (NSString *) classifier
{
  return _classifier;
}

/**
 * Maven classifier.
 */
- (void) setClassifier: (NSString *) newClassifier
{
  [newClassifier retain];
  [_classifier release];
  _classifier = newClassifier;
}

/**
 * Maven extention.
 */
- (NSString *) extension
{
  return _extension;
}

/**
 * Maven extention.
 */
- (void) setExtension: (NSString *) newExtension
{
  [newExtension retain];
  [_extension release];
  _extension = newExtension;
}

/**
 * Maven dependency XML to be included in a pom file.
 */
- (NSString *) dependencyXmlChunk
{
  return _dependencyXmlChunk;
}

/**
 * Maven dependency XML to be included in a pom file.
 */
- (void) setDependencyXmlChunk: (NSString *) newDependencyXmlChunk
{
  [newDependencyXmlChunk retain];
  [_dependencyXmlChunk release];
  _dependencyXmlChunk = newDependencyXmlChunk;
}

- (void) dealloc
{
  [self setGroupId: nil];
  [self setArtifactId: nil];
  [self setVersion: nil];
  [self setBaseVersion: nil];
  [self setClassifier: nil];
  [self setExtension: nil];
  [self setDependencyXmlChunk: nil];
  [super dealloc];
}
@end /* implementation NEXUS_REST_APINS0Maven2ArtifactInfoResource */

/**
 * Internal, private interface for JAXB reading and writing.
 */
@interface NEXUS_REST_APINS0Maven2ArtifactInfoResource (JAXB) <JAXBReading, JAXBWriting, JAXBType>

@end /*interface NEXUS_REST_APINS0Maven2ArtifactInfoResource (JAXB)*/

/**
 * Internal, private implementation for JAXB reading and writing.
 */
@implementation NEXUS_REST_APINS0Maven2ArtifactInfoResource (JAXB)

/**
 * Read an instance of NEXUS_REST_APINS0Maven2ArtifactInfoResource from an XML reader.
 *
 * @param reader The reader.
 * @return An instance of NEXUS_REST_APINS0Maven2ArtifactInfoResource defined by the XML reader.
 */
+ (id<JAXBType>) readXMLType: (xmlTextReaderPtr) reader
{
  NEXUS_REST_APINS0Maven2ArtifactInfoResource *_nEXUS_REST_APINS0Maven2ArtifactInfoResource = [[NEXUS_REST_APINS0Maven2ArtifactInfoResource alloc] init];
  NS_DURING
  {
    [_nEXUS_REST_APINS0Maven2ArtifactInfoResource initWithReader: reader];
  }
  NS_HANDLER
  {
    [_nEXUS_REST_APINS0Maven2ArtifactInfoResource dealloc];
    _nEXUS_REST_APINS0Maven2ArtifactInfoResource = nil;
    [localException raise];
  }
  NS_ENDHANDLER

  [_nEXUS_REST_APINS0Maven2ArtifactInfoResource autorelease];
  return _nEXUS_REST_APINS0Maven2ArtifactInfoResource;
}

/**
 * Initialize this instance of NEXUS_REST_APINS0Maven2ArtifactInfoResource according to
 * the XML being read from the reader.
 *
 * @param reader The reader.
 */
- (id) initWithReader: (xmlTextReaderPtr) reader
{
  return [super initWithReader: reader];
}

/**
 * Write the XML for this instance of NEXUS_REST_APINS0Maven2ArtifactInfoResource to the writer.
 * Note that since we're only writing the XML type,
 * No start/end element will be written.
 *
 * @param reader The reader.
 */
- (void) writeXMLType: (xmlTextWriterPtr) writer
{
  [super writeXMLType:writer];
}

//documentation inherited.
- (BOOL) readJAXBAttribute: (xmlTextReaderPtr) reader
{
  void *_child_accessor;

  if ([super readJAXBAttribute: reader]) {
    return YES;
  }

  return NO;
}

//documentation inherited.
- (BOOL) readJAXBValue: (xmlTextReaderPtr) reader
{
  return [super readJAXBValue: reader];
}

//documentation inherited.
- (BOOL) readJAXBChildElement: (xmlTextReaderPtr) reader
{
  id __child;
  void *_child_accessor;
  int status, depth;

  if ([super readJAXBChildElement: reader]) {
    return YES;
  }
  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "groupId", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}groupId of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}groupId of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setGroupId: __child];
    return YES;
  } //end "if choice"

  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "artifactId", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}artifactId of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}artifactId of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setArtifactId: __child];
    return YES;
  } //end "if choice"

  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "version", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}version of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}version of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setVersion: __child];
    return YES;
  } //end "if choice"

  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "baseVersion", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}baseVersion of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}baseVersion of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setBaseVersion: __child];
    return YES;
  } //end "if choice"

  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "classifier", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}classifier of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}classifier of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setClassifier: __child];
    return YES;
  } //end "if choice"

  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "extension", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}extension of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}extension of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setExtension: __child];
    return YES;
  } //end "if choice"

  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "dependencyXmlChunk", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}dependencyXmlChunk of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}dependencyXmlChunk of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setDependencyXmlChunk: __child];
    return YES;
  } //end "if choice"


  return NO;
}

//documentation inherited.
- (int) readUnknownJAXBChildElement: (xmlTextReaderPtr) reader
{
  return [super readUnknownJAXBChildElement: reader];
}

//documentation inherited.
- (void) readUnknownJAXBAttribute: (xmlTextReaderPtr) reader
{
  [super readUnknownJAXBAttribute: reader];
}

//documentation inherited.
- (void) writeJAXBAttributes: (xmlTextWriterPtr) writer
{
  int status;

  [super writeJAXBAttributes: writer];

}

//documentation inherited.
- (void) writeJAXBValue: (xmlTextWriterPtr) writer
{
  [super writeJAXBValue: writer];
}

/**
 * Method for writing the child elements.
 *
 * @param writer The writer.
 */
- (void) writeJAXBChildElements: (xmlTextWriterPtr) writer
{
  int status;
  id __item;
  NSEnumerator *__enumerator;

  [super writeJAXBChildElements: writer];

  if ([self groupId]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "groupId", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}groupId."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}groupId...");
#endif
    [[self groupId] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}groupId...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}groupId."];
    }
  }
  if ([self artifactId]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "artifactId", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}artifactId."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}artifactId...");
#endif
    [[self artifactId] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}artifactId...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}artifactId."];
    }
  }
  if ([self version]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "version", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}version."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}version...");
#endif
    [[self version] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}version...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}version."];
    }
  }
  if ([self baseVersion]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "baseVersion", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}baseVersion."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}baseVersion...");
#endif
    [[self baseVersion] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}baseVersion...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}baseVersion."];
    }
  }
  if ([self classifier]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "classifier", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}classifier."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}classifier...");
#endif
    [[self classifier] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}classifier...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}classifier."];
    }
  }
  if ([self extension]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "extension", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}extension."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}extension...");
#endif
    [[self extension] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}extension...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}extension."];
    }
  }
  if ([self dependencyXmlChunk]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "dependencyXmlChunk", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}dependencyXmlChunk."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}dependencyXmlChunk...");
#endif
    [[self dependencyXmlChunk] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}dependencyXmlChunk...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}dependencyXmlChunk."];
    }
  }
}
@end /* implementation NEXUS_REST_APINS0Maven2ArtifactInfoResource (JAXB) */

#endif /* DEF_NEXUS_REST_APINS0Maven2ArtifactInfoResource_M */
#ifndef DEF_NEXUS_REST_APINS0NFCRepositoryResource_M
#define DEF_NEXUS_REST_APINS0NFCRepositoryResource_M

/**
 *  Details about NFC usage for a repository.
 
 @version $Revision$ $Date$

 */
@implementation NEXUS_REST_APINS0NFCRepositoryResource

/**
 * The repository id that the nfc details are for.
 */
- (NSString *) repositoryId
{
  return _repositoryId;
}

/**
 * The repository id that the nfc details are for.
 */
- (void) setRepositoryId: (NSString *) newRepositoryId
{
  [newRepositoryId retain];
  [_repositoryId release];
  _repositoryId = newRepositoryId;
}

/**
 * NFC statistics.
 */
- (NEXUS_REST_APINS0NFCStats *) nfcStats
{
  return _nfcStats;
}

/**
 * NFC statistics.
 */
- (void) setNfcStats: (NEXUS_REST_APINS0NFCStats *) newNfcStats
{
  [newNfcStats retain];
  [_nfcStats release];
  _nfcStats = newNfcStats;
}

/**
 * Field nfcPaths.
 */
- (NSArray *) nfcPaths
{
  return _nfcPaths;
}

/**
 * Field nfcPaths.
 */
- (void) setNfcPaths: (NSArray *) newNfcPaths
{
  [newNfcPaths retain];
  [_nfcPaths release];
  _nfcPaths = newNfcPaths;
}

- (void) dealloc
{
  [self setRepositoryId: nil];
  [self setNfcStats: nil];
  [self setNfcPaths: nil];
  [super dealloc];
}
@end /* implementation NEXUS_REST_APINS0NFCRepositoryResource */

/**
 * Internal, private interface for JAXB reading and writing.
 */
@interface NEXUS_REST_APINS0NFCRepositoryResource (JAXB) <JAXBReading, JAXBWriting, JAXBType>

@end /*interface NEXUS_REST_APINS0NFCRepositoryResource (JAXB)*/

/**
 * Internal, private implementation for JAXB reading and writing.
 */
@implementation NEXUS_REST_APINS0NFCRepositoryResource (JAXB)

/**
 * Read an instance of NEXUS_REST_APINS0NFCRepositoryResource from an XML reader.
 *
 * @param reader The reader.
 * @return An instance of NEXUS_REST_APINS0NFCRepositoryResource defined by the XML reader.
 */
+ (id<JAXBType>) readXMLType: (xmlTextReaderPtr) reader
{
  NEXUS_REST_APINS0NFCRepositoryResource *_nEXUS_REST_APINS0NFCRepositoryResource = [[NEXUS_REST_APINS0NFCRepositoryResource alloc] init];
  NS_DURING
  {
    [_nEXUS_REST_APINS0NFCRepositoryResource initWithReader: reader];
  }
  NS_HANDLER
  {
    [_nEXUS_REST_APINS0NFCRepositoryResource dealloc];
    _nEXUS_REST_APINS0NFCRepositoryResource = nil;
    [localException raise];
  }
  NS_ENDHANDLER

  [_nEXUS_REST_APINS0NFCRepositoryResource autorelease];
  return _nEXUS_REST_APINS0NFCRepositoryResource;
}

/**
 * Initialize this instance of NEXUS_REST_APINS0NFCRepositoryResource according to
 * the XML being read from the reader.
 *
 * @param reader The reader.
 */
- (id) initWithReader: (xmlTextReaderPtr) reader
{
  return [super initWithReader: reader];
}

/**
 * Write the XML for this instance of NEXUS_REST_APINS0NFCRepositoryResource to the writer.
 * Note that since we're only writing the XML type,
 * No start/end element will be written.
 *
 * @param reader The reader.
 */
- (void) writeXMLType: (xmlTextWriterPtr) writer
{
  [super writeXMLType:writer];
}

//documentation inherited.
- (BOOL) readJAXBAttribute: (xmlTextReaderPtr) reader
{
  void *_child_accessor;

  if ([super readJAXBAttribute: reader]) {
    return YES;
  }

  return NO;
}

//documentation inherited.
- (BOOL) readJAXBValue: (xmlTextReaderPtr) reader
{
  return [super readJAXBValue: reader];
}

//documentation inherited.
- (BOOL) readJAXBChildElement: (xmlTextReaderPtr) reader
{
  id __child;
  void *_child_accessor;
  int status, depth;

  if ([super readJAXBChildElement: reader]) {
    return YES;
  }
  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "repositoryId", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}repositoryId of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}repositoryId of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setRepositoryId: __child];
    return YES;
  } //end "if choice"

  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "nfcStats", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}nfcStats of type {}nfc-stats.");
#endif
    __child = [NEXUS_REST_APINS0NFCStats readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}nfcStats of type {}nfc-stats.");
#endif

    [self setNfcStats: __child];
    return YES;
  } //end "if choice"

  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "nfcPaths", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

    if (xmlTextReaderIsEmptyElement(reader) == 0) {
#if DEBUG_ENUNCIATE > 1
      NSLog(@"Unwrapping wrapper element {}nfcPaths...");
#endif
      //start wrapper element "{}nfcPaths"
      depth = xmlTextReaderDepth(reader);
      status = xmlTextReaderAdvanceToNextStartOrEndElement(reader);
      while (xmlTextReaderDepth(reader) > depth) {
        if (status < 1) {
          //panic: XML read error.
          [self dealloc];
          [NSException raise: @"XMLReadError"
                       format: @"Failure to advance to next wrapped child element."];
        }
  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "path", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}path of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}path of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    if ([self nfcPaths]) {
      [self setNfcPaths: [[self nfcPaths] arrayByAddingObject: __child]];
    }
    else {
      [self setNfcPaths: [NSArray arrayWithObject: __child]];
    }
    continue; //continue "while in wrapper element" loop
  } //end "if choice"

        status = xmlTextReaderAdvanceToNextStartOrEndElement(reader);
#if DEBUG_ENUNCIATE > 1
        NSLog(@"successfully unwrapped wrapper element {}nfcPaths...");
#endif
      } // end "while in wrapper element" loop

      if (status < 1) {
        //panic: XML read error.
        [self dealloc];
        [NSException raise: @"XMLReadError"
                     format: @"Failure to advance to end wrapper element."];
      }
      else {
        //end wrapper element "{}nfcPaths"
        status = xmlTextReaderAdvanceToNextStartOrEndElement(reader);
      }
    } //end "if empty element" clause
    else {
      __child = [NSArray array];
      [self setNfcPaths: (NSArray*) __child];
    }

    return YES;
  } // end "if wrapper element" clause

  return NO;
}

//documentation inherited.
- (int) readUnknownJAXBChildElement: (xmlTextReaderPtr) reader
{
  return [super readUnknownJAXBChildElement: reader];
}

//documentation inherited.
- (void) readUnknownJAXBAttribute: (xmlTextReaderPtr) reader
{
  [super readUnknownJAXBAttribute: reader];
}

//documentation inherited.
- (void) writeJAXBAttributes: (xmlTextWriterPtr) writer
{
  int status;

  [super writeJAXBAttributes: writer];

}

//documentation inherited.
- (void) writeJAXBValue: (xmlTextWriterPtr) writer
{
  [super writeJAXBValue: writer];
}

/**
 * Method for writing the child elements.
 *
 * @param writer The writer.
 */
- (void) writeJAXBChildElements: (xmlTextWriterPtr) writer
{
  int status;
  id __item;
  NSEnumerator *__enumerator;

  [super writeJAXBChildElements: writer];

  if ([self repositoryId]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "repositoryId", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}repositoryId."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}repositoryId...");
#endif
    [[self repositoryId] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}repositoryId...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}repositoryId."];
    }
  }
  if ([self nfcStats]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "nfcStats", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}nfcStats."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}nfcStats...");
#endif
    [[self nfcStats] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}nfcStats...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}nfcStats."];
    }
  }
  if ([self nfcPaths]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "nfcPaths", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start wrapper element {}nfcPaths."];
    }
    __enumerator = [[self nfcPaths] objectEnumerator];

    while ( (__item = [__enumerator nextObject]) ) {
      status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "path", NULL);
      if (status < 0) {
        [NSException raise: @"XMLWriteError"
                     format: @"Error writing start child element {}path."];
      }

#if DEBUG_ENUNCIATE > 1
      NSLog(@"writing element {}path...");
#endif
      [__item writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
      NSLog(@"successfully wrote element {}path...");
#endif

      status = xmlTextWriterEndElement(writer);
      if (status < 0) {
        [NSException raise: @"XMLWriteError"
                     format: @"Error writing end child element {}path."];
      }
    } //end item iterator.

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end wrapper element {}nfcPaths."];
    }
  }
}
@end /* implementation NEXUS_REST_APINS0NFCRepositoryResource (JAXB) */

#endif /* DEF_NEXUS_REST_APINS0NFCRepositoryResource_M */
#ifndef DEF_NEXUS_REST_APINS0NFCResource_M
#define DEF_NEXUS_REST_APINS0NFCResource_M

/**
 *  Contains a list of items stored in the NFC.
 
 @version $Revision$ $Date$

 */
@implementation NEXUS_REST_APINS0NFCResource

/**
 * Field nfcContents.
 */
- (NSArray *) nfcContents
{
  return _nfcContents;
}

/**
 * Field nfcContents.
 */
- (void) setNfcContents: (NSArray *) newNfcContents
{
  [newNfcContents retain];
  [_nfcContents release];
  _nfcContents = newNfcContents;
}

- (void) dealloc
{
  [self setNfcContents: nil];
  [super dealloc];
}
@end /* implementation NEXUS_REST_APINS0NFCResource */

/**
 * Internal, private interface for JAXB reading and writing.
 */
@interface NEXUS_REST_APINS0NFCResource (JAXB) <JAXBReading, JAXBWriting, JAXBType>

@end /*interface NEXUS_REST_APINS0NFCResource (JAXB)*/

/**
 * Internal, private implementation for JAXB reading and writing.
 */
@implementation NEXUS_REST_APINS0NFCResource (JAXB)

/**
 * Read an instance of NEXUS_REST_APINS0NFCResource from an XML reader.
 *
 * @param reader The reader.
 * @return An instance of NEXUS_REST_APINS0NFCResource defined by the XML reader.
 */
+ (id<JAXBType>) readXMLType: (xmlTextReaderPtr) reader
{
  NEXUS_REST_APINS0NFCResource *_nEXUS_REST_APINS0NFCResource = [[NEXUS_REST_APINS0NFCResource alloc] init];
  NS_DURING
  {
    [_nEXUS_REST_APINS0NFCResource initWithReader: reader];
  }
  NS_HANDLER
  {
    [_nEXUS_REST_APINS0NFCResource dealloc];
    _nEXUS_REST_APINS0NFCResource = nil;
    [localException raise];
  }
  NS_ENDHANDLER

  [_nEXUS_REST_APINS0NFCResource autorelease];
  return _nEXUS_REST_APINS0NFCResource;
}

/**
 * Initialize this instance of NEXUS_REST_APINS0NFCResource according to
 * the XML being read from the reader.
 *
 * @param reader The reader.
 */
- (id) initWithReader: (xmlTextReaderPtr) reader
{
  return [super initWithReader: reader];
}

/**
 * Write the XML for this instance of NEXUS_REST_APINS0NFCResource to the writer.
 * Note that since we're only writing the XML type,
 * No start/end element will be written.
 *
 * @param reader The reader.
 */
- (void) writeXMLType: (xmlTextWriterPtr) writer
{
  [super writeXMLType:writer];
}

//documentation inherited.
- (BOOL) readJAXBAttribute: (xmlTextReaderPtr) reader
{
  void *_child_accessor;

  if ([super readJAXBAttribute: reader]) {
    return YES;
  }

  return NO;
}

//documentation inherited.
- (BOOL) readJAXBValue: (xmlTextReaderPtr) reader
{
  return [super readJAXBValue: reader];
}

//documentation inherited.
- (BOOL) readJAXBChildElement: (xmlTextReaderPtr) reader
{
  id __child;
  void *_child_accessor;
  int status, depth;

  if ([super readJAXBChildElement: reader]) {
    return YES;
  }
  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "nfcContents", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

    if (xmlTextReaderIsEmptyElement(reader) == 0) {
#if DEBUG_ENUNCIATE > 1
      NSLog(@"Unwrapping wrapper element {}nfcContents...");
#endif
      //start wrapper element "{}nfcContents"
      depth = xmlTextReaderDepth(reader);
      status = xmlTextReaderAdvanceToNextStartOrEndElement(reader);
      while (xmlTextReaderDepth(reader) > depth) {
        if (status < 1) {
          //panic: XML read error.
          [self dealloc];
          [NSException raise: @"XMLReadError"
                       format: @"Failure to advance to next wrapped child element."];
        }
  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "nfc-repo-info", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}nfc-repo-info of type {}nfc-repository-resource.");
#endif

    __child = [NEXUS_REST_APINS0NFCRepositoryResource readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}nfc-repo-info of type {}nfc-repository-resource.");
#endif

    if ([self nfcContents]) {
      [self setNfcContents: [[self nfcContents] arrayByAddingObject: __child]];
    }
    else {
      [self setNfcContents: [NSArray arrayWithObject: __child]];
    }
    continue; //continue "while in wrapper element" loop
  } //end "if choice"

        status = xmlTextReaderAdvanceToNextStartOrEndElement(reader);
#if DEBUG_ENUNCIATE > 1
        NSLog(@"successfully unwrapped wrapper element {}nfcContents...");
#endif
      } // end "while in wrapper element" loop

      if (status < 1) {
        //panic: XML read error.
        [self dealloc];
        [NSException raise: @"XMLReadError"
                     format: @"Failure to advance to end wrapper element."];
      }
      else {
        //end wrapper element "{}nfcContents"
        status = xmlTextReaderAdvanceToNextStartOrEndElement(reader);
      }
    } //end "if empty element" clause
    else {
      __child = [NSArray array];
      [self setNfcContents: (NSArray*) __child];
    }

    return YES;
  } // end "if wrapper element" clause

  return NO;
}

//documentation inherited.
- (int) readUnknownJAXBChildElement: (xmlTextReaderPtr) reader
{
  return [super readUnknownJAXBChildElement: reader];
}

//documentation inherited.
- (void) readUnknownJAXBAttribute: (xmlTextReaderPtr) reader
{
  [super readUnknownJAXBAttribute: reader];
}

//documentation inherited.
- (void) writeJAXBAttributes: (xmlTextWriterPtr) writer
{
  int status;

  [super writeJAXBAttributes: writer];

}

//documentation inherited.
- (void) writeJAXBValue: (xmlTextWriterPtr) writer
{
  [super writeJAXBValue: writer];
}

/**
 * Method for writing the child elements.
 *
 * @param writer The writer.
 */
- (void) writeJAXBChildElements: (xmlTextWriterPtr) writer
{
  int status;
  id __item;
  NSEnumerator *__enumerator;

  [super writeJAXBChildElements: writer];

  if ([self nfcContents]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "nfcContents", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start wrapper element {}nfcContents."];
    }
    __enumerator = [[self nfcContents] objectEnumerator];

    while ( (__item = [__enumerator nextObject]) ) {
      status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "nfc-repo-info", NULL);
      if (status < 0) {
        [NSException raise: @"XMLWriteError"
                     format: @"Error writing start child element {}nfc-repo-info."];
      }

#if DEBUG_ENUNCIATE > 1
      NSLog(@"writing element {}nfc-repo-info...");
#endif
      [__item writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
      NSLog(@"successfully wrote element {}nfc-repo-info...");
#endif

      status = xmlTextWriterEndElement(writer);
      if (status < 0) {
        [NSException raise: @"XMLWriteError"
                     format: @"Error writing end child element {}nfc-repo-info."];
      }
    } //end item iterator.

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end wrapper element {}nfcContents."];
    }
  }
}
@end /* implementation NEXUS_REST_APINS0NFCResource (JAXB) */

#endif /* DEF_NEXUS_REST_APINS0NFCResource_M */
#ifndef DEF_NEXUS_REST_APINS0NFCStats_M
#define DEF_NEXUS_REST_APINS0NFCStats_M

/**
 *  NFC Statistics.
 
 @version $Revision$ $Date$

 */
@implementation NEXUS_REST_APINS0NFCStats

/**
 * The number of paths stored in the NFC.
 */
- (long) size
{
  return _size;
}

/**
 * The number of paths stored in the NFC.
 */
- (void) setSize: (long) newSize
{
  _size = newSize;
}

/**
 * The number of checks against this NFC that have found matches
 */
- (long) hits
{
  return _hits;
}

/**
 * The number of checks against this NFC that have found matches
 */
- (void) setHits: (long) newHits
{
  _hits = newHits;
}

/**
 * The number of checks against this NFC that have not found
matches.
 */
- (long) misses
{
  return _misses;
}

/**
 * The number of checks against this NFC that have not found
matches.
 */
- (void) setMisses: (long) newMisses
{
  _misses = newMisses;
}

- (void) dealloc
{
  [super dealloc];
}
@end /* implementation NEXUS_REST_APINS0NFCStats */

/**
 * Internal, private interface for JAXB reading and writing.
 */
@interface NEXUS_REST_APINS0NFCStats (JAXB) <JAXBReading, JAXBWriting, JAXBType>

@end /*interface NEXUS_REST_APINS0NFCStats (JAXB)*/

/**
 * Internal, private implementation for JAXB reading and writing.
 */
@implementation NEXUS_REST_APINS0NFCStats (JAXB)

/**
 * Read an instance of NEXUS_REST_APINS0NFCStats from an XML reader.
 *
 * @param reader The reader.
 * @return An instance of NEXUS_REST_APINS0NFCStats defined by the XML reader.
 */
+ (id<JAXBType>) readXMLType: (xmlTextReaderPtr) reader
{
  NEXUS_REST_APINS0NFCStats *_nEXUS_REST_APINS0NFCStats = [[NEXUS_REST_APINS0NFCStats alloc] init];
  NS_DURING
  {
    [_nEXUS_REST_APINS0NFCStats initWithReader: reader];
  }
  NS_HANDLER
  {
    [_nEXUS_REST_APINS0NFCStats dealloc];
    _nEXUS_REST_APINS0NFCStats = nil;
    [localException raise];
  }
  NS_ENDHANDLER

  [_nEXUS_REST_APINS0NFCStats autorelease];
  return _nEXUS_REST_APINS0NFCStats;
}

/**
 * Initialize this instance of NEXUS_REST_APINS0NFCStats according to
 * the XML being read from the reader.
 *
 * @param reader The reader.
 */
- (id) initWithReader: (xmlTextReaderPtr) reader
{
  return [super initWithReader: reader];
}

/**
 * Write the XML for this instance of NEXUS_REST_APINS0NFCStats to the writer.
 * Note that since we're only writing the XML type,
 * No start/end element will be written.
 *
 * @param reader The reader.
 */
- (void) writeXMLType: (xmlTextWriterPtr) writer
{
  [super writeXMLType:writer];
}

//documentation inherited.
- (BOOL) readJAXBAttribute: (xmlTextReaderPtr) reader
{
  void *_child_accessor;

  if ([super readJAXBAttribute: reader]) {
    return YES;
  }

  return NO;
}

//documentation inherited.
- (BOOL) readJAXBValue: (xmlTextReaderPtr) reader
{
  return [super readJAXBValue: reader];
}

//documentation inherited.
- (BOOL) readJAXBChildElement: (xmlTextReaderPtr) reader
{
  id __child;
  void *_child_accessor;
  int status, depth;

  if ([super readJAXBChildElement: reader]) {
    return YES;
  }

  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "size", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

    _child_accessor = xmlTextReaderReadLongType(reader);
    if (_child_accessor == NULL) {
      //panic: unable to return the value for some reason.
      [self dealloc];
      [NSException raise: @"XMLReadError"
                   format: @"Error reading element value."];
    }
    [self setSize: *((long*) _child_accessor)];
    free(_child_accessor);
    return YES;
  }

  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "hits", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

    _child_accessor = xmlTextReaderReadLongType(reader);
    if (_child_accessor == NULL) {
      //panic: unable to return the value for some reason.
      [self dealloc];
      [NSException raise: @"XMLReadError"
                   format: @"Error reading element value."];
    }
    [self setHits: *((long*) _child_accessor)];
    free(_child_accessor);
    return YES;
  }

  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "misses", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

    _child_accessor = xmlTextReaderReadLongType(reader);
    if (_child_accessor == NULL) {
      //panic: unable to return the value for some reason.
      [self dealloc];
      [NSException raise: @"XMLReadError"
                   format: @"Error reading element value."];
    }
    [self setMisses: *((long*) _child_accessor)];
    free(_child_accessor);
    return YES;
  }

  return NO;
}

//documentation inherited.
- (int) readUnknownJAXBChildElement: (xmlTextReaderPtr) reader
{
  return [super readUnknownJAXBChildElement: reader];
}

//documentation inherited.
- (void) readUnknownJAXBAttribute: (xmlTextReaderPtr) reader
{
  [super readUnknownJAXBAttribute: reader];
}

//documentation inherited.
- (void) writeJAXBAttributes: (xmlTextWriterPtr) writer
{
  int status;

  [super writeJAXBAttributes: writer];

}

//documentation inherited.
- (void) writeJAXBValue: (xmlTextWriterPtr) writer
{
  [super writeJAXBValue: writer];
}

/**
 * Method for writing the child elements.
 *
 * @param writer The writer.
 */
- (void) writeJAXBChildElements: (xmlTextWriterPtr) writer
{
  int status;
  id __item;
  NSEnumerator *__enumerator;

  [super writeJAXBChildElements: writer];

  if (YES) { //always write the primitive element...
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "size", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}size."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}size...");
#endif
    status = xmlTextWriterWriteLongType(writer, &_size);
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}size...");
#endif
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing child element {}size."];
    }

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}size."];
    }
  }
  if (YES) { //always write the primitive element...
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "hits", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}hits."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}hits...");
#endif
    status = xmlTextWriterWriteLongType(writer, &_hits);
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}hits...");
#endif
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing child element {}hits."];
    }

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}hits."];
    }
  }
  if (YES) { //always write the primitive element...
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "misses", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}misses."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}misses...");
#endif
    status = xmlTextWriterWriteLongType(writer, &_misses);
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}misses...");
#endif
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing child element {}misses."];
    }

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}misses."];
    }
  }
}
@end /* implementation NEXUS_REST_APINS0NFCStats (JAXB) */

#endif /* DEF_NEXUS_REST_APINS0NFCStats_M */
#ifndef DEF_NEXUS_REST_APINS0NexusRepositoryTypeListResourceResponse_M
#define DEF_NEXUS_REST_APINS0NexusRepositoryTypeListResourceResponse_M

/**
 *  REST Response object for a list of repository types, contains
 the typical 'data' parameter, which is the repository types.
 
 @version $Revision$ $Date$

 */
@implementation NEXUS_REST_APINS0NexusRepositoryTypeListResourceResponse

/**
 * Field data.
 */
- (NSArray *) data
{
  return _data;
}

/**
 * Field data.
 */
- (void) setData: (NSArray *) newData
{
  [newData retain];
  [_data release];
  _data = newData;
}

- (void) dealloc
{
  [self setData: nil];
  [super dealloc];
}

//documentation inherited.
+ (id<EnunciateXML>) readFromXML: (NSData *) xml
{
  NEXUS_REST_APINS0NexusRepositoryTypeListResourceResponse *_nEXUS_REST_APINS0NexusRepositoryTypeListResourceResponse;
  xmlTextReaderPtr reader = xmlReaderForMemory([xml bytes], [xml length], NULL, NULL, 0);
  if (reader == NULL) {
    [NSException raise: @"XMLReadError"
                 format: @"Error instantiating an XML reader."];
    return nil;
  }

  _nEXUS_REST_APINS0NexusRepositoryTypeListResourceResponse = (NEXUS_REST_APINS0NexusRepositoryTypeListResourceResponse *) [NEXUS_REST_APINS0NexusRepositoryTypeListResourceResponse readXMLElement: reader];
  xmlFreeTextReader(reader); //free the reader
  return _nEXUS_REST_APINS0NexusRepositoryTypeListResourceResponse;
}

//documentation inherited.
- (NSData *) writeToXML
{
  xmlBufferPtr buf;
  xmlTextWriterPtr writer;
  int rc;
  NSData *data;

  buf = xmlBufferCreate();
  if (buf == NULL) {
    [NSException raise: @"XMLWriteError"
                 format: @"Error creating an XML buffer."];
    return nil;
  }

  writer = xmlNewTextWriterMemory(buf, 0);
  if (writer == NULL) {
    xmlBufferFree(buf);
    [NSException raise: @"XMLWriteError"
                 format: @"Error creating an XML writer."];
    return nil;
  }

  rc = xmlTextWriterStartDocument(writer, NULL, "utf-8", NULL);
  if (rc < 0) {
    xmlFreeTextWriter(writer);
    xmlBufferFree(buf);
    [NSException raise: @"XMLWriteError"
                 format: @"Error writing XML start document."];
    return nil;
  }

  NS_DURING
  {
    [self writeXMLElement: writer];
  }
  NS_HANDLER
  {
    xmlFreeTextWriter(writer);
    xmlBufferFree(buf);
    [localException raise];
  }
  NS_ENDHANDLER

  rc = xmlTextWriterEndDocument(writer);
  if (rc < 0) {
    xmlFreeTextWriter(writer);
    xmlBufferFree(buf);
    [NSException raise: @"XMLWriteError"
                 format: @"Error writing XML end document."];
    return nil;
  }

  xmlFreeTextWriter(writer);
  data = [NSData dataWithBytes: buf->content length: buf->use];
  xmlBufferFree(buf);
  return data;
}
@end /* implementation NEXUS_REST_APINS0NexusRepositoryTypeListResourceResponse */

/**
 * Internal, private interface for JAXB reading and writing.
 */
@interface NEXUS_REST_APINS0NexusRepositoryTypeListResourceResponse (JAXB) <JAXBReading, JAXBWriting, JAXBType, JAXBElement>

@end /*interface NEXUS_REST_APINS0NexusRepositoryTypeListResourceResponse (JAXB)*/

/**
 * Internal, private implementation for JAXB reading and writing.
 */
@implementation NEXUS_REST_APINS0NexusRepositoryTypeListResourceResponse (JAXB)

/**
 * Read an instance of NEXUS_REST_APINS0NexusRepositoryTypeListResourceResponse from an XML reader.
 *
 * @param reader The reader.
 * @return An instance of NEXUS_REST_APINS0NexusRepositoryTypeListResourceResponse defined by the XML reader.
 */
+ (id<JAXBType>) readXMLType: (xmlTextReaderPtr) reader
{
  NEXUS_REST_APINS0NexusRepositoryTypeListResourceResponse *_nEXUS_REST_APINS0NexusRepositoryTypeListResourceResponse = [[NEXUS_REST_APINS0NexusRepositoryTypeListResourceResponse alloc] init];
  NS_DURING
  {
    [_nEXUS_REST_APINS0NexusRepositoryTypeListResourceResponse initWithReader: reader];
  }
  NS_HANDLER
  {
    [_nEXUS_REST_APINS0NexusRepositoryTypeListResourceResponse dealloc];
    _nEXUS_REST_APINS0NexusRepositoryTypeListResourceResponse = nil;
    [localException raise];
  }
  NS_ENDHANDLER

  [_nEXUS_REST_APINS0NexusRepositoryTypeListResourceResponse autorelease];
  return _nEXUS_REST_APINS0NexusRepositoryTypeListResourceResponse;
}

/**
 * Initialize this instance of NEXUS_REST_APINS0NexusRepositoryTypeListResourceResponse according to
 * the XML being read from the reader.
 *
 * @param reader The reader.
 */
- (id) initWithReader: (xmlTextReaderPtr) reader
{
  return [super initWithReader: reader];
}

/**
 * Write the XML for this instance of NEXUS_REST_APINS0NexusRepositoryTypeListResourceResponse to the writer.
 * Note that since we're only writing the XML type,
 * No start/end element will be written.
 *
 * @param reader The reader.
 */
- (void) writeXMLType: (xmlTextWriterPtr) writer
{
  [super writeXMLType:writer];
}

/**
 * Reads a NEXUS_REST_APINS0NexusRepositoryTypeListResourceResponse from an XML reader. The element to be read is
 * "repositoryTypes".
 *
 * @param reader The XML reader.
 * @return The NEXUS_REST_APINS0NexusRepositoryTypeListResourceResponse.
 */
+ (id<JAXBElement>) readXMLElement: (xmlTextReaderPtr) reader {
  int status;
  NEXUS_REST_APINS0NexusRepositoryTypeListResourceResponse *_nexusRepositoryTypeListResourceResponse = nil;

  if (xmlTextReaderNodeType(reader) != XML_READER_TYPE_ELEMENT) {
    status = xmlTextReaderAdvanceToNextStartOrEndElement(reader);
    if (status < 1) {
      [NSException raise: @"XMLReadError"
                   format: @"Error advancing the reader to start element repositoryTypes."];
    }
  }

  if (xmlStrcmp(BAD_CAST "repositoryTypes", xmlTextReaderConstLocalName(reader)) == 0
      && xmlTextReaderConstNamespaceUri(reader) == NULL) {
#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read root element {}repositoryTypes.");
#endif
    _nexusRepositoryTypeListResourceResponse = (NEXUS_REST_APINS0NexusRepositoryTypeListResourceResponse *)[NEXUS_REST_APINS0NexusRepositoryTypeListResourceResponse readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"Successfully read root element {}repositoryTypes.");
#endif
  }
  else {
    if (xmlTextReaderConstNamespaceUri(reader) == NULL) {
      [NSException raise: @"XMLReadError"
                   format: @"Unable to read NEXUS_REST_APINS0NexusRepositoryTypeListResourceResponse. Expected element repositoryTypes. Current element: {}%s", xmlTextReaderConstLocalName(reader)];
    }
    else {
      [NSException raise: @"XMLReadError"
                   format: @"Unable to read NEXUS_REST_APINS0NexusRepositoryTypeListResourceResponse. Expected element repositoryTypes. Current element: {%s}%s\n", xmlTextReaderConstNamespaceUri(reader), xmlTextReaderConstLocalName(reader)];
    }
  }

  return _nexusRepositoryTypeListResourceResponse;
}

/**
 * Writes this NEXUS_REST_APINS0NexusRepositoryTypeListResourceResponse to XML under element name "repositoryTypes".
 * The namespace declarations for the element will be written.
 *
 * @param writer The XML writer.
 * @param _nexusRepositoryTypeListResourceResponse The NexusRepositoryTypeListResourceResponse to write.
 * @return 1 if successful, 0 otherwise.
 */
- (void) writeXMLElement: (xmlTextWriterPtr) writer
{
  [self writeXMLElement: writer writeNamespaces: YES];
}

/**
 * Writes this NEXUS_REST_APINS0NexusRepositoryTypeListResourceResponse to an XML writer.
 *
 * @param writer The writer.
 * @param writeNs Whether to write the namespaces for this element to the xml writer.
 */
- (void) writeXMLElement: (xmlTextWriterPtr) writer writeNamespaces: (BOOL) writeNs
{
  int rc = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "repositoryTypes", NULL);
  if (rc < 0) {
    [NSException raise: @"XMLWriteError"
                 format: @"Error writing start element {}repositoryTypes. XML writer status: %i\n", rc];
  }

#if DEBUG_ENUNCIATE > 1
  NSLog(@"writing type {}nexusRepositoryTypeListResourceResponse for root element {}repositoryTypes...");
#endif
  [self writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
  NSLog(@"successfully wrote type {}nexusRepositoryTypeListResourceResponse for root element {}repositoryTypes...");
#endif
  rc = xmlTextWriterEndElement(writer);
  if (rc < 0) {
    [NSException raise: @"XMLWriteError"
                 format: @"Error writing end element {}repositoryTypes. XML writer status: %i\n", rc];
  }
}

//documentation inherited.
- (BOOL) readJAXBAttribute: (xmlTextReaderPtr) reader
{
  void *_child_accessor;

  if ([super readJAXBAttribute: reader]) {
    return YES;
  }

  return NO;
}

//documentation inherited.
- (BOOL) readJAXBValue: (xmlTextReaderPtr) reader
{
  return [super readJAXBValue: reader];
}

//documentation inherited.
- (BOOL) readJAXBChildElement: (xmlTextReaderPtr) reader
{
  id __child;
  void *_child_accessor;
  int status, depth;

  if ([super readJAXBChildElement: reader]) {
    return YES;
  }
  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "data", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

    if (xmlTextReaderIsEmptyElement(reader) == 0) {
#if DEBUG_ENUNCIATE > 1
      NSLog(@"Unwrapping wrapper element {}data...");
#endif
      //start wrapper element "{}data"
      depth = xmlTextReaderDepth(reader);
      status = xmlTextReaderAdvanceToNextStartOrEndElement(reader);
      while (xmlTextReaderDepth(reader) > depth) {
        if (status < 1) {
          //panic: XML read error.
          [self dealloc];
          [NSException raise: @"XMLReadError"
                       format: @"Failure to advance to next wrapped child element."];
        }
  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "repositoryType", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}repositoryType of type {}nexus-repository-type-list-resource.");
#endif

    __child = [NEXUS_REST_APINS0NexusRepositoryTypeListResource readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}repositoryType of type {}nexus-repository-type-list-resource.");
#endif

    if ([self data]) {
      [self setData: [[self data] arrayByAddingObject: __child]];
    }
    else {
      [self setData: [NSArray arrayWithObject: __child]];
    }
    continue; //continue "while in wrapper element" loop
  } //end "if choice"

        status = xmlTextReaderAdvanceToNextStartOrEndElement(reader);
#if DEBUG_ENUNCIATE > 1
        NSLog(@"successfully unwrapped wrapper element {}data...");
#endif
      } // end "while in wrapper element" loop

      if (status < 1) {
        //panic: XML read error.
        [self dealloc];
        [NSException raise: @"XMLReadError"
                     format: @"Failure to advance to end wrapper element."];
      }
      else {
        //end wrapper element "{}data"
        status = xmlTextReaderAdvanceToNextStartOrEndElement(reader);
      }
    } //end "if empty element" clause
    else {
      __child = [NSArray array];
      [self setData: (NSArray*) __child];
    }

    return YES;
  } // end "if wrapper element" clause

  return NO;
}

//documentation inherited.
- (int) readUnknownJAXBChildElement: (xmlTextReaderPtr) reader
{
  return [super readUnknownJAXBChildElement: reader];
}

//documentation inherited.
- (void) readUnknownJAXBAttribute: (xmlTextReaderPtr) reader
{
  [super readUnknownJAXBAttribute: reader];
}

//documentation inherited.
- (void) writeJAXBAttributes: (xmlTextWriterPtr) writer
{
  int status;

  [super writeJAXBAttributes: writer];

}

//documentation inherited.
- (void) writeJAXBValue: (xmlTextWriterPtr) writer
{
  [super writeJAXBValue: writer];
}

/**
 * Method for writing the child elements.
 *
 * @param writer The writer.
 */
- (void) writeJAXBChildElements: (xmlTextWriterPtr) writer
{
  int status;
  id __item;
  NSEnumerator *__enumerator;

  [super writeJAXBChildElements: writer];

  if ([self data]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "data", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start wrapper element {}data."];
    }
    __enumerator = [[self data] objectEnumerator];

    while ( (__item = [__enumerator nextObject]) ) {
      status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "repositoryType", NULL);
      if (status < 0) {
        [NSException raise: @"XMLWriteError"
                     format: @"Error writing start child element {}repositoryType."];
      }

#if DEBUG_ENUNCIATE > 1
      NSLog(@"writing element {}repositoryType...");
#endif
      [__item writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
      NSLog(@"successfully wrote element {}repositoryType...");
#endif

      status = xmlTextWriterEndElement(writer);
      if (status < 0) {
        [NSException raise: @"XMLWriteError"
                     format: @"Error writing end child element {}repositoryType."];
      }
    } //end item iterator.

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end wrapper element {}data."];
    }
  }
}
@end /* implementation NEXUS_REST_APINS0NexusRepositoryTypeListResourceResponse (JAXB) */

#endif /* DEF_NEXUS_REST_APINS0NexusRepositoryTypeListResourceResponse_M */
#ifndef DEF_NEXUS_REST_APINS0PlexusComponentListResource_M
#define DEF_NEXUS_REST_APINS0PlexusComponentListResource_M

/**
 *  Plexus component details.
 
 @version $Revision$ $Date$

 */
@implementation NEXUS_REST_APINS0PlexusComponentListResource

/**
 * The plexus role hint of the component.
 */
- (NSString *) roleHint
{
  return _roleHint;
}

/**
 * The plexus role hint of the component.
 */
- (void) setRoleHint: (NSString *) newRoleHint
{
  [newRoleHint retain];
  [_roleHint release];
  _roleHint = newRoleHint;
}

/**
 * The plexus description of the component.
 */
- (NSString *) description
{
  return _description;
}

/**
 * The plexus description of the component.
 */
- (void) setDescription: (NSString *) newDescription
{
  [newDescription retain];
  [_description release];
  _description = newDescription;
}

- (void) dealloc
{
  [self setRoleHint: nil];
  [self setDescription: nil];
  [super dealloc];
}
@end /* implementation NEXUS_REST_APINS0PlexusComponentListResource */

/**
 * Internal, private interface for JAXB reading and writing.
 */
@interface NEXUS_REST_APINS0PlexusComponentListResource (JAXB) <JAXBReading, JAXBWriting, JAXBType>

@end /*interface NEXUS_REST_APINS0PlexusComponentListResource (JAXB)*/

/**
 * Internal, private implementation for JAXB reading and writing.
 */
@implementation NEXUS_REST_APINS0PlexusComponentListResource (JAXB)

/**
 * Read an instance of NEXUS_REST_APINS0PlexusComponentListResource from an XML reader.
 *
 * @param reader The reader.
 * @return An instance of NEXUS_REST_APINS0PlexusComponentListResource defined by the XML reader.
 */
+ (id<JAXBType>) readXMLType: (xmlTextReaderPtr) reader
{
  NEXUS_REST_APINS0PlexusComponentListResource *_nEXUS_REST_APINS0PlexusComponentListResource = [[NEXUS_REST_APINS0PlexusComponentListResource alloc] init];
  NS_DURING
  {
    [_nEXUS_REST_APINS0PlexusComponentListResource initWithReader: reader];
  }
  NS_HANDLER
  {
    [_nEXUS_REST_APINS0PlexusComponentListResource dealloc];
    _nEXUS_REST_APINS0PlexusComponentListResource = nil;
    [localException raise];
  }
  NS_ENDHANDLER

  [_nEXUS_REST_APINS0PlexusComponentListResource autorelease];
  return _nEXUS_REST_APINS0PlexusComponentListResource;
}

/**
 * Initialize this instance of NEXUS_REST_APINS0PlexusComponentListResource according to
 * the XML being read from the reader.
 *
 * @param reader The reader.
 */
- (id) initWithReader: (xmlTextReaderPtr) reader
{
  return [super initWithReader: reader];
}

/**
 * Write the XML for this instance of NEXUS_REST_APINS0PlexusComponentListResource to the writer.
 * Note that since we're only writing the XML type,
 * No start/end element will be written.
 *
 * @param reader The reader.
 */
- (void) writeXMLType: (xmlTextWriterPtr) writer
{
  [super writeXMLType:writer];
}

//documentation inherited.
- (BOOL) readJAXBAttribute: (xmlTextReaderPtr) reader
{
  void *_child_accessor;

  if ([super readJAXBAttribute: reader]) {
    return YES;
  }

  return NO;
}

//documentation inherited.
- (BOOL) readJAXBValue: (xmlTextReaderPtr) reader
{
  return [super readJAXBValue: reader];
}

//documentation inherited.
- (BOOL) readJAXBChildElement: (xmlTextReaderPtr) reader
{
  id __child;
  void *_child_accessor;
  int status, depth;

  if ([super readJAXBChildElement: reader]) {
    return YES;
  }
  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "roleHint", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}roleHint of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}roleHint of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setRoleHint: __child];
    return YES;
  } //end "if choice"

  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "description", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}description of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}description of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setDescription: __child];
    return YES;
  } //end "if choice"


  return NO;
}

//documentation inherited.
- (int) readUnknownJAXBChildElement: (xmlTextReaderPtr) reader
{
  return [super readUnknownJAXBChildElement: reader];
}

//documentation inherited.
- (void) readUnknownJAXBAttribute: (xmlTextReaderPtr) reader
{
  [super readUnknownJAXBAttribute: reader];
}

//documentation inherited.
- (void) writeJAXBAttributes: (xmlTextWriterPtr) writer
{
  int status;

  [super writeJAXBAttributes: writer];

}

//documentation inherited.
- (void) writeJAXBValue: (xmlTextWriterPtr) writer
{
  [super writeJAXBValue: writer];
}

/**
 * Method for writing the child elements.
 *
 * @param writer The writer.
 */
- (void) writeJAXBChildElements: (xmlTextWriterPtr) writer
{
  int status;
  id __item;
  NSEnumerator *__enumerator;

  [super writeJAXBChildElements: writer];

  if ([self roleHint]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "roleHint", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}roleHint."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}roleHint...");
#endif
    [[self roleHint] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}roleHint...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}roleHint."];
    }
  }
  if ([self description]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "description", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}description."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}description...");
#endif
    [[self description] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}description...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}description."];
    }
  }
}
@end /* implementation NEXUS_REST_APINS0PlexusComponentListResource (JAXB) */

#endif /* DEF_NEXUS_REST_APINS0PlexusComponentListResource_M */
#ifndef DEF_NEXUS_REST_APINS0PrivilegeResource_M
#define DEF_NEXUS_REST_APINS0PrivilegeResource_M

/**
 *  Privilege details.
 
 @version $Revision$ $Date$

 */
@implementation NEXUS_REST_APINS0PrivilegeResource

/**
 * The name of the privilege.
 */
- (NSString *) name
{
  return _name;
}

/**
 * The name of the privilege.
 */
- (void) setName: (NSString *) newName
{
  [newName retain];
  [_name release];
  _name = newName;
}

/**
 * The type of the privilege.
 */
- (NSString *) type
{
  return _type;
}

/**
 * The type of the privilege.
 */
- (void) setType: (NSString *) newType
{
  [newType retain];
  [_type release];
  _type = newType;
}

/**
 * The description of the privilege.
 */
- (NSString *) description
{
  return _description;
}

/**
 * The description of the privilege.
 */
- (void) setDescription: (NSString *) newDescription
{
  [newDescription retain];
  [_description release];
  _description = newDescription;
}

/**
 * Field method.
 */
- (NSArray *) method
{
  return _method;
}

/**
 * Field method.
 */
- (void) setMethod: (NSArray *) newMethod
{
  [newMethod retain];
  [_method release];
  _method = newMethod;
}

/**
 * Target id for the privilege.
 */
- (NSString *) repositoryTargetId
{
  return _repositoryTargetId;
}

/**
 * Target id for the privilege.
 */
- (void) setRepositoryTargetId: (NSString *) newRepositoryTargetId
{
  [newRepositoryTargetId retain];
  [_repositoryTargetId release];
  _repositoryTargetId = newRepositoryTargetId;
}

/**
 * Repository id of the privilege.
 */
- (NSString *) repositoryId
{
  return _repositoryId;
}

/**
 * Repository id of the privilege.
 */
- (void) setRepositoryId: (NSString *) newRepositoryId
{
  [newRepositoryId retain];
  [_repositoryId release];
  _repositoryId = newRepositoryId;
}

/**
 * Group id of the privilege.
 */
- (NSString *) repositoryGroupId
{
  return _repositoryGroupId;
}

/**
 * Group id of the privilege.
 */
- (void) setRepositoryGroupId: (NSString *) newRepositoryGroupId
{
  [newRepositoryGroupId retain];
  [_repositoryGroupId release];
  _repositoryGroupId = newRepositoryGroupId;
}

- (void) dealloc
{
  [self setName: nil];
  [self setType: nil];
  [self setDescription: nil];
  [self setMethod: nil];
  [self setRepositoryTargetId: nil];
  [self setRepositoryId: nil];
  [self setRepositoryGroupId: nil];
  [super dealloc];
}
@end /* implementation NEXUS_REST_APINS0PrivilegeResource */

/**
 * Internal, private interface for JAXB reading and writing.
 */
@interface NEXUS_REST_APINS0PrivilegeResource (JAXB) <JAXBReading, JAXBWriting, JAXBType>

@end /*interface NEXUS_REST_APINS0PrivilegeResource (JAXB)*/

/**
 * Internal, private implementation for JAXB reading and writing.
 */
@implementation NEXUS_REST_APINS0PrivilegeResource (JAXB)

/**
 * Read an instance of NEXUS_REST_APINS0PrivilegeResource from an XML reader.
 *
 * @param reader The reader.
 * @return An instance of NEXUS_REST_APINS0PrivilegeResource defined by the XML reader.
 */
+ (id<JAXBType>) readXMLType: (xmlTextReaderPtr) reader
{
  NEXUS_REST_APINS0PrivilegeResource *_nEXUS_REST_APINS0PrivilegeResource = [[NEXUS_REST_APINS0PrivilegeResource alloc] init];
  NS_DURING
  {
    [_nEXUS_REST_APINS0PrivilegeResource initWithReader: reader];
  }
  NS_HANDLER
  {
    [_nEXUS_REST_APINS0PrivilegeResource dealloc];
    _nEXUS_REST_APINS0PrivilegeResource = nil;
    [localException raise];
  }
  NS_ENDHANDLER

  [_nEXUS_REST_APINS0PrivilegeResource autorelease];
  return _nEXUS_REST_APINS0PrivilegeResource;
}

/**
 * Initialize this instance of NEXUS_REST_APINS0PrivilegeResource according to
 * the XML being read from the reader.
 *
 * @param reader The reader.
 */
- (id) initWithReader: (xmlTextReaderPtr) reader
{
  return [super initWithReader: reader];
}

/**
 * Write the XML for this instance of NEXUS_REST_APINS0PrivilegeResource to the writer.
 * Note that since we're only writing the XML type,
 * No start/end element will be written.
 *
 * @param reader The reader.
 */
- (void) writeXMLType: (xmlTextWriterPtr) writer
{
  [super writeXMLType:writer];
}

//documentation inherited.
- (BOOL) readJAXBAttribute: (xmlTextReaderPtr) reader
{
  void *_child_accessor;

  if ([super readJAXBAttribute: reader]) {
    return YES;
  }

  return NO;
}

//documentation inherited.
- (BOOL) readJAXBValue: (xmlTextReaderPtr) reader
{
  return [super readJAXBValue: reader];
}

//documentation inherited.
- (BOOL) readJAXBChildElement: (xmlTextReaderPtr) reader
{
  id __child;
  void *_child_accessor;
  int status, depth;

  if ([super readJAXBChildElement: reader]) {
    return YES;
  }
  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "name", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}name of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}name of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setName: __child];
    return YES;
  } //end "if choice"

  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "type", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}type of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}type of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setType: __child];
    return YES;
  } //end "if choice"

  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "description", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}description of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}description of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setDescription: __child];
    return YES;
  } //end "if choice"

  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "methods", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

    if (xmlTextReaderIsEmptyElement(reader) == 0) {
#if DEBUG_ENUNCIATE > 1
      NSLog(@"Unwrapping wrapper element {}methods...");
#endif
      //start wrapper element "{}methods"
      depth = xmlTextReaderDepth(reader);
      status = xmlTextReaderAdvanceToNextStartOrEndElement(reader);
      while (xmlTextReaderDepth(reader) > depth) {
        if (status < 1) {
          //panic: XML read error.
          [self dealloc];
          [NSException raise: @"XMLReadError"
                       format: @"Failure to advance to next wrapped child element."];
        }
  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "method", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}method of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}method of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    if ([self method]) {
      [self setMethod: [[self method] arrayByAddingObject: __child]];
    }
    else {
      [self setMethod: [NSArray arrayWithObject: __child]];
    }
    continue; //continue "while in wrapper element" loop
  } //end "if choice"

        status = xmlTextReaderAdvanceToNextStartOrEndElement(reader);
#if DEBUG_ENUNCIATE > 1
        NSLog(@"successfully unwrapped wrapper element {}methods...");
#endif
      } // end "while in wrapper element" loop

      if (status < 1) {
        //panic: XML read error.
        [self dealloc];
        [NSException raise: @"XMLReadError"
                     format: @"Failure to advance to end wrapper element."];
      }
      else {
        //end wrapper element "{}methods"
        status = xmlTextReaderAdvanceToNextStartOrEndElement(reader);
      }
    } //end "if empty element" clause
    else {
      __child = [NSArray array];
      [self setMethod: (NSArray*) __child];
    }

    return YES;
  } // end "if wrapper element" clause
  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "repositoryTargetId", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}repositoryTargetId of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}repositoryTargetId of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setRepositoryTargetId: __child];
    return YES;
  } //end "if choice"

  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "repositoryId", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}repositoryId of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}repositoryId of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setRepositoryId: __child];
    return YES;
  } //end "if choice"

  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "repositoryGroupId", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}repositoryGroupId of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}repositoryGroupId of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setRepositoryGroupId: __child];
    return YES;
  } //end "if choice"


  return NO;
}

//documentation inherited.
- (int) readUnknownJAXBChildElement: (xmlTextReaderPtr) reader
{
  return [super readUnknownJAXBChildElement: reader];
}

//documentation inherited.
- (void) readUnknownJAXBAttribute: (xmlTextReaderPtr) reader
{
  [super readUnknownJAXBAttribute: reader];
}

//documentation inherited.
- (void) writeJAXBAttributes: (xmlTextWriterPtr) writer
{
  int status;

  [super writeJAXBAttributes: writer];

}

//documentation inherited.
- (void) writeJAXBValue: (xmlTextWriterPtr) writer
{
  [super writeJAXBValue: writer];
}

/**
 * Method for writing the child elements.
 *
 * @param writer The writer.
 */
- (void) writeJAXBChildElements: (xmlTextWriterPtr) writer
{
  int status;
  id __item;
  NSEnumerator *__enumerator;

  [super writeJAXBChildElements: writer];

  if ([self name]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "name", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}name."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}name...");
#endif
    [[self name] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}name...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}name."];
    }
  }
  if ([self type]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "type", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}type."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}type...");
#endif
    [[self type] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}type...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}type."];
    }
  }
  if ([self description]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "description", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}description."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}description...");
#endif
    [[self description] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}description...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}description."];
    }
  }
  if ([self method]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "methods", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start wrapper element {}methods."];
    }
    __enumerator = [[self method] objectEnumerator];

    while ( (__item = [__enumerator nextObject]) ) {
      status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "method", NULL);
      if (status < 0) {
        [NSException raise: @"XMLWriteError"
                     format: @"Error writing start child element {}method."];
      }

#if DEBUG_ENUNCIATE > 1
      NSLog(@"writing element {}method...");
#endif
      [__item writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
      NSLog(@"successfully wrote element {}method...");
#endif

      status = xmlTextWriterEndElement(writer);
      if (status < 0) {
        [NSException raise: @"XMLWriteError"
                     format: @"Error writing end child element {}method."];
      }
    } //end item iterator.

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end wrapper element {}methods."];
    }
  }
  if ([self repositoryTargetId]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "repositoryTargetId", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}repositoryTargetId."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}repositoryTargetId...");
#endif
    [[self repositoryTargetId] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}repositoryTargetId...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}repositoryTargetId."];
    }
  }
  if ([self repositoryId]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "repositoryId", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}repositoryId."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}repositoryId...");
#endif
    [[self repositoryId] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}repositoryId...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}repositoryId."];
    }
  }
  if ([self repositoryGroupId]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "repositoryGroupId", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}repositoryGroupId."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}repositoryGroupId...");
#endif
    [[self repositoryGroupId] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}repositoryGroupId...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}repositoryGroupId."];
    }
  }
}
@end /* implementation NEXUS_REST_APINS0PrivilegeResource (JAXB) */

#endif /* DEF_NEXUS_REST_APINS0PrivilegeResource_M */
#ifndef DEF_NEXUS_REST_APINS0RemoteConnectionSettings_M
#define DEF_NEXUS_REST_APINS0RemoteConnectionSettings_M

/**
 *  
         The connections settings defines common connection
 properties, like retries count and timeouts.
       
 
 @version $Revision$ $Date$

 */
@implementation NEXUS_REST_APINS0RemoteConnectionSettings

/**
 * Connection timeout in milliseconds.
 */
- (int) connectionTimeout
{
  return _connectionTimeout;
}

/**
 * Connection timeout in milliseconds.
 */
- (void) setConnectionTimeout: (int) newConnectionTimeout
{
  _connectionTimeout = newConnectionTimeout;
}

/**
 * The retry count before remote connection is declared
unsuccesful.
 */
- (int) retrievalRetryCount
{
  return _retrievalRetryCount;
}

/**
 * The retry count before remote connection is declared
unsuccesful.
 */
- (void) setRetrievalRetryCount: (int) newRetrievalRetryCount
{
  _retrievalRetryCount = newRetrievalRetryCount;
}

/**
 * Query string that is appended to remote requests.
 */
- (NSString *) queryString
{
  return _queryString;
}

/**
 * Query string that is appended to remote requests.
 */
- (void) setQueryString: (NSString *) newQueryString
{
  [newQueryString retain];
  [_queryString release];
  _queryString = newQueryString;
}

/**
 * User agent string that is used to customize Nexus user agent
string user for remote HTTP requests.
 */
- (NSString *) userAgentString
{
  return _userAgentString;
}

/**
 * User agent string that is used to customize Nexus user agent
string user for remote HTTP requests.
 */
- (void) setUserAgentString: (NSString *) newUserAgentString
{
  [newUserAgentString retain];
  [_userAgentString release];
  _userAgentString = newUserAgentString;
}

- (void) dealloc
{
  [self setQueryString: nil];
  [self setUserAgentString: nil];
  [super dealloc];
}
@end /* implementation NEXUS_REST_APINS0RemoteConnectionSettings */

/**
 * Internal, private interface for JAXB reading and writing.
 */
@interface NEXUS_REST_APINS0RemoteConnectionSettings (JAXB) <JAXBReading, JAXBWriting, JAXBType>

@end /*interface NEXUS_REST_APINS0RemoteConnectionSettings (JAXB)*/

/**
 * Internal, private implementation for JAXB reading and writing.
 */
@implementation NEXUS_REST_APINS0RemoteConnectionSettings (JAXB)

/**
 * Read an instance of NEXUS_REST_APINS0RemoteConnectionSettings from an XML reader.
 *
 * @param reader The reader.
 * @return An instance of NEXUS_REST_APINS0RemoteConnectionSettings defined by the XML reader.
 */
+ (id<JAXBType>) readXMLType: (xmlTextReaderPtr) reader
{
  NEXUS_REST_APINS0RemoteConnectionSettings *_nEXUS_REST_APINS0RemoteConnectionSettings = [[NEXUS_REST_APINS0RemoteConnectionSettings alloc] init];
  NS_DURING
  {
    [_nEXUS_REST_APINS0RemoteConnectionSettings initWithReader: reader];
  }
  NS_HANDLER
  {
    [_nEXUS_REST_APINS0RemoteConnectionSettings dealloc];
    _nEXUS_REST_APINS0RemoteConnectionSettings = nil;
    [localException raise];
  }
  NS_ENDHANDLER

  [_nEXUS_REST_APINS0RemoteConnectionSettings autorelease];
  return _nEXUS_REST_APINS0RemoteConnectionSettings;
}

/**
 * Initialize this instance of NEXUS_REST_APINS0RemoteConnectionSettings according to
 * the XML being read from the reader.
 *
 * @param reader The reader.
 */
- (id) initWithReader: (xmlTextReaderPtr) reader
{
  return [super initWithReader: reader];
}

/**
 * Write the XML for this instance of NEXUS_REST_APINS0RemoteConnectionSettings to the writer.
 * Note that since we're only writing the XML type,
 * No start/end element will be written.
 *
 * @param reader The reader.
 */
- (void) writeXMLType: (xmlTextWriterPtr) writer
{
  [super writeXMLType:writer];
}

//documentation inherited.
- (BOOL) readJAXBAttribute: (xmlTextReaderPtr) reader
{
  void *_child_accessor;

  if ([super readJAXBAttribute: reader]) {
    return YES;
  }

  return NO;
}

//documentation inherited.
- (BOOL) readJAXBValue: (xmlTextReaderPtr) reader
{
  return [super readJAXBValue: reader];
}

//documentation inherited.
- (BOOL) readJAXBChildElement: (xmlTextReaderPtr) reader
{
  id __child;
  void *_child_accessor;
  int status, depth;

  if ([super readJAXBChildElement: reader]) {
    return YES;
  }

  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "connectionTimeout", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

    _child_accessor = xmlTextReaderReadIntType(reader);
    if (_child_accessor == NULL) {
      //panic: unable to return the value for some reason.
      [self dealloc];
      [NSException raise: @"XMLReadError"
                   format: @"Error reading element value."];
    }
    [self setConnectionTimeout: *((int*) _child_accessor)];
    free(_child_accessor);
    return YES;
  }

  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "retrievalRetryCount", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

    _child_accessor = xmlTextReaderReadIntType(reader);
    if (_child_accessor == NULL) {
      //panic: unable to return the value for some reason.
      [self dealloc];
      [NSException raise: @"XMLReadError"
                   format: @"Error reading element value."];
    }
    [self setRetrievalRetryCount: *((int*) _child_accessor)];
    free(_child_accessor);
    return YES;
  }
  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "queryString", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}queryString of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}queryString of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setQueryString: __child];
    return YES;
  } //end "if choice"

  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "userAgentString", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}userAgentString of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}userAgentString of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setUserAgentString: __child];
    return YES;
  } //end "if choice"


  return NO;
}

//documentation inherited.
- (int) readUnknownJAXBChildElement: (xmlTextReaderPtr) reader
{
  return [super readUnknownJAXBChildElement: reader];
}

//documentation inherited.
- (void) readUnknownJAXBAttribute: (xmlTextReaderPtr) reader
{
  [super readUnknownJAXBAttribute: reader];
}

//documentation inherited.
- (void) writeJAXBAttributes: (xmlTextWriterPtr) writer
{
  int status;

  [super writeJAXBAttributes: writer];

}

//documentation inherited.
- (void) writeJAXBValue: (xmlTextWriterPtr) writer
{
  [super writeJAXBValue: writer];
}

/**
 * Method for writing the child elements.
 *
 * @param writer The writer.
 */
- (void) writeJAXBChildElements: (xmlTextWriterPtr) writer
{
  int status;
  id __item;
  NSEnumerator *__enumerator;

  [super writeJAXBChildElements: writer];

  if (YES) { //always write the primitive element...
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "connectionTimeout", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}connectionTimeout."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}connectionTimeout...");
#endif
    status = xmlTextWriterWriteIntType(writer, &_connectionTimeout);
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}connectionTimeout...");
#endif
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing child element {}connectionTimeout."];
    }

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}connectionTimeout."];
    }
  }
  if (YES) { //always write the primitive element...
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "retrievalRetryCount", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}retrievalRetryCount."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}retrievalRetryCount...");
#endif
    status = xmlTextWriterWriteIntType(writer, &_retrievalRetryCount);
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}retrievalRetryCount...");
#endif
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing child element {}retrievalRetryCount."];
    }

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}retrievalRetryCount."];
    }
  }
  if ([self queryString]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "queryString", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}queryString."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}queryString...");
#endif
    [[self queryString] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}queryString...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}queryString."];
    }
  }
  if ([self userAgentString]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "userAgentString", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}userAgentString."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}userAgentString...");
#endif
    [[self userAgentString] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}userAgentString...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}userAgentString."];
    }
  }
}
@end /* implementation NEXUS_REST_APINS0RemoteConnectionSettings (JAXB) */

#endif /* DEF_NEXUS_REST_APINS0RemoteConnectionSettings_M */
#ifndef DEF_NEXUS_REST_APINS0RepositoryBaseResource_M
#define DEF_NEXUS_REST_APINS0RepositoryBaseResource_M

/**
 *  The repository base object, this could be extended by a new
 object if new fields are required.
 
 @version $Revision$ $Date$

 */
@implementation NEXUS_REST_APINS0RepositoryBaseResource

/**
 * The URL to access the content resource of the repository.
 */
- (NSString *) contentResourceURI
{
  return _contentResourceURI;
}

/**
 * The URL to access the content resource of the repository.
 */
- (void) setContentResourceURI: (NSString *) newContentResourceURI
{
  [newContentResourceURI retain];
  [_contentResourceURI release];
  _contentResourceURI = newContentResourceURI;
}

/**
 * The id of the repository.
 */
- (NSString *) id
{
  return _id;
}

/**
 * The id of the repository.
 */
- (void) setId: (NSString *) newId
{
  [newId retain];
  [_id release];
  _id = newId;
}

/**
 * The name of the repository.
 */
- (NSString *) name
{
  return _name;
}

/**
 * The name of the repository.
 */
- (void) setName: (NSString *) newName
{
  [newName retain];
  [_name release];
  _name = newName;
}

/**
 * The provider of the repository (i.e. maven, p2, obr, etc.).
 */
- (NSString *) provider
{
  return _provider;
}

/**
 * The provider of the repository (i.e. maven, p2, obr, etc.).
 */
- (void) setProvider: (NSString *) newProvider
{
  [newProvider retain];
  [_provider release];
  _provider = newProvider;
}

/**
 * The role of the repository (i.e. Repository,
GroupRepository, etc.).
 */
- (NSString *) providerRole
{
  return _providerRole;
}

/**
 * The role of the repository (i.e. Repository,
GroupRepository, etc.).
 */
- (void) setProviderRole: (NSString *) newProviderRole
{
  [newProviderRole retain];
  [_providerRole release];
  _providerRole = newProviderRole;
}

/**
 * The format of the repository.
 */
- (NSString *) format
{
  return _format;
}

/**
 * The format of the repository.
 */
- (void) setFormat: (NSString *) newFormat
{
  [newFormat retain];
  [_format release];
  _format = newFormat;
}

/**
 * The type of the repository.
 */
- (NSString *) repoType
{
  return _repoType;
}

/**
 * The type of the repository.
 */
- (void) setRepoType: (NSString *) newRepoType
{
  [newRepoType retain];
  [_repoType release];
  _repoType = newRepoType;
}

/**
 * Flag that states whether the repository should be available
over the content resource.
 */
- (BOOL) exposed
{
  return _exposed;
}

/**
 * Flag that states whether the repository should be available
over the content resource.
 */
- (void) setExposed: (BOOL) newExposed
{
  _exposed = newExposed;
}

- (void) dealloc
{
  [self setContentResourceURI: nil];
  [self setId: nil];
  [self setName: nil];
  [self setProvider: nil];
  [self setProviderRole: nil];
  [self setFormat: nil];
  [self setRepoType: nil];
  [super dealloc];
}
@end /* implementation NEXUS_REST_APINS0RepositoryBaseResource */

/**
 * Internal, private interface for JAXB reading and writing.
 */
@interface NEXUS_REST_APINS0RepositoryBaseResource (JAXB) <JAXBReading, JAXBWriting, JAXBType>

@end /*interface NEXUS_REST_APINS0RepositoryBaseResource (JAXB)*/

/**
 * Internal, private implementation for JAXB reading and writing.
 */
@implementation NEXUS_REST_APINS0RepositoryBaseResource (JAXB)

/**
 * Read an instance of NEXUS_REST_APINS0RepositoryBaseResource from an XML reader.
 *
 * @param reader The reader.
 * @return An instance of NEXUS_REST_APINS0RepositoryBaseResource defined by the XML reader.
 */
+ (id<JAXBType>) readXMLType: (xmlTextReaderPtr) reader
{
  NEXUS_REST_APINS0RepositoryBaseResource *_nEXUS_REST_APINS0RepositoryBaseResource = [[NEXUS_REST_APINS0RepositoryBaseResource alloc] init];
  NS_DURING
  {
    [_nEXUS_REST_APINS0RepositoryBaseResource initWithReader: reader];
  }
  NS_HANDLER
  {
    [_nEXUS_REST_APINS0RepositoryBaseResource dealloc];
    _nEXUS_REST_APINS0RepositoryBaseResource = nil;
    [localException raise];
  }
  NS_ENDHANDLER

  [_nEXUS_REST_APINS0RepositoryBaseResource autorelease];
  return _nEXUS_REST_APINS0RepositoryBaseResource;
}

/**
 * Initialize this instance of NEXUS_REST_APINS0RepositoryBaseResource according to
 * the XML being read from the reader.
 *
 * @param reader The reader.
 */
- (id) initWithReader: (xmlTextReaderPtr) reader
{
  return [super initWithReader: reader];
}

/**
 * Write the XML for this instance of NEXUS_REST_APINS0RepositoryBaseResource to the writer.
 * Note that since we're only writing the XML type,
 * No start/end element will be written.
 *
 * @param reader The reader.
 */
- (void) writeXMLType: (xmlTextWriterPtr) writer
{
  [super writeXMLType:writer];
}

//documentation inherited.
- (BOOL) readJAXBAttribute: (xmlTextReaderPtr) reader
{
  void *_child_accessor;

  if ([super readJAXBAttribute: reader]) {
    return YES;
  }

  return NO;
}

//documentation inherited.
- (BOOL) readJAXBValue: (xmlTextReaderPtr) reader
{
  return [super readJAXBValue: reader];
}

//documentation inherited.
- (BOOL) readJAXBChildElement: (xmlTextReaderPtr) reader
{
  id __child;
  void *_child_accessor;
  int status, depth;

  if ([super readJAXBChildElement: reader]) {
    return YES;
  }
  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "contentResourceURI", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}contentResourceURI of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}contentResourceURI of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setContentResourceURI: __child];
    return YES;
  } //end "if choice"

  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "id", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}id of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}id of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setId: __child];
    return YES;
  } //end "if choice"

  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "name", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}name of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}name of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setName: __child];
    return YES;
  } //end "if choice"

  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "provider", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}provider of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}provider of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setProvider: __child];
    return YES;
  } //end "if choice"

  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "providerRole", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}providerRole of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}providerRole of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setProviderRole: __child];
    return YES;
  } //end "if choice"

  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "format", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}format of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}format of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setFormat: __child];
    return YES;
  } //end "if choice"

  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "repoType", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}repoType of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}repoType of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setRepoType: __child];
    return YES;
  } //end "if choice"


  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "exposed", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

    _child_accessor = xmlTextReaderReadBooleanType(reader);
    if (_child_accessor == NULL) {
      //panic: unable to return the value for some reason.
      [self dealloc];
      [NSException raise: @"XMLReadError"
                   format: @"Error reading element value."];
    }
    [self setExposed: *((BOOL*) _child_accessor)];
    free(_child_accessor);
    return YES;
  }

  return NO;
}

//documentation inherited.
- (int) readUnknownJAXBChildElement: (xmlTextReaderPtr) reader
{
  return [super readUnknownJAXBChildElement: reader];
}

//documentation inherited.
- (void) readUnknownJAXBAttribute: (xmlTextReaderPtr) reader
{
  [super readUnknownJAXBAttribute: reader];
}

//documentation inherited.
- (void) writeJAXBAttributes: (xmlTextWriterPtr) writer
{
  int status;

  [super writeJAXBAttributes: writer];

}

//documentation inherited.
- (void) writeJAXBValue: (xmlTextWriterPtr) writer
{
  [super writeJAXBValue: writer];
}

/**
 * Method for writing the child elements.
 *
 * @param writer The writer.
 */
- (void) writeJAXBChildElements: (xmlTextWriterPtr) writer
{
  int status;
  id __item;
  NSEnumerator *__enumerator;

  [super writeJAXBChildElements: writer];

  if ([self contentResourceURI]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "contentResourceURI", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}contentResourceURI."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}contentResourceURI...");
#endif
    [[self contentResourceURI] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}contentResourceURI...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}contentResourceURI."];
    }
  }
  if ([self id]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "id", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}id."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}id...");
#endif
    [[self id] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}id...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}id."];
    }
  }
  if ([self name]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "name", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}name."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}name...");
#endif
    [[self name] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}name...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}name."];
    }
  }
  if ([self provider]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "provider", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}provider."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}provider...");
#endif
    [[self provider] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}provider...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}provider."];
    }
  }
  if ([self providerRole]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "providerRole", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}providerRole."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}providerRole...");
#endif
    [[self providerRole] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}providerRole...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}providerRole."];
    }
  }
  if ([self format]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "format", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}format."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}format...");
#endif
    [[self format] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}format...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}format."];
    }
  }
  if ([self repoType]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "repoType", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}repoType."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}repoType...");
#endif
    [[self repoType] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}repoType...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}repoType."];
    }
  }
  if (YES) { //always write the primitive element...
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "exposed", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}exposed."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}exposed...");
#endif
    status = xmlTextWriterWriteBooleanType(writer, &_exposed);
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}exposed...");
#endif
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing child element {}exposed."];
    }

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}exposed."];
    }
  }
}
@end /* implementation NEXUS_REST_APINS0RepositoryBaseResource (JAXB) */

#endif /* DEF_NEXUS_REST_APINS0RepositoryBaseResource_M */
#ifndef DEF_NEXUS_REST_APINS0RepositoryContentClassListResource_M
#define DEF_NEXUS_REST_APINS0RepositoryContentClassListResource_M

/**
 *  Repository content class definition.
 
 @version $Revision$ $Date$

 */
@implementation NEXUS_REST_APINS0RepositoryContentClassListResource

/**
 * The content class.
 */
- (NSString *) contentClass
{
  return _contentClass;
}

/**
 * The content class.
 */
- (void) setContentClass: (NSString *) newContentClass
{
  [newContentClass retain];
  [_contentClass release];
  _contentClass = newContentClass;
}

/**
 * The name of the content class.
 */
- (NSString *) name
{
  return _name;
}

/**
 * The name of the content class.
 */
- (void) setName: (NSString *) newName
{
  [newName retain];
  [_name release];
  _name = newName;
}

/**
 * Flag stating if this content class can be placed in group.
 */
- (BOOL) groupable
{
  return _groupable;
}

/**
 * Flag stating if this content class can be placed in group.
 */
- (void) setGroupable: (BOOL) newGroupable
{
  _groupable = newGroupable;
}

/**
 * Field compatibleTypes.
 */
- (NSArray *) compatibleTypes
{
  return _compatibleTypes;
}

/**
 * Field compatibleTypes.
 */
- (void) setCompatibleTypes: (NSArray *) newCompatibleTypes
{
  [newCompatibleTypes retain];
  [_compatibleTypes release];
  _compatibleTypes = newCompatibleTypes;
}

- (void) dealloc
{
  [self setContentClass: nil];
  [self setName: nil];
  [self setCompatibleTypes: nil];
  [super dealloc];
}
@end /* implementation NEXUS_REST_APINS0RepositoryContentClassListResource */

/**
 * Internal, private interface for JAXB reading and writing.
 */
@interface NEXUS_REST_APINS0RepositoryContentClassListResource (JAXB) <JAXBReading, JAXBWriting, JAXBType>

@end /*interface NEXUS_REST_APINS0RepositoryContentClassListResource (JAXB)*/

/**
 * Internal, private implementation for JAXB reading and writing.
 */
@implementation NEXUS_REST_APINS0RepositoryContentClassListResource (JAXB)

/**
 * Read an instance of NEXUS_REST_APINS0RepositoryContentClassListResource from an XML reader.
 *
 * @param reader The reader.
 * @return An instance of NEXUS_REST_APINS0RepositoryContentClassListResource defined by the XML reader.
 */
+ (id<JAXBType>) readXMLType: (xmlTextReaderPtr) reader
{
  NEXUS_REST_APINS0RepositoryContentClassListResource *_nEXUS_REST_APINS0RepositoryContentClassListResource = [[NEXUS_REST_APINS0RepositoryContentClassListResource alloc] init];
  NS_DURING
  {
    [_nEXUS_REST_APINS0RepositoryContentClassListResource initWithReader: reader];
  }
  NS_HANDLER
  {
    [_nEXUS_REST_APINS0RepositoryContentClassListResource dealloc];
    _nEXUS_REST_APINS0RepositoryContentClassListResource = nil;
    [localException raise];
  }
  NS_ENDHANDLER

  [_nEXUS_REST_APINS0RepositoryContentClassListResource autorelease];
  return _nEXUS_REST_APINS0RepositoryContentClassListResource;
}

/**
 * Initialize this instance of NEXUS_REST_APINS0RepositoryContentClassListResource according to
 * the XML being read from the reader.
 *
 * @param reader The reader.
 */
- (id) initWithReader: (xmlTextReaderPtr) reader
{
  return [super initWithReader: reader];
}

/**
 * Write the XML for this instance of NEXUS_REST_APINS0RepositoryContentClassListResource to the writer.
 * Note that since we're only writing the XML type,
 * No start/end element will be written.
 *
 * @param reader The reader.
 */
- (void) writeXMLType: (xmlTextWriterPtr) writer
{
  [super writeXMLType:writer];
}

//documentation inherited.
- (BOOL) readJAXBAttribute: (xmlTextReaderPtr) reader
{
  void *_child_accessor;

  if ([super readJAXBAttribute: reader]) {
    return YES;
  }

  return NO;
}

//documentation inherited.
- (BOOL) readJAXBValue: (xmlTextReaderPtr) reader
{
  return [super readJAXBValue: reader];
}

//documentation inherited.
- (BOOL) readJAXBChildElement: (xmlTextReaderPtr) reader
{
  id __child;
  void *_child_accessor;
  int status, depth;

  if ([super readJAXBChildElement: reader]) {
    return YES;
  }
  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "contentClass", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}contentClass of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}contentClass of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setContentClass: __child];
    return YES;
  } //end "if choice"

  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "name", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}name of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}name of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setName: __child];
    return YES;
  } //end "if choice"


  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "groupable", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

    _child_accessor = xmlTextReaderReadBooleanType(reader);
    if (_child_accessor == NULL) {
      //panic: unable to return the value for some reason.
      [self dealloc];
      [NSException raise: @"XMLReadError"
                   format: @"Error reading element value."];
    }
    [self setGroupable: *((BOOL*) _child_accessor)];
    free(_child_accessor);
    return YES;
  }
  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "compatibleTypes", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

    if (xmlTextReaderIsEmptyElement(reader) == 0) {
#if DEBUG_ENUNCIATE > 1
      NSLog(@"Unwrapping wrapper element {}compatibleTypes...");
#endif
      //start wrapper element "{}compatibleTypes"
      depth = xmlTextReaderDepth(reader);
      status = xmlTextReaderAdvanceToNextStartOrEndElement(reader);
      while (xmlTextReaderDepth(reader) > depth) {
        if (status < 1) {
          //panic: XML read error.
          [self dealloc];
          [NSException raise: @"XMLReadError"
                       format: @"Failure to advance to next wrapped child element."];
        }
  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "compatibleType", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}compatibleType of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}compatibleType of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    if ([self compatibleTypes]) {
      [self setCompatibleTypes: [[self compatibleTypes] arrayByAddingObject: __child]];
    }
    else {
      [self setCompatibleTypes: [NSArray arrayWithObject: __child]];
    }
    continue; //continue "while in wrapper element" loop
  } //end "if choice"

        status = xmlTextReaderAdvanceToNextStartOrEndElement(reader);
#if DEBUG_ENUNCIATE > 1
        NSLog(@"successfully unwrapped wrapper element {}compatibleTypes...");
#endif
      } // end "while in wrapper element" loop

      if (status < 1) {
        //panic: XML read error.
        [self dealloc];
        [NSException raise: @"XMLReadError"
                     format: @"Failure to advance to end wrapper element."];
      }
      else {
        //end wrapper element "{}compatibleTypes"
        status = xmlTextReaderAdvanceToNextStartOrEndElement(reader);
      }
    } //end "if empty element" clause
    else {
      __child = [NSArray array];
      [self setCompatibleTypes: (NSArray*) __child];
    }

    return YES;
  } // end "if wrapper element" clause

  return NO;
}

//documentation inherited.
- (int) readUnknownJAXBChildElement: (xmlTextReaderPtr) reader
{
  return [super readUnknownJAXBChildElement: reader];
}

//documentation inherited.
- (void) readUnknownJAXBAttribute: (xmlTextReaderPtr) reader
{
  [super readUnknownJAXBAttribute: reader];
}

//documentation inherited.
- (void) writeJAXBAttributes: (xmlTextWriterPtr) writer
{
  int status;

  [super writeJAXBAttributes: writer];

}

//documentation inherited.
- (void) writeJAXBValue: (xmlTextWriterPtr) writer
{
  [super writeJAXBValue: writer];
}

/**
 * Method for writing the child elements.
 *
 * @param writer The writer.
 */
- (void) writeJAXBChildElements: (xmlTextWriterPtr) writer
{
  int status;
  id __item;
  NSEnumerator *__enumerator;

  [super writeJAXBChildElements: writer];

  if ([self contentClass]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "contentClass", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}contentClass."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}contentClass...");
#endif
    [[self contentClass] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}contentClass...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}contentClass."];
    }
  }
  if ([self name]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "name", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}name."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}name...");
#endif
    [[self name] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}name...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}name."];
    }
  }
  if (YES) { //always write the primitive element...
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "groupable", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}groupable."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}groupable...");
#endif
    status = xmlTextWriterWriteBooleanType(writer, &_groupable);
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}groupable...");
#endif
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing child element {}groupable."];
    }

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}groupable."];
    }
  }
  if ([self compatibleTypes]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "compatibleTypes", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start wrapper element {}compatibleTypes."];
    }
    __enumerator = [[self compatibleTypes] objectEnumerator];

    while ( (__item = [__enumerator nextObject]) ) {
      status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "compatibleType", NULL);
      if (status < 0) {
        [NSException raise: @"XMLWriteError"
                     format: @"Error writing start child element {}compatibleType."];
      }

#if DEBUG_ENUNCIATE > 1
      NSLog(@"writing element {}compatibleType...");
#endif
      [__item writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
      NSLog(@"successfully wrote element {}compatibleType...");
#endif

      status = xmlTextWriterEndElement(writer);
      if (status < 0) {
        [NSException raise: @"XMLWriteError"
                     format: @"Error writing end child element {}compatibleType."];
      }
    } //end item iterator.

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end wrapper element {}compatibleTypes."];
    }
  }
}
@end /* implementation NEXUS_REST_APINS0RepositoryContentClassListResource (JAXB) */

#endif /* DEF_NEXUS_REST_APINS0RepositoryContentClassListResource_M */
#ifndef DEF_NEXUS_REST_APINS0RepositoryGroupListResource_M
#define DEF_NEXUS_REST_APINS0RepositoryGroupListResource_M

/**
 *  The basic set of details of a repository group.
 
 @version $Revision$ $Date$

 */
@implementation NEXUS_REST_APINS0RepositoryGroupListResource

/**
 * URL used to manage the repository group.
 */
- (NSString *) resourceURI
{
  return _resourceURI;
}

/**
 * URL used to manage the repository group.
 */
- (void) setResourceURI: (NSString *) newResourceURI
{
  [newResourceURI retain];
  [_resourceURI release];
  _resourceURI = newResourceURI;
}

/**
 * URL used to manage content of the repository group.
 */
- (NSString *) contentResourceURI
{
  return _contentResourceURI;
}

/**
 * URL used to manage content of the repository group.
 */
- (void) setContentResourceURI: (NSString *) newContentResourceURI
{
  [newContentResourceURI retain];
  [_contentResourceURI release];
  _contentResourceURI = newContentResourceURI;
}

/**
 * The id of the repository group.
 */
- (NSString *) id
{
  return _id;
}

/**
 * The id of the repository group.
 */
- (void) setId: (NSString *) newId
{
  [newId retain];
  [_id release];
  _id = newId;
}

/**
 * The name of the repository group.
 */
- (NSString *) name
{
  return _name;
}

/**
 * The name of the repository group.
 */
- (void) setName: (NSString *) newName
{
  [newName retain];
  [_name release];
  _name = newName;
}

/**
 * The format of the repository group.
 */
- (NSString *) format
{
  return _format;
}

/**
 * The format of the repository group.
 */
- (void) setFormat: (NSString *) newFormat
{
  [newFormat retain];
  [_format release];
  _format = newFormat;
}

/**
 * Flag that states if the repository group is available over
the content resource.
 */
- (BOOL) exposed
{
  return _exposed;
}

/**
 * Flag that states if the repository group is available over
the content resource.
 */
- (void) setExposed: (BOOL) newExposed
{
  _exposed = newExposed;
}

/**
 * Flag that states if the repository is manageable by the user.
 */
- (BOOL) userManaged
{
  return _userManaged;
}

/**
 * Flag that states if the repository is manageable by the user.
 */
- (void) setUserManaged: (BOOL) newUserManaged
{
  _userManaged = newUserManaged;
}

- (void) dealloc
{
  [self setResourceURI: nil];
  [self setContentResourceURI: nil];
  [self setId: nil];
  [self setName: nil];
  [self setFormat: nil];
  [super dealloc];
}
@end /* implementation NEXUS_REST_APINS0RepositoryGroupListResource */

/**
 * Internal, private interface for JAXB reading and writing.
 */
@interface NEXUS_REST_APINS0RepositoryGroupListResource (JAXB) <JAXBReading, JAXBWriting, JAXBType>

@end /*interface NEXUS_REST_APINS0RepositoryGroupListResource (JAXB)*/

/**
 * Internal, private implementation for JAXB reading and writing.
 */
@implementation NEXUS_REST_APINS0RepositoryGroupListResource (JAXB)

/**
 * Read an instance of NEXUS_REST_APINS0RepositoryGroupListResource from an XML reader.
 *
 * @param reader The reader.
 * @return An instance of NEXUS_REST_APINS0RepositoryGroupListResource defined by the XML reader.
 */
+ (id<JAXBType>) readXMLType: (xmlTextReaderPtr) reader
{
  NEXUS_REST_APINS0RepositoryGroupListResource *_nEXUS_REST_APINS0RepositoryGroupListResource = [[NEXUS_REST_APINS0RepositoryGroupListResource alloc] init];
  NS_DURING
  {
    [_nEXUS_REST_APINS0RepositoryGroupListResource initWithReader: reader];
  }
  NS_HANDLER
  {
    [_nEXUS_REST_APINS0RepositoryGroupListResource dealloc];
    _nEXUS_REST_APINS0RepositoryGroupListResource = nil;
    [localException raise];
  }
  NS_ENDHANDLER

  [_nEXUS_REST_APINS0RepositoryGroupListResource autorelease];
  return _nEXUS_REST_APINS0RepositoryGroupListResource;
}

/**
 * Initialize this instance of NEXUS_REST_APINS0RepositoryGroupListResource according to
 * the XML being read from the reader.
 *
 * @param reader The reader.
 */
- (id) initWithReader: (xmlTextReaderPtr) reader
{
  return [super initWithReader: reader];
}

/**
 * Write the XML for this instance of NEXUS_REST_APINS0RepositoryGroupListResource to the writer.
 * Note that since we're only writing the XML type,
 * No start/end element will be written.
 *
 * @param reader The reader.
 */
- (void) writeXMLType: (xmlTextWriterPtr) writer
{
  [super writeXMLType:writer];
}

//documentation inherited.
- (BOOL) readJAXBAttribute: (xmlTextReaderPtr) reader
{
  void *_child_accessor;

  if ([super readJAXBAttribute: reader]) {
    return YES;
  }

  return NO;
}

//documentation inherited.
- (BOOL) readJAXBValue: (xmlTextReaderPtr) reader
{
  return [super readJAXBValue: reader];
}

//documentation inherited.
- (BOOL) readJAXBChildElement: (xmlTextReaderPtr) reader
{
  id __child;
  void *_child_accessor;
  int status, depth;

  if ([super readJAXBChildElement: reader]) {
    return YES;
  }
  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "resourceURI", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}resourceURI of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}resourceURI of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setResourceURI: __child];
    return YES;
  } //end "if choice"

  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "contentResourceURI", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}contentResourceURI of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}contentResourceURI of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setContentResourceURI: __child];
    return YES;
  } //end "if choice"

  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "id", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}id of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}id of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setId: __child];
    return YES;
  } //end "if choice"

  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "name", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}name of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}name of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setName: __child];
    return YES;
  } //end "if choice"

  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "format", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}format of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}format of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setFormat: __child];
    return YES;
  } //end "if choice"


  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "exposed", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

    _child_accessor = xmlTextReaderReadBooleanType(reader);
    if (_child_accessor == NULL) {
      //panic: unable to return the value for some reason.
      [self dealloc];
      [NSException raise: @"XMLReadError"
                   format: @"Error reading element value."];
    }
    [self setExposed: *((BOOL*) _child_accessor)];
    free(_child_accessor);
    return YES;
  }

  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "userManaged", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

    _child_accessor = xmlTextReaderReadBooleanType(reader);
    if (_child_accessor == NULL) {
      //panic: unable to return the value for some reason.
      [self dealloc];
      [NSException raise: @"XMLReadError"
                   format: @"Error reading element value."];
    }
    [self setUserManaged: *((BOOL*) _child_accessor)];
    free(_child_accessor);
    return YES;
  }

  return NO;
}

//documentation inherited.
- (int) readUnknownJAXBChildElement: (xmlTextReaderPtr) reader
{
  return [super readUnknownJAXBChildElement: reader];
}

//documentation inherited.
- (void) readUnknownJAXBAttribute: (xmlTextReaderPtr) reader
{
  [super readUnknownJAXBAttribute: reader];
}

//documentation inherited.
- (void) writeJAXBAttributes: (xmlTextWriterPtr) writer
{
  int status;

  [super writeJAXBAttributes: writer];

}

//documentation inherited.
- (void) writeJAXBValue: (xmlTextWriterPtr) writer
{
  [super writeJAXBValue: writer];
}

/**
 * Method for writing the child elements.
 *
 * @param writer The writer.
 */
- (void) writeJAXBChildElements: (xmlTextWriterPtr) writer
{
  int status;
  id __item;
  NSEnumerator *__enumerator;

  [super writeJAXBChildElements: writer];

  if ([self resourceURI]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "resourceURI", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}resourceURI."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}resourceURI...");
#endif
    [[self resourceURI] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}resourceURI...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}resourceURI."];
    }
  }
  if ([self contentResourceURI]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "contentResourceURI", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}contentResourceURI."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}contentResourceURI...");
#endif
    [[self contentResourceURI] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}contentResourceURI...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}contentResourceURI."];
    }
  }
  if ([self id]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "id", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}id."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}id...");
#endif
    [[self id] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}id...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}id."];
    }
  }
  if ([self name]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "name", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}name."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}name...");
#endif
    [[self name] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}name...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}name."];
    }
  }
  if ([self format]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "format", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}format."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}format...");
#endif
    [[self format] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}format...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}format."];
    }
  }
  if (YES) { //always write the primitive element...
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "exposed", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}exposed."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}exposed...");
#endif
    status = xmlTextWriterWriteBooleanType(writer, &_exposed);
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}exposed...");
#endif
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing child element {}exposed."];
    }

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}exposed."];
    }
  }
  if (YES) { //always write the primitive element...
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "userManaged", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}userManaged."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}userManaged...");
#endif
    status = xmlTextWriterWriteBooleanType(writer, &_userManaged);
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}userManaged...");
#endif
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing child element {}userManaged."];
    }

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}userManaged."];
    }
  }
}
@end /* implementation NEXUS_REST_APINS0RepositoryGroupListResource (JAXB) */

#endif /* DEF_NEXUS_REST_APINS0RepositoryGroupListResource_M */
#ifndef DEF_NEXUS_REST_APINS0RepositoryGroupMemberRepository_M
#define DEF_NEXUS_REST_APINS0RepositoryGroupMemberRepository_M

/**
 *  A repository that is contained within a group.
 
 @version $Revision$ $Date$

 */
@implementation NEXUS_REST_APINS0RepositoryGroupMemberRepository

/**
 * The repository id.
 */
- (NSString *) id
{
  return _id;
}

/**
 * The repository id.
 */
- (void) setId: (NSString *) newId
{
  [newId retain];
  [_id release];
  _id = newId;
}

/**
 * The repository name.
 */
- (NSString *) name
{
  return _name;
}

/**
 * The repository name.
 */
- (void) setName: (NSString *) newName
{
  [newName retain];
  [_name release];
  _name = newName;
}

/**
 * The URL used to manage the repository.
 */
- (NSString *) resourceURI
{
  return _resourceURI;
}

/**
 * The URL used to manage the repository.
 */
- (void) setResourceURI: (NSString *) newResourceURI
{
  [newResourceURI retain];
  [_resourceURI release];
  _resourceURI = newResourceURI;
}

- (void) dealloc
{
  [self setId: nil];
  [self setName: nil];
  [self setResourceURI: nil];
  [super dealloc];
}
@end /* implementation NEXUS_REST_APINS0RepositoryGroupMemberRepository */

/**
 * Internal, private interface for JAXB reading and writing.
 */
@interface NEXUS_REST_APINS0RepositoryGroupMemberRepository (JAXB) <JAXBReading, JAXBWriting, JAXBType>

@end /*interface NEXUS_REST_APINS0RepositoryGroupMemberRepository (JAXB)*/

/**
 * Internal, private implementation for JAXB reading and writing.
 */
@implementation NEXUS_REST_APINS0RepositoryGroupMemberRepository (JAXB)

/**
 * Read an instance of NEXUS_REST_APINS0RepositoryGroupMemberRepository from an XML reader.
 *
 * @param reader The reader.
 * @return An instance of NEXUS_REST_APINS0RepositoryGroupMemberRepository defined by the XML reader.
 */
+ (id<JAXBType>) readXMLType: (xmlTextReaderPtr) reader
{
  NEXUS_REST_APINS0RepositoryGroupMemberRepository *_nEXUS_REST_APINS0RepositoryGroupMemberRepository = [[NEXUS_REST_APINS0RepositoryGroupMemberRepository alloc] init];
  NS_DURING
  {
    [_nEXUS_REST_APINS0RepositoryGroupMemberRepository initWithReader: reader];
  }
  NS_HANDLER
  {
    [_nEXUS_REST_APINS0RepositoryGroupMemberRepository dealloc];
    _nEXUS_REST_APINS0RepositoryGroupMemberRepository = nil;
    [localException raise];
  }
  NS_ENDHANDLER

  [_nEXUS_REST_APINS0RepositoryGroupMemberRepository autorelease];
  return _nEXUS_REST_APINS0RepositoryGroupMemberRepository;
}

/**
 * Initialize this instance of NEXUS_REST_APINS0RepositoryGroupMemberRepository according to
 * the XML being read from the reader.
 *
 * @param reader The reader.
 */
- (id) initWithReader: (xmlTextReaderPtr) reader
{
  return [super initWithReader: reader];
}

/**
 * Write the XML for this instance of NEXUS_REST_APINS0RepositoryGroupMemberRepository to the writer.
 * Note that since we're only writing the XML type,
 * No start/end element will be written.
 *
 * @param reader The reader.
 */
- (void) writeXMLType: (xmlTextWriterPtr) writer
{
  [super writeXMLType:writer];
}

//documentation inherited.
- (BOOL) readJAXBAttribute: (xmlTextReaderPtr) reader
{
  void *_child_accessor;

  if ([super readJAXBAttribute: reader]) {
    return YES;
  }

  return NO;
}

//documentation inherited.
- (BOOL) readJAXBValue: (xmlTextReaderPtr) reader
{
  return [super readJAXBValue: reader];
}

//documentation inherited.
- (BOOL) readJAXBChildElement: (xmlTextReaderPtr) reader
{
  id __child;
  void *_child_accessor;
  int status, depth;

  if ([super readJAXBChildElement: reader]) {
    return YES;
  }
  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "id", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}id of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}id of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setId: __child];
    return YES;
  } //end "if choice"

  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "name", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}name of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}name of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setName: __child];
    return YES;
  } //end "if choice"

  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "resourceURI", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}resourceURI of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}resourceURI of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setResourceURI: __child];
    return YES;
  } //end "if choice"


  return NO;
}

//documentation inherited.
- (int) readUnknownJAXBChildElement: (xmlTextReaderPtr) reader
{
  return [super readUnknownJAXBChildElement: reader];
}

//documentation inherited.
- (void) readUnknownJAXBAttribute: (xmlTextReaderPtr) reader
{
  [super readUnknownJAXBAttribute: reader];
}

//documentation inherited.
- (void) writeJAXBAttributes: (xmlTextWriterPtr) writer
{
  int status;

  [super writeJAXBAttributes: writer];

}

//documentation inherited.
- (void) writeJAXBValue: (xmlTextWriterPtr) writer
{
  [super writeJAXBValue: writer];
}

/**
 * Method for writing the child elements.
 *
 * @param writer The writer.
 */
- (void) writeJAXBChildElements: (xmlTextWriterPtr) writer
{
  int status;
  id __item;
  NSEnumerator *__enumerator;

  [super writeJAXBChildElements: writer];

  if ([self id]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "id", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}id."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}id...");
#endif
    [[self id] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}id...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}id."];
    }
  }
  if ([self name]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "name", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}name."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}name...");
#endif
    [[self name] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}name...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}name."];
    }
  }
  if ([self resourceURI]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "resourceURI", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}resourceURI."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}resourceURI...");
#endif
    [[self resourceURI] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}resourceURI...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}resourceURI."];
    }
  }
}
@end /* implementation NEXUS_REST_APINS0RepositoryGroupMemberRepository (JAXB) */

#endif /* DEF_NEXUS_REST_APINS0RepositoryGroupMemberRepository_M */
#ifndef DEF_NEXUS_REST_APINS0RepositoryDependentStatusResource_M
#define DEF_NEXUS_REST_APINS0RepositoryDependentStatusResource_M

/**
 *  Details of a repository that shadow another repository.
 
 @version $Revision$ $Date$

 */
@implementation NEXUS_REST_APINS0RepositoryDependentStatusResource

/**
 * The shadow repository id.
 */
- (NSString *) id
{
  return _id;
}

/**
 * The shadow repository id.
 */
- (void) setId: (NSString *) newId
{
  [newId retain];
  [_id release];
  _id = newId;
}

/**
 * The shadow repository type.
 */
- (NSString *) repoType
{
  return _repoType;
}

/**
 * The shadow repository type.
 */
- (void) setRepoType: (NSString *) newRepoType
{
  [newRepoType retain];
  [_repoType release];
  _repoType = newRepoType;
}

/**
 * The shadow repository format.
 */
- (NSString *) format
{
  return _format;
}

/**
 * The shadow repository format.
 */
- (void) setFormat: (NSString *) newFormat
{
  [newFormat retain];
  [_format release];
  _format = newFormat;
}

/**
 * The shadow repository local status.
 */
- (NSString *) localStatus
{
  return _localStatus;
}

/**
 * The shadow repository local status.
 */
- (void) setLocalStatus: (NSString *) newLocalStatus
{
  [newLocalStatus retain];
  [_localStatus release];
  _localStatus = newLocalStatus;
}

- (void) dealloc
{
  [self setId: nil];
  [self setRepoType: nil];
  [self setFormat: nil];
  [self setLocalStatus: nil];
  [super dealloc];
}
@end /* implementation NEXUS_REST_APINS0RepositoryDependentStatusResource */

/**
 * Internal, private interface for JAXB reading and writing.
 */
@interface NEXUS_REST_APINS0RepositoryDependentStatusResource (JAXB) <JAXBReading, JAXBWriting, JAXBType>

@end /*interface NEXUS_REST_APINS0RepositoryDependentStatusResource (JAXB)*/

/**
 * Internal, private implementation for JAXB reading and writing.
 */
@implementation NEXUS_REST_APINS0RepositoryDependentStatusResource (JAXB)

/**
 * Read an instance of NEXUS_REST_APINS0RepositoryDependentStatusResource from an XML reader.
 *
 * @param reader The reader.
 * @return An instance of NEXUS_REST_APINS0RepositoryDependentStatusResource defined by the XML reader.
 */
+ (id<JAXBType>) readXMLType: (xmlTextReaderPtr) reader
{
  NEXUS_REST_APINS0RepositoryDependentStatusResource *_nEXUS_REST_APINS0RepositoryDependentStatusResource = [[NEXUS_REST_APINS0RepositoryDependentStatusResource alloc] init];
  NS_DURING
  {
    [_nEXUS_REST_APINS0RepositoryDependentStatusResource initWithReader: reader];
  }
  NS_HANDLER
  {
    [_nEXUS_REST_APINS0RepositoryDependentStatusResource dealloc];
    _nEXUS_REST_APINS0RepositoryDependentStatusResource = nil;
    [localException raise];
  }
  NS_ENDHANDLER

  [_nEXUS_REST_APINS0RepositoryDependentStatusResource autorelease];
  return _nEXUS_REST_APINS0RepositoryDependentStatusResource;
}

/**
 * Initialize this instance of NEXUS_REST_APINS0RepositoryDependentStatusResource according to
 * the XML being read from the reader.
 *
 * @param reader The reader.
 */
- (id) initWithReader: (xmlTextReaderPtr) reader
{
  return [super initWithReader: reader];
}

/**
 * Write the XML for this instance of NEXUS_REST_APINS0RepositoryDependentStatusResource to the writer.
 * Note that since we're only writing the XML type,
 * No start/end element will be written.
 *
 * @param reader The reader.
 */
- (void) writeXMLType: (xmlTextWriterPtr) writer
{
  [super writeXMLType:writer];
}

//documentation inherited.
- (BOOL) readJAXBAttribute: (xmlTextReaderPtr) reader
{
  void *_child_accessor;

  if ([super readJAXBAttribute: reader]) {
    return YES;
  }

  return NO;
}

//documentation inherited.
- (BOOL) readJAXBValue: (xmlTextReaderPtr) reader
{
  return [super readJAXBValue: reader];
}

//documentation inherited.
- (BOOL) readJAXBChildElement: (xmlTextReaderPtr) reader
{
  id __child;
  void *_child_accessor;
  int status, depth;

  if ([super readJAXBChildElement: reader]) {
    return YES;
  }
  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "id", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}id of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}id of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setId: __child];
    return YES;
  } //end "if choice"

  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "repoType", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}repoType of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}repoType of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setRepoType: __child];
    return YES;
  } //end "if choice"

  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "format", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}format of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}format of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setFormat: __child];
    return YES;
  } //end "if choice"

  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "localStatus", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}localStatus of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}localStatus of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setLocalStatus: __child];
    return YES;
  } //end "if choice"


  return NO;
}

//documentation inherited.
- (int) readUnknownJAXBChildElement: (xmlTextReaderPtr) reader
{
  return [super readUnknownJAXBChildElement: reader];
}

//documentation inherited.
- (void) readUnknownJAXBAttribute: (xmlTextReaderPtr) reader
{
  [super readUnknownJAXBAttribute: reader];
}

//documentation inherited.
- (void) writeJAXBAttributes: (xmlTextWriterPtr) writer
{
  int status;

  [super writeJAXBAttributes: writer];

}

//documentation inherited.
- (void) writeJAXBValue: (xmlTextWriterPtr) writer
{
  [super writeJAXBValue: writer];
}

/**
 * Method for writing the child elements.
 *
 * @param writer The writer.
 */
- (void) writeJAXBChildElements: (xmlTextWriterPtr) writer
{
  int status;
  id __item;
  NSEnumerator *__enumerator;

  [super writeJAXBChildElements: writer];

  if ([self id]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "id", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}id."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}id...");
#endif
    [[self id] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}id...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}id."];
    }
  }
  if ([self repoType]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "repoType", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}repoType."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}repoType...");
#endif
    [[self repoType] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}repoType...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}repoType."];
    }
  }
  if ([self format]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "format", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}format."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}format...");
#endif
    [[self format] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}format...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}format."];
    }
  }
  if ([self localStatus]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "localStatus", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}localStatus."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}localStatus...");
#endif
    [[self localStatus] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}localStatus...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}localStatus."];
    }
  }
}
@end /* implementation NEXUS_REST_APINS0RepositoryDependentStatusResource (JAXB) */

#endif /* DEF_NEXUS_REST_APINS0RepositoryDependentStatusResource_M */
#ifndef DEF_NEXUS_REST_APINS0RepositoryListResource_M
#define DEF_NEXUS_REST_APINS0RepositoryListResource_M

/**
 *  Repository general details.
 
 @version $Revision$ $Date$

 */
@implementation NEXUS_REST_APINS0RepositoryListResource

/**
 * URI used to manage the repository.
 */
- (NSString *) resourceURI
{
  return _resourceURI;
}

/**
 * URI used to manage the repository.
 */
- (void) setResourceURI: (NSString *) newResourceURI
{
  [newResourceURI retain];
  [_resourceURI release];
  _resourceURI = newResourceURI;
}

/**
 * URI used to access repository over /content URL (as maven
would do for example).
 */
- (NSString *) contentResourceURI
{
  return _contentResourceURI;
}

/**
 * URI used to access repository over /content URL (as maven
would do for example).
 */
- (void) setContentResourceURI: (NSString *) newContentResourceURI
{
  [newContentResourceURI retain];
  [_contentResourceURI release];
  _contentResourceURI = newContentResourceURI;
}

/**
 * The id of the repository.
 */
- (NSString *) id
{
  return _id;
}

/**
 * The id of the repository.
 */
- (void) setId: (NSString *) newId
{
  [newId retain];
  [_id release];
  _id = newId;
}

/**
 * The name of the repository.
 */
- (NSString *) name
{
  return _name;
}

/**
 * The name of the repository.
 */
- (void) setName: (NSString *) newName
{
  [newName retain];
  [_name release];
  _name = newName;
}

/**
 * The type of the repository.
 */
- (NSString *) repoType
{
  return _repoType;
}

/**
 * The type of the repository.
 */
- (void) setRepoType: (NSString *) newRepoType
{
  [newRepoType retain];
  [_repoType release];
  _repoType = newRepoType;
}

/**
 * The policy of the repository.
 */
- (NSString *) repoPolicy
{
  return _repoPolicy;
}

/**
 * The policy of the repository.
 */
- (void) setRepoPolicy: (NSString *) newRepoPolicy
{
  [newRepoPolicy retain];
  [_repoPolicy release];
  _repoPolicy = newRepoPolicy;
}

/**
 * The repository provider.
 */
- (NSString *) provider
{
  return _provider;
}

/**
 * The repository provider.
 */
- (void) setProvider: (NSString *) newProvider
{
  [newProvider retain];
  [_provider release];
  _provider = newProvider;
}

/**
 * The role of the repository (classname).
 */
- (NSString *) providerRole
{
  return _providerRole;
}

/**
 * The role of the repository (classname).
 */
- (void) setProviderRole: (NSString *) newProviderRole
{
  [newProviderRole retain];
  [_providerRole release];
  _providerRole = newProviderRole;
}

/**
 * The format of the repository.
 */
- (NSString *) format
{
  return _format;
}

/**
 * The format of the repository.
 */
- (void) setFormat: (NSString *) newFormat
{
  [newFormat retain];
  [_format release];
  _format = newFormat;
}

/**
 * Flag that states if the repository is manageable by the user.
 */
- (BOOL) userManaged
{
  return _userManaged;
}

/**
 * Flag that states if the repository is manageable by the user.
 */
- (void) setUserManaged: (BOOL) newUserManaged
{
  _userManaged = newUserManaged;
}

/**
 * Flag that states if the repository is exposed over the
content url.
 */
- (BOOL) exposed
{
  return _exposed;
}

/**
 * Flag that states if the repository is exposed over the
content url.
 */
- (void) setExposed: (BOOL) newExposed
{
  _exposed = newExposed;
}

/**
 * The URL where the repository storage is on server.
 */
- (NSString *) effectiveLocalStorageUrl
{
  return _effectiveLocalStorageUrl;
}

/**
 * The URL where the repository storage is on server.
 */
- (void) setEffectiveLocalStorageUrl: (NSString *) newEffectiveLocalStorageUrl
{
  [newEffectiveLocalStorageUrl retain];
  [_effectiveLocalStorageUrl release];
  _effectiveLocalStorageUrl = newEffectiveLocalStorageUrl;
}

/**
 * The remote URI of the repository.
 */
- (NSString *) remoteUri
{
  return _remoteUri;
}

/**
 * The remote URI of the repository.
 */
- (void) setRemoteUri: (NSString *) newRemoteUri
{
  [newRemoteUri retain];
  [_remoteUri release];
  _remoteUri = newRemoteUri;
}

- (void) dealloc
{
  [self setResourceURI: nil];
  [self setContentResourceURI: nil];
  [self setId: nil];
  [self setName: nil];
  [self setRepoType: nil];
  [self setRepoPolicy: nil];
  [self setProvider: nil];
  [self setProviderRole: nil];
  [self setFormat: nil];
  [self setEffectiveLocalStorageUrl: nil];
  [self setRemoteUri: nil];
  [super dealloc];
}
@end /* implementation NEXUS_REST_APINS0RepositoryListResource */

/**
 * Internal, private interface for JAXB reading and writing.
 */
@interface NEXUS_REST_APINS0RepositoryListResource (JAXB) <JAXBReading, JAXBWriting, JAXBType>

@end /*interface NEXUS_REST_APINS0RepositoryListResource (JAXB)*/

/**
 * Internal, private implementation for JAXB reading and writing.
 */
@implementation NEXUS_REST_APINS0RepositoryListResource (JAXB)

/**
 * Read an instance of NEXUS_REST_APINS0RepositoryListResource from an XML reader.
 *
 * @param reader The reader.
 * @return An instance of NEXUS_REST_APINS0RepositoryListResource defined by the XML reader.
 */
+ (id<JAXBType>) readXMLType: (xmlTextReaderPtr) reader
{
  NEXUS_REST_APINS0RepositoryListResource *_nEXUS_REST_APINS0RepositoryListResource = [[NEXUS_REST_APINS0RepositoryListResource alloc] init];
  NS_DURING
  {
    [_nEXUS_REST_APINS0RepositoryListResource initWithReader: reader];
  }
  NS_HANDLER
  {
    [_nEXUS_REST_APINS0RepositoryListResource dealloc];
    _nEXUS_REST_APINS0RepositoryListResource = nil;
    [localException raise];
  }
  NS_ENDHANDLER

  [_nEXUS_REST_APINS0RepositoryListResource autorelease];
  return _nEXUS_REST_APINS0RepositoryListResource;
}

/**
 * Initialize this instance of NEXUS_REST_APINS0RepositoryListResource according to
 * the XML being read from the reader.
 *
 * @param reader The reader.
 */
- (id) initWithReader: (xmlTextReaderPtr) reader
{
  return [super initWithReader: reader];
}

/**
 * Write the XML for this instance of NEXUS_REST_APINS0RepositoryListResource to the writer.
 * Note that since we're only writing the XML type,
 * No start/end element will be written.
 *
 * @param reader The reader.
 */
- (void) writeXMLType: (xmlTextWriterPtr) writer
{
  [super writeXMLType:writer];
}

//documentation inherited.
- (BOOL) readJAXBAttribute: (xmlTextReaderPtr) reader
{
  void *_child_accessor;

  if ([super readJAXBAttribute: reader]) {
    return YES;
  }

  return NO;
}

//documentation inherited.
- (BOOL) readJAXBValue: (xmlTextReaderPtr) reader
{
  return [super readJAXBValue: reader];
}

//documentation inherited.
- (BOOL) readJAXBChildElement: (xmlTextReaderPtr) reader
{
  id __child;
  void *_child_accessor;
  int status, depth;

  if ([super readJAXBChildElement: reader]) {
    return YES;
  }
  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "resourceURI", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}resourceURI of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}resourceURI of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setResourceURI: __child];
    return YES;
  } //end "if choice"

  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "contentResourceURI", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}contentResourceURI of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}contentResourceURI of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setContentResourceURI: __child];
    return YES;
  } //end "if choice"

  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "id", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}id of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}id of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setId: __child];
    return YES;
  } //end "if choice"

  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "name", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}name of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}name of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setName: __child];
    return YES;
  } //end "if choice"

  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "repoType", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}repoType of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}repoType of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setRepoType: __child];
    return YES;
  } //end "if choice"

  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "repoPolicy", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}repoPolicy of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}repoPolicy of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setRepoPolicy: __child];
    return YES;
  } //end "if choice"

  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "provider", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}provider of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}provider of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setProvider: __child];
    return YES;
  } //end "if choice"

  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "providerRole", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}providerRole of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}providerRole of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setProviderRole: __child];
    return YES;
  } //end "if choice"

  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "format", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}format of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}format of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setFormat: __child];
    return YES;
  } //end "if choice"


  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "userManaged", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

    _child_accessor = xmlTextReaderReadBooleanType(reader);
    if (_child_accessor == NULL) {
      //panic: unable to return the value for some reason.
      [self dealloc];
      [NSException raise: @"XMLReadError"
                   format: @"Error reading element value."];
    }
    [self setUserManaged: *((BOOL*) _child_accessor)];
    free(_child_accessor);
    return YES;
  }

  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "exposed", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

    _child_accessor = xmlTextReaderReadBooleanType(reader);
    if (_child_accessor == NULL) {
      //panic: unable to return the value for some reason.
      [self dealloc];
      [NSException raise: @"XMLReadError"
                   format: @"Error reading element value."];
    }
    [self setExposed: *((BOOL*) _child_accessor)];
    free(_child_accessor);
    return YES;
  }
  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "effectiveLocalStorageUrl", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}effectiveLocalStorageUrl of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}effectiveLocalStorageUrl of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setEffectiveLocalStorageUrl: __child];
    return YES;
  } //end "if choice"

  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "remoteUri", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}remoteUri of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}remoteUri of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setRemoteUri: __child];
    return YES;
  } //end "if choice"


  return NO;
}

//documentation inherited.
- (int) readUnknownJAXBChildElement: (xmlTextReaderPtr) reader
{
  return [super readUnknownJAXBChildElement: reader];
}

//documentation inherited.
- (void) readUnknownJAXBAttribute: (xmlTextReaderPtr) reader
{
  [super readUnknownJAXBAttribute: reader];
}

//documentation inherited.
- (void) writeJAXBAttributes: (xmlTextWriterPtr) writer
{
  int status;

  [super writeJAXBAttributes: writer];

}

//documentation inherited.
- (void) writeJAXBValue: (xmlTextWriterPtr) writer
{
  [super writeJAXBValue: writer];
}

/**
 * Method for writing the child elements.
 *
 * @param writer The writer.
 */
- (void) writeJAXBChildElements: (xmlTextWriterPtr) writer
{
  int status;
  id __item;
  NSEnumerator *__enumerator;

  [super writeJAXBChildElements: writer];

  if ([self resourceURI]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "resourceURI", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}resourceURI."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}resourceURI...");
#endif
    [[self resourceURI] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}resourceURI...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}resourceURI."];
    }
  }
  if ([self contentResourceURI]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "contentResourceURI", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}contentResourceURI."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}contentResourceURI...");
#endif
    [[self contentResourceURI] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}contentResourceURI...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}contentResourceURI."];
    }
  }
  if ([self id]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "id", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}id."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}id...");
#endif
    [[self id] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}id...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}id."];
    }
  }
  if ([self name]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "name", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}name."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}name...");
#endif
    [[self name] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}name...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}name."];
    }
  }
  if ([self repoType]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "repoType", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}repoType."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}repoType...");
#endif
    [[self repoType] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}repoType...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}repoType."];
    }
  }
  if ([self repoPolicy]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "repoPolicy", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}repoPolicy."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}repoPolicy...");
#endif
    [[self repoPolicy] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}repoPolicy...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}repoPolicy."];
    }
  }
  if ([self provider]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "provider", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}provider."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}provider...");
#endif
    [[self provider] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}provider...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}provider."];
    }
  }
  if ([self providerRole]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "providerRole", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}providerRole."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}providerRole...");
#endif
    [[self providerRole] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}providerRole...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}providerRole."];
    }
  }
  if ([self format]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "format", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}format."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}format...");
#endif
    [[self format] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}format...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}format."];
    }
  }
  if (YES) { //always write the primitive element...
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "userManaged", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}userManaged."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}userManaged...");
#endif
    status = xmlTextWriterWriteBooleanType(writer, &_userManaged);
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}userManaged...");
#endif
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing child element {}userManaged."];
    }

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}userManaged."];
    }
  }
  if (YES) { //always write the primitive element...
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "exposed", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}exposed."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}exposed...");
#endif
    status = xmlTextWriterWriteBooleanType(writer, &_exposed);
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}exposed...");
#endif
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing child element {}exposed."];
    }

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}exposed."];
    }
  }
  if ([self effectiveLocalStorageUrl]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "effectiveLocalStorageUrl", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}effectiveLocalStorageUrl."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}effectiveLocalStorageUrl...");
#endif
    [[self effectiveLocalStorageUrl] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}effectiveLocalStorageUrl...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}effectiveLocalStorageUrl."];
    }
  }
  if ([self remoteUri]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "remoteUri", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}remoteUri."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}remoteUri...");
#endif
    [[self remoteUri] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}remoteUri...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}remoteUri."];
    }
  }
}
@end /* implementation NEXUS_REST_APINS0RepositoryListResource (JAXB) */

#endif /* DEF_NEXUS_REST_APINS0RepositoryListResource_M */
#ifndef DEF_NEXUS_REST_APINS0RepositoryMetaResource_M
#define DEF_NEXUS_REST_APINS0RepositoryMetaResource_M

/**
 *  Details about the repository.
 
 @version $Revision$ $Date$

 */
@implementation NEXUS_REST_APINS0RepositoryMetaResource

/**
 * The repository id.
 */
- (NSString *) id
{
  return _id;
}

/**
 * The repository id.
 */
- (void) setId: (NSString *) newId
{
  [newId retain];
  [_id release];
  _id = newId;
}

/**
 * The repository type.
 */
- (NSString *) repoType
{
  return _repoType;
}

/**
 * The repository type.
 */
- (void) setRepoType: (NSString *) newRepoType
{
  [newRepoType retain];
  [_repoType release];
  _repoType = newRepoType;
}

/**
 * The repository format.
 */
- (NSString *) format
{
  return _format;
}

/**
 * The repository format.
 */
- (void) setFormat: (NSString *) newFormat
{
  [newFormat retain];
  [_format release];
  _format = newFormat;
}

/**
 * The size on disk the repository consumes.
 */
- (long) sizeOnDisk
{
  return _sizeOnDisk;
}

/**
 * The size on disk the repository consumes.
 */
- (void) setSizeOnDisk: (long) newSizeOnDisk
{
  _sizeOnDisk = newSizeOnDisk;
}

/**
 * The size available on disk where the repository is located.
 */
- (long) freeSpaceOnDisk
{
  return _freeSpaceOnDisk;
}

/**
 * The size available on disk where the repository is located.
 */
- (void) setFreeSpaceOnDisk: (long) newFreeSpaceOnDisk
{
  _freeSpaceOnDisk = newFreeSpaceOnDisk;
}

/**
 * The number of files held in the repository.
 */
- (long) fileCountInRepository
{
  return _fileCountInRepository;
}

/**
 * The number of files held in the repository.
 */
- (void) setFileCountInRepository: (long) newFileCountInRepository
{
  _fileCountInRepository = newFileCountInRepository;
}

/**
 * The number of requested paths that are currently in the not
found cache.
 */
- (long) notFoundCacheSize
{
  return _notFoundCacheSize;
}

/**
 * The number of requested paths that are currently in the not
found cache.
 */
- (void) setNotFoundCacheSize: (long) newNotFoundCacheSize
{
  _notFoundCacheSize = newNotFoundCacheSize;
}

/**
 * The number of checks against the not found cache that have
succeeded (and thus saved a remote check).
 */
- (long) notFoundCacheHits
{
  return _notFoundCacheHits;
}

/**
 * The number of checks against the not found cache that have
succeeded (and thus saved a remote check).
 */
- (void) setNotFoundCacheHits: (long) newNotFoundCacheHits
{
  _notFoundCacheHits = newNotFoundCacheHits;
}

/**
 * The number of checks against the not found cache that have
failed (and thus required a remote check).
 */
- (long) notFoundCacheMisses
{
  return _notFoundCacheMisses;
}

/**
 * The number of checks against the not found cache that have
failed (and thus required a remote check).
 */
- (void) setNotFoundCacheMisses: (long) newNotFoundCacheMisses
{
  _notFoundCacheMisses = newNotFoundCacheMisses;
}

/**
 * The number of errors reported by local storage.
 */
- (int) localStorageErrorsCount
{
  return _localStorageErrorsCount;
}

/**
 * The number of errors reported by local storage.
 */
- (void) setLocalStorageErrorsCount: (int) newLocalStorageErrorsCount
{
  _localStorageErrorsCount = newLocalStorageErrorsCount;
}

/**
 * The number of errors reported by remote storage.
 */
- (int) remoteStorageErrorsCount
{
  return _remoteStorageErrorsCount;
}

/**
 * The number of errors reported by remote storage.
 */
- (void) setRemoteStorageErrorsCount: (int) newRemoteStorageErrorsCount
{
  _remoteStorageErrorsCount = newRemoteStorageErrorsCount;
}

/**
 * Field groups.
 */
- (NSArray *) groups
{
  return _groups;
}

/**
 * Field groups.
 */
- (void) setGroups: (NSArray *) newGroups
{
  [newGroups retain];
  [_groups release];
  _groups = newGroups;
}

- (void) dealloc
{
  [self setId: nil];
  [self setRepoType: nil];
  [self setFormat: nil];
  [self setGroups: nil];
  [super dealloc];
}
@end /* implementation NEXUS_REST_APINS0RepositoryMetaResource */

/**
 * Internal, private interface for JAXB reading and writing.
 */
@interface NEXUS_REST_APINS0RepositoryMetaResource (JAXB) <JAXBReading, JAXBWriting, JAXBType>

@end /*interface NEXUS_REST_APINS0RepositoryMetaResource (JAXB)*/

/**
 * Internal, private implementation for JAXB reading and writing.
 */
@implementation NEXUS_REST_APINS0RepositoryMetaResource (JAXB)

/**
 * Read an instance of NEXUS_REST_APINS0RepositoryMetaResource from an XML reader.
 *
 * @param reader The reader.
 * @return An instance of NEXUS_REST_APINS0RepositoryMetaResource defined by the XML reader.
 */
+ (id<JAXBType>) readXMLType: (xmlTextReaderPtr) reader
{
  NEXUS_REST_APINS0RepositoryMetaResource *_nEXUS_REST_APINS0RepositoryMetaResource = [[NEXUS_REST_APINS0RepositoryMetaResource alloc] init];
  NS_DURING
  {
    [_nEXUS_REST_APINS0RepositoryMetaResource initWithReader: reader];
  }
  NS_HANDLER
  {
    [_nEXUS_REST_APINS0RepositoryMetaResource dealloc];
    _nEXUS_REST_APINS0RepositoryMetaResource = nil;
    [localException raise];
  }
  NS_ENDHANDLER

  [_nEXUS_REST_APINS0RepositoryMetaResource autorelease];
  return _nEXUS_REST_APINS0RepositoryMetaResource;
}

/**
 * Initialize this instance of NEXUS_REST_APINS0RepositoryMetaResource according to
 * the XML being read from the reader.
 *
 * @param reader The reader.
 */
- (id) initWithReader: (xmlTextReaderPtr) reader
{
  return [super initWithReader: reader];
}

/**
 * Write the XML for this instance of NEXUS_REST_APINS0RepositoryMetaResource to the writer.
 * Note that since we're only writing the XML type,
 * No start/end element will be written.
 *
 * @param reader The reader.
 */
- (void) writeXMLType: (xmlTextWriterPtr) writer
{
  [super writeXMLType:writer];
}

//documentation inherited.
- (BOOL) readJAXBAttribute: (xmlTextReaderPtr) reader
{
  void *_child_accessor;

  if ([super readJAXBAttribute: reader]) {
    return YES;
  }

  return NO;
}

//documentation inherited.
- (BOOL) readJAXBValue: (xmlTextReaderPtr) reader
{
  return [super readJAXBValue: reader];
}

//documentation inherited.
- (BOOL) readJAXBChildElement: (xmlTextReaderPtr) reader
{
  id __child;
  void *_child_accessor;
  int status, depth;

  if ([super readJAXBChildElement: reader]) {
    return YES;
  }
  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "id", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}id of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}id of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setId: __child];
    return YES;
  } //end "if choice"

  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "repoType", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}repoType of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}repoType of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setRepoType: __child];
    return YES;
  } //end "if choice"

  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "format", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}format of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}format of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setFormat: __child];
    return YES;
  } //end "if choice"


  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "sizeOnDisk", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

    _child_accessor = xmlTextReaderReadLongType(reader);
    if (_child_accessor == NULL) {
      //panic: unable to return the value for some reason.
      [self dealloc];
      [NSException raise: @"XMLReadError"
                   format: @"Error reading element value."];
    }
    [self setSizeOnDisk: *((long*) _child_accessor)];
    free(_child_accessor);
    return YES;
  }

  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "freeSpaceOnDisk", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

    _child_accessor = xmlTextReaderReadLongType(reader);
    if (_child_accessor == NULL) {
      //panic: unable to return the value for some reason.
      [self dealloc];
      [NSException raise: @"XMLReadError"
                   format: @"Error reading element value."];
    }
    [self setFreeSpaceOnDisk: *((long*) _child_accessor)];
    free(_child_accessor);
    return YES;
  }

  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "fileCountInRepository", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

    _child_accessor = xmlTextReaderReadLongType(reader);
    if (_child_accessor == NULL) {
      //panic: unable to return the value for some reason.
      [self dealloc];
      [NSException raise: @"XMLReadError"
                   format: @"Error reading element value."];
    }
    [self setFileCountInRepository: *((long*) _child_accessor)];
    free(_child_accessor);
    return YES;
  }

  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "notFoundCacheSize", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

    _child_accessor = xmlTextReaderReadLongType(reader);
    if (_child_accessor == NULL) {
      //panic: unable to return the value for some reason.
      [self dealloc];
      [NSException raise: @"XMLReadError"
                   format: @"Error reading element value."];
    }
    [self setNotFoundCacheSize: *((long*) _child_accessor)];
    free(_child_accessor);
    return YES;
  }

  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "notFoundCacheHits", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

    _child_accessor = xmlTextReaderReadLongType(reader);
    if (_child_accessor == NULL) {
      //panic: unable to return the value for some reason.
      [self dealloc];
      [NSException raise: @"XMLReadError"
                   format: @"Error reading element value."];
    }
    [self setNotFoundCacheHits: *((long*) _child_accessor)];
    free(_child_accessor);
    return YES;
  }

  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "notFoundCacheMisses", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

    _child_accessor = xmlTextReaderReadLongType(reader);
    if (_child_accessor == NULL) {
      //panic: unable to return the value for some reason.
      [self dealloc];
      [NSException raise: @"XMLReadError"
                   format: @"Error reading element value."];
    }
    [self setNotFoundCacheMisses: *((long*) _child_accessor)];
    free(_child_accessor);
    return YES;
  }

  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "localStorageErrorsCount", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

    _child_accessor = xmlTextReaderReadIntType(reader);
    if (_child_accessor == NULL) {
      //panic: unable to return the value for some reason.
      [self dealloc];
      [NSException raise: @"XMLReadError"
                   format: @"Error reading element value."];
    }
    [self setLocalStorageErrorsCount: *((int*) _child_accessor)];
    free(_child_accessor);
    return YES;
  }

  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "remoteStorageErrorsCount", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

    _child_accessor = xmlTextReaderReadIntType(reader);
    if (_child_accessor == NULL) {
      //panic: unable to return the value for some reason.
      [self dealloc];
      [NSException raise: @"XMLReadError"
                   format: @"Error reading element value."];
    }
    [self setRemoteStorageErrorsCount: *((int*) _child_accessor)];
    free(_child_accessor);
    return YES;
  }
  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "groups", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

    if (xmlTextReaderIsEmptyElement(reader) == 0) {
#if DEBUG_ENUNCIATE > 1
      NSLog(@"Unwrapping wrapper element {}groups...");
#endif
      //start wrapper element "{}groups"
      depth = xmlTextReaderDepth(reader);
      status = xmlTextReaderAdvanceToNextStartOrEndElement(reader);
      while (xmlTextReaderDepth(reader) > depth) {
        if (status < 1) {
          //panic: XML read error.
          [self dealloc];
          [NSException raise: @"XMLReadError"
                       format: @"Failure to advance to next wrapped child element."];
        }
  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "string", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}string of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}string of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    if ([self groups]) {
      [self setGroups: [[self groups] arrayByAddingObject: __child]];
    }
    else {
      [self setGroups: [NSArray arrayWithObject: __child]];
    }
    continue; //continue "while in wrapper element" loop
  } //end "if choice"

        status = xmlTextReaderAdvanceToNextStartOrEndElement(reader);
#if DEBUG_ENUNCIATE > 1
        NSLog(@"successfully unwrapped wrapper element {}groups...");
#endif
      } // end "while in wrapper element" loop

      if (status < 1) {
        //panic: XML read error.
        [self dealloc];
        [NSException raise: @"XMLReadError"
                     format: @"Failure to advance to end wrapper element."];
      }
      else {
        //end wrapper element "{}groups"
        status = xmlTextReaderAdvanceToNextStartOrEndElement(reader);
      }
    } //end "if empty element" clause
    else {
      __child = [NSArray array];
      [self setGroups: (NSArray*) __child];
    }

    return YES;
  } // end "if wrapper element" clause

  return NO;
}

//documentation inherited.
- (int) readUnknownJAXBChildElement: (xmlTextReaderPtr) reader
{
  return [super readUnknownJAXBChildElement: reader];
}

//documentation inherited.
- (void) readUnknownJAXBAttribute: (xmlTextReaderPtr) reader
{
  [super readUnknownJAXBAttribute: reader];
}

//documentation inherited.
- (void) writeJAXBAttributes: (xmlTextWriterPtr) writer
{
  int status;

  [super writeJAXBAttributes: writer];

}

//documentation inherited.
- (void) writeJAXBValue: (xmlTextWriterPtr) writer
{
  [super writeJAXBValue: writer];
}

/**
 * Method for writing the child elements.
 *
 * @param writer The writer.
 */
- (void) writeJAXBChildElements: (xmlTextWriterPtr) writer
{
  int status;
  id __item;
  NSEnumerator *__enumerator;

  [super writeJAXBChildElements: writer];

  if ([self id]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "id", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}id."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}id...");
#endif
    [[self id] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}id...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}id."];
    }
  }
  if ([self repoType]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "repoType", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}repoType."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}repoType...");
#endif
    [[self repoType] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}repoType...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}repoType."];
    }
  }
  if ([self format]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "format", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}format."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}format...");
#endif
    [[self format] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}format...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}format."];
    }
  }
  if (YES) { //always write the primitive element...
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "sizeOnDisk", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}sizeOnDisk."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}sizeOnDisk...");
#endif
    status = xmlTextWriterWriteLongType(writer, &_sizeOnDisk);
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}sizeOnDisk...");
#endif
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing child element {}sizeOnDisk."];
    }

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}sizeOnDisk."];
    }
  }
  if (YES) { //always write the primitive element...
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "freeSpaceOnDisk", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}freeSpaceOnDisk."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}freeSpaceOnDisk...");
#endif
    status = xmlTextWriterWriteLongType(writer, &_freeSpaceOnDisk);
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}freeSpaceOnDisk...");
#endif
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing child element {}freeSpaceOnDisk."];
    }

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}freeSpaceOnDisk."];
    }
  }
  if (YES) { //always write the primitive element...
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "fileCountInRepository", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}fileCountInRepository."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}fileCountInRepository...");
#endif
    status = xmlTextWriterWriteLongType(writer, &_fileCountInRepository);
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}fileCountInRepository...");
#endif
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing child element {}fileCountInRepository."];
    }

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}fileCountInRepository."];
    }
  }
  if (YES) { //always write the primitive element...
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "notFoundCacheSize", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}notFoundCacheSize."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}notFoundCacheSize...");
#endif
    status = xmlTextWriterWriteLongType(writer, &_notFoundCacheSize);
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}notFoundCacheSize...");
#endif
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing child element {}notFoundCacheSize."];
    }

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}notFoundCacheSize."];
    }
  }
  if (YES) { //always write the primitive element...
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "notFoundCacheHits", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}notFoundCacheHits."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}notFoundCacheHits...");
#endif
    status = xmlTextWriterWriteLongType(writer, &_notFoundCacheHits);
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}notFoundCacheHits...");
#endif
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing child element {}notFoundCacheHits."];
    }

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}notFoundCacheHits."];
    }
  }
  if (YES) { //always write the primitive element...
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "notFoundCacheMisses", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}notFoundCacheMisses."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}notFoundCacheMisses...");
#endif
    status = xmlTextWriterWriteLongType(writer, &_notFoundCacheMisses);
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}notFoundCacheMisses...");
#endif
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing child element {}notFoundCacheMisses."];
    }

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}notFoundCacheMisses."];
    }
  }
  if (YES) { //always write the primitive element...
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "localStorageErrorsCount", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}localStorageErrorsCount."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}localStorageErrorsCount...");
#endif
    status = xmlTextWriterWriteIntType(writer, &_localStorageErrorsCount);
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}localStorageErrorsCount...");
#endif
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing child element {}localStorageErrorsCount."];
    }

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}localStorageErrorsCount."];
    }
  }
  if (YES) { //always write the primitive element...
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "remoteStorageErrorsCount", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}remoteStorageErrorsCount."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}remoteStorageErrorsCount...");
#endif
    status = xmlTextWriterWriteIntType(writer, &_remoteStorageErrorsCount);
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}remoteStorageErrorsCount...");
#endif
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing child element {}remoteStorageErrorsCount."];
    }

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}remoteStorageErrorsCount."];
    }
  }
  if ([self groups]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "groups", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start wrapper element {}groups."];
    }
    __enumerator = [[self groups] objectEnumerator];

    while ( (__item = [__enumerator nextObject]) ) {
      status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "string", NULL);
      if (status < 0) {
        [NSException raise: @"XMLWriteError"
                     format: @"Error writing start child element {}string."];
      }

#if DEBUG_ENUNCIATE > 1
      NSLog(@"writing element {}string...");
#endif
      [__item writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
      NSLog(@"successfully wrote element {}string...");
#endif

      status = xmlTextWriterEndElement(writer);
      if (status < 0) {
        [NSException raise: @"XMLWriteError"
                     format: @"Error writing end child element {}string."];
      }
    } //end item iterator.

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end wrapper element {}groups."];
    }
  }
}
@end /* implementation NEXUS_REST_APINS0RepositoryMetaResource (JAXB) */

#endif /* DEF_NEXUS_REST_APINS0RepositoryMetaResource_M */
#ifndef DEF_NEXUS_REST_APINS0RepositoryRouteListResource_M
#define DEF_NEXUS_REST_APINS0RepositoryRouteListResource_M

/**
 *  A repository route basic set of details, for display in lists
 (full details can be retrieved using the resourceURI).
 
 @version $Revision$ $Date$

 */
@implementation NEXUS_REST_APINS0RepositoryRouteListResource

/**
 * The URL used to manage this repository route.
 */
- (NSString *) resourceURI
{
  return _resourceURI;
}

/**
 * The URL used to manage this repository route.
 */
- (void) setResourceURI: (NSString *) newResourceURI
{
  [newResourceURI retain];
  [_resourceURI release];
  _resourceURI = newResourceURI;
}

/**
 * The group this route is attached to.
 */
- (NSString *) groupId
{
  return _groupId;
}

/**
 * The group this route is attached to.
 */
- (void) setGroupId: (NSString *) newGroupId
{
  [newGroupId retain];
  [_groupId release];
  _groupId = newGroupId;
}

/**
 * The type of rule (inclusive, exclusive, etc.).
 */
- (NSString *) ruleType
{
  return _ruleType;
}

/**
 * The type of rule (inclusive, exclusive, etc.).
 */
- (void) setRuleType: (NSString *) newRuleType
{
  [newRuleType retain];
  [_ruleType release];
  _ruleType = newRuleType;
}

/**
 * The pattern associated to this route.
 */
- (NSString *) pattern
{
  return _pattern;
}

/**
 * The pattern associated to this route.
 */
- (void) setPattern: (NSString *) newPattern
{
  [newPattern retain];
  [_pattern release];
  _pattern = newPattern;
}

/**
 * Field repositories.
 */
- (NSArray *) repositories
{
  return _repositories;
}

/**
 * Field repositories.
 */
- (void) setRepositories: (NSArray *) newRepositories
{
  [newRepositories retain];
  [_repositories release];
  _repositories = newRepositories;
}

- (void) dealloc
{
  [self setResourceURI: nil];
  [self setGroupId: nil];
  [self setRuleType: nil];
  [self setPattern: nil];
  [self setRepositories: nil];
  [super dealloc];
}
@end /* implementation NEXUS_REST_APINS0RepositoryRouteListResource */

/**
 * Internal, private interface for JAXB reading and writing.
 */
@interface NEXUS_REST_APINS0RepositoryRouteListResource (JAXB) <JAXBReading, JAXBWriting, JAXBType>

@end /*interface NEXUS_REST_APINS0RepositoryRouteListResource (JAXB)*/

/**
 * Internal, private implementation for JAXB reading and writing.
 */
@implementation NEXUS_REST_APINS0RepositoryRouteListResource (JAXB)

/**
 * Read an instance of NEXUS_REST_APINS0RepositoryRouteListResource from an XML reader.
 *
 * @param reader The reader.
 * @return An instance of NEXUS_REST_APINS0RepositoryRouteListResource defined by the XML reader.
 */
+ (id<JAXBType>) readXMLType: (xmlTextReaderPtr) reader
{
  NEXUS_REST_APINS0RepositoryRouteListResource *_nEXUS_REST_APINS0RepositoryRouteListResource = [[NEXUS_REST_APINS0RepositoryRouteListResource alloc] init];
  NS_DURING
  {
    [_nEXUS_REST_APINS0RepositoryRouteListResource initWithReader: reader];
  }
  NS_HANDLER
  {
    [_nEXUS_REST_APINS0RepositoryRouteListResource dealloc];
    _nEXUS_REST_APINS0RepositoryRouteListResource = nil;
    [localException raise];
  }
  NS_ENDHANDLER

  [_nEXUS_REST_APINS0RepositoryRouteListResource autorelease];
  return _nEXUS_REST_APINS0RepositoryRouteListResource;
}

/**
 * Initialize this instance of NEXUS_REST_APINS0RepositoryRouteListResource according to
 * the XML being read from the reader.
 *
 * @param reader The reader.
 */
- (id) initWithReader: (xmlTextReaderPtr) reader
{
  return [super initWithReader: reader];
}

/**
 * Write the XML for this instance of NEXUS_REST_APINS0RepositoryRouteListResource to the writer.
 * Note that since we're only writing the XML type,
 * No start/end element will be written.
 *
 * @param reader The reader.
 */
- (void) writeXMLType: (xmlTextWriterPtr) writer
{
  [super writeXMLType:writer];
}

//documentation inherited.
- (BOOL) readJAXBAttribute: (xmlTextReaderPtr) reader
{
  void *_child_accessor;

  if ([super readJAXBAttribute: reader]) {
    return YES;
  }

  return NO;
}

//documentation inherited.
- (BOOL) readJAXBValue: (xmlTextReaderPtr) reader
{
  return [super readJAXBValue: reader];
}

//documentation inherited.
- (BOOL) readJAXBChildElement: (xmlTextReaderPtr) reader
{
  id __child;
  void *_child_accessor;
  int status, depth;

  if ([super readJAXBChildElement: reader]) {
    return YES;
  }
  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "resourceURI", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}resourceURI of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}resourceURI of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setResourceURI: __child];
    return YES;
  } //end "if choice"

  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "groupId", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}groupId of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}groupId of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setGroupId: __child];
    return YES;
  } //end "if choice"

  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "ruleType", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}ruleType of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}ruleType of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setRuleType: __child];
    return YES;
  } //end "if choice"

  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "pattern", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}pattern of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}pattern of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setPattern: __child];
    return YES;
  } //end "if choice"

  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "repositories", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

    if (xmlTextReaderIsEmptyElement(reader) == 0) {
#if DEBUG_ENUNCIATE > 1
      NSLog(@"Unwrapping wrapper element {}repositories...");
#endif
      //start wrapper element "{}repositories"
      depth = xmlTextReaderDepth(reader);
      status = xmlTextReaderAdvanceToNextStartOrEndElement(reader);
      while (xmlTextReaderDepth(reader) > depth) {
        if (status < 1) {
          //panic: XML read error.
          [self dealloc];
          [NSException raise: @"XMLReadError"
                       format: @"Failure to advance to next wrapped child element."];
        }
  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "repo-routes-member", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}repo-routes-member of type {}repository-route-member-repo.");
#endif

    __child = [NEXUS_REST_APINS0RepositoryRouteMemberRepository readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}repo-routes-member of type {}repository-route-member-repo.");
#endif

    if ([self repositories]) {
      [self setRepositories: [[self repositories] arrayByAddingObject: __child]];
    }
    else {
      [self setRepositories: [NSArray arrayWithObject: __child]];
    }
    continue; //continue "while in wrapper element" loop
  } //end "if choice"

        status = xmlTextReaderAdvanceToNextStartOrEndElement(reader);
#if DEBUG_ENUNCIATE > 1
        NSLog(@"successfully unwrapped wrapper element {}repositories...");
#endif
      } // end "while in wrapper element" loop

      if (status < 1) {
        //panic: XML read error.
        [self dealloc];
        [NSException raise: @"XMLReadError"
                     format: @"Failure to advance to end wrapper element."];
      }
      else {
        //end wrapper element "{}repositories"
        status = xmlTextReaderAdvanceToNextStartOrEndElement(reader);
      }
    } //end "if empty element" clause
    else {
      __child = [NSArray array];
      [self setRepositories: (NSArray*) __child];
    }

    return YES;
  } // end "if wrapper element" clause

  return NO;
}

//documentation inherited.
- (int) readUnknownJAXBChildElement: (xmlTextReaderPtr) reader
{
  return [super readUnknownJAXBChildElement: reader];
}

//documentation inherited.
- (void) readUnknownJAXBAttribute: (xmlTextReaderPtr) reader
{
  [super readUnknownJAXBAttribute: reader];
}

//documentation inherited.
- (void) writeJAXBAttributes: (xmlTextWriterPtr) writer
{
  int status;

  [super writeJAXBAttributes: writer];

}

//documentation inherited.
- (void) writeJAXBValue: (xmlTextWriterPtr) writer
{
  [super writeJAXBValue: writer];
}

/**
 * Method for writing the child elements.
 *
 * @param writer The writer.
 */
- (void) writeJAXBChildElements: (xmlTextWriterPtr) writer
{
  int status;
  id __item;
  NSEnumerator *__enumerator;

  [super writeJAXBChildElements: writer];

  if ([self resourceURI]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "resourceURI", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}resourceURI."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}resourceURI...");
#endif
    [[self resourceURI] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}resourceURI...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}resourceURI."];
    }
  }
  if ([self groupId]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "groupId", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}groupId."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}groupId...");
#endif
    [[self groupId] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}groupId...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}groupId."];
    }
  }
  if ([self ruleType]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "ruleType", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}ruleType."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}ruleType...");
#endif
    [[self ruleType] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}ruleType...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}ruleType."];
    }
  }
  if ([self pattern]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "pattern", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}pattern."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}pattern...");
#endif
    [[self pattern] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}pattern...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}pattern."];
    }
  }
  if ([self repositories]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "repositories", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start wrapper element {}repositories."];
    }
    __enumerator = [[self repositories] objectEnumerator];

    while ( (__item = [__enumerator nextObject]) ) {
      status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "repo-routes-member", NULL);
      if (status < 0) {
        [NSException raise: @"XMLWriteError"
                     format: @"Error writing start child element {}repo-routes-member."];
      }

#if DEBUG_ENUNCIATE > 1
      NSLog(@"writing element {}repo-routes-member...");
#endif
      [__item writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
      NSLog(@"successfully wrote element {}repo-routes-member...");
#endif

      status = xmlTextWriterEndElement(writer);
      if (status < 0) {
        [NSException raise: @"XMLWriteError"
                     format: @"Error writing end child element {}repo-routes-member."];
      }
    } //end item iterator.

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end wrapper element {}repositories."];
    }
  }
}
@end /* implementation NEXUS_REST_APINS0RepositoryRouteListResource (JAXB) */

#endif /* DEF_NEXUS_REST_APINS0RepositoryRouteListResource_M */
#ifndef DEF_NEXUS_REST_APINS0RepositoryRouteMemberRepository_M
#define DEF_NEXUS_REST_APINS0RepositoryRouteMemberRepository_M

/**
 *  Repository details in a repository route.
 
 @version $Revision$ $Date$

 */
@implementation NEXUS_REST_APINS0RepositoryRouteMemberRepository

/**
 * The repository id.
 */
- (NSString *) id
{
  return _id;
}

/**
 * The repository id.
 */
- (void) setId: (NSString *) newId
{
  [newId retain];
  [_id release];
  _id = newId;
}

/**
 * The repository name.
 */
- (NSString *) name
{
  return _name;
}

/**
 * The repository name.
 */
- (void) setName: (NSString *) newName
{
  [newName retain];
  [_name release];
  _name = newName;
}

/**
 * The URL that can be used to manage the repository.
 */
- (NSString *) resourceURI
{
  return _resourceURI;
}

/**
 * The URL that can be used to manage the repository.
 */
- (void) setResourceURI: (NSString *) newResourceURI
{
  [newResourceURI retain];
  [_resourceURI release];
  _resourceURI = newResourceURI;
}

- (void) dealloc
{
  [self setId: nil];
  [self setName: nil];
  [self setResourceURI: nil];
  [super dealloc];
}
@end /* implementation NEXUS_REST_APINS0RepositoryRouteMemberRepository */

/**
 * Internal, private interface for JAXB reading and writing.
 */
@interface NEXUS_REST_APINS0RepositoryRouteMemberRepository (JAXB) <JAXBReading, JAXBWriting, JAXBType>

@end /*interface NEXUS_REST_APINS0RepositoryRouteMemberRepository (JAXB)*/

/**
 * Internal, private implementation for JAXB reading and writing.
 */
@implementation NEXUS_REST_APINS0RepositoryRouteMemberRepository (JAXB)

/**
 * Read an instance of NEXUS_REST_APINS0RepositoryRouteMemberRepository from an XML reader.
 *
 * @param reader The reader.
 * @return An instance of NEXUS_REST_APINS0RepositoryRouteMemberRepository defined by the XML reader.
 */
+ (id<JAXBType>) readXMLType: (xmlTextReaderPtr) reader
{
  NEXUS_REST_APINS0RepositoryRouteMemberRepository *_nEXUS_REST_APINS0RepositoryRouteMemberRepository = [[NEXUS_REST_APINS0RepositoryRouteMemberRepository alloc] init];
  NS_DURING
  {
    [_nEXUS_REST_APINS0RepositoryRouteMemberRepository initWithReader: reader];
  }
  NS_HANDLER
  {
    [_nEXUS_REST_APINS0RepositoryRouteMemberRepository dealloc];
    _nEXUS_REST_APINS0RepositoryRouteMemberRepository = nil;
    [localException raise];
  }
  NS_ENDHANDLER

  [_nEXUS_REST_APINS0RepositoryRouteMemberRepository autorelease];
  return _nEXUS_REST_APINS0RepositoryRouteMemberRepository;
}

/**
 * Initialize this instance of NEXUS_REST_APINS0RepositoryRouteMemberRepository according to
 * the XML being read from the reader.
 *
 * @param reader The reader.
 */
- (id) initWithReader: (xmlTextReaderPtr) reader
{
  return [super initWithReader: reader];
}

/**
 * Write the XML for this instance of NEXUS_REST_APINS0RepositoryRouteMemberRepository to the writer.
 * Note that since we're only writing the XML type,
 * No start/end element will be written.
 *
 * @param reader The reader.
 */
- (void) writeXMLType: (xmlTextWriterPtr) writer
{
  [super writeXMLType:writer];
}

//documentation inherited.
- (BOOL) readJAXBAttribute: (xmlTextReaderPtr) reader
{
  void *_child_accessor;

  if ([super readJAXBAttribute: reader]) {
    return YES;
  }

  return NO;
}

//documentation inherited.
- (BOOL) readJAXBValue: (xmlTextReaderPtr) reader
{
  return [super readJAXBValue: reader];
}

//documentation inherited.
- (BOOL) readJAXBChildElement: (xmlTextReaderPtr) reader
{
  id __child;
  void *_child_accessor;
  int status, depth;

  if ([super readJAXBChildElement: reader]) {
    return YES;
  }
  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "id", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}id of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}id of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setId: __child];
    return YES;
  } //end "if choice"

  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "name", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}name of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}name of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setName: __child];
    return YES;
  } //end "if choice"

  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "resourceURI", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}resourceURI of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}resourceURI of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setResourceURI: __child];
    return YES;
  } //end "if choice"


  return NO;
}

//documentation inherited.
- (int) readUnknownJAXBChildElement: (xmlTextReaderPtr) reader
{
  return [super readUnknownJAXBChildElement: reader];
}

//documentation inherited.
- (void) readUnknownJAXBAttribute: (xmlTextReaderPtr) reader
{
  [super readUnknownJAXBAttribute: reader];
}

//documentation inherited.
- (void) writeJAXBAttributes: (xmlTextWriterPtr) writer
{
  int status;

  [super writeJAXBAttributes: writer];

}

//documentation inherited.
- (void) writeJAXBValue: (xmlTextWriterPtr) writer
{
  [super writeJAXBValue: writer];
}

/**
 * Method for writing the child elements.
 *
 * @param writer The writer.
 */
- (void) writeJAXBChildElements: (xmlTextWriterPtr) writer
{
  int status;
  id __item;
  NSEnumerator *__enumerator;

  [super writeJAXBChildElements: writer];

  if ([self id]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "id", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}id."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}id...");
#endif
    [[self id] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}id...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}id."];
    }
  }
  if ([self name]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "name", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}name."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}name...");
#endif
    [[self name] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}name...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}name."];
    }
  }
  if ([self resourceURI]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "resourceURI", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}resourceURI."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}resourceURI...");
#endif
    [[self resourceURI] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}resourceURI...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}resourceURI."];
    }
  }
}
@end /* implementation NEXUS_REST_APINS0RepositoryRouteMemberRepository (JAXB) */

#endif /* DEF_NEXUS_REST_APINS0RepositoryRouteMemberRepository_M */
#ifndef DEF_NEXUS_REST_APINS0RepositoryRouteResource_M
#define DEF_NEXUS_REST_APINS0RepositoryRouteResource_M

/**
 *  Class RepositoryRouteResource.
 
 @version $Revision$ $Date$

 */
@implementation NEXUS_REST_APINS0RepositoryRouteResource

/**
 * The id of the repository route.
 */
- (NSString *) id
{
  return _id;
}

/**
 * The id of the repository route.
 */
- (void) setId: (NSString *) newId
{
  [newId retain];
  [_id release];
  _id = newId;
}

/**
 * The group id that the route is applied on.
 */
- (NSString *) groupId
{
  return _groupId;
}

/**
 * The group id that the route is applied on.
 */
- (void) setGroupId: (NSString *) newGroupId
{
  [newGroupId retain];
  [_groupId release];
  _groupId = newGroupId;
}

/**
 * The rule type of the route (inclusive, exclusive, etc.).
 */
- (NSString *) ruleType
{
  return _ruleType;
}

/**
 * The rule type of the route (inclusive, exclusive, etc.).
 */
- (void) setRuleType: (NSString *) newRuleType
{
  [newRuleType retain];
  [_ruleType release];
  _ruleType = newRuleType;
}

/**
 * The regex pattern that will be matched to see if route is
applied to request.
 */
- (NSString *) pattern
{
  return _pattern;
}

/**
 * The regex pattern that will be matched to see if route is
applied to request.
 */
- (void) setPattern: (NSString *) newPattern
{
  [newPattern retain];
  [_pattern release];
  _pattern = newPattern;
}

/**
 * Field repositories.
 */
- (NSArray *) repositories
{
  return _repositories;
}

/**
 * Field repositories.
 */
- (void) setRepositories: (NSArray *) newRepositories
{
  [newRepositories retain];
  [_repositories release];
  _repositories = newRepositories;
}

- (void) dealloc
{
  [self setId: nil];
  [self setGroupId: nil];
  [self setRuleType: nil];
  [self setPattern: nil];
  [self setRepositories: nil];
  [super dealloc];
}
@end /* implementation NEXUS_REST_APINS0RepositoryRouteResource */

/**
 * Internal, private interface for JAXB reading and writing.
 */
@interface NEXUS_REST_APINS0RepositoryRouteResource (JAXB) <JAXBReading, JAXBWriting, JAXBType>

@end /*interface NEXUS_REST_APINS0RepositoryRouteResource (JAXB)*/

/**
 * Internal, private implementation for JAXB reading and writing.
 */
@implementation NEXUS_REST_APINS0RepositoryRouteResource (JAXB)

/**
 * Read an instance of NEXUS_REST_APINS0RepositoryRouteResource from an XML reader.
 *
 * @param reader The reader.
 * @return An instance of NEXUS_REST_APINS0RepositoryRouteResource defined by the XML reader.
 */
+ (id<JAXBType>) readXMLType: (xmlTextReaderPtr) reader
{
  NEXUS_REST_APINS0RepositoryRouteResource *_nEXUS_REST_APINS0RepositoryRouteResource = [[NEXUS_REST_APINS0RepositoryRouteResource alloc] init];
  NS_DURING
  {
    [_nEXUS_REST_APINS0RepositoryRouteResource initWithReader: reader];
  }
  NS_HANDLER
  {
    [_nEXUS_REST_APINS0RepositoryRouteResource dealloc];
    _nEXUS_REST_APINS0RepositoryRouteResource = nil;
    [localException raise];
  }
  NS_ENDHANDLER

  [_nEXUS_REST_APINS0RepositoryRouteResource autorelease];
  return _nEXUS_REST_APINS0RepositoryRouteResource;
}

/**
 * Initialize this instance of NEXUS_REST_APINS0RepositoryRouteResource according to
 * the XML being read from the reader.
 *
 * @param reader The reader.
 */
- (id) initWithReader: (xmlTextReaderPtr) reader
{
  return [super initWithReader: reader];
}

/**
 * Write the XML for this instance of NEXUS_REST_APINS0RepositoryRouteResource to the writer.
 * Note that since we're only writing the XML type,
 * No start/end element will be written.
 *
 * @param reader The reader.
 */
- (void) writeXMLType: (xmlTextWriterPtr) writer
{
  [super writeXMLType:writer];
}

//documentation inherited.
- (BOOL) readJAXBAttribute: (xmlTextReaderPtr) reader
{
  void *_child_accessor;

  if ([super readJAXBAttribute: reader]) {
    return YES;
  }

  return NO;
}

//documentation inherited.
- (BOOL) readJAXBValue: (xmlTextReaderPtr) reader
{
  return [super readJAXBValue: reader];
}

//documentation inherited.
- (BOOL) readJAXBChildElement: (xmlTextReaderPtr) reader
{
  id __child;
  void *_child_accessor;
  int status, depth;

  if ([super readJAXBChildElement: reader]) {
    return YES;
  }
  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "id", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}id of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}id of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setId: __child];
    return YES;
  } //end "if choice"

  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "groupId", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}groupId of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}groupId of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setGroupId: __child];
    return YES;
  } //end "if choice"

  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "ruleType", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}ruleType of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}ruleType of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setRuleType: __child];
    return YES;
  } //end "if choice"

  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "pattern", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}pattern of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}pattern of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setPattern: __child];
    return YES;
  } //end "if choice"

  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "repositories", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

    if (xmlTextReaderIsEmptyElement(reader) == 0) {
#if DEBUG_ENUNCIATE > 1
      NSLog(@"Unwrapping wrapper element {}repositories...");
#endif
      //start wrapper element "{}repositories"
      depth = xmlTextReaderDepth(reader);
      status = xmlTextReaderAdvanceToNextStartOrEndElement(reader);
      while (xmlTextReaderDepth(reader) > depth) {
        if (status < 1) {
          //panic: XML read error.
          [self dealloc];
          [NSException raise: @"XMLReadError"
                       format: @"Failure to advance to next wrapped child element."];
        }
  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "repository", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}repository of type {}repository-route-member-repo.");
#endif

    __child = [NEXUS_REST_APINS0RepositoryRouteMemberRepository readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}repository of type {}repository-route-member-repo.");
#endif

    if ([self repositories]) {
      [self setRepositories: [[self repositories] arrayByAddingObject: __child]];
    }
    else {
      [self setRepositories: [NSArray arrayWithObject: __child]];
    }
    continue; //continue "while in wrapper element" loop
  } //end "if choice"

        status = xmlTextReaderAdvanceToNextStartOrEndElement(reader);
#if DEBUG_ENUNCIATE > 1
        NSLog(@"successfully unwrapped wrapper element {}repositories...");
#endif
      } // end "while in wrapper element" loop

      if (status < 1) {
        //panic: XML read error.
        [self dealloc];
        [NSException raise: @"XMLReadError"
                     format: @"Failure to advance to end wrapper element."];
      }
      else {
        //end wrapper element "{}repositories"
        status = xmlTextReaderAdvanceToNextStartOrEndElement(reader);
      }
    } //end "if empty element" clause
    else {
      __child = [NSArray array];
      [self setRepositories: (NSArray*) __child];
    }

    return YES;
  } // end "if wrapper element" clause

  return NO;
}

//documentation inherited.
- (int) readUnknownJAXBChildElement: (xmlTextReaderPtr) reader
{
  return [super readUnknownJAXBChildElement: reader];
}

//documentation inherited.
- (void) readUnknownJAXBAttribute: (xmlTextReaderPtr) reader
{
  [super readUnknownJAXBAttribute: reader];
}

//documentation inherited.
- (void) writeJAXBAttributes: (xmlTextWriterPtr) writer
{
  int status;

  [super writeJAXBAttributes: writer];

}

//documentation inherited.
- (void) writeJAXBValue: (xmlTextWriterPtr) writer
{
  [super writeJAXBValue: writer];
}

/**
 * Method for writing the child elements.
 *
 * @param writer The writer.
 */
- (void) writeJAXBChildElements: (xmlTextWriterPtr) writer
{
  int status;
  id __item;
  NSEnumerator *__enumerator;

  [super writeJAXBChildElements: writer];

  if ([self id]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "id", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}id."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}id...");
#endif
    [[self id] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}id...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}id."];
    }
  }
  if ([self groupId]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "groupId", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}groupId."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}groupId...");
#endif
    [[self groupId] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}groupId...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}groupId."];
    }
  }
  if ([self ruleType]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "ruleType", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}ruleType."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}ruleType...");
#endif
    [[self ruleType] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}ruleType...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}ruleType."];
    }
  }
  if ([self pattern]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "pattern", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}pattern."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}pattern...");
#endif
    [[self pattern] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}pattern...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}pattern."];
    }
  }
  if ([self repositories]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "repositories", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start wrapper element {}repositories."];
    }
    __enumerator = [[self repositories] objectEnumerator];

    while ( (__item = [__enumerator nextObject]) ) {
      status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "repository", NULL);
      if (status < 0) {
        [NSException raise: @"XMLWriteError"
                     format: @"Error writing start child element {}repository."];
      }

#if DEBUG_ENUNCIATE > 1
      NSLog(@"writing element {}repository...");
#endif
      [__item writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
      NSLog(@"successfully wrote element {}repository...");
#endif

      status = xmlTextWriterEndElement(writer);
      if (status < 0) {
        [NSException raise: @"XMLWriteError"
                     format: @"Error writing end child element {}repository."];
      }
    } //end item iterator.

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end wrapper element {}repositories."];
    }
  }
}
@end /* implementation NEXUS_REST_APINS0RepositoryRouteResource (JAXB) */

#endif /* DEF_NEXUS_REST_APINS0RepositoryRouteResource_M */
#ifndef DEF_NEXUS_REST_APINS0RepositoryStatusListResource_M
#define DEF_NEXUS_REST_APINS0RepositoryStatusListResource_M

/**
 *  Some general details and status of the repostiory.
 
 @version $Revision$ $Date$

 */
@implementation NEXUS_REST_APINS0RepositoryStatusListResource

/**
 * The URI that can be used to manage the repository.
 */
- (NSString *) resourceURI
{
  return _resourceURI;
}

/**
 * The URI that can be used to manage the repository.
 */
- (void) setResourceURI: (NSString *) newResourceURI
{
  [newResourceURI retain];
  [_resourceURI release];
  _resourceURI = newResourceURI;
}

/**
 * The id of the repository.
 */
- (NSString *) id
{
  return _id;
}

/**
 * The id of the repository.
 */
- (void) setId: (NSString *) newId
{
  [newId retain];
  [_id release];
  _id = newId;
}

/**
 * The name of the repository.
 */
- (NSString *) name
{
  return _name;
}

/**
 * The name of the repository.
 */
- (void) setName: (NSString *) newName
{
  [newName retain];
  [_name release];
  _name = newName;
}

/**
 * The type of repository.
 */
- (NSString *) repoType
{
  return _repoType;
}

/**
 * The type of repository.
 */
- (void) setRepoType: (NSString *) newRepoType
{
  [newRepoType retain];
  [_repoType release];
  _repoType = newRepoType;
}

/**
 * The repository policy.
 */
- (NSString *) repoPolicy
{
  return _repoPolicy;
}

/**
 * The repository policy.
 */
- (void) setRepoPolicy: (NSString *) newRepoPolicy
{
  [newRepoPolicy retain];
  [_repoPolicy release];
  _repoPolicy = newRepoPolicy;
}

/**
 * The repository format.
 */
- (NSString *) format
{
  return _format;
}

/**
 * The repository format.
 */
- (void) setFormat: (NSString *) newFormat
{
  [newFormat retain];
  [_format release];
  _format = newFormat;
}

/**
 * The repository status object.
 */
- (NEXUS_REST_APINS0RepositoryStatusResource *) status
{
  return _status;
}

/**
 * The repository status object.
 */
- (void) setStatus: (NEXUS_REST_APINS0RepositoryStatusResource *) newStatus
{
  [newStatus retain];
  [_status release];
  _status = newStatus;
}

- (void) dealloc
{
  [self setResourceURI: nil];
  [self setId: nil];
  [self setName: nil];
  [self setRepoType: nil];
  [self setRepoPolicy: nil];
  [self setFormat: nil];
  [self setStatus: nil];
  [super dealloc];
}
@end /* implementation NEXUS_REST_APINS0RepositoryStatusListResource */

/**
 * Internal, private interface for JAXB reading and writing.
 */
@interface NEXUS_REST_APINS0RepositoryStatusListResource (JAXB) <JAXBReading, JAXBWriting, JAXBType>

@end /*interface NEXUS_REST_APINS0RepositoryStatusListResource (JAXB)*/

/**
 * Internal, private implementation for JAXB reading and writing.
 */
@implementation NEXUS_REST_APINS0RepositoryStatusListResource (JAXB)

/**
 * Read an instance of NEXUS_REST_APINS0RepositoryStatusListResource from an XML reader.
 *
 * @param reader The reader.
 * @return An instance of NEXUS_REST_APINS0RepositoryStatusListResource defined by the XML reader.
 */
+ (id<JAXBType>) readXMLType: (xmlTextReaderPtr) reader
{
  NEXUS_REST_APINS0RepositoryStatusListResource *_nEXUS_REST_APINS0RepositoryStatusListResource = [[NEXUS_REST_APINS0RepositoryStatusListResource alloc] init];
  NS_DURING
  {
    [_nEXUS_REST_APINS0RepositoryStatusListResource initWithReader: reader];
  }
  NS_HANDLER
  {
    [_nEXUS_REST_APINS0RepositoryStatusListResource dealloc];
    _nEXUS_REST_APINS0RepositoryStatusListResource = nil;
    [localException raise];
  }
  NS_ENDHANDLER

  [_nEXUS_REST_APINS0RepositoryStatusListResource autorelease];
  return _nEXUS_REST_APINS0RepositoryStatusListResource;
}

/**
 * Initialize this instance of NEXUS_REST_APINS0RepositoryStatusListResource according to
 * the XML being read from the reader.
 *
 * @param reader The reader.
 */
- (id) initWithReader: (xmlTextReaderPtr) reader
{
  return [super initWithReader: reader];
}

/**
 * Write the XML for this instance of NEXUS_REST_APINS0RepositoryStatusListResource to the writer.
 * Note that since we're only writing the XML type,
 * No start/end element will be written.
 *
 * @param reader The reader.
 */
- (void) writeXMLType: (xmlTextWriterPtr) writer
{
  [super writeXMLType:writer];
}

//documentation inherited.
- (BOOL) readJAXBAttribute: (xmlTextReaderPtr) reader
{
  void *_child_accessor;

  if ([super readJAXBAttribute: reader]) {
    return YES;
  }

  return NO;
}

//documentation inherited.
- (BOOL) readJAXBValue: (xmlTextReaderPtr) reader
{
  return [super readJAXBValue: reader];
}

//documentation inherited.
- (BOOL) readJAXBChildElement: (xmlTextReaderPtr) reader
{
  id __child;
  void *_child_accessor;
  int status, depth;

  if ([super readJAXBChildElement: reader]) {
    return YES;
  }
  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "resourceURI", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}resourceURI of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}resourceURI of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setResourceURI: __child];
    return YES;
  } //end "if choice"

  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "id", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}id of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}id of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setId: __child];
    return YES;
  } //end "if choice"

  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "name", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}name of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}name of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setName: __child];
    return YES;
  } //end "if choice"

  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "repoType", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}repoType of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}repoType of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setRepoType: __child];
    return YES;
  } //end "if choice"

  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "repoPolicy", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}repoPolicy of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}repoPolicy of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setRepoPolicy: __child];
    return YES;
  } //end "if choice"

  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "format", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}format of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}format of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setFormat: __child];
    return YES;
  } //end "if choice"

  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "status", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}status of type {}repository-status.");
#endif
    __child = [NEXUS_REST_APINS0RepositoryStatusResource readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}status of type {}repository-status.");
#endif

    [self setStatus: __child];
    return YES;
  } //end "if choice"


  return NO;
}

//documentation inherited.
- (int) readUnknownJAXBChildElement: (xmlTextReaderPtr) reader
{
  return [super readUnknownJAXBChildElement: reader];
}

//documentation inherited.
- (void) readUnknownJAXBAttribute: (xmlTextReaderPtr) reader
{
  [super readUnknownJAXBAttribute: reader];
}

//documentation inherited.
- (void) writeJAXBAttributes: (xmlTextWriterPtr) writer
{
  int status;

  [super writeJAXBAttributes: writer];

}

//documentation inherited.
- (void) writeJAXBValue: (xmlTextWriterPtr) writer
{
  [super writeJAXBValue: writer];
}

/**
 * Method for writing the child elements.
 *
 * @param writer The writer.
 */
- (void) writeJAXBChildElements: (xmlTextWriterPtr) writer
{
  int status;
  id __item;
  NSEnumerator *__enumerator;

  [super writeJAXBChildElements: writer];

  if ([self resourceURI]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "resourceURI", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}resourceURI."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}resourceURI...");
#endif
    [[self resourceURI] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}resourceURI...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}resourceURI."];
    }
  }
  if ([self id]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "id", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}id."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}id...");
#endif
    [[self id] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}id...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}id."];
    }
  }
  if ([self name]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "name", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}name."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}name...");
#endif
    [[self name] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}name...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}name."];
    }
  }
  if ([self repoType]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "repoType", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}repoType."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}repoType...");
#endif
    [[self repoType] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}repoType...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}repoType."];
    }
  }
  if ([self repoPolicy]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "repoPolicy", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}repoPolicy."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}repoPolicy...");
#endif
    [[self repoPolicy] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}repoPolicy...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}repoPolicy."];
    }
  }
  if ([self format]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "format", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}format."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}format...");
#endif
    [[self format] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}format...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}format."];
    }
  }
  if ([self status]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "status", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}status."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}status...");
#endif
    [[self status] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}status...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}status."];
    }
  }
}
@end /* implementation NEXUS_REST_APINS0RepositoryStatusListResource (JAXB) */

#endif /* DEF_NEXUS_REST_APINS0RepositoryStatusListResource_M */
#ifndef DEF_NEXUS_REST_APINS0RepositoryStatusResource_M
#define DEF_NEXUS_REST_APINS0RepositoryStatusResource_M

/**
 *  Repository status parameters.
 
 @version $Revision$ $Date$

 */
@implementation NEXUS_REST_APINS0RepositoryStatusResource

/**
 * The id of the repository.
 */
- (NSString *) id
{
  return _id;
}

/**
 * The id of the repository.
 */
- (void) setId: (NSString *) newId
{
  [newId retain];
  [_id release];
  _id = newId;
}

/**
 * The type of the repository.
 */
- (NSString *) repoType
{
  return _repoType;
}

/**
 * The type of the repository.
 */
- (void) setRepoType: (NSString *) newRepoType
{
  [newRepoType retain];
  [_repoType release];
  _repoType = newRepoType;
}

/**
 * The format of the repository.
 */
- (NSString *) format
{
  return _format;
}

/**
 * The format of the repository.
 */
- (void) setFormat: (NSString *) newFormat
{
  [newFormat retain];
  [_format release];
  _format = newFormat;
}

/**
 * The local status of the repository (user blocked for example)
 */
- (NSString *) localStatus
{
  return _localStatus;
}

/**
 * The local status of the repository (user blocked for example)
 */
- (void) setLocalStatus: (NSString *) newLocalStatus
{
  [newLocalStatus retain];
  [_localStatus release];
  _localStatus = newLocalStatus;
}

/**
 * The remote status of the repository (unreachable for example)
 */
- (NSString *) remoteStatus
{
  return _remoteStatus;
}

/**
 * The remote status of the repository (unreachable for example)
 */
- (void) setRemoteStatus: (NSString *) newRemoteStatus
{
  [newRemoteStatus retain];
  [_remoteStatus release];
  _remoteStatus = newRemoteStatus;
}

/**
 * The repository proxy mode (allow, blocked, etc.).
 */
- (NSString *) proxyMode
{
  return _proxyMode;
}

/**
 * The repository proxy mode (allow, blocked, etc.).
 */
- (void) setProxyMode: (NSString *) newProxyMode
{
  [newProxyMode retain];
  [_proxyMode release];
  _proxyMode = newProxyMode;
}

/**
 * Field dependentRepos.
 */
- (NSArray *) dependentRepos
{
  return _dependentRepos;
}

/**
 * Field dependentRepos.
 */
- (void) setDependentRepos: (NSArray *) newDependentRepos
{
  [newDependentRepos retain];
  [_dependentRepos release];
  _dependentRepos = newDependentRepos;
}

- (void) dealloc
{
  [self setId: nil];
  [self setRepoType: nil];
  [self setFormat: nil];
  [self setLocalStatus: nil];
  [self setRemoteStatus: nil];
  [self setProxyMode: nil];
  [self setDependentRepos: nil];
  [super dealloc];
}
@end /* implementation NEXUS_REST_APINS0RepositoryStatusResource */

/**
 * Internal, private interface for JAXB reading and writing.
 */
@interface NEXUS_REST_APINS0RepositoryStatusResource (JAXB) <JAXBReading, JAXBWriting, JAXBType>

@end /*interface NEXUS_REST_APINS0RepositoryStatusResource (JAXB)*/

/**
 * Internal, private implementation for JAXB reading and writing.
 */
@implementation NEXUS_REST_APINS0RepositoryStatusResource (JAXB)

/**
 * Read an instance of NEXUS_REST_APINS0RepositoryStatusResource from an XML reader.
 *
 * @param reader The reader.
 * @return An instance of NEXUS_REST_APINS0RepositoryStatusResource defined by the XML reader.
 */
+ (id<JAXBType>) readXMLType: (xmlTextReaderPtr) reader
{
  NEXUS_REST_APINS0RepositoryStatusResource *_nEXUS_REST_APINS0RepositoryStatusResource = [[NEXUS_REST_APINS0RepositoryStatusResource alloc] init];
  NS_DURING
  {
    [_nEXUS_REST_APINS0RepositoryStatusResource initWithReader: reader];
  }
  NS_HANDLER
  {
    [_nEXUS_REST_APINS0RepositoryStatusResource dealloc];
    _nEXUS_REST_APINS0RepositoryStatusResource = nil;
    [localException raise];
  }
  NS_ENDHANDLER

  [_nEXUS_REST_APINS0RepositoryStatusResource autorelease];
  return _nEXUS_REST_APINS0RepositoryStatusResource;
}

/**
 * Initialize this instance of NEXUS_REST_APINS0RepositoryStatusResource according to
 * the XML being read from the reader.
 *
 * @param reader The reader.
 */
- (id) initWithReader: (xmlTextReaderPtr) reader
{
  return [super initWithReader: reader];
}

/**
 * Write the XML for this instance of NEXUS_REST_APINS0RepositoryStatusResource to the writer.
 * Note that since we're only writing the XML type,
 * No start/end element will be written.
 *
 * @param reader The reader.
 */
- (void) writeXMLType: (xmlTextWriterPtr) writer
{
  [super writeXMLType:writer];
}

//documentation inherited.
- (BOOL) readJAXBAttribute: (xmlTextReaderPtr) reader
{
  void *_child_accessor;

  if ([super readJAXBAttribute: reader]) {
    return YES;
  }

  return NO;
}

//documentation inherited.
- (BOOL) readJAXBValue: (xmlTextReaderPtr) reader
{
  return [super readJAXBValue: reader];
}

//documentation inherited.
- (BOOL) readJAXBChildElement: (xmlTextReaderPtr) reader
{
  id __child;
  void *_child_accessor;
  int status, depth;

  if ([super readJAXBChildElement: reader]) {
    return YES;
  }
  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "id", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}id of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}id of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setId: __child];
    return YES;
  } //end "if choice"

  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "repoType", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}repoType of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}repoType of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setRepoType: __child];
    return YES;
  } //end "if choice"

  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "format", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}format of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}format of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setFormat: __child];
    return YES;
  } //end "if choice"

  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "localStatus", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}localStatus of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}localStatus of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setLocalStatus: __child];
    return YES;
  } //end "if choice"

  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "remoteStatus", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}remoteStatus of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}remoteStatus of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setRemoteStatus: __child];
    return YES;
  } //end "if choice"

  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "proxyMode", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}proxyMode of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}proxyMode of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setProxyMode: __child];
    return YES;
  } //end "if choice"

  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "dependentRepos", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

    if (xmlTextReaderIsEmptyElement(reader) == 0) {
#if DEBUG_ENUNCIATE > 1
      NSLog(@"Unwrapping wrapper element {}dependentRepos...");
#endif
      //start wrapper element "{}dependentRepos"
      depth = xmlTextReaderDepth(reader);
      status = xmlTextReaderAdvanceToNextStartOrEndElement(reader);
      while (xmlTextReaderDepth(reader) > depth) {
        if (status < 1) {
          //panic: XML read error.
          [self dealloc];
          [NSException raise: @"XMLReadError"
                       format: @"Failure to advance to next wrapped child element."];
        }
  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "dependentRepoItem", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}dependentRepoItem of type {}repository-dependent-status.");
#endif

    __child = [NEXUS_REST_APINS0RepositoryDependentStatusResource readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}dependentRepoItem of type {}repository-dependent-status.");
#endif

    if ([self dependentRepos]) {
      [self setDependentRepos: [[self dependentRepos] arrayByAddingObject: __child]];
    }
    else {
      [self setDependentRepos: [NSArray arrayWithObject: __child]];
    }
    continue; //continue "while in wrapper element" loop
  } //end "if choice"

        status = xmlTextReaderAdvanceToNextStartOrEndElement(reader);
#if DEBUG_ENUNCIATE > 1
        NSLog(@"successfully unwrapped wrapper element {}dependentRepos...");
#endif
      } // end "while in wrapper element" loop

      if (status < 1) {
        //panic: XML read error.
        [self dealloc];
        [NSException raise: @"XMLReadError"
                     format: @"Failure to advance to end wrapper element."];
      }
      else {
        //end wrapper element "{}dependentRepos"
        status = xmlTextReaderAdvanceToNextStartOrEndElement(reader);
      }
    } //end "if empty element" clause
    else {
      __child = [NSArray array];
      [self setDependentRepos: (NSArray*) __child];
    }

    return YES;
  } // end "if wrapper element" clause

  return NO;
}

//documentation inherited.
- (int) readUnknownJAXBChildElement: (xmlTextReaderPtr) reader
{
  return [super readUnknownJAXBChildElement: reader];
}

//documentation inherited.
- (void) readUnknownJAXBAttribute: (xmlTextReaderPtr) reader
{
  [super readUnknownJAXBAttribute: reader];
}

//documentation inherited.
- (void) writeJAXBAttributes: (xmlTextWriterPtr) writer
{
  int status;

  [super writeJAXBAttributes: writer];

}

//documentation inherited.
- (void) writeJAXBValue: (xmlTextWriterPtr) writer
{
  [super writeJAXBValue: writer];
}

/**
 * Method for writing the child elements.
 *
 * @param writer The writer.
 */
- (void) writeJAXBChildElements: (xmlTextWriterPtr) writer
{
  int status;
  id __item;
  NSEnumerator *__enumerator;

  [super writeJAXBChildElements: writer];

  if ([self id]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "id", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}id."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}id...");
#endif
    [[self id] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}id...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}id."];
    }
  }
  if ([self repoType]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "repoType", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}repoType."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}repoType...");
#endif
    [[self repoType] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}repoType...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}repoType."];
    }
  }
  if ([self format]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "format", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}format."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}format...");
#endif
    [[self format] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}format...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}format."];
    }
  }
  if ([self localStatus]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "localStatus", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}localStatus."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}localStatus...");
#endif
    [[self localStatus] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}localStatus...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}localStatus."];
    }
  }
  if ([self remoteStatus]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "remoteStatus", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}remoteStatus."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}remoteStatus...");
#endif
    [[self remoteStatus] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}remoteStatus...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}remoteStatus."];
    }
  }
  if ([self proxyMode]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "proxyMode", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}proxyMode."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}proxyMode...");
#endif
    [[self proxyMode] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}proxyMode...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}proxyMode."];
    }
  }
  if ([self dependentRepos]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "dependentRepos", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start wrapper element {}dependentRepos."];
    }
    __enumerator = [[self dependentRepos] objectEnumerator];

    while ( (__item = [__enumerator nextObject]) ) {
      status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "dependentRepoItem", NULL);
      if (status < 0) {
        [NSException raise: @"XMLWriteError"
                     format: @"Error writing start child element {}dependentRepoItem."];
      }

#if DEBUG_ENUNCIATE > 1
      NSLog(@"writing element {}dependentRepoItem...");
#endif
      [__item writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
      NSLog(@"successfully wrote element {}dependentRepoItem...");
#endif

      status = xmlTextWriterEndElement(writer);
      if (status < 0) {
        [NSException raise: @"XMLWriteError"
                     format: @"Error writing end child element {}dependentRepoItem."];
      }
    } //end item iterator.

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end wrapper element {}dependentRepos."];
    }
  }
}
@end /* implementation NEXUS_REST_APINS0RepositoryStatusResource (JAXB) */

#endif /* DEF_NEXUS_REST_APINS0RepositoryStatusResource_M */
#ifndef DEF_NEXUS_REST_APINS0RepositoryTargetListResource_M
#define DEF_NEXUS_REST_APINS0RepositoryTargetListResource_M

/**
 *  The repository target list details.
 
 @version $Revision$ $Date$

 */
@implementation NEXUS_REST_APINS0RepositoryTargetListResource

/**
 * URL that can be used to manage the repository target.
 */
- (NSString *) resourceURI
{
  return _resourceURI;
}

/**
 * URL that can be used to manage the repository target.
 */
- (void) setResourceURI: (NSString *) newResourceURI
{
  [newResourceURI retain];
  [_resourceURI release];
  _resourceURI = newResourceURI;
}

/**
 * The id of the repository target.
 */
- (NSString *) id
{
  return _id;
}

/**
 * The id of the repository target.
 */
- (void) setId: (NSString *) newId
{
  [newId retain];
  [_id release];
  _id = newId;
}

/**
 * The name of the repository target.
 */
- (NSString *) name
{
  return _name;
}

/**
 * The name of the repository target.
 */
- (void) setName: (NSString *) newName
{
  [newName retain];
  [_name release];
  _name = newName;
}

/**
 * The content class of the repository target.
 */
- (NSString *) contentClass
{
  return _contentClass;
}

/**
 * The content class of the repository target.
 */
- (void) setContentClass: (NSString *) newContentClass
{
  [newContentClass retain];
  [_contentClass release];
  _contentClass = newContentClass;
}

- (void) dealloc
{
  [self setResourceURI: nil];
  [self setId: nil];
  [self setName: nil];
  [self setContentClass: nil];
  [super dealloc];
}
@end /* implementation NEXUS_REST_APINS0RepositoryTargetListResource */

/**
 * Internal, private interface for JAXB reading and writing.
 */
@interface NEXUS_REST_APINS0RepositoryTargetListResource (JAXB) <JAXBReading, JAXBWriting, JAXBType>

@end /*interface NEXUS_REST_APINS0RepositoryTargetListResource (JAXB)*/

/**
 * Internal, private implementation for JAXB reading and writing.
 */
@implementation NEXUS_REST_APINS0RepositoryTargetListResource (JAXB)

/**
 * Read an instance of NEXUS_REST_APINS0RepositoryTargetListResource from an XML reader.
 *
 * @param reader The reader.
 * @return An instance of NEXUS_REST_APINS0RepositoryTargetListResource defined by the XML reader.
 */
+ (id<JAXBType>) readXMLType: (xmlTextReaderPtr) reader
{
  NEXUS_REST_APINS0RepositoryTargetListResource *_nEXUS_REST_APINS0RepositoryTargetListResource = [[NEXUS_REST_APINS0RepositoryTargetListResource alloc] init];
  NS_DURING
  {
    [_nEXUS_REST_APINS0RepositoryTargetListResource initWithReader: reader];
  }
  NS_HANDLER
  {
    [_nEXUS_REST_APINS0RepositoryTargetListResource dealloc];
    _nEXUS_REST_APINS0RepositoryTargetListResource = nil;
    [localException raise];
  }
  NS_ENDHANDLER

  [_nEXUS_REST_APINS0RepositoryTargetListResource autorelease];
  return _nEXUS_REST_APINS0RepositoryTargetListResource;
}

/**
 * Initialize this instance of NEXUS_REST_APINS0RepositoryTargetListResource according to
 * the XML being read from the reader.
 *
 * @param reader The reader.
 */
- (id) initWithReader: (xmlTextReaderPtr) reader
{
  return [super initWithReader: reader];
}

/**
 * Write the XML for this instance of NEXUS_REST_APINS0RepositoryTargetListResource to the writer.
 * Note that since we're only writing the XML type,
 * No start/end element will be written.
 *
 * @param reader The reader.
 */
- (void) writeXMLType: (xmlTextWriterPtr) writer
{
  [super writeXMLType:writer];
}

//documentation inherited.
- (BOOL) readJAXBAttribute: (xmlTextReaderPtr) reader
{
  void *_child_accessor;

  if ([super readJAXBAttribute: reader]) {
    return YES;
  }

  return NO;
}

//documentation inherited.
- (BOOL) readJAXBValue: (xmlTextReaderPtr) reader
{
  return [super readJAXBValue: reader];
}

//documentation inherited.
- (BOOL) readJAXBChildElement: (xmlTextReaderPtr) reader
{
  id __child;
  void *_child_accessor;
  int status, depth;

  if ([super readJAXBChildElement: reader]) {
    return YES;
  }
  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "resourceURI", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}resourceURI of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}resourceURI of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setResourceURI: __child];
    return YES;
  } //end "if choice"

  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "id", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}id of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}id of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setId: __child];
    return YES;
  } //end "if choice"

  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "name", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}name of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}name of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setName: __child];
    return YES;
  } //end "if choice"

  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "contentClass", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}contentClass of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}contentClass of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setContentClass: __child];
    return YES;
  } //end "if choice"


  return NO;
}

//documentation inherited.
- (int) readUnknownJAXBChildElement: (xmlTextReaderPtr) reader
{
  return [super readUnknownJAXBChildElement: reader];
}

//documentation inherited.
- (void) readUnknownJAXBAttribute: (xmlTextReaderPtr) reader
{
  [super readUnknownJAXBAttribute: reader];
}

//documentation inherited.
- (void) writeJAXBAttributes: (xmlTextWriterPtr) writer
{
  int status;

  [super writeJAXBAttributes: writer];

}

//documentation inherited.
- (void) writeJAXBValue: (xmlTextWriterPtr) writer
{
  [super writeJAXBValue: writer];
}

/**
 * Method for writing the child elements.
 *
 * @param writer The writer.
 */
- (void) writeJAXBChildElements: (xmlTextWriterPtr) writer
{
  int status;
  id __item;
  NSEnumerator *__enumerator;

  [super writeJAXBChildElements: writer];

  if ([self resourceURI]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "resourceURI", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}resourceURI."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}resourceURI...");
#endif
    [[self resourceURI] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}resourceURI...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}resourceURI."];
    }
  }
  if ([self id]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "id", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}id."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}id...");
#endif
    [[self id] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}id...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}id."];
    }
  }
  if ([self name]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "name", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}name."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}name...");
#endif
    [[self name] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}name...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}name."];
    }
  }
  if ([self contentClass]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "contentClass", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}contentClass."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}contentClass...");
#endif
    [[self contentClass] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}contentClass...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}contentClass."];
    }
  }
}
@end /* implementation NEXUS_REST_APINS0RepositoryTargetListResource (JAXB) */

#endif /* DEF_NEXUS_REST_APINS0RepositoryTargetListResource_M */
#ifndef DEF_NEXUS_REST_APINS0RepositoryTargetResource_M
#define DEF_NEXUS_REST_APINS0RepositoryTargetResource_M

/**
 *  The repository target configuration.
 
 @version $Revision$ $Date$

 */
@implementation NEXUS_REST_APINS0RepositoryTargetResource

/**
 * The URL used to manage the repository target.
 */
- (NSString *) resourceURI
{
  return _resourceURI;
}

/**
 * The URL used to manage the repository target.
 */
- (void) setResourceURI: (NSString *) newResourceURI
{
  [newResourceURI retain];
  [_resourceURI release];
  _resourceURI = newResourceURI;
}

/**
 * The id of the repository target.
 */
- (NSString *) id
{
  return _id;
}

/**
 * The id of the repository target.
 */
- (void) setId: (NSString *) newId
{
  [newId retain];
  [_id release];
  _id = newId;
}

/**
 * The name of the repository target.
 */
- (NSString *) name
{
  return _name;
}

/**
 * The name of the repository target.
 */
- (void) setName: (NSString *) newName
{
  [newName retain];
  [_name release];
  _name = newName;
}

/**
 * The content class of the repository target.
 */
- (NSString *) contentClass
{
  return _contentClass;
}

/**
 * The content class of the repository target.
 */
- (void) setContentClass: (NSString *) newContentClass
{
  [newContentClass retain];
  [_contentClass release];
  _contentClass = newContentClass;
}

/**
 * Field patterns.
 */
- (NSArray *) patterns
{
  return _patterns;
}

/**
 * Field patterns.
 */
- (void) setPatterns: (NSArray *) newPatterns
{
  [newPatterns retain];
  [_patterns release];
  _patterns = newPatterns;
}

- (void) dealloc
{
  [self setResourceURI: nil];
  [self setId: nil];
  [self setName: nil];
  [self setContentClass: nil];
  [self setPatterns: nil];
  [super dealloc];
}
@end /* implementation NEXUS_REST_APINS0RepositoryTargetResource */

/**
 * Internal, private interface for JAXB reading and writing.
 */
@interface NEXUS_REST_APINS0RepositoryTargetResource (JAXB) <JAXBReading, JAXBWriting, JAXBType>

@end /*interface NEXUS_REST_APINS0RepositoryTargetResource (JAXB)*/

/**
 * Internal, private implementation for JAXB reading and writing.
 */
@implementation NEXUS_REST_APINS0RepositoryTargetResource (JAXB)

/**
 * Read an instance of NEXUS_REST_APINS0RepositoryTargetResource from an XML reader.
 *
 * @param reader The reader.
 * @return An instance of NEXUS_REST_APINS0RepositoryTargetResource defined by the XML reader.
 */
+ (id<JAXBType>) readXMLType: (xmlTextReaderPtr) reader
{
  NEXUS_REST_APINS0RepositoryTargetResource *_nEXUS_REST_APINS0RepositoryTargetResource = [[NEXUS_REST_APINS0RepositoryTargetResource alloc] init];
  NS_DURING
  {
    [_nEXUS_REST_APINS0RepositoryTargetResource initWithReader: reader];
  }
  NS_HANDLER
  {
    [_nEXUS_REST_APINS0RepositoryTargetResource dealloc];
    _nEXUS_REST_APINS0RepositoryTargetResource = nil;
    [localException raise];
  }
  NS_ENDHANDLER

  [_nEXUS_REST_APINS0RepositoryTargetResource autorelease];
  return _nEXUS_REST_APINS0RepositoryTargetResource;
}

/**
 * Initialize this instance of NEXUS_REST_APINS0RepositoryTargetResource according to
 * the XML being read from the reader.
 *
 * @param reader The reader.
 */
- (id) initWithReader: (xmlTextReaderPtr) reader
{
  return [super initWithReader: reader];
}

/**
 * Write the XML for this instance of NEXUS_REST_APINS0RepositoryTargetResource to the writer.
 * Note that since we're only writing the XML type,
 * No start/end element will be written.
 *
 * @param reader The reader.
 */
- (void) writeXMLType: (xmlTextWriterPtr) writer
{
  [super writeXMLType:writer];
}

//documentation inherited.
- (BOOL) readJAXBAttribute: (xmlTextReaderPtr) reader
{
  void *_child_accessor;

  if ([super readJAXBAttribute: reader]) {
    return YES;
  }

  return NO;
}

//documentation inherited.
- (BOOL) readJAXBValue: (xmlTextReaderPtr) reader
{
  return [super readJAXBValue: reader];
}

//documentation inherited.
- (BOOL) readJAXBChildElement: (xmlTextReaderPtr) reader
{
  id __child;
  void *_child_accessor;
  int status, depth;

  if ([super readJAXBChildElement: reader]) {
    return YES;
  }
  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "resourceURI", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}resourceURI of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}resourceURI of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setResourceURI: __child];
    return YES;
  } //end "if choice"

  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "id", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}id of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}id of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setId: __child];
    return YES;
  } //end "if choice"

  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "name", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}name of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}name of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setName: __child];
    return YES;
  } //end "if choice"

  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "contentClass", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}contentClass of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}contentClass of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setContentClass: __child];
    return YES;
  } //end "if choice"

  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "patterns", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

    if (xmlTextReaderIsEmptyElement(reader) == 0) {
#if DEBUG_ENUNCIATE > 1
      NSLog(@"Unwrapping wrapper element {}patterns...");
#endif
      //start wrapper element "{}patterns"
      depth = xmlTextReaderDepth(reader);
      status = xmlTextReaderAdvanceToNextStartOrEndElement(reader);
      while (xmlTextReaderDepth(reader) > depth) {
        if (status < 1) {
          //panic: XML read error.
          [self dealloc];
          [NSException raise: @"XMLReadError"
                       format: @"Failure to advance to next wrapped child element."];
        }
  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "pattern", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}pattern of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}pattern of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    if ([self patterns]) {
      [self setPatterns: [[self patterns] arrayByAddingObject: __child]];
    }
    else {
      [self setPatterns: [NSArray arrayWithObject: __child]];
    }
    continue; //continue "while in wrapper element" loop
  } //end "if choice"

        status = xmlTextReaderAdvanceToNextStartOrEndElement(reader);
#if DEBUG_ENUNCIATE > 1
        NSLog(@"successfully unwrapped wrapper element {}patterns...");
#endif
      } // end "while in wrapper element" loop

      if (status < 1) {
        //panic: XML read error.
        [self dealloc];
        [NSException raise: @"XMLReadError"
                     format: @"Failure to advance to end wrapper element."];
      }
      else {
        //end wrapper element "{}patterns"
        status = xmlTextReaderAdvanceToNextStartOrEndElement(reader);
      }
    } //end "if empty element" clause
    else {
      __child = [NSArray array];
      [self setPatterns: (NSArray*) __child];
    }

    return YES;
  } // end "if wrapper element" clause

  return NO;
}

//documentation inherited.
- (int) readUnknownJAXBChildElement: (xmlTextReaderPtr) reader
{
  return [super readUnknownJAXBChildElement: reader];
}

//documentation inherited.
- (void) readUnknownJAXBAttribute: (xmlTextReaderPtr) reader
{
  [super readUnknownJAXBAttribute: reader];
}

//documentation inherited.
- (void) writeJAXBAttributes: (xmlTextWriterPtr) writer
{
  int status;

  [super writeJAXBAttributes: writer];

}

//documentation inherited.
- (void) writeJAXBValue: (xmlTextWriterPtr) writer
{
  [super writeJAXBValue: writer];
}

/**
 * Method for writing the child elements.
 *
 * @param writer The writer.
 */
- (void) writeJAXBChildElements: (xmlTextWriterPtr) writer
{
  int status;
  id __item;
  NSEnumerator *__enumerator;

  [super writeJAXBChildElements: writer];

  if ([self resourceURI]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "resourceURI", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}resourceURI."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}resourceURI...");
#endif
    [[self resourceURI] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}resourceURI...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}resourceURI."];
    }
  }
  if ([self id]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "id", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}id."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}id...");
#endif
    [[self id] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}id...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}id."];
    }
  }
  if ([self name]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "name", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}name."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}name...");
#endif
    [[self name] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}name...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}name."];
    }
  }
  if ([self contentClass]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "contentClass", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}contentClass."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}contentClass...");
#endif
    [[self contentClass] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}contentClass...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}contentClass."];
    }
  }
  if ([self patterns]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "patterns", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start wrapper element {}patterns."];
    }
    __enumerator = [[self patterns] objectEnumerator];

    while ( (__item = [__enumerator nextObject]) ) {
      status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "pattern", NULL);
      if (status < 0) {
        [NSException raise: @"XMLWriteError"
                     format: @"Error writing start child element {}pattern."];
      }

#if DEBUG_ENUNCIATE > 1
      NSLog(@"writing element {}pattern...");
#endif
      [__item writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
      NSLog(@"successfully wrote element {}pattern...");
#endif

      status = xmlTextWriterEndElement(writer);
      if (status < 0) {
        [NSException raise: @"XMLWriteError"
                     format: @"Error writing end child element {}pattern."];
      }
    } //end item iterator.

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end wrapper element {}patterns."];
    }
  }
}
@end /* implementation NEXUS_REST_APINS0RepositoryTargetResource (JAXB) */

#endif /* DEF_NEXUS_REST_APINS0RepositoryTargetResource_M */
#ifndef DEF_NEXUS_REST_APINS0RestApiSettings_M
#define DEF_NEXUS_REST_APINS0RestApiSettings_M

/**
 *  The rest api configuration settings.
 
 @version $Revision$ $Date$

 */
@implementation NEXUS_REST_APINS0RestApiSettings

/**
 * Flag that states whether to forcefully set the baseUrl
defined in rest responses.
 */
- (BOOL) forceBaseUrl
{
  return _forceBaseUrl;
}

/**
 * Flag that states whether to forcefully set the baseUrl
defined in rest responses.
 */
- (void) setForceBaseUrl: (BOOL) newForceBaseUrl
{
  _forceBaseUrl = newForceBaseUrl;
}

/**
 * The baseUrl of the nexus server.
 */
- (NSString *) baseUrl
{
  return _baseUrl;
}

/**
 * The baseUrl of the nexus server.
 */
- (void) setBaseUrl: (NSString *) newBaseUrl
{
  [newBaseUrl retain];
  [_baseUrl release];
  _baseUrl = newBaseUrl;
}

/**
 * UI timeout in milliseconds.
 */
- (int) uiTimeout
{
  return _uiTimeout;
}

/**
 * UI timeout in milliseconds.
 */
- (void) setUiTimeout: (int) newUiTimeout
{
  _uiTimeout = newUiTimeout;
}

- (void) dealloc
{
  [self setBaseUrl: nil];
  [super dealloc];
}
@end /* implementation NEXUS_REST_APINS0RestApiSettings */

/**
 * Internal, private interface for JAXB reading and writing.
 */
@interface NEXUS_REST_APINS0RestApiSettings (JAXB) <JAXBReading, JAXBWriting, JAXBType>

@end /*interface NEXUS_REST_APINS0RestApiSettings (JAXB)*/

/**
 * Internal, private implementation for JAXB reading and writing.
 */
@implementation NEXUS_REST_APINS0RestApiSettings (JAXB)

/**
 * Read an instance of NEXUS_REST_APINS0RestApiSettings from an XML reader.
 *
 * @param reader The reader.
 * @return An instance of NEXUS_REST_APINS0RestApiSettings defined by the XML reader.
 */
+ (id<JAXBType>) readXMLType: (xmlTextReaderPtr) reader
{
  NEXUS_REST_APINS0RestApiSettings *_nEXUS_REST_APINS0RestApiSettings = [[NEXUS_REST_APINS0RestApiSettings alloc] init];
  NS_DURING
  {
    [_nEXUS_REST_APINS0RestApiSettings initWithReader: reader];
  }
  NS_HANDLER
  {
    [_nEXUS_REST_APINS0RestApiSettings dealloc];
    _nEXUS_REST_APINS0RestApiSettings = nil;
    [localException raise];
  }
  NS_ENDHANDLER

  [_nEXUS_REST_APINS0RestApiSettings autorelease];
  return _nEXUS_REST_APINS0RestApiSettings;
}

/**
 * Initialize this instance of NEXUS_REST_APINS0RestApiSettings according to
 * the XML being read from the reader.
 *
 * @param reader The reader.
 */
- (id) initWithReader: (xmlTextReaderPtr) reader
{
  return [super initWithReader: reader];
}

/**
 * Write the XML for this instance of NEXUS_REST_APINS0RestApiSettings to the writer.
 * Note that since we're only writing the XML type,
 * No start/end element will be written.
 *
 * @param reader The reader.
 */
- (void) writeXMLType: (xmlTextWriterPtr) writer
{
  [super writeXMLType:writer];
}

//documentation inherited.
- (BOOL) readJAXBAttribute: (xmlTextReaderPtr) reader
{
  void *_child_accessor;

  if ([super readJAXBAttribute: reader]) {
    return YES;
  }

  return NO;
}

//documentation inherited.
- (BOOL) readJAXBValue: (xmlTextReaderPtr) reader
{
  return [super readJAXBValue: reader];
}

//documentation inherited.
- (BOOL) readJAXBChildElement: (xmlTextReaderPtr) reader
{
  id __child;
  void *_child_accessor;
  int status, depth;

  if ([super readJAXBChildElement: reader]) {
    return YES;
  }

  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "forceBaseUrl", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

    _child_accessor = xmlTextReaderReadBooleanType(reader);
    if (_child_accessor == NULL) {
      //panic: unable to return the value for some reason.
      [self dealloc];
      [NSException raise: @"XMLReadError"
                   format: @"Error reading element value."];
    }
    [self setForceBaseUrl: *((BOOL*) _child_accessor)];
    free(_child_accessor);
    return YES;
  }
  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "baseUrl", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}baseUrl of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}baseUrl of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setBaseUrl: __child];
    return YES;
  } //end "if choice"


  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "uiTimeout", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

    _child_accessor = xmlTextReaderReadIntType(reader);
    if (_child_accessor == NULL) {
      //panic: unable to return the value for some reason.
      [self dealloc];
      [NSException raise: @"XMLReadError"
                   format: @"Error reading element value."];
    }
    [self setUiTimeout: *((int*) _child_accessor)];
    free(_child_accessor);
    return YES;
  }

  return NO;
}

//documentation inherited.
- (int) readUnknownJAXBChildElement: (xmlTextReaderPtr) reader
{
  return [super readUnknownJAXBChildElement: reader];
}

//documentation inherited.
- (void) readUnknownJAXBAttribute: (xmlTextReaderPtr) reader
{
  [super readUnknownJAXBAttribute: reader];
}

//documentation inherited.
- (void) writeJAXBAttributes: (xmlTextWriterPtr) writer
{
  int status;

  [super writeJAXBAttributes: writer];

}

//documentation inherited.
- (void) writeJAXBValue: (xmlTextWriterPtr) writer
{
  [super writeJAXBValue: writer];
}

/**
 * Method for writing the child elements.
 *
 * @param writer The writer.
 */
- (void) writeJAXBChildElements: (xmlTextWriterPtr) writer
{
  int status;
  id __item;
  NSEnumerator *__enumerator;

  [super writeJAXBChildElements: writer];

  if (YES) { //always write the primitive element...
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "forceBaseUrl", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}forceBaseUrl."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}forceBaseUrl...");
#endif
    status = xmlTextWriterWriteBooleanType(writer, &_forceBaseUrl);
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}forceBaseUrl...");
#endif
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing child element {}forceBaseUrl."];
    }

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}forceBaseUrl."];
    }
  }
  if ([self baseUrl]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "baseUrl", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}baseUrl."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}baseUrl...");
#endif
    [[self baseUrl] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}baseUrl...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}baseUrl."];
    }
  }
  if (YES) { //always write the primitive element...
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "uiTimeout", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}uiTimeout."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}uiTimeout...");
#endif
    status = xmlTextWriterWriteIntType(writer, &_uiTimeout);
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}uiTimeout...");
#endif
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing child element {}uiTimeout."];
    }

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}uiTimeout."];
    }
  }
}
@end /* implementation NEXUS_REST_APINS0RestApiSettings (JAXB) */

#endif /* DEF_NEXUS_REST_APINS0RestApiSettings_M */
#ifndef DEF_NEXUS_REST_APINS0ScheduledServiceListResource_M
#define DEF_NEXUS_REST_APINS0ScheduledServiceListResource_M

/**
 *  Scheduled service list item details.
 
 @version $Revision$ $Date$

 */
@implementation NEXUS_REST_APINS0ScheduledServiceListResource

/**
 * The URL that can be used to manage the scheduled service.
 */
- (NSString *) resourceURI
{
  return _resourceURI;
}

/**
 * The URL that can be used to manage the scheduled service.
 */
- (void) setResourceURI: (NSString *) newResourceURI
{
  [newResourceURI retain];
  [_resourceURI release];
  _resourceURI = newResourceURI;
}

/**
 * The id of the scheduled service.
 */
- (NSString *) id
{
  return _id;
}

/**
 * The id of the scheduled service.
 */
- (void) setId: (NSString *) newId
{
  [newId retain];
  [_id release];
  _id = newId;
}

/**
 * Flag that states if the service is enabled.
 */
- (BOOL) enabled
{
  return _enabled;
}

/**
 * Flag that states if the service is enabled.
 */
- (void) setEnabled: (BOOL) newEnabled
{
  _enabled = newEnabled;
}

/**
 * The name of the scheduled service.
 */
- (NSString *) name
{
  return _name;
}

/**
 * The name of the scheduled service.
 */
- (void) setName: (NSString *) newName
{
  [newName retain];
  [_name release];
  _name = newName;
}

/**
 * The type id of the scheduled service.
 */
- (NSString *) typeId
{
  return _typeId;
}

/**
 * The type id of the scheduled service.
 */
- (void) setTypeId: (NSString *) newTypeId
{
  [newTypeId retain];
  [_typeId release];
  _typeId = newTypeId;
}

/**
 * The type name of the scheduled service.
 */
- (NSString *) typeName
{
  return _typeName;
}

/**
 * The type name of the scheduled service.
 */
- (void) setTypeName: (NSString *) newTypeName
{
  [newTypeName retain];
  [_typeName release];
  _typeName = newTypeName;
}

/**
 * The status of the scheduled service (running, broken, etc.).
 */
- (NSString *) status
{
  return _status;
}

/**
 * The status of the scheduled service (running, broken, etc.).
 */
- (void) setStatus: (NSString *) newStatus
{
  [newStatus retain];
  [_status release];
  _status = newStatus;
}

/**
 * The status of the scheduled service (running, broken, etc.).
 */
- (NSString *) readableStatus
{
  return _readableStatus;
}

/**
 * The status of the scheduled service (running, broken, etc.).
 */
- (void) setReadableStatus: (NSString *) newReadableStatus
{
  [newReadableStatus retain];
  [_readableStatus release];
  _readableStatus = newReadableStatus;
}

/**
 * The type of schedule the service is run on (monthly, daily,
etc.).
 */
- (NSString *) schedule
{
  return _schedule;
}

/**
 * The type of schedule the service is run on (monthly, daily,
etc.).
 */
- (void) setSchedule: (NSString *) newSchedule
{
  [newSchedule retain];
  [_schedule release];
  _schedule = newSchedule;
}

/**
 * The next time the scheduled service will run.
 */
- (NSString *) nextRunTime
{
  return _nextRunTime;
}

/**
 * The next time the scheduled service will run.
 */
- (void) setNextRunTime: (NSString *) newNextRunTime
{
  [newNextRunTime retain];
  [_nextRunTime release];
  _nextRunTime = newNextRunTime;
}

/**
 * The last time the scheduled service ran.
 */
- (NSString *) lastRunTime
{
  return _lastRunTime;
}

/**
 * The last time the scheduled service ran.
 */
- (void) setLastRunTime: (NSString *) newLastRunTime
{
  [newLastRunTime retain];
  [_lastRunTime release];
  _lastRunTime = newLastRunTime;
}

/**
 * The result of the last service run.
 */
- (NSString *) lastRunResult
{
  return _lastRunResult;
}

/**
 * The result of the last service run.
 */
- (void) setLastRunResult: (NSString *) newLastRunResult
{
  [newLastRunResult retain];
  [_lastRunResult release];
  _lastRunResult = newLastRunResult;
}

/**
 * The date the service was created.
 */
- (NSString *) created
{
  return _created;
}

/**
 * The date the service was created.
 */
- (void) setCreated: (NSString *) newCreated
{
  [newCreated retain];
  [_created release];
  _created = newCreated;
}

- (void) dealloc
{
  [self setResourceURI: nil];
  [self setId: nil];
  [self setName: nil];
  [self setTypeId: nil];
  [self setTypeName: nil];
  [self setStatus: nil];
  [self setReadableStatus: nil];
  [self setSchedule: nil];
  [self setNextRunTime: nil];
  [self setLastRunTime: nil];
  [self setLastRunResult: nil];
  [self setCreated: nil];
  [super dealloc];
}
@end /* implementation NEXUS_REST_APINS0ScheduledServiceListResource */

/**
 * Internal, private interface for JAXB reading and writing.
 */
@interface NEXUS_REST_APINS0ScheduledServiceListResource (JAXB) <JAXBReading, JAXBWriting, JAXBType>

@end /*interface NEXUS_REST_APINS0ScheduledServiceListResource (JAXB)*/

/**
 * Internal, private implementation for JAXB reading and writing.
 */
@implementation NEXUS_REST_APINS0ScheduledServiceListResource (JAXB)

/**
 * Read an instance of NEXUS_REST_APINS0ScheduledServiceListResource from an XML reader.
 *
 * @param reader The reader.
 * @return An instance of NEXUS_REST_APINS0ScheduledServiceListResource defined by the XML reader.
 */
+ (id<JAXBType>) readXMLType: (xmlTextReaderPtr) reader
{
  NEXUS_REST_APINS0ScheduledServiceListResource *_nEXUS_REST_APINS0ScheduledServiceListResource = [[NEXUS_REST_APINS0ScheduledServiceListResource alloc] init];
  NS_DURING
  {
    [_nEXUS_REST_APINS0ScheduledServiceListResource initWithReader: reader];
  }
  NS_HANDLER
  {
    [_nEXUS_REST_APINS0ScheduledServiceListResource dealloc];
    _nEXUS_REST_APINS0ScheduledServiceListResource = nil;
    [localException raise];
  }
  NS_ENDHANDLER

  [_nEXUS_REST_APINS0ScheduledServiceListResource autorelease];
  return _nEXUS_REST_APINS0ScheduledServiceListResource;
}

/**
 * Initialize this instance of NEXUS_REST_APINS0ScheduledServiceListResource according to
 * the XML being read from the reader.
 *
 * @param reader The reader.
 */
- (id) initWithReader: (xmlTextReaderPtr) reader
{
  return [super initWithReader: reader];
}

/**
 * Write the XML for this instance of NEXUS_REST_APINS0ScheduledServiceListResource to the writer.
 * Note that since we're only writing the XML type,
 * No start/end element will be written.
 *
 * @param reader The reader.
 */
- (void) writeXMLType: (xmlTextWriterPtr) writer
{
  [super writeXMLType:writer];
}

//documentation inherited.
- (BOOL) readJAXBAttribute: (xmlTextReaderPtr) reader
{
  void *_child_accessor;

  if ([super readJAXBAttribute: reader]) {
    return YES;
  }

  return NO;
}

//documentation inherited.
- (BOOL) readJAXBValue: (xmlTextReaderPtr) reader
{
  return [super readJAXBValue: reader];
}

//documentation inherited.
- (BOOL) readJAXBChildElement: (xmlTextReaderPtr) reader
{
  id __child;
  void *_child_accessor;
  int status, depth;

  if ([super readJAXBChildElement: reader]) {
    return YES;
  }
  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "resourceURI", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}resourceURI of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}resourceURI of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setResourceURI: __child];
    return YES;
  } //end "if choice"

  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "id", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}id of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}id of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setId: __child];
    return YES;
  } //end "if choice"


  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "enabled", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

    _child_accessor = xmlTextReaderReadBooleanType(reader);
    if (_child_accessor == NULL) {
      //panic: unable to return the value for some reason.
      [self dealloc];
      [NSException raise: @"XMLReadError"
                   format: @"Error reading element value."];
    }
    [self setEnabled: *((BOOL*) _child_accessor)];
    free(_child_accessor);
    return YES;
  }
  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "name", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}name of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}name of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setName: __child];
    return YES;
  } //end "if choice"

  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "typeId", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}typeId of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}typeId of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setTypeId: __child];
    return YES;
  } //end "if choice"

  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "typeName", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}typeName of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}typeName of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setTypeName: __child];
    return YES;
  } //end "if choice"

  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "status", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}status of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}status of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setStatus: __child];
    return YES;
  } //end "if choice"

  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "readableStatus", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}readableStatus of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}readableStatus of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setReadableStatus: __child];
    return YES;
  } //end "if choice"

  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "schedule", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}schedule of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}schedule of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setSchedule: __child];
    return YES;
  } //end "if choice"

  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "nextRunTime", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}nextRunTime of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}nextRunTime of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setNextRunTime: __child];
    return YES;
  } //end "if choice"

  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "lastRunTime", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}lastRunTime of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}lastRunTime of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setLastRunTime: __child];
    return YES;
  } //end "if choice"

  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "lastRunResult", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}lastRunResult of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}lastRunResult of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setLastRunResult: __child];
    return YES;
  } //end "if choice"

  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "created", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}created of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}created of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setCreated: __child];
    return YES;
  } //end "if choice"


  return NO;
}

//documentation inherited.
- (int) readUnknownJAXBChildElement: (xmlTextReaderPtr) reader
{
  return [super readUnknownJAXBChildElement: reader];
}

//documentation inherited.
- (void) readUnknownJAXBAttribute: (xmlTextReaderPtr) reader
{
  [super readUnknownJAXBAttribute: reader];
}

//documentation inherited.
- (void) writeJAXBAttributes: (xmlTextWriterPtr) writer
{
  int status;

  [super writeJAXBAttributes: writer];

}

//documentation inherited.
- (void) writeJAXBValue: (xmlTextWriterPtr) writer
{
  [super writeJAXBValue: writer];
}

/**
 * Method for writing the child elements.
 *
 * @param writer The writer.
 */
- (void) writeJAXBChildElements: (xmlTextWriterPtr) writer
{
  int status;
  id __item;
  NSEnumerator *__enumerator;

  [super writeJAXBChildElements: writer];

  if ([self resourceURI]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "resourceURI", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}resourceURI."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}resourceURI...");
#endif
    [[self resourceURI] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}resourceURI...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}resourceURI."];
    }
  }
  if ([self id]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "id", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}id."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}id...");
#endif
    [[self id] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}id...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}id."];
    }
  }
  if (YES) { //always write the primitive element...
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "enabled", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}enabled."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}enabled...");
#endif
    status = xmlTextWriterWriteBooleanType(writer, &_enabled);
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}enabled...");
#endif
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing child element {}enabled."];
    }

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}enabled."];
    }
  }
  if ([self name]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "name", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}name."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}name...");
#endif
    [[self name] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}name...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}name."];
    }
  }
  if ([self typeId]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "typeId", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}typeId."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}typeId...");
#endif
    [[self typeId] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}typeId...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}typeId."];
    }
  }
  if ([self typeName]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "typeName", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}typeName."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}typeName...");
#endif
    [[self typeName] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}typeName...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}typeName."];
    }
  }
  if ([self status]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "status", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}status."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}status...");
#endif
    [[self status] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}status...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}status."];
    }
  }
  if ([self readableStatus]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "readableStatus", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}readableStatus."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}readableStatus...");
#endif
    [[self readableStatus] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}readableStatus...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}readableStatus."];
    }
  }
  if ([self schedule]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "schedule", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}schedule."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}schedule...");
#endif
    [[self schedule] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}schedule...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}schedule."];
    }
  }
  if ([self nextRunTime]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "nextRunTime", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}nextRunTime."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}nextRunTime...");
#endif
    [[self nextRunTime] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}nextRunTime...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}nextRunTime."];
    }
  }
  if ([self lastRunTime]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "lastRunTime", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}lastRunTime."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}lastRunTime...");
#endif
    [[self lastRunTime] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}lastRunTime...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}lastRunTime."];
    }
  }
  if ([self lastRunResult]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "lastRunResult", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}lastRunResult."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}lastRunResult...");
#endif
    [[self lastRunResult] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}lastRunResult...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}lastRunResult."];
    }
  }
  if ([self created]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "created", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}created."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}created...");
#endif
    [[self created] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}created...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}created."];
    }
  }
}
@end /* implementation NEXUS_REST_APINS0ScheduledServiceListResource (JAXB) */

#endif /* DEF_NEXUS_REST_APINS0ScheduledServiceListResource_M */
#ifndef DEF_NEXUS_REST_APINS0ScheduledServicePropertyResource_M
#define DEF_NEXUS_REST_APINS0ScheduledServicePropertyResource_M

/**
 *  A configuration property for a scheduled service.
 
 @version $Revision$ $Date$

 */
@implementation NEXUS_REST_APINS0ScheduledServicePropertyResource

/**
 * The id of the property.
 */
- (NSString *) key
{
  return _key;
}

/**
 * The id of the property.
 */
- (void) setKey: (NSString *) newKey
{
  [newKey retain];
  [_key release];
  _key = newKey;
}

/**
 * The value of the property.
 */
- (NSString *) value
{
  return _value;
}

/**
 * The value of the property.
 */
- (void) setValue: (NSString *) newValue
{
  [newValue retain];
  [_value release];
  _value = newValue;
}

- (void) dealloc
{
  [self setKey: nil];
  [self setValue: nil];
  [super dealloc];
}
@end /* implementation NEXUS_REST_APINS0ScheduledServicePropertyResource */

/**
 * Internal, private interface for JAXB reading and writing.
 */
@interface NEXUS_REST_APINS0ScheduledServicePropertyResource (JAXB) <JAXBReading, JAXBWriting, JAXBType>

@end /*interface NEXUS_REST_APINS0ScheduledServicePropertyResource (JAXB)*/

/**
 * Internal, private implementation for JAXB reading and writing.
 */
@implementation NEXUS_REST_APINS0ScheduledServicePropertyResource (JAXB)

/**
 * Read an instance of NEXUS_REST_APINS0ScheduledServicePropertyResource from an XML reader.
 *
 * @param reader The reader.
 * @return An instance of NEXUS_REST_APINS0ScheduledServicePropertyResource defined by the XML reader.
 */
+ (id<JAXBType>) readXMLType: (xmlTextReaderPtr) reader
{
  NEXUS_REST_APINS0ScheduledServicePropertyResource *_nEXUS_REST_APINS0ScheduledServicePropertyResource = [[NEXUS_REST_APINS0ScheduledServicePropertyResource alloc] init];
  NS_DURING
  {
    [_nEXUS_REST_APINS0ScheduledServicePropertyResource initWithReader: reader];
  }
  NS_HANDLER
  {
    [_nEXUS_REST_APINS0ScheduledServicePropertyResource dealloc];
    _nEXUS_REST_APINS0ScheduledServicePropertyResource = nil;
    [localException raise];
  }
  NS_ENDHANDLER

  [_nEXUS_REST_APINS0ScheduledServicePropertyResource autorelease];
  return _nEXUS_REST_APINS0ScheduledServicePropertyResource;
}

/**
 * Initialize this instance of NEXUS_REST_APINS0ScheduledServicePropertyResource according to
 * the XML being read from the reader.
 *
 * @param reader The reader.
 */
- (id) initWithReader: (xmlTextReaderPtr) reader
{
  return [super initWithReader: reader];
}

/**
 * Write the XML for this instance of NEXUS_REST_APINS0ScheduledServicePropertyResource to the writer.
 * Note that since we're only writing the XML type,
 * No start/end element will be written.
 *
 * @param reader The reader.
 */
- (void) writeXMLType: (xmlTextWriterPtr) writer
{
  [super writeXMLType:writer];
}

//documentation inherited.
- (BOOL) readJAXBAttribute: (xmlTextReaderPtr) reader
{
  void *_child_accessor;

  if ([super readJAXBAttribute: reader]) {
    return YES;
  }

  return NO;
}

//documentation inherited.
- (BOOL) readJAXBValue: (xmlTextReaderPtr) reader
{
  return [super readJAXBValue: reader];
}

//documentation inherited.
- (BOOL) readJAXBChildElement: (xmlTextReaderPtr) reader
{
  id __child;
  void *_child_accessor;
  int status, depth;

  if ([super readJAXBChildElement: reader]) {
    return YES;
  }
  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "key", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}key of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}key of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setKey: __child];
    return YES;
  } //end "if choice"

  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "value", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}value of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}value of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setValue: __child];
    return YES;
  } //end "if choice"


  return NO;
}

//documentation inherited.
- (int) readUnknownJAXBChildElement: (xmlTextReaderPtr) reader
{
  return [super readUnknownJAXBChildElement: reader];
}

//documentation inherited.
- (void) readUnknownJAXBAttribute: (xmlTextReaderPtr) reader
{
  [super readUnknownJAXBAttribute: reader];
}

//documentation inherited.
- (void) writeJAXBAttributes: (xmlTextWriterPtr) writer
{
  int status;

  [super writeJAXBAttributes: writer];

}

//documentation inherited.
- (void) writeJAXBValue: (xmlTextWriterPtr) writer
{
  [super writeJAXBValue: writer];
}

/**
 * Method for writing the child elements.
 *
 * @param writer The writer.
 */
- (void) writeJAXBChildElements: (xmlTextWriterPtr) writer
{
  int status;
  id __item;
  NSEnumerator *__enumerator;

  [super writeJAXBChildElements: writer];

  if ([self key]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "key", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}key."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}key...");
#endif
    [[self key] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}key...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}key."];
    }
  }
  if ([self value]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "value", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}value."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}value...");
#endif
    [[self value] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}value...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}value."];
    }
  }
}
@end /* implementation NEXUS_REST_APINS0ScheduledServicePropertyResource (JAXB) */

#endif /* DEF_NEXUS_REST_APINS0ScheduledServicePropertyResource_M */
#ifndef DEF_NEXUS_REST_APINS0ScheduledServiceResourceStatus_M
#define DEF_NEXUS_REST_APINS0ScheduledServiceResourceStatus_M

/**
 *  Scheduled service status details.
 
 @version $Revision$ $Date$

 */
@implementation NEXUS_REST_APINS0ScheduledServiceResourceStatus

/**
 * The scheduled service configuration.
 */
- (NEXUS_REST_APINS0ScheduledServiceBaseResource *) resource
{
  return _resource;
}

/**
 * The scheduled service configuration.
 */
- (void) setResource: (NEXUS_REST_APINS0ScheduledServiceBaseResource *) newResource
{
  [newResource retain];
  [_resource release];
  _resource = newResource;
}

/**
 * The URL used to managed the scheduled service.
 */
- (NSString *) resourceURI
{
  return _resourceURI;
}

/**
 * The URL used to managed the scheduled service.
 */
- (void) setResourceURI: (NSString *) newResourceURI
{
  [newResourceURI retain];
  [_resourceURI release];
  _resourceURI = newResourceURI;
}

/**
 * The status of the scheduled service.
 */
- (NSString *) status
{
  return _status;
}

/**
 * The status of the scheduled service.
 */
- (void) setStatus: (NSString *) newStatus
{
  [newStatus retain];
  [_status release];
  _status = newStatus;
}

/**
 * The status of the scheduled service (running, broken, etc.).
 */
- (NSString *) readableStatus
{
  return _readableStatus;
}

/**
 * The status of the scheduled service (running, broken, etc.).
 */
- (void) setReadableStatus: (NSString *) newReadableStatus
{
  [newReadableStatus retain];
  [_readableStatus release];
  _readableStatus = newReadableStatus;
}

/**
 * The next time the scheduled service will run.
 */
- (NSString *) nextRunTime
{
  return _nextRunTime;
}

/**
 * The next time the scheduled service will run.
 */
- (void) setNextRunTime: (NSString *) newNextRunTime
{
  [newNextRunTime retain];
  [_nextRunTime release];
  _nextRunTime = newNextRunTime;
}

/**
 * The last time the scheduled service ran.
 */
- (NSString *) lastRunTime
{
  return _lastRunTime;
}

/**
 * The last time the scheduled service ran.
 */
- (void) setLastRunTime: (NSString *) newLastRunTime
{
  [newLastRunTime retain];
  [_lastRunTime release];
  _lastRunTime = newLastRunTime;
}

/**
 * The result of the last service run.
 */
- (NSString *) lastRunResult
{
  return _lastRunResult;
}

/**
 * The result of the last service run.
 */
- (void) setLastRunResult: (NSString *) newLastRunResult
{
  [newLastRunResult retain];
  [_lastRunResult release];
  _lastRunResult = newLastRunResult;
}

/**
 * The date the service was created.
 */
- (NSString *) created
{
  return _created;
}

/**
 * The date the service was created.
 */
- (void) setCreated: (NSString *) newCreated
{
  [newCreated retain];
  [_created release];
  _created = newCreated;
}

- (void) dealloc
{
  [self setResource: nil];
  [self setResourceURI: nil];
  [self setStatus: nil];
  [self setReadableStatus: nil];
  [self setNextRunTime: nil];
  [self setLastRunTime: nil];
  [self setLastRunResult: nil];
  [self setCreated: nil];
  [super dealloc];
}
@end /* implementation NEXUS_REST_APINS0ScheduledServiceResourceStatus */

/**
 * Internal, private interface for JAXB reading and writing.
 */
@interface NEXUS_REST_APINS0ScheduledServiceResourceStatus (JAXB) <JAXBReading, JAXBWriting, JAXBType>

@end /*interface NEXUS_REST_APINS0ScheduledServiceResourceStatus (JAXB)*/

/**
 * Internal, private implementation for JAXB reading and writing.
 */
@implementation NEXUS_REST_APINS0ScheduledServiceResourceStatus (JAXB)

/**
 * Read an instance of NEXUS_REST_APINS0ScheduledServiceResourceStatus from an XML reader.
 *
 * @param reader The reader.
 * @return An instance of NEXUS_REST_APINS0ScheduledServiceResourceStatus defined by the XML reader.
 */
+ (id<JAXBType>) readXMLType: (xmlTextReaderPtr) reader
{
  NEXUS_REST_APINS0ScheduledServiceResourceStatus *_nEXUS_REST_APINS0ScheduledServiceResourceStatus = [[NEXUS_REST_APINS0ScheduledServiceResourceStatus alloc] init];
  NS_DURING
  {
    [_nEXUS_REST_APINS0ScheduledServiceResourceStatus initWithReader: reader];
  }
  NS_HANDLER
  {
    [_nEXUS_REST_APINS0ScheduledServiceResourceStatus dealloc];
    _nEXUS_REST_APINS0ScheduledServiceResourceStatus = nil;
    [localException raise];
  }
  NS_ENDHANDLER

  [_nEXUS_REST_APINS0ScheduledServiceResourceStatus autorelease];
  return _nEXUS_REST_APINS0ScheduledServiceResourceStatus;
}

/**
 * Initialize this instance of NEXUS_REST_APINS0ScheduledServiceResourceStatus according to
 * the XML being read from the reader.
 *
 * @param reader The reader.
 */
- (id) initWithReader: (xmlTextReaderPtr) reader
{
  return [super initWithReader: reader];
}

/**
 * Write the XML for this instance of NEXUS_REST_APINS0ScheduledServiceResourceStatus to the writer.
 * Note that since we're only writing the XML type,
 * No start/end element will be written.
 *
 * @param reader The reader.
 */
- (void) writeXMLType: (xmlTextWriterPtr) writer
{
  [super writeXMLType:writer];
}

//documentation inherited.
- (BOOL) readJAXBAttribute: (xmlTextReaderPtr) reader
{
  void *_child_accessor;

  if ([super readJAXBAttribute: reader]) {
    return YES;
  }

  return NO;
}

//documentation inherited.
- (BOOL) readJAXBValue: (xmlTextReaderPtr) reader
{
  return [super readJAXBValue: reader];
}

//documentation inherited.
- (BOOL) readJAXBChildElement: (xmlTextReaderPtr) reader
{
  id __child;
  void *_child_accessor;
  int status, depth;

  if ([super readJAXBChildElement: reader]) {
    return YES;
  }
  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "resource", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}resource of type {}scheduled-service-base-resource.");
#endif
    __child = [NEXUS_REST_APINS0ScheduledServiceBaseResource readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}resource of type {}scheduled-service-base-resource.");
#endif

    [self setResource: __child];
    return YES;
  } //end "if choice"

  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "resourceURI", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}resourceURI of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}resourceURI of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setResourceURI: __child];
    return YES;
  } //end "if choice"

  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "status", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}status of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}status of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setStatus: __child];
    return YES;
  } //end "if choice"

  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "readableStatus", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}readableStatus of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}readableStatus of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setReadableStatus: __child];
    return YES;
  } //end "if choice"

  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "nextRunTime", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}nextRunTime of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}nextRunTime of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setNextRunTime: __child];
    return YES;
  } //end "if choice"

  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "lastRunTime", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}lastRunTime of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}lastRunTime of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setLastRunTime: __child];
    return YES;
  } //end "if choice"

  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "lastRunResult", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}lastRunResult of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}lastRunResult of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setLastRunResult: __child];
    return YES;
  } //end "if choice"

  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "created", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}created of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}created of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setCreated: __child];
    return YES;
  } //end "if choice"


  return NO;
}

//documentation inherited.
- (int) readUnknownJAXBChildElement: (xmlTextReaderPtr) reader
{
  return [super readUnknownJAXBChildElement: reader];
}

//documentation inherited.
- (void) readUnknownJAXBAttribute: (xmlTextReaderPtr) reader
{
  [super readUnknownJAXBAttribute: reader];
}

//documentation inherited.
- (void) writeJAXBAttributes: (xmlTextWriterPtr) writer
{
  int status;

  [super writeJAXBAttributes: writer];

}

//documentation inherited.
- (void) writeJAXBValue: (xmlTextWriterPtr) writer
{
  [super writeJAXBValue: writer];
}

/**
 * Method for writing the child elements.
 *
 * @param writer The writer.
 */
- (void) writeJAXBChildElements: (xmlTextWriterPtr) writer
{
  int status;
  id __item;
  NSEnumerator *__enumerator;

  [super writeJAXBChildElements: writer];

  if ([self resource]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "resource", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}resource."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}resource...");
#endif
    [[self resource] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}resource...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}resource."];
    }
  }
  if ([self resourceURI]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "resourceURI", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}resourceURI."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}resourceURI...");
#endif
    [[self resourceURI] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}resourceURI...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}resourceURI."];
    }
  }
  if ([self status]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "status", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}status."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}status...");
#endif
    [[self status] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}status...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}status."];
    }
  }
  if ([self readableStatus]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "readableStatus", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}readableStatus."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}readableStatus...");
#endif
    [[self readableStatus] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}readableStatus...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}readableStatus."];
    }
  }
  if ([self nextRunTime]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "nextRunTime", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}nextRunTime."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}nextRunTime...");
#endif
    [[self nextRunTime] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}nextRunTime...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}nextRunTime."];
    }
  }
  if ([self lastRunTime]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "lastRunTime", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}lastRunTime."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}lastRunTime...");
#endif
    [[self lastRunTime] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}lastRunTime...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}lastRunTime."];
    }
  }
  if ([self lastRunResult]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "lastRunResult", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}lastRunResult."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}lastRunResult...");
#endif
    [[self lastRunResult] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}lastRunResult...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}lastRunResult."];
    }
  }
  if ([self created]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "created", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}created."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}created...");
#endif
    [[self created] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}created...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}created."];
    }
  }
}
@end /* implementation NEXUS_REST_APINS0ScheduledServiceResourceStatus (JAXB) */

#endif /* DEF_NEXUS_REST_APINS0ScheduledServiceResourceStatus_M */
#ifndef DEF_NEXUS_REST_APINS0ScheduledServiceTypeResource_M
#define DEF_NEXUS_REST_APINS0ScheduledServiceTypeResource_M

/**
 *  Scheduled service type, which you can create a scheduled task
 against.
 
 @version $Revision$ $Date$

 */
@implementation NEXUS_REST_APINS0ScheduledServiceTypeResource

/**
 * The id of the service type.
 */
- (NSString *) id
{
  return _id;
}

/**
 * The id of the service type.
 */
- (void) setId: (NSString *) newId
{
  [newId retain];
  [_id release];
  _id = newId;
}

/**
 * The name of the service type.
 */
- (NSString *) name
{
  return _name;
}

/**
 * The name of the service type.
 */
- (void) setName: (NSString *) newName
{
  [newName retain];
  [_name release];
  _name = newName;
}

/**
 * Field formFields.
 */
- (NSArray *) formFields
{
  return _formFields;
}

/**
 * Field formFields.
 */
- (void) setFormFields: (NSArray *) newFormFields
{
  [newFormFields retain];
  [_formFields release];
  _formFields = newFormFields;
}

- (void) dealloc
{
  [self setId: nil];
  [self setName: nil];
  [self setFormFields: nil];
  [super dealloc];
}
@end /* implementation NEXUS_REST_APINS0ScheduledServiceTypeResource */

/**
 * Internal, private interface for JAXB reading and writing.
 */
@interface NEXUS_REST_APINS0ScheduledServiceTypeResource (JAXB) <JAXBReading, JAXBWriting, JAXBType>

@end /*interface NEXUS_REST_APINS0ScheduledServiceTypeResource (JAXB)*/

/**
 * Internal, private implementation for JAXB reading and writing.
 */
@implementation NEXUS_REST_APINS0ScheduledServiceTypeResource (JAXB)

/**
 * Read an instance of NEXUS_REST_APINS0ScheduledServiceTypeResource from an XML reader.
 *
 * @param reader The reader.
 * @return An instance of NEXUS_REST_APINS0ScheduledServiceTypeResource defined by the XML reader.
 */
+ (id<JAXBType>) readXMLType: (xmlTextReaderPtr) reader
{
  NEXUS_REST_APINS0ScheduledServiceTypeResource *_nEXUS_REST_APINS0ScheduledServiceTypeResource = [[NEXUS_REST_APINS0ScheduledServiceTypeResource alloc] init];
  NS_DURING
  {
    [_nEXUS_REST_APINS0ScheduledServiceTypeResource initWithReader: reader];
  }
  NS_HANDLER
  {
    [_nEXUS_REST_APINS0ScheduledServiceTypeResource dealloc];
    _nEXUS_REST_APINS0ScheduledServiceTypeResource = nil;
    [localException raise];
  }
  NS_ENDHANDLER

  [_nEXUS_REST_APINS0ScheduledServiceTypeResource autorelease];
  return _nEXUS_REST_APINS0ScheduledServiceTypeResource;
}

/**
 * Initialize this instance of NEXUS_REST_APINS0ScheduledServiceTypeResource according to
 * the XML being read from the reader.
 *
 * @param reader The reader.
 */
- (id) initWithReader: (xmlTextReaderPtr) reader
{
  return [super initWithReader: reader];
}

/**
 * Write the XML for this instance of NEXUS_REST_APINS0ScheduledServiceTypeResource to the writer.
 * Note that since we're only writing the XML type,
 * No start/end element will be written.
 *
 * @param reader The reader.
 */
- (void) writeXMLType: (xmlTextWriterPtr) writer
{
  [super writeXMLType:writer];
}

//documentation inherited.
- (BOOL) readJAXBAttribute: (xmlTextReaderPtr) reader
{
  void *_child_accessor;

  if ([super readJAXBAttribute: reader]) {
    return YES;
  }

  return NO;
}

//documentation inherited.
- (BOOL) readJAXBValue: (xmlTextReaderPtr) reader
{
  return [super readJAXBValue: reader];
}

//documentation inherited.
- (BOOL) readJAXBChildElement: (xmlTextReaderPtr) reader
{
  id __child;
  void *_child_accessor;
  int status, depth;

  if ([super readJAXBChildElement: reader]) {
    return YES;
  }
  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "id", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}id of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}id of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setId: __child];
    return YES;
  } //end "if choice"

  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "name", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}name of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}name of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setName: __child];
    return YES;
  } //end "if choice"

  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "form-fields", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

    if (xmlTextReaderIsEmptyElement(reader) == 0) {
#if DEBUG_ENUNCIATE > 1
      NSLog(@"Unwrapping wrapper element {}form-fields...");
#endif
      //start wrapper element "{}form-fields"
      depth = xmlTextReaderDepth(reader);
      status = xmlTextReaderAdvanceToNextStartOrEndElement(reader);
      while (xmlTextReaderDepth(reader) > depth) {
        if (status < 1) {
          //panic: XML read error.
          [self dealloc];
          [NSException raise: @"XMLReadError"
                       format: @"Failure to advance to next wrapped child element."];
        }
  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "form-field", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}form-field of type {}form-field.");
#endif

    __child = [NEXUS_REST_APINS0FormFieldResource readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}form-field of type {}form-field.");
#endif

    if ([self formFields]) {
      [self setFormFields: [[self formFields] arrayByAddingObject: __child]];
    }
    else {
      [self setFormFields: [NSArray arrayWithObject: __child]];
    }
    continue; //continue "while in wrapper element" loop
  } //end "if choice"

        status = xmlTextReaderAdvanceToNextStartOrEndElement(reader);
#if DEBUG_ENUNCIATE > 1
        NSLog(@"successfully unwrapped wrapper element {}form-fields...");
#endif
      } // end "while in wrapper element" loop

      if (status < 1) {
        //panic: XML read error.
        [self dealloc];
        [NSException raise: @"XMLReadError"
                     format: @"Failure to advance to end wrapper element."];
      }
      else {
        //end wrapper element "{}form-fields"
        status = xmlTextReaderAdvanceToNextStartOrEndElement(reader);
      }
    } //end "if empty element" clause
    else {
      __child = [NSArray array];
      [self setFormFields: (NSArray*) __child];
    }

    return YES;
  } // end "if wrapper element" clause

  return NO;
}

//documentation inherited.
- (int) readUnknownJAXBChildElement: (xmlTextReaderPtr) reader
{
  return [super readUnknownJAXBChildElement: reader];
}

//documentation inherited.
- (void) readUnknownJAXBAttribute: (xmlTextReaderPtr) reader
{
  [super readUnknownJAXBAttribute: reader];
}

//documentation inherited.
- (void) writeJAXBAttributes: (xmlTextWriterPtr) writer
{
  int status;

  [super writeJAXBAttributes: writer];

}

//documentation inherited.
- (void) writeJAXBValue: (xmlTextWriterPtr) writer
{
  [super writeJAXBValue: writer];
}

/**
 * Method for writing the child elements.
 *
 * @param writer The writer.
 */
- (void) writeJAXBChildElements: (xmlTextWriterPtr) writer
{
  int status;
  id __item;
  NSEnumerator *__enumerator;

  [super writeJAXBChildElements: writer];

  if ([self id]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "id", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}id."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}id...");
#endif
    [[self id] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}id...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}id."];
    }
  }
  if ([self name]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "name", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}name."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}name...");
#endif
    [[self name] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}name...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}name."];
    }
  }
  if ([self formFields]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "form-fields", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start wrapper element {}form-fields."];
    }
    __enumerator = [[self formFields] objectEnumerator];

    while ( (__item = [__enumerator nextObject]) ) {
      status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "form-field", NULL);
      if (status < 0) {
        [NSException raise: @"XMLWriteError"
                     format: @"Error writing start child element {}form-field."];
      }

#if DEBUG_ENUNCIATE > 1
      NSLog(@"writing element {}form-field...");
#endif
      [__item writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
      NSLog(@"successfully wrote element {}form-field...");
#endif

      status = xmlTextWriterEndElement(writer);
      if (status < 0) {
        [NSException raise: @"XMLWriteError"
                     format: @"Error writing end child element {}form-field."];
      }
    } //end item iterator.

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end wrapper element {}form-fields."];
    }
  }
}
@end /* implementation NEXUS_REST_APINS0ScheduledServiceTypeResource (JAXB) */

#endif /* DEF_NEXUS_REST_APINS0ScheduledServiceTypeResource_M */
#ifndef DEF_NEXUS_REST_APINS0SmtpSettings_M
#define DEF_NEXUS_REST_APINS0SmtpSettings_M

/**
 *  The connections settings for an smtp server.
 
 @version $Revision$ $Date$

 */
@implementation NEXUS_REST_APINS0SmtpSettings

/**
 * The smtp host.
 */
- (NSString *) host
{
  return _host;
}

/**
 * The smtp host.
 */
- (void) setHost: (NSString *) newHost
{
  [newHost retain];
  [_host release];
  _host = newHost;
}

/**
 * The smtp port.
 */
- (int) port
{
  return _port;
}

/**
 * The smtp port.
 */
- (void) setPort: (int) newPort
{
  _port = newPort;
}

/**
 * The smtp server username.
 */
- (NSString *) username
{
  return _username;
}

/**
 * The smtp server username.
 */
- (void) setUsername: (NSString *) newUsername
{
  [newUsername retain];
  [_username release];
  _username = newUsername;
}

/**
 * The smtp server password.
 */
- (NSString *) password
{
  return _password;
}

/**
 * The smtp server password.
 */
- (void) setPassword: (NSString *) newPassword
{
  [newPassword retain];
  [_password release];
  _password = newPassword;
}

/**
 * The email address that emails will be sent from.
 */
- (NSString *) systemEmailAddress
{
  return _systemEmailAddress;
}

/**
 * The email address that emails will be sent from.
 */
- (void) setSystemEmailAddress: (NSString *) newSystemEmailAddress
{
  [newSystemEmailAddress retain];
  [_systemEmailAddress release];
  _systemEmailAddress = newSystemEmailAddress;
}

/**
 * Flag that states whether to use ssl.
 */
- (BOOL) sslEnabled
{
  return _sslEnabled;
}

/**
 * Flag that states whether to use ssl.
 */
- (void) setSslEnabled: (BOOL) newSslEnabled
{
  _sslEnabled = newSslEnabled;
}

/**
 * Flag that states whether to use tls.
 */
- (BOOL) tlsEnabled
{
  return _tlsEnabled;
}

/**
 * Flag that states whether to use tls.
 */
- (void) setTlsEnabled: (BOOL) newTlsEnabled
{
  _tlsEnabled = newTlsEnabled;
}

- (void) dealloc
{
  [self setHost: nil];
  [self setUsername: nil];
  [self setPassword: nil];
  [self setSystemEmailAddress: nil];
  [super dealloc];
}
@end /* implementation NEXUS_REST_APINS0SmtpSettings */

/**
 * Internal, private interface for JAXB reading and writing.
 */
@interface NEXUS_REST_APINS0SmtpSettings (JAXB) <JAXBReading, JAXBWriting, JAXBType>

@end /*interface NEXUS_REST_APINS0SmtpSettings (JAXB)*/

/**
 * Internal, private implementation for JAXB reading and writing.
 */
@implementation NEXUS_REST_APINS0SmtpSettings (JAXB)

/**
 * Read an instance of NEXUS_REST_APINS0SmtpSettings from an XML reader.
 *
 * @param reader The reader.
 * @return An instance of NEXUS_REST_APINS0SmtpSettings defined by the XML reader.
 */
+ (id<JAXBType>) readXMLType: (xmlTextReaderPtr) reader
{
  NEXUS_REST_APINS0SmtpSettings *_nEXUS_REST_APINS0SmtpSettings = [[NEXUS_REST_APINS0SmtpSettings alloc] init];
  NS_DURING
  {
    [_nEXUS_REST_APINS0SmtpSettings initWithReader: reader];
  }
  NS_HANDLER
  {
    [_nEXUS_REST_APINS0SmtpSettings dealloc];
    _nEXUS_REST_APINS0SmtpSettings = nil;
    [localException raise];
  }
  NS_ENDHANDLER

  [_nEXUS_REST_APINS0SmtpSettings autorelease];
  return _nEXUS_REST_APINS0SmtpSettings;
}

/**
 * Initialize this instance of NEXUS_REST_APINS0SmtpSettings according to
 * the XML being read from the reader.
 *
 * @param reader The reader.
 */
- (id) initWithReader: (xmlTextReaderPtr) reader
{
  return [super initWithReader: reader];
}

/**
 * Write the XML for this instance of NEXUS_REST_APINS0SmtpSettings to the writer.
 * Note that since we're only writing the XML type,
 * No start/end element will be written.
 *
 * @param reader The reader.
 */
- (void) writeXMLType: (xmlTextWriterPtr) writer
{
  [super writeXMLType:writer];
}

//documentation inherited.
- (BOOL) readJAXBAttribute: (xmlTextReaderPtr) reader
{
  void *_child_accessor;

  if ([super readJAXBAttribute: reader]) {
    return YES;
  }

  return NO;
}

//documentation inherited.
- (BOOL) readJAXBValue: (xmlTextReaderPtr) reader
{
  return [super readJAXBValue: reader];
}

//documentation inherited.
- (BOOL) readJAXBChildElement: (xmlTextReaderPtr) reader
{
  id __child;
  void *_child_accessor;
  int status, depth;

  if ([super readJAXBChildElement: reader]) {
    return YES;
  }
  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "host", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}host of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}host of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setHost: __child];
    return YES;
  } //end "if choice"


  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "port", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

    _child_accessor = xmlTextReaderReadIntType(reader);
    if (_child_accessor == NULL) {
      //panic: unable to return the value for some reason.
      [self dealloc];
      [NSException raise: @"XMLReadError"
                   format: @"Error reading element value."];
    }
    [self setPort: *((int*) _child_accessor)];
    free(_child_accessor);
    return YES;
  }
  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "username", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}username of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}username of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setUsername: __child];
    return YES;
  } //end "if choice"

  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "password", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}password of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}password of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setPassword: __child];
    return YES;
  } //end "if choice"

  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "systemEmailAddress", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}systemEmailAddress of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}systemEmailAddress of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setSystemEmailAddress: __child];
    return YES;
  } //end "if choice"


  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "sslEnabled", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

    _child_accessor = xmlTextReaderReadBooleanType(reader);
    if (_child_accessor == NULL) {
      //panic: unable to return the value for some reason.
      [self dealloc];
      [NSException raise: @"XMLReadError"
                   format: @"Error reading element value."];
    }
    [self setSslEnabled: *((BOOL*) _child_accessor)];
    free(_child_accessor);
    return YES;
  }

  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "tlsEnabled", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

    _child_accessor = xmlTextReaderReadBooleanType(reader);
    if (_child_accessor == NULL) {
      //panic: unable to return the value for some reason.
      [self dealloc];
      [NSException raise: @"XMLReadError"
                   format: @"Error reading element value."];
    }
    [self setTlsEnabled: *((BOOL*) _child_accessor)];
    free(_child_accessor);
    return YES;
  }

  return NO;
}

//documentation inherited.
- (int) readUnknownJAXBChildElement: (xmlTextReaderPtr) reader
{
  return [super readUnknownJAXBChildElement: reader];
}

//documentation inherited.
- (void) readUnknownJAXBAttribute: (xmlTextReaderPtr) reader
{
  [super readUnknownJAXBAttribute: reader];
}

//documentation inherited.
- (void) writeJAXBAttributes: (xmlTextWriterPtr) writer
{
  int status;

  [super writeJAXBAttributes: writer];

}

//documentation inherited.
- (void) writeJAXBValue: (xmlTextWriterPtr) writer
{
  [super writeJAXBValue: writer];
}

/**
 * Method for writing the child elements.
 *
 * @param writer The writer.
 */
- (void) writeJAXBChildElements: (xmlTextWriterPtr) writer
{
  int status;
  id __item;
  NSEnumerator *__enumerator;

  [super writeJAXBChildElements: writer];

  if ([self host]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "host", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}host."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}host...");
#endif
    [[self host] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}host...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}host."];
    }
  }
  if (YES) { //always write the primitive element...
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "port", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}port."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}port...");
#endif
    status = xmlTextWriterWriteIntType(writer, &_port);
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}port...");
#endif
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing child element {}port."];
    }

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}port."];
    }
  }
  if ([self username]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "username", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}username."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}username...");
#endif
    [[self username] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}username...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}username."];
    }
  }
  if ([self password]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "password", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}password."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}password...");
#endif
    [[self password] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}password...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}password."];
    }
  }
  if ([self systemEmailAddress]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "systemEmailAddress", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}systemEmailAddress."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}systemEmailAddress...");
#endif
    [[self systemEmailAddress] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}systemEmailAddress...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}systemEmailAddress."];
    }
  }
  if (YES) { //always write the primitive element...
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "sslEnabled", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}sslEnabled."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}sslEnabled...");
#endif
    status = xmlTextWriterWriteBooleanType(writer, &_sslEnabled);
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}sslEnabled...");
#endif
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing child element {}sslEnabled."];
    }

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}sslEnabled."];
    }
  }
  if (YES) { //always write the primitive element...
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "tlsEnabled", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}tlsEnabled."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}tlsEnabled...");
#endif
    status = xmlTextWriterWriteBooleanType(writer, &_tlsEnabled);
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}tlsEnabled...");
#endif
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing child element {}tlsEnabled."];
    }

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}tlsEnabled."];
    }
  }
}
@end /* implementation NEXUS_REST_APINS0SmtpSettings (JAXB) */

#endif /* DEF_NEXUS_REST_APINS0SmtpSettings_M */
#ifndef DEF_NEXUS_REST_APINS0SmtpSettingsResource_M
#define DEF_NEXUS_REST_APINS0SmtpSettingsResource_M

/**
 *  The smtp settings request.
 
 @version $Revision$ $Date$

 */
@implementation NEXUS_REST_APINS0SmtpSettingsResource

/**
 * Test email address to send a validation mail to.
 */
- (NSString *) testEmail
{
  return _testEmail;
}

/**
 * Test email address to send a validation mail to.
 */
- (void) setTestEmail: (NSString *) newTestEmail
{
  [newTestEmail retain];
  [_testEmail release];
  _testEmail = newTestEmail;
}

/**
 * The smtp host.
 */
- (NSString *) host
{
  return _host;
}

/**
 * The smtp host.
 */
- (void) setHost: (NSString *) newHost
{
  [newHost retain];
  [_host release];
  _host = newHost;
}

/**
 * The smtp port.
 */
- (int) port
{
  return _port;
}

/**
 * The smtp port.
 */
- (void) setPort: (int) newPort
{
  _port = newPort;
}

/**
 * The smtp username.
 */
- (NSString *) username
{
  return _username;
}

/**
 * The smtp username.
 */
- (void) setUsername: (NSString *) newUsername
{
  [newUsername retain];
  [_username release];
  _username = newUsername;
}

/**
 * The smtp password.
 */
- (NSString *) password
{
  return _password;
}

/**
 * The smtp password.
 */
- (void) setPassword: (NSString *) newPassword
{
  [newPassword retain];
  [_password release];
  _password = newPassword;
}

/**
 * The email address that nexus will send emails from.
 */
- (NSString *) systemEmailAddress
{
  return _systemEmailAddress;
}

/**
 * The email address that nexus will send emails from.
 */
- (void) setSystemEmailAddress: (NSString *) newSystemEmailAddress
{
  [newSystemEmailAddress retain];
  [_systemEmailAddress release];
  _systemEmailAddress = newSystemEmailAddress;
}

/**
 * Flag that states whether to use SSL.
 */
- (BOOL) sslEnabled
{
  return _sslEnabled;
}

/**
 * Flag that states whether to use SSL.
 */
- (void) setSslEnabled: (BOOL) newSslEnabled
{
  _sslEnabled = newSslEnabled;
}

/**
 * Flag that states whether to use TLS.
 */
- (BOOL) tlsEnabled
{
  return _tlsEnabled;
}

/**
 * Flag that states whether to use TLS.
 */
- (void) setTlsEnabled: (BOOL) newTlsEnabled
{
  _tlsEnabled = newTlsEnabled;
}

- (void) dealloc
{
  [self setTestEmail: nil];
  [self setHost: nil];
  [self setUsername: nil];
  [self setPassword: nil];
  [self setSystemEmailAddress: nil];
  [super dealloc];
}
@end /* implementation NEXUS_REST_APINS0SmtpSettingsResource */

/**
 * Internal, private interface for JAXB reading and writing.
 */
@interface NEXUS_REST_APINS0SmtpSettingsResource (JAXB) <JAXBReading, JAXBWriting, JAXBType>

@end /*interface NEXUS_REST_APINS0SmtpSettingsResource (JAXB)*/

/**
 * Internal, private implementation for JAXB reading and writing.
 */
@implementation NEXUS_REST_APINS0SmtpSettingsResource (JAXB)

/**
 * Read an instance of NEXUS_REST_APINS0SmtpSettingsResource from an XML reader.
 *
 * @param reader The reader.
 * @return An instance of NEXUS_REST_APINS0SmtpSettingsResource defined by the XML reader.
 */
+ (id<JAXBType>) readXMLType: (xmlTextReaderPtr) reader
{
  NEXUS_REST_APINS0SmtpSettingsResource *_nEXUS_REST_APINS0SmtpSettingsResource = [[NEXUS_REST_APINS0SmtpSettingsResource alloc] init];
  NS_DURING
  {
    [_nEXUS_REST_APINS0SmtpSettingsResource initWithReader: reader];
  }
  NS_HANDLER
  {
    [_nEXUS_REST_APINS0SmtpSettingsResource dealloc];
    _nEXUS_REST_APINS0SmtpSettingsResource = nil;
    [localException raise];
  }
  NS_ENDHANDLER

  [_nEXUS_REST_APINS0SmtpSettingsResource autorelease];
  return _nEXUS_REST_APINS0SmtpSettingsResource;
}

/**
 * Initialize this instance of NEXUS_REST_APINS0SmtpSettingsResource according to
 * the XML being read from the reader.
 *
 * @param reader The reader.
 */
- (id) initWithReader: (xmlTextReaderPtr) reader
{
  return [super initWithReader: reader];
}

/**
 * Write the XML for this instance of NEXUS_REST_APINS0SmtpSettingsResource to the writer.
 * Note that since we're only writing the XML type,
 * No start/end element will be written.
 *
 * @param reader The reader.
 */
- (void) writeXMLType: (xmlTextWriterPtr) writer
{
  [super writeXMLType:writer];
}

//documentation inherited.
- (BOOL) readJAXBAttribute: (xmlTextReaderPtr) reader
{
  void *_child_accessor;

  if ([super readJAXBAttribute: reader]) {
    return YES;
  }

  return NO;
}

//documentation inherited.
- (BOOL) readJAXBValue: (xmlTextReaderPtr) reader
{
  return [super readJAXBValue: reader];
}

//documentation inherited.
- (BOOL) readJAXBChildElement: (xmlTextReaderPtr) reader
{
  id __child;
  void *_child_accessor;
  int status, depth;

  if ([super readJAXBChildElement: reader]) {
    return YES;
  }
  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "testEmail", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}testEmail of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}testEmail of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setTestEmail: __child];
    return YES;
  } //end "if choice"

  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "host", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}host of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}host of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setHost: __child];
    return YES;
  } //end "if choice"


  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "port", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

    _child_accessor = xmlTextReaderReadIntType(reader);
    if (_child_accessor == NULL) {
      //panic: unable to return the value for some reason.
      [self dealloc];
      [NSException raise: @"XMLReadError"
                   format: @"Error reading element value."];
    }
    [self setPort: *((int*) _child_accessor)];
    free(_child_accessor);
    return YES;
  }
  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "username", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}username of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}username of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setUsername: __child];
    return YES;
  } //end "if choice"

  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "password", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}password of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}password of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setPassword: __child];
    return YES;
  } //end "if choice"

  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "systemEmailAddress", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}systemEmailAddress of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}systemEmailAddress of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setSystemEmailAddress: __child];
    return YES;
  } //end "if choice"


  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "sslEnabled", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

    _child_accessor = xmlTextReaderReadBooleanType(reader);
    if (_child_accessor == NULL) {
      //panic: unable to return the value for some reason.
      [self dealloc];
      [NSException raise: @"XMLReadError"
                   format: @"Error reading element value."];
    }
    [self setSslEnabled: *((BOOL*) _child_accessor)];
    free(_child_accessor);
    return YES;
  }

  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "tlsEnabled", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

    _child_accessor = xmlTextReaderReadBooleanType(reader);
    if (_child_accessor == NULL) {
      //panic: unable to return the value for some reason.
      [self dealloc];
      [NSException raise: @"XMLReadError"
                   format: @"Error reading element value."];
    }
    [self setTlsEnabled: *((BOOL*) _child_accessor)];
    free(_child_accessor);
    return YES;
  }

  return NO;
}

//documentation inherited.
- (int) readUnknownJAXBChildElement: (xmlTextReaderPtr) reader
{
  return [super readUnknownJAXBChildElement: reader];
}

//documentation inherited.
- (void) readUnknownJAXBAttribute: (xmlTextReaderPtr) reader
{
  [super readUnknownJAXBAttribute: reader];
}

//documentation inherited.
- (void) writeJAXBAttributes: (xmlTextWriterPtr) writer
{
  int status;

  [super writeJAXBAttributes: writer];

}

//documentation inherited.
- (void) writeJAXBValue: (xmlTextWriterPtr) writer
{
  [super writeJAXBValue: writer];
}

/**
 * Method for writing the child elements.
 *
 * @param writer The writer.
 */
- (void) writeJAXBChildElements: (xmlTextWriterPtr) writer
{
  int status;
  id __item;
  NSEnumerator *__enumerator;

  [super writeJAXBChildElements: writer];

  if ([self testEmail]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "testEmail", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}testEmail."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}testEmail...");
#endif
    [[self testEmail] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}testEmail...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}testEmail."];
    }
  }
  if ([self host]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "host", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}host."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}host...");
#endif
    [[self host] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}host...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}host."];
    }
  }
  if (YES) { //always write the primitive element...
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "port", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}port."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}port...");
#endif
    status = xmlTextWriterWriteIntType(writer, &_port);
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}port...");
#endif
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing child element {}port."];
    }

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}port."];
    }
  }
  if ([self username]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "username", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}username."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}username...");
#endif
    [[self username] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}username...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}username."];
    }
  }
  if ([self password]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "password", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}password."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}password...");
#endif
    [[self password] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}password...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}password."];
    }
  }
  if ([self systemEmailAddress]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "systemEmailAddress", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}systemEmailAddress."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}systemEmailAddress...");
#endif
    [[self systemEmailAddress] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}systemEmailAddress...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}systemEmailAddress."];
    }
  }
  if (YES) { //always write the primitive element...
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "sslEnabled", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}sslEnabled."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}sslEnabled...");
#endif
    status = xmlTextWriterWriteBooleanType(writer, &_sslEnabled);
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}sslEnabled...");
#endif
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing child element {}sslEnabled."];
    }

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}sslEnabled."];
    }
  }
  if (YES) { //always write the primitive element...
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "tlsEnabled", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}tlsEnabled."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}tlsEnabled...");
#endif
    status = xmlTextWriterWriteBooleanType(writer, &_tlsEnabled);
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}tlsEnabled...");
#endif
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing child element {}tlsEnabled."];
    }

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}tlsEnabled."];
    }
  }
}
@end /* implementation NEXUS_REST_APINS0SmtpSettingsResource (JAXB) */

#endif /* DEF_NEXUS_REST_APINS0SmtpSettingsResource_M */
#ifndef DEF_NEXUS_REST_APINS0StatusResource_M
#define DEF_NEXUS_REST_APINS0StatusResource_M

/**
 *  Nexus status details.
 
 @version $Revision$ $Date$

 */
@implementation NEXUS_REST_APINS0StatusResource

/**
 * The application name.
 */
- (NSString *) appName
{
  return _appName;
}

/**
 * The application name.
 */
- (void) setAppName: (NSString *) newAppName
{
  [newAppName retain];
  [_appName release];
  _appName = newAppName;
}

/**
 * The formatted application name (html formatting).
 */
- (NSString *) formattedAppName
{
  return _formattedAppName;
}

/**
 * The formatted application name (html formatting).
 */
- (void) setFormattedAppName: (NSString *) newFormattedAppName
{
  [newFormattedAppName retain];
  [_formattedAppName release];
  _formattedAppName = newFormattedAppName;
}

/**
 * The version of the nexus instance.
 */
- (NSString *) version
{
  return _version;
}

/**
 * The version of the nexus instance.
 */
- (void) setVersion: (NSString *) newVersion
{
  [newVersion retain];
  [_version release];
  _version = newVersion;
}

/**
 * The version of the core nexus instance.
 */
- (NSString *) apiVersion
{
  return _apiVersion;
}

/**
 * The version of the core nexus instance.
 */
- (void) setApiVersion: (NSString *) newApiVersion
{
  [newApiVersion retain];
  [_apiVersion release];
  _apiVersion = newApiVersion;
}

/**
 * The long version of the nexus edition (i.e. Open Source or
Professional).
 */
- (NSString *) editionLong
{
  return _editionLong;
}

/**
 * The long version of the nexus edition (i.e. Open Source or
Professional).
 */
- (void) setEditionLong: (NSString *) newEditionLong
{
  [newEditionLong retain];
  [_editionLong release];
  _editionLong = newEditionLong;
}

/**
 * The short version of the nexus edition (i.e. OSS or PRO).
 */
- (NSString *) editionShort
{
  return _editionShort;
}

/**
 * The short version of the nexus edition (i.e. OSS or PRO).
 */
- (void) setEditionShort: (NSString *) newEditionShort
{
  [newEditionShort retain];
  [_editionShort release];
  _editionShort = newEditionShort;
}

/**
 * The state of the nexus instance.
 */
- (NSString *) state
{
  return _state;
}

/**
 * The state of the nexus instance.
 */
- (void) setState: (NSString *) newState
{
  [newState retain];
  [_state release];
  _state = newState;
}

/**
 * The operation mode of the nexus instance.
 */
- (NSString *) operationMode
{
  return _operationMode;
}

/**
 * The operation mode of the nexus instance.
 */
- (void) setOperationMode: (NSString *) newOperationMode
{
  [newOperationMode retain];
  [_operationMode release];
  _operationMode = newOperationMode;
}

/**
 * The date the instance was first initialized.
 */
- (NSDate *) initializedAt
{
  return _initializedAt;
}

/**
 * The date the instance was first initialized.
 */
- (void) setInitializedAt: (NSDate *) newInitializedAt
{
  [newInitializedAt retain];
  [_initializedAt release];
  _initializedAt = newInitializedAt;
}

/**
 * The date the instance was last started.
 */
- (NSDate *) startedAt
{
  return _startedAt;
}

/**
 * The date the instance was last started.
 */
- (void) setStartedAt: (NSDate *) newStartedAt
{
  [newStartedAt retain];
  [_startedAt release];
  _startedAt = newStartedAt;
}

/**
 * The last time the nexus configuration was updated.
 */
- (NSDate *) lastConfigChange
{
  return _lastConfigChange;
}

/**
 * The last time the nexus configuration was updated.
 */
- (void) setLastConfigChange: (NSDate *) newLastConfigChange
{
  [newLastConfigChange retain];
  [_lastConfigChange release];
  _lastConfigChange = newLastConfigChange;
}

/**
 * Flag that states if this is the first time nexus was started.
 */
- (BOOL) firstStart
{
  return _firstStart;
}

/**
 * Flag that states if this is the first time nexus was started.
 */
- (void) setFirstStart: (BOOL) newFirstStart
{
  _firstStart = newFirstStart;
}

/**
 * Flag that states if the nexus instance has been upgraded.
 */
- (BOOL) instanceUpgraded
{
  return _instanceUpgraded;
}

/**
 * Flag that states if the nexus instance has been upgraded.
 */
- (void) setInstanceUpgraded: (BOOL) newInstanceUpgraded
{
  _instanceUpgraded = newInstanceUpgraded;
}

/**
 * Flag that states if the nexus configuration has been upgraded
 */
- (BOOL) configurationUpgraded
{
  return _configurationUpgraded;
}

/**
 * Flag that states if the nexus configuration has been upgraded
 */
- (void) setConfigurationUpgraded: (BOOL) newConfigurationUpgraded
{
  _configurationUpgraded = newConfigurationUpgraded;
}

/**
 * Configuration validation status.
 */
- (NEXUS_REST_APINS0StatusConfigurationValidationResponse *) configurationValidationResponse
{
  return _configurationValidationResponse;
}

/**
 * Configuration validation status.
 */
- (void) setConfigurationValidationResponse: (NEXUS_REST_APINS0StatusConfigurationValidationResponse *) newConfigurationValidationResponse
{
  [newConfigurationValidationResponse retain];
  [_configurationValidationResponse release];
  _configurationValidationResponse = newConfigurationValidationResponse;
}

/**
 * Errors occuring during nexus startup.
 */
- (NSString *) errorCause
{
  return _errorCause;
}

/**
 * Errors occuring during nexus startup.
 */
- (void) setErrorCause: (NSString *) newErrorCause
{
  [newErrorCause retain];
  [_errorCause release];
  _errorCause = newErrorCause;
}

/**
 * Permissions that are available to the current user.
 */
- (NEXUS_REST_APINS0NexusAuthenticationClientPermissions *) clientPermissions
{
  return _clientPermissions;
}

/**
 * Permissions that are available to the current user.
 */
- (void) setClientPermissions: (NEXUS_REST_APINS0NexusAuthenticationClientPermissions *) newClientPermissions
{
  [newClientPermissions retain];
  [_clientPermissions release];
  _clientPermissions = newClientPermissions;
}

/**
 * The base url of the nexus instance.
 */
- (NSString *) baseUrl
{
  return _baseUrl;
}

/**
 * The base url of the nexus instance.
 */
- (void) setBaseUrl: (NSString *) newBaseUrl
{
  [newBaseUrl retain];
  [_baseUrl release];
  _baseUrl = newBaseUrl;
}

- (void) dealloc
{
  [self setAppName: nil];
  [self setFormattedAppName: nil];
  [self setVersion: nil];
  [self setApiVersion: nil];
  [self setEditionLong: nil];
  [self setEditionShort: nil];
  [self setState: nil];
  [self setOperationMode: nil];
  [self setInitializedAt: nil];
  [self setStartedAt: nil];
  [self setLastConfigChange: nil];
  [self setConfigurationValidationResponse: nil];
  [self setErrorCause: nil];
  [self setClientPermissions: nil];
  [self setBaseUrl: nil];
  [super dealloc];
}
@end /* implementation NEXUS_REST_APINS0StatusResource */

/**
 * Internal, private interface for JAXB reading and writing.
 */
@interface NEXUS_REST_APINS0StatusResource (JAXB) <JAXBReading, JAXBWriting, JAXBType>

@end /*interface NEXUS_REST_APINS0StatusResource (JAXB)*/

/**
 * Internal, private implementation for JAXB reading and writing.
 */
@implementation NEXUS_REST_APINS0StatusResource (JAXB)

/**
 * Read an instance of NEXUS_REST_APINS0StatusResource from an XML reader.
 *
 * @param reader The reader.
 * @return An instance of NEXUS_REST_APINS0StatusResource defined by the XML reader.
 */
+ (id<JAXBType>) readXMLType: (xmlTextReaderPtr) reader
{
  NEXUS_REST_APINS0StatusResource *_nEXUS_REST_APINS0StatusResource = [[NEXUS_REST_APINS0StatusResource alloc] init];
  NS_DURING
  {
    [_nEXUS_REST_APINS0StatusResource initWithReader: reader];
  }
  NS_HANDLER
  {
    [_nEXUS_REST_APINS0StatusResource dealloc];
    _nEXUS_REST_APINS0StatusResource = nil;
    [localException raise];
  }
  NS_ENDHANDLER

  [_nEXUS_REST_APINS0StatusResource autorelease];
  return _nEXUS_REST_APINS0StatusResource;
}

/**
 * Initialize this instance of NEXUS_REST_APINS0StatusResource according to
 * the XML being read from the reader.
 *
 * @param reader The reader.
 */
- (id) initWithReader: (xmlTextReaderPtr) reader
{
  return [super initWithReader: reader];
}

/**
 * Write the XML for this instance of NEXUS_REST_APINS0StatusResource to the writer.
 * Note that since we're only writing the XML type,
 * No start/end element will be written.
 *
 * @param reader The reader.
 */
- (void) writeXMLType: (xmlTextWriterPtr) writer
{
  [super writeXMLType:writer];
}

//documentation inherited.
- (BOOL) readJAXBAttribute: (xmlTextReaderPtr) reader
{
  void *_child_accessor;

  if ([super readJAXBAttribute: reader]) {
    return YES;
  }

  return NO;
}

//documentation inherited.
- (BOOL) readJAXBValue: (xmlTextReaderPtr) reader
{
  return [super readJAXBValue: reader];
}

//documentation inherited.
- (BOOL) readJAXBChildElement: (xmlTextReaderPtr) reader
{
  id __child;
  void *_child_accessor;
  int status, depth;

  if ([super readJAXBChildElement: reader]) {
    return YES;
  }
  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "appName", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}appName of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}appName of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setAppName: __child];
    return YES;
  } //end "if choice"

  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "formattedAppName", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}formattedAppName of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}formattedAppName of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setFormattedAppName: __child];
    return YES;
  } //end "if choice"

  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "version", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}version of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}version of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setVersion: __child];
    return YES;
  } //end "if choice"

  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "apiVersion", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}apiVersion of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}apiVersion of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setApiVersion: __child];
    return YES;
  } //end "if choice"

  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "editionLong", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}editionLong of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}editionLong of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setEditionLong: __child];
    return YES;
  } //end "if choice"

  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "editionShort", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}editionShort of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}editionShort of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setEditionShort: __child];
    return YES;
  } //end "if choice"

  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "state", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}state of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}state of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setState: __child];
    return YES;
  } //end "if choice"

  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "operationMode", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}operationMode of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}operationMode of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setOperationMode: __child];
    return YES;
  } //end "if choice"

  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "initializedAt", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}initializedAt of type {http://www.w3.org/2001/XMLSchema}dateTime.");
#endif
    __child = [NSDate readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}initializedAt of type {http://www.w3.org/2001/XMLSchema}dateTime.");
#endif

    [self setInitializedAt: __child];
    return YES;
  } //end "if choice"

  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "startedAt", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}startedAt of type {http://www.w3.org/2001/XMLSchema}dateTime.");
#endif
    __child = [NSDate readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}startedAt of type {http://www.w3.org/2001/XMLSchema}dateTime.");
#endif

    [self setStartedAt: __child];
    return YES;
  } //end "if choice"

  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "lastConfigChange", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}lastConfigChange of type {http://www.w3.org/2001/XMLSchema}dateTime.");
#endif
    __child = [NSDate readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}lastConfigChange of type {http://www.w3.org/2001/XMLSchema}dateTime.");
#endif

    [self setLastConfigChange: __child];
    return YES;
  } //end "if choice"


  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "firstStart", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

    _child_accessor = xmlTextReaderReadBooleanType(reader);
    if (_child_accessor == NULL) {
      //panic: unable to return the value for some reason.
      [self dealloc];
      [NSException raise: @"XMLReadError"
                   format: @"Error reading element value."];
    }
    [self setFirstStart: *((BOOL*) _child_accessor)];
    free(_child_accessor);
    return YES;
  }

  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "instanceUpgraded", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

    _child_accessor = xmlTextReaderReadBooleanType(reader);
    if (_child_accessor == NULL) {
      //panic: unable to return the value for some reason.
      [self dealloc];
      [NSException raise: @"XMLReadError"
                   format: @"Error reading element value."];
    }
    [self setInstanceUpgraded: *((BOOL*) _child_accessor)];
    free(_child_accessor);
    return YES;
  }

  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "configurationUpgraded", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

    _child_accessor = xmlTextReaderReadBooleanType(reader);
    if (_child_accessor == NULL) {
      //panic: unable to return the value for some reason.
      [self dealloc];
      [NSException raise: @"XMLReadError"
                   format: @"Error reading element value."];
    }
    [self setConfigurationUpgraded: *((BOOL*) _child_accessor)];
    free(_child_accessor);
    return YES;
  }
  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "configurationValidationResponse", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}configurationValidationResponse of type {}status-configuration-validation-response.");
#endif
    __child = [NEXUS_REST_APINS0StatusConfigurationValidationResponse readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}configurationValidationResponse of type {}status-configuration-validation-response.");
#endif

    [self setConfigurationValidationResponse: __child];
    return YES;
  } //end "if choice"

  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "errorCause", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}errorCause of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}errorCause of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setErrorCause: __child];
    return YES;
  } //end "if choice"

  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "clientPermissions", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}clientPermissions of type {}nexus-authentication-client-permissions.");
#endif
    __child = [NEXUS_REST_APINS0NexusAuthenticationClientPermissions readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}clientPermissions of type {}nexus-authentication-client-permissions.");
#endif

    [self setClientPermissions: __child];
    return YES;
  } //end "if choice"

  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "baseUrl", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}baseUrl of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}baseUrl of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setBaseUrl: __child];
    return YES;
  } //end "if choice"


  return NO;
}

//documentation inherited.
- (int) readUnknownJAXBChildElement: (xmlTextReaderPtr) reader
{
  return [super readUnknownJAXBChildElement: reader];
}

//documentation inherited.
- (void) readUnknownJAXBAttribute: (xmlTextReaderPtr) reader
{
  [super readUnknownJAXBAttribute: reader];
}

//documentation inherited.
- (void) writeJAXBAttributes: (xmlTextWriterPtr) writer
{
  int status;

  [super writeJAXBAttributes: writer];

}

//documentation inherited.
- (void) writeJAXBValue: (xmlTextWriterPtr) writer
{
  [super writeJAXBValue: writer];
}

/**
 * Method for writing the child elements.
 *
 * @param writer The writer.
 */
- (void) writeJAXBChildElements: (xmlTextWriterPtr) writer
{
  int status;
  id __item;
  NSEnumerator *__enumerator;

  [super writeJAXBChildElements: writer];

  if ([self appName]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "appName", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}appName."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}appName...");
#endif
    [[self appName] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}appName...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}appName."];
    }
  }
  if ([self formattedAppName]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "formattedAppName", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}formattedAppName."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}formattedAppName...");
#endif
    [[self formattedAppName] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}formattedAppName...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}formattedAppName."];
    }
  }
  if ([self version]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "version", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}version."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}version...");
#endif
    [[self version] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}version...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}version."];
    }
  }
  if ([self apiVersion]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "apiVersion", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}apiVersion."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}apiVersion...");
#endif
    [[self apiVersion] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}apiVersion...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}apiVersion."];
    }
  }
  if ([self editionLong]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "editionLong", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}editionLong."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}editionLong...");
#endif
    [[self editionLong] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}editionLong...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}editionLong."];
    }
  }
  if ([self editionShort]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "editionShort", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}editionShort."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}editionShort...");
#endif
    [[self editionShort] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}editionShort...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}editionShort."];
    }
  }
  if ([self state]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "state", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}state."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}state...");
#endif
    [[self state] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}state...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}state."];
    }
  }
  if ([self operationMode]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "operationMode", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}operationMode."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}operationMode...");
#endif
    [[self operationMode] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}operationMode...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}operationMode."];
    }
  }
  if ([self initializedAt]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "initializedAt", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}initializedAt."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}initializedAt...");
#endif
    [[self initializedAt] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}initializedAt...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}initializedAt."];
    }
  }
  if ([self startedAt]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "startedAt", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}startedAt."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}startedAt...");
#endif
    [[self startedAt] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}startedAt...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}startedAt."];
    }
  }
  if ([self lastConfigChange]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "lastConfigChange", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}lastConfigChange."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}lastConfigChange...");
#endif
    [[self lastConfigChange] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}lastConfigChange...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}lastConfigChange."];
    }
  }
  if (YES) { //always write the primitive element...
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "firstStart", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}firstStart."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}firstStart...");
#endif
    status = xmlTextWriterWriteBooleanType(writer, &_firstStart);
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}firstStart...");
#endif
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing child element {}firstStart."];
    }

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}firstStart."];
    }
  }
  if (YES) { //always write the primitive element...
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "instanceUpgraded", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}instanceUpgraded."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}instanceUpgraded...");
#endif
    status = xmlTextWriterWriteBooleanType(writer, &_instanceUpgraded);
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}instanceUpgraded...");
#endif
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing child element {}instanceUpgraded."];
    }

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}instanceUpgraded."];
    }
  }
  if (YES) { //always write the primitive element...
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "configurationUpgraded", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}configurationUpgraded."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}configurationUpgraded...");
#endif
    status = xmlTextWriterWriteBooleanType(writer, &_configurationUpgraded);
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}configurationUpgraded...");
#endif
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing child element {}configurationUpgraded."];
    }

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}configurationUpgraded."];
    }
  }
  if ([self configurationValidationResponse]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "configurationValidationResponse", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}configurationValidationResponse."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}configurationValidationResponse...");
#endif
    [[self configurationValidationResponse] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}configurationValidationResponse...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}configurationValidationResponse."];
    }
  }
  if ([self errorCause]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "errorCause", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}errorCause."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}errorCause...");
#endif
    [[self errorCause] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}errorCause...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}errorCause."];
    }
  }
  if ([self clientPermissions]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "clientPermissions", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}clientPermissions."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}clientPermissions...");
#endif
    [[self clientPermissions] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}clientPermissions...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}clientPermissions."];
    }
  }
  if ([self baseUrl]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "baseUrl", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}baseUrl."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}baseUrl...");
#endif
    [[self baseUrl] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}baseUrl...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}baseUrl."];
    }
  }
}
@end /* implementation NEXUS_REST_APINS0StatusResource (JAXB) */

#endif /* DEF_NEXUS_REST_APINS0StatusResource_M */
#ifndef DEF_NEXUS_REST_APINS0SystemNotificationSettings_M
#define DEF_NEXUS_REST_APINS0SystemNotificationSettings_M

/**
 *  
         The notification settings tell nexus who to notify when
 certain events occur (such as a proxy repository being
 auto-blocked).
       
 
 @version $Revision$ $Date$

 */
@implementation NEXUS_REST_APINS0SystemNotificationSettings

/**
 * Flag that states whether to enable notifications.
 */
- (BOOL) enabled
{
  return _enabled;
}

/**
 * Flag that states whether to enable notifications.
 */
- (void) setEnabled: (BOOL) newEnabled
{
  _enabled = newEnabled;
}

/**
 * Comma seperated list of email addresses to notify.
 */
- (NSString *) emailAddresses
{
  return _emailAddresses;
}

/**
 * Comma seperated list of email addresses to notify.
 */
- (void) setEmailAddresses: (NSString *) newEmailAddresses
{
  [newEmailAddresses retain];
  [_emailAddresses release];
  _emailAddresses = newEmailAddresses;
}

/**
 * Field roles.
 */
- (NSArray *) roles
{
  return _roles;
}

/**
 * Field roles.
 */
- (void) setRoles: (NSArray *) newRoles
{
  [newRoles retain];
  [_roles release];
  _roles = newRoles;
}

- (void) dealloc
{
  [self setEmailAddresses: nil];
  [self setRoles: nil];
  [super dealloc];
}
@end /* implementation NEXUS_REST_APINS0SystemNotificationSettings */

/**
 * Internal, private interface for JAXB reading and writing.
 */
@interface NEXUS_REST_APINS0SystemNotificationSettings (JAXB) <JAXBReading, JAXBWriting, JAXBType>

@end /*interface NEXUS_REST_APINS0SystemNotificationSettings (JAXB)*/

/**
 * Internal, private implementation for JAXB reading and writing.
 */
@implementation NEXUS_REST_APINS0SystemNotificationSettings (JAXB)

/**
 * Read an instance of NEXUS_REST_APINS0SystemNotificationSettings from an XML reader.
 *
 * @param reader The reader.
 * @return An instance of NEXUS_REST_APINS0SystemNotificationSettings defined by the XML reader.
 */
+ (id<JAXBType>) readXMLType: (xmlTextReaderPtr) reader
{
  NEXUS_REST_APINS0SystemNotificationSettings *_nEXUS_REST_APINS0SystemNotificationSettings = [[NEXUS_REST_APINS0SystemNotificationSettings alloc] init];
  NS_DURING
  {
    [_nEXUS_REST_APINS0SystemNotificationSettings initWithReader: reader];
  }
  NS_HANDLER
  {
    [_nEXUS_REST_APINS0SystemNotificationSettings dealloc];
    _nEXUS_REST_APINS0SystemNotificationSettings = nil;
    [localException raise];
  }
  NS_ENDHANDLER

  [_nEXUS_REST_APINS0SystemNotificationSettings autorelease];
  return _nEXUS_REST_APINS0SystemNotificationSettings;
}

/**
 * Initialize this instance of NEXUS_REST_APINS0SystemNotificationSettings according to
 * the XML being read from the reader.
 *
 * @param reader The reader.
 */
- (id) initWithReader: (xmlTextReaderPtr) reader
{
  return [super initWithReader: reader];
}

/**
 * Write the XML for this instance of NEXUS_REST_APINS0SystemNotificationSettings to the writer.
 * Note that since we're only writing the XML type,
 * No start/end element will be written.
 *
 * @param reader The reader.
 */
- (void) writeXMLType: (xmlTextWriterPtr) writer
{
  [super writeXMLType:writer];
}

//documentation inherited.
- (BOOL) readJAXBAttribute: (xmlTextReaderPtr) reader
{
  void *_child_accessor;

  if ([super readJAXBAttribute: reader]) {
    return YES;
  }

  return NO;
}

//documentation inherited.
- (BOOL) readJAXBValue: (xmlTextReaderPtr) reader
{
  return [super readJAXBValue: reader];
}

//documentation inherited.
- (BOOL) readJAXBChildElement: (xmlTextReaderPtr) reader
{
  id __child;
  void *_child_accessor;
  int status, depth;

  if ([super readJAXBChildElement: reader]) {
    return YES;
  }

  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "enabled", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

    _child_accessor = xmlTextReaderReadBooleanType(reader);
    if (_child_accessor == NULL) {
      //panic: unable to return the value for some reason.
      [self dealloc];
      [NSException raise: @"XMLReadError"
                   format: @"Error reading element value."];
    }
    [self setEnabled: *((BOOL*) _child_accessor)];
    free(_child_accessor);
    return YES;
  }
  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "emailAddresses", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}emailAddresses of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}emailAddresses of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setEmailAddresses: __child];
    return YES;
  } //end "if choice"

  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "roles", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}roles of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}roles of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    if ([self roles]) {
      [self setRoles: [[self roles] arrayByAddingObject: __child]];
    }
    else {
      [self setRoles: [NSArray arrayWithObject: __child]];
    }
    return YES;
  } //end "if choice"


  return NO;
}

//documentation inherited.
- (int) readUnknownJAXBChildElement: (xmlTextReaderPtr) reader
{
  return [super readUnknownJAXBChildElement: reader];
}

//documentation inherited.
- (void) readUnknownJAXBAttribute: (xmlTextReaderPtr) reader
{
  [super readUnknownJAXBAttribute: reader];
}

//documentation inherited.
- (void) writeJAXBAttributes: (xmlTextWriterPtr) writer
{
  int status;

  [super writeJAXBAttributes: writer];

}

//documentation inherited.
- (void) writeJAXBValue: (xmlTextWriterPtr) writer
{
  [super writeJAXBValue: writer];
}

/**
 * Method for writing the child elements.
 *
 * @param writer The writer.
 */
- (void) writeJAXBChildElements: (xmlTextWriterPtr) writer
{
  int status;
  id __item;
  NSEnumerator *__enumerator;

  [super writeJAXBChildElements: writer];

  if (YES) { //always write the primitive element...
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "enabled", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}enabled."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}enabled...");
#endif
    status = xmlTextWriterWriteBooleanType(writer, &_enabled);
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}enabled...");
#endif
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing child element {}enabled."];
    }

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}enabled."];
    }
  }
  if ([self emailAddresses]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "emailAddresses", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}emailAddresses."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}emailAddresses...");
#endif
    [[self emailAddresses] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}emailAddresses...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}emailAddresses."];
    }
  }
  if ([self roles]) {
    __enumerator = [[self roles] objectEnumerator];

    while ( (__item = [__enumerator nextObject]) ) {
      status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "roles", NULL);
      if (status < 0) {
        [NSException raise: @"XMLWriteError"
                     format: @"Error writing start child element {}roles."];
      }

#if DEBUG_ENUNCIATE > 1
      NSLog(@"writing element {}roles...");
#endif
      [__item writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
      NSLog(@"successfully wrote element {}roles...");
#endif

      status = xmlTextWriterEndElement(writer);
      if (status < 0) {
        [NSException raise: @"XMLWriteError"
                     format: @"Error writing end child element {}roles."];
      }
    } //end item iterator.
  }
}
@end /* implementation NEXUS_REST_APINS0SystemNotificationSettings (JAXB) */

#endif /* DEF_NEXUS_REST_APINS0SystemNotificationSettings_M */
#ifndef DEF_NEXUS_REST_APINS0WastebasketResource_M
#define DEF_NEXUS_REST_APINS0WastebasketResource_M

/**
 *  Details about the nexus wastebasket.
 
 @version $Revision$ $Date$

 */
@implementation NEXUS_REST_APINS0WastebasketResource

/**
 * The size of the contents in the wastebasket.
 */
- (long) size
{
  return _size;
}

/**
 * The size of the contents in the wastebasket.
 */
- (void) setSize: (long) newSize
{
  _size = newSize;
}

/**
 * The number of items in the wastebasket.
 */
- (long) itemCount
{
  return _itemCount;
}

/**
 * The number of items in the wastebasket.
 */
- (void) setItemCount: (long) newItemCount
{
  _itemCount = newItemCount;
}

- (void) dealloc
{
  [super dealloc];
}
@end /* implementation NEXUS_REST_APINS0WastebasketResource */

/**
 * Internal, private interface for JAXB reading and writing.
 */
@interface NEXUS_REST_APINS0WastebasketResource (JAXB) <JAXBReading, JAXBWriting, JAXBType>

@end /*interface NEXUS_REST_APINS0WastebasketResource (JAXB)*/

/**
 * Internal, private implementation for JAXB reading and writing.
 */
@implementation NEXUS_REST_APINS0WastebasketResource (JAXB)

/**
 * Read an instance of NEXUS_REST_APINS0WastebasketResource from an XML reader.
 *
 * @param reader The reader.
 * @return An instance of NEXUS_REST_APINS0WastebasketResource defined by the XML reader.
 */
+ (id<JAXBType>) readXMLType: (xmlTextReaderPtr) reader
{
  NEXUS_REST_APINS0WastebasketResource *_nEXUS_REST_APINS0WastebasketResource = [[NEXUS_REST_APINS0WastebasketResource alloc] init];
  NS_DURING
  {
    [_nEXUS_REST_APINS0WastebasketResource initWithReader: reader];
  }
  NS_HANDLER
  {
    [_nEXUS_REST_APINS0WastebasketResource dealloc];
    _nEXUS_REST_APINS0WastebasketResource = nil;
    [localException raise];
  }
  NS_ENDHANDLER

  [_nEXUS_REST_APINS0WastebasketResource autorelease];
  return _nEXUS_REST_APINS0WastebasketResource;
}

/**
 * Initialize this instance of NEXUS_REST_APINS0WastebasketResource according to
 * the XML being read from the reader.
 *
 * @param reader The reader.
 */
- (id) initWithReader: (xmlTextReaderPtr) reader
{
  return [super initWithReader: reader];
}

/**
 * Write the XML for this instance of NEXUS_REST_APINS0WastebasketResource to the writer.
 * Note that since we're only writing the XML type,
 * No start/end element will be written.
 *
 * @param reader The reader.
 */
- (void) writeXMLType: (xmlTextWriterPtr) writer
{
  [super writeXMLType:writer];
}

//documentation inherited.
- (BOOL) readJAXBAttribute: (xmlTextReaderPtr) reader
{
  void *_child_accessor;

  if ([super readJAXBAttribute: reader]) {
    return YES;
  }

  return NO;
}

//documentation inherited.
- (BOOL) readJAXBValue: (xmlTextReaderPtr) reader
{
  return [super readJAXBValue: reader];
}

//documentation inherited.
- (BOOL) readJAXBChildElement: (xmlTextReaderPtr) reader
{
  id __child;
  void *_child_accessor;
  int status, depth;

  if ([super readJAXBChildElement: reader]) {
    return YES;
  }

  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "size", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

    _child_accessor = xmlTextReaderReadLongType(reader);
    if (_child_accessor == NULL) {
      //panic: unable to return the value for some reason.
      [self dealloc];
      [NSException raise: @"XMLReadError"
                   format: @"Error reading element value."];
    }
    [self setSize: *((long*) _child_accessor)];
    free(_child_accessor);
    return YES;
  }

  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "itemCount", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

    _child_accessor = xmlTextReaderReadLongType(reader);
    if (_child_accessor == NULL) {
      //panic: unable to return the value for some reason.
      [self dealloc];
      [NSException raise: @"XMLReadError"
                   format: @"Error reading element value."];
    }
    [self setItemCount: *((long*) _child_accessor)];
    free(_child_accessor);
    return YES;
  }

  return NO;
}

//documentation inherited.
- (int) readUnknownJAXBChildElement: (xmlTextReaderPtr) reader
{
  return [super readUnknownJAXBChildElement: reader];
}

//documentation inherited.
- (void) readUnknownJAXBAttribute: (xmlTextReaderPtr) reader
{
  [super readUnknownJAXBAttribute: reader];
}

//documentation inherited.
- (void) writeJAXBAttributes: (xmlTextWriterPtr) writer
{
  int status;

  [super writeJAXBAttributes: writer];

}

//documentation inherited.
- (void) writeJAXBValue: (xmlTextWriterPtr) writer
{
  [super writeJAXBValue: writer];
}

/**
 * Method for writing the child elements.
 *
 * @param writer The writer.
 */
- (void) writeJAXBChildElements: (xmlTextWriterPtr) writer
{
  int status;
  id __item;
  NSEnumerator *__enumerator;

  [super writeJAXBChildElements: writer];

  if (YES) { //always write the primitive element...
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "size", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}size."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}size...");
#endif
    status = xmlTextWriterWriteLongType(writer, &_size);
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}size...");
#endif
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing child element {}size."];
    }

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}size."];
    }
  }
  if (YES) { //always write the primitive element...
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "itemCount", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}itemCount."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}itemCount...");
#endif
    status = xmlTextWriterWriteLongType(writer, &_itemCount);
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}itemCount...");
#endif
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing child element {}itemCount."];
    }

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}itemCount."];
    }
  }
}
@end /* implementation NEXUS_REST_APINS0WastebasketResource (JAXB) */

#endif /* DEF_NEXUS_REST_APINS0WastebasketResource_M */
#ifndef DEF_NEXUS_REST_APINS0ClientPermission_M
#define DEF_NEXUS_REST_APINS0ClientPermission_M

/**
 * (no documentation provided)
 */
@implementation NEXUS_REST_APINS0ClientPermission

/**
 * (no documentation provided)
 */
- (NSString *) id
{
  return _id;
}

/**
 * (no documentation provided)
 */
- (void) setId: (NSString *) newId
{
  [newId retain];
  [_id release];
  _id = newId;
}

/**
 * (no documentation provided)
 */
- (int) value
{
  return _value;
}

/**
 * (no documentation provided)
 */
- (void) setValue: (int) newValue
{
  _value = newValue;
}

- (void) dealloc
{
  [self setId: nil];
  [super dealloc];
}
@end /* implementation NEXUS_REST_APINS0ClientPermission */

/**
 * Internal, private interface for JAXB reading and writing.
 */
@interface NEXUS_REST_APINS0ClientPermission (JAXB) <JAXBReading, JAXBWriting, JAXBType>

@end /*interface NEXUS_REST_APINS0ClientPermission (JAXB)*/

/**
 * Internal, private implementation for JAXB reading and writing.
 */
@implementation NEXUS_REST_APINS0ClientPermission (JAXB)

/**
 * Read an instance of NEXUS_REST_APINS0ClientPermission from an XML reader.
 *
 * @param reader The reader.
 * @return An instance of NEXUS_REST_APINS0ClientPermission defined by the XML reader.
 */
+ (id<JAXBType>) readXMLType: (xmlTextReaderPtr) reader
{
  NEXUS_REST_APINS0ClientPermission *_nEXUS_REST_APINS0ClientPermission = [[NEXUS_REST_APINS0ClientPermission alloc] init];
  NS_DURING
  {
    [_nEXUS_REST_APINS0ClientPermission initWithReader: reader];
  }
  NS_HANDLER
  {
    [_nEXUS_REST_APINS0ClientPermission dealloc];
    _nEXUS_REST_APINS0ClientPermission = nil;
    [localException raise];
  }
  NS_ENDHANDLER

  [_nEXUS_REST_APINS0ClientPermission autorelease];
  return _nEXUS_REST_APINS0ClientPermission;
}

/**
 * Initialize this instance of NEXUS_REST_APINS0ClientPermission according to
 * the XML being read from the reader.
 *
 * @param reader The reader.
 */
- (id) initWithReader: (xmlTextReaderPtr) reader
{
  return [super initWithReader: reader];
}

/**
 * Write the XML for this instance of NEXUS_REST_APINS0ClientPermission to the writer.
 * Note that since we're only writing the XML type,
 * No start/end element will be written.
 *
 * @param reader The reader.
 */
- (void) writeXMLType: (xmlTextWriterPtr) writer
{
  [super writeXMLType:writer];
}

//documentation inherited.
- (BOOL) readJAXBAttribute: (xmlTextReaderPtr) reader
{
  void *_child_accessor;

  if ([super readJAXBAttribute: reader]) {
    return YES;
  }

  return NO;
}

//documentation inherited.
- (BOOL) readJAXBValue: (xmlTextReaderPtr) reader
{
  return [super readJAXBValue: reader];
}

//documentation inherited.
- (BOOL) readJAXBChildElement: (xmlTextReaderPtr) reader
{
  id __child;
  void *_child_accessor;
  int status, depth;

  if ([super readJAXBChildElement: reader]) {
    return YES;
  }
  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "id", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}id of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}id of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setId: __child];
    return YES;
  } //end "if choice"


  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "value", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

    _child_accessor = xmlTextReaderReadIntType(reader);
    if (_child_accessor == NULL) {
      //panic: unable to return the value for some reason.
      [self dealloc];
      [NSException raise: @"XMLReadError"
                   format: @"Error reading element value."];
    }
    [self setValue: *((int*) _child_accessor)];
    free(_child_accessor);
    return YES;
  }

  return NO;
}

//documentation inherited.
- (int) readUnknownJAXBChildElement: (xmlTextReaderPtr) reader
{
  return [super readUnknownJAXBChildElement: reader];
}

//documentation inherited.
- (void) readUnknownJAXBAttribute: (xmlTextReaderPtr) reader
{
  [super readUnknownJAXBAttribute: reader];
}

//documentation inherited.
- (void) writeJAXBAttributes: (xmlTextWriterPtr) writer
{
  int status;

  [super writeJAXBAttributes: writer];

}

//documentation inherited.
- (void) writeJAXBValue: (xmlTextWriterPtr) writer
{
  [super writeJAXBValue: writer];
}

/**
 * Method for writing the child elements.
 *
 * @param writer The writer.
 */
- (void) writeJAXBChildElements: (xmlTextWriterPtr) writer
{
  int status;
  id __item;
  NSEnumerator *__enumerator;

  [super writeJAXBChildElements: writer];

  if ([self id]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "id", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}id."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}id...");
#endif
    [[self id] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}id...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}id."];
    }
  }
  if (YES) { //always write the primitive element...
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "value", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}value."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}value...");
#endif
    status = xmlTextWriterWriteIntType(writer, &_value);
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}value...");
#endif
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing child element {}value."];
    }

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}value."];
    }
  }
}
@end /* implementation NEXUS_REST_APINS0ClientPermission (JAXB) */

#endif /* DEF_NEXUS_REST_APINS0ClientPermission_M */
#ifndef DEF_NEXUS_REST_APINS0AuthenticationClientPermissions_M
#define DEF_NEXUS_REST_APINS0AuthenticationClientPermissions_M

/**
 * (no documentation provided)
 */
@implementation NEXUS_REST_APINS0AuthenticationClientPermissions

/**
 * (no documentation provided)
 */
- (BOOL) loggedIn
{
  return _loggedIn;
}

/**
 * (no documentation provided)
 */
- (void) setLoggedIn: (BOOL) newLoggedIn
{
  _loggedIn = newLoggedIn;
}

/**
 * (no documentation provided)
 */
- (NSArray *) permissions
{
  return _permissions;
}

/**
 * (no documentation provided)
 */
- (void) setPermissions: (NSArray *) newPermissions
{
  [newPermissions retain];
  [_permissions release];
  _permissions = newPermissions;
}

/**
 * (no documentation provided)
 */
- (NSString *) loggedInUserSource
{
  return _loggedInUserSource;
}

/**
 * (no documentation provided)
 */
- (void) setLoggedInUserSource: (NSString *) newLoggedInUserSource
{
  [newLoggedInUserSource retain];
  [_loggedInUserSource release];
  _loggedInUserSource = newLoggedInUserSource;
}

/**
 * (no documentation provided)
 */
- (NSString *) loggedInUsername
{
  return _loggedInUsername;
}

/**
 * (no documentation provided)
 */
- (void) setLoggedInUsername: (NSString *) newLoggedInUsername
{
  [newLoggedInUsername retain];
  [_loggedInUsername release];
  _loggedInUsername = newLoggedInUsername;
}

- (void) dealloc
{
  [self setPermissions: nil];
  [self setLoggedInUserSource: nil];
  [self setLoggedInUsername: nil];
  [super dealloc];
}
@end /* implementation NEXUS_REST_APINS0AuthenticationClientPermissions */

/**
 * Internal, private interface for JAXB reading and writing.
 */
@interface NEXUS_REST_APINS0AuthenticationClientPermissions (JAXB) <JAXBReading, JAXBWriting, JAXBType>

@end /*interface NEXUS_REST_APINS0AuthenticationClientPermissions (JAXB)*/

/**
 * Internal, private implementation for JAXB reading and writing.
 */
@implementation NEXUS_REST_APINS0AuthenticationClientPermissions (JAXB)

/**
 * Read an instance of NEXUS_REST_APINS0AuthenticationClientPermissions from an XML reader.
 *
 * @param reader The reader.
 * @return An instance of NEXUS_REST_APINS0AuthenticationClientPermissions defined by the XML reader.
 */
+ (id<JAXBType>) readXMLType: (xmlTextReaderPtr) reader
{
  NEXUS_REST_APINS0AuthenticationClientPermissions *_nEXUS_REST_APINS0AuthenticationClientPermissions = [[NEXUS_REST_APINS0AuthenticationClientPermissions alloc] init];
  NS_DURING
  {
    [_nEXUS_REST_APINS0AuthenticationClientPermissions initWithReader: reader];
  }
  NS_HANDLER
  {
    [_nEXUS_REST_APINS0AuthenticationClientPermissions dealloc];
    _nEXUS_REST_APINS0AuthenticationClientPermissions = nil;
    [localException raise];
  }
  NS_ENDHANDLER

  [_nEXUS_REST_APINS0AuthenticationClientPermissions autorelease];
  return _nEXUS_REST_APINS0AuthenticationClientPermissions;
}

/**
 * Initialize this instance of NEXUS_REST_APINS0AuthenticationClientPermissions according to
 * the XML being read from the reader.
 *
 * @param reader The reader.
 */
- (id) initWithReader: (xmlTextReaderPtr) reader
{
  return [super initWithReader: reader];
}

/**
 * Write the XML for this instance of NEXUS_REST_APINS0AuthenticationClientPermissions to the writer.
 * Note that since we're only writing the XML type,
 * No start/end element will be written.
 *
 * @param reader The reader.
 */
- (void) writeXMLType: (xmlTextWriterPtr) writer
{
  [super writeXMLType:writer];
}

//documentation inherited.
- (BOOL) readJAXBAttribute: (xmlTextReaderPtr) reader
{
  void *_child_accessor;

  if ([super readJAXBAttribute: reader]) {
    return YES;
  }

  return NO;
}

//documentation inherited.
- (BOOL) readJAXBValue: (xmlTextReaderPtr) reader
{
  return [super readJAXBValue: reader];
}

//documentation inherited.
- (BOOL) readJAXBChildElement: (xmlTextReaderPtr) reader
{
  id __child;
  void *_child_accessor;
  int status, depth;

  if ([super readJAXBChildElement: reader]) {
    return YES;
  }

  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "loggedIn", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

    _child_accessor = xmlTextReaderReadBooleanType(reader);
    if (_child_accessor == NULL) {
      //panic: unable to return the value for some reason.
      [self dealloc];
      [NSException raise: @"XMLReadError"
                   format: @"Error reading element value."];
    }
    [self setLoggedIn: *((BOOL*) _child_accessor)];
    free(_child_accessor);
    return YES;
  }
  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "permissions", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

    if (xmlTextReaderIsEmptyElement(reader) == 0) {
#if DEBUG_ENUNCIATE > 1
      NSLog(@"Unwrapping wrapper element {}permissions...");
#endif
      //start wrapper element "{}permissions"
      depth = xmlTextReaderDepth(reader);
      status = xmlTextReaderAdvanceToNextStartOrEndElement(reader);
      while (xmlTextReaderDepth(reader) > depth) {
        if (status < 1) {
          //panic: XML read error.
          [self dealloc];
          [NSException raise: @"XMLReadError"
                       format: @"Failure to advance to next wrapped child element."];
        }
  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "permission", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}permission of type {}clientPermission.");
#endif

    __child = [NEXUS_REST_APINS0ClientPermission readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}permission of type {}clientPermission.");
#endif

    if ([self permissions]) {
      [self setPermissions: [[self permissions] arrayByAddingObject: __child]];
    }
    else {
      [self setPermissions: [NSArray arrayWithObject: __child]];
    }
    continue; //continue "while in wrapper element" loop
  } //end "if choice"

        status = xmlTextReaderAdvanceToNextStartOrEndElement(reader);
#if DEBUG_ENUNCIATE > 1
        NSLog(@"successfully unwrapped wrapper element {}permissions...");
#endif
      } // end "while in wrapper element" loop

      if (status < 1) {
        //panic: XML read error.
        [self dealloc];
        [NSException raise: @"XMLReadError"
                     format: @"Failure to advance to end wrapper element."];
      }
      else {
        //end wrapper element "{}permissions"
        status = xmlTextReaderAdvanceToNextStartOrEndElement(reader);
      }
    } //end "if empty element" clause
    else {
      __child = [NSArray array];
      [self setPermissions: (NSArray*) __child];
    }

    return YES;
  } // end "if wrapper element" clause
  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "loggedInUserSource", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}loggedInUserSource of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}loggedInUserSource of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setLoggedInUserSource: __child];
    return YES;
  } //end "if choice"

  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "loggedInUsername", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}loggedInUsername of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}loggedInUsername of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setLoggedInUsername: __child];
    return YES;
  } //end "if choice"


  return NO;
}

//documentation inherited.
- (int) readUnknownJAXBChildElement: (xmlTextReaderPtr) reader
{
  return [super readUnknownJAXBChildElement: reader];
}

//documentation inherited.
- (void) readUnknownJAXBAttribute: (xmlTextReaderPtr) reader
{
  [super readUnknownJAXBAttribute: reader];
}

//documentation inherited.
- (void) writeJAXBAttributes: (xmlTextWriterPtr) writer
{
  int status;

  [super writeJAXBAttributes: writer];

}

//documentation inherited.
- (void) writeJAXBValue: (xmlTextWriterPtr) writer
{
  [super writeJAXBValue: writer];
}

/**
 * Method for writing the child elements.
 *
 * @param writer The writer.
 */
- (void) writeJAXBChildElements: (xmlTextWriterPtr) writer
{
  int status;
  id __item;
  NSEnumerator *__enumerator;

  [super writeJAXBChildElements: writer];

  if (YES) { //always write the primitive element...
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "loggedIn", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}loggedIn."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}loggedIn...");
#endif
    status = xmlTextWriterWriteBooleanType(writer, &_loggedIn);
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}loggedIn...");
#endif
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing child element {}loggedIn."];
    }

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}loggedIn."];
    }
  }
  if ([self permissions]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "permissions", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start wrapper element {}permissions."];
    }
    __enumerator = [[self permissions] objectEnumerator];

    while ( (__item = [__enumerator nextObject]) ) {
      status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "permission", NULL);
      if (status < 0) {
        [NSException raise: @"XMLWriteError"
                     format: @"Error writing start child element {}permission."];
      }

#if DEBUG_ENUNCIATE > 1
      NSLog(@"writing element {}permission...");
#endif
      [__item writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
      NSLog(@"successfully wrote element {}permission...");
#endif

      status = xmlTextWriterEndElement(writer);
      if (status < 0) {
        [NSException raise: @"XMLWriteError"
                     format: @"Error writing end child element {}permission."];
      }
    } //end item iterator.

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end wrapper element {}permissions."];
    }
  }
  if ([self loggedInUserSource]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "loggedInUserSource", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}loggedInUserSource."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}loggedInUserSource...");
#endif
    [[self loggedInUserSource] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}loggedInUserSource...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}loggedInUserSource."];
    }
  }
  if ([self loggedInUsername]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "loggedInUsername", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}loggedInUsername."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}loggedInUsername...");
#endif
    [[self loggedInUsername] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}loggedInUsername...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}loggedInUsername."];
    }
  }
}
@end /* implementation NEXUS_REST_APINS0AuthenticationClientPermissions (JAXB) */

#endif /* DEF_NEXUS_REST_APINS0AuthenticationClientPermissions_M */
#ifndef DEF_NEXUS_REST_APINS0StatusConfigurationValidationResponse_M
#define DEF_NEXUS_REST_APINS0StatusConfigurationValidationResponse_M

/**
 *  Configuration validation status.
 
 @version $Revision$ $Date$

 */
@implementation NEXUS_REST_APINS0StatusConfigurationValidationResponse

/**
 * Flag that states if the nexus configuration is valid.
 */
- (BOOL) valid
{
  return _valid;
}

/**
 * Flag that states if the nexus configuration is valid.
 */
- (void) setValid: (BOOL) newValid
{
  _valid = newValid;
}

/**
 * Flag that states if nexus had to modify the nexus
configuration.
 */
- (BOOL) modified
{
  return _modified;
}

/**
 * Flag that states if nexus had to modify the nexus
configuration.
 */
- (void) setModified: (BOOL) newModified
{
  _modified = newModified;
}

/**
 * Field validationErrors.
 */
- (NSArray *) validationErrors
{
  return _validationErrors;
}

/**
 * Field validationErrors.
 */
- (void) setValidationErrors: (NSArray *) newValidationErrors
{
  [newValidationErrors retain];
  [_validationErrors release];
  _validationErrors = newValidationErrors;
}

/**
 * Field validationWarnings.
 */
- (NSArray *) validationWarnings
{
  return _validationWarnings;
}

/**
 * Field validationWarnings.
 */
- (void) setValidationWarnings: (NSArray *) newValidationWarnings
{
  [newValidationWarnings retain];
  [_validationWarnings release];
  _validationWarnings = newValidationWarnings;
}

- (void) dealloc
{
  [self setValidationErrors: nil];
  [self setValidationWarnings: nil];
  [super dealloc];
}
@end /* implementation NEXUS_REST_APINS0StatusConfigurationValidationResponse */

/**
 * Internal, private interface for JAXB reading and writing.
 */
@interface NEXUS_REST_APINS0StatusConfigurationValidationResponse (JAXB) <JAXBReading, JAXBWriting, JAXBType>

@end /*interface NEXUS_REST_APINS0StatusConfigurationValidationResponse (JAXB)*/

/**
 * Internal, private implementation for JAXB reading and writing.
 */
@implementation NEXUS_REST_APINS0StatusConfigurationValidationResponse (JAXB)

/**
 * Read an instance of NEXUS_REST_APINS0StatusConfigurationValidationResponse from an XML reader.
 *
 * @param reader The reader.
 * @return An instance of NEXUS_REST_APINS0StatusConfigurationValidationResponse defined by the XML reader.
 */
+ (id<JAXBType>) readXMLType: (xmlTextReaderPtr) reader
{
  NEXUS_REST_APINS0StatusConfigurationValidationResponse *_nEXUS_REST_APINS0StatusConfigurationValidationResponse = [[NEXUS_REST_APINS0StatusConfigurationValidationResponse alloc] init];
  NS_DURING
  {
    [_nEXUS_REST_APINS0StatusConfigurationValidationResponse initWithReader: reader];
  }
  NS_HANDLER
  {
    [_nEXUS_REST_APINS0StatusConfigurationValidationResponse dealloc];
    _nEXUS_REST_APINS0StatusConfigurationValidationResponse = nil;
    [localException raise];
  }
  NS_ENDHANDLER

  [_nEXUS_REST_APINS0StatusConfigurationValidationResponse autorelease];
  return _nEXUS_REST_APINS0StatusConfigurationValidationResponse;
}

/**
 * Initialize this instance of NEXUS_REST_APINS0StatusConfigurationValidationResponse according to
 * the XML being read from the reader.
 *
 * @param reader The reader.
 */
- (id) initWithReader: (xmlTextReaderPtr) reader
{
  return [super initWithReader: reader];
}

/**
 * Write the XML for this instance of NEXUS_REST_APINS0StatusConfigurationValidationResponse to the writer.
 * Note that since we're only writing the XML type,
 * No start/end element will be written.
 *
 * @param reader The reader.
 */
- (void) writeXMLType: (xmlTextWriterPtr) writer
{
  [super writeXMLType:writer];
}

//documentation inherited.
- (BOOL) readJAXBAttribute: (xmlTextReaderPtr) reader
{
  void *_child_accessor;

  if ([super readJAXBAttribute: reader]) {
    return YES;
  }

  return NO;
}

//documentation inherited.
- (BOOL) readJAXBValue: (xmlTextReaderPtr) reader
{
  return [super readJAXBValue: reader];
}

//documentation inherited.
- (BOOL) readJAXBChildElement: (xmlTextReaderPtr) reader
{
  id __child;
  void *_child_accessor;
  int status, depth;

  if ([super readJAXBChildElement: reader]) {
    return YES;
  }

  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "valid", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

    _child_accessor = xmlTextReaderReadBooleanType(reader);
    if (_child_accessor == NULL) {
      //panic: unable to return the value for some reason.
      [self dealloc];
      [NSException raise: @"XMLReadError"
                   format: @"Error reading element value."];
    }
    [self setValid: *((BOOL*) _child_accessor)];
    free(_child_accessor);
    return YES;
  }

  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "modified", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

    _child_accessor = xmlTextReaderReadBooleanType(reader);
    if (_child_accessor == NULL) {
      //panic: unable to return the value for some reason.
      [self dealloc];
      [NSException raise: @"XMLReadError"
                   format: @"Error reading element value."];
    }
    [self setModified: *((BOOL*) _child_accessor)];
    free(_child_accessor);
    return YES;
  }
  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "validationErrors", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

    if (xmlTextReaderIsEmptyElement(reader) == 0) {
#if DEBUG_ENUNCIATE > 1
      NSLog(@"Unwrapping wrapper element {}validationErrors...");
#endif
      //start wrapper element "{}validationErrors"
      depth = xmlTextReaderDepth(reader);
      status = xmlTextReaderAdvanceToNextStartOrEndElement(reader);
      while (xmlTextReaderDepth(reader) > depth) {
        if (status < 1) {
          //panic: XML read error.
          [self dealloc];
          [NSException raise: @"XMLReadError"
                       format: @"Failure to advance to next wrapped child element."];
        }
  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "error", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}error of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}error of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    if ([self validationErrors]) {
      [self setValidationErrors: [[self validationErrors] arrayByAddingObject: __child]];
    }
    else {
      [self setValidationErrors: [NSArray arrayWithObject: __child]];
    }
    continue; //continue "while in wrapper element" loop
  } //end "if choice"

        status = xmlTextReaderAdvanceToNextStartOrEndElement(reader);
#if DEBUG_ENUNCIATE > 1
        NSLog(@"successfully unwrapped wrapper element {}validationErrors...");
#endif
      } // end "while in wrapper element" loop

      if (status < 1) {
        //panic: XML read error.
        [self dealloc];
        [NSException raise: @"XMLReadError"
                     format: @"Failure to advance to end wrapper element."];
      }
      else {
        //end wrapper element "{}validationErrors"
        status = xmlTextReaderAdvanceToNextStartOrEndElement(reader);
      }
    } //end "if empty element" clause
    else {
      __child = [NSArray array];
      [self setValidationErrors: (NSArray*) __child];
    }

    return YES;
  } // end "if wrapper element" clause
  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "validationWarnings", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

    if (xmlTextReaderIsEmptyElement(reader) == 0) {
#if DEBUG_ENUNCIATE > 1
      NSLog(@"Unwrapping wrapper element {}validationWarnings...");
#endif
      //start wrapper element "{}validationWarnings"
      depth = xmlTextReaderDepth(reader);
      status = xmlTextReaderAdvanceToNextStartOrEndElement(reader);
      while (xmlTextReaderDepth(reader) > depth) {
        if (status < 1) {
          //panic: XML read error.
          [self dealloc];
          [NSException raise: @"XMLReadError"
                       format: @"Failure to advance to next wrapped child element."];
        }
  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "warning", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}warning of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}warning of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    if ([self validationWarnings]) {
      [self setValidationWarnings: [[self validationWarnings] arrayByAddingObject: __child]];
    }
    else {
      [self setValidationWarnings: [NSArray arrayWithObject: __child]];
    }
    continue; //continue "while in wrapper element" loop
  } //end "if choice"

        status = xmlTextReaderAdvanceToNextStartOrEndElement(reader);
#if DEBUG_ENUNCIATE > 1
        NSLog(@"successfully unwrapped wrapper element {}validationWarnings...");
#endif
      } // end "while in wrapper element" loop

      if (status < 1) {
        //panic: XML read error.
        [self dealloc];
        [NSException raise: @"XMLReadError"
                     format: @"Failure to advance to end wrapper element."];
      }
      else {
        //end wrapper element "{}validationWarnings"
        status = xmlTextReaderAdvanceToNextStartOrEndElement(reader);
      }
    } //end "if empty element" clause
    else {
      __child = [NSArray array];
      [self setValidationWarnings: (NSArray*) __child];
    }

    return YES;
  } // end "if wrapper element" clause

  return NO;
}

//documentation inherited.
- (int) readUnknownJAXBChildElement: (xmlTextReaderPtr) reader
{
  return [super readUnknownJAXBChildElement: reader];
}

//documentation inherited.
- (void) readUnknownJAXBAttribute: (xmlTextReaderPtr) reader
{
  [super readUnknownJAXBAttribute: reader];
}

//documentation inherited.
- (void) writeJAXBAttributes: (xmlTextWriterPtr) writer
{
  int status;

  [super writeJAXBAttributes: writer];

}

//documentation inherited.
- (void) writeJAXBValue: (xmlTextWriterPtr) writer
{
  [super writeJAXBValue: writer];
}

/**
 * Method for writing the child elements.
 *
 * @param writer The writer.
 */
- (void) writeJAXBChildElements: (xmlTextWriterPtr) writer
{
  int status;
  id __item;
  NSEnumerator *__enumerator;

  [super writeJAXBChildElements: writer];

  if (YES) { //always write the primitive element...
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "valid", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}valid."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}valid...");
#endif
    status = xmlTextWriterWriteBooleanType(writer, &_valid);
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}valid...");
#endif
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing child element {}valid."];
    }

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}valid."];
    }
  }
  if (YES) { //always write the primitive element...
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "modified", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}modified."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}modified...");
#endif
    status = xmlTextWriterWriteBooleanType(writer, &_modified);
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}modified...");
#endif
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing child element {}modified."];
    }

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}modified."];
    }
  }
  if ([self validationErrors]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "validationErrors", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start wrapper element {}validationErrors."];
    }
    __enumerator = [[self validationErrors] objectEnumerator];

    while ( (__item = [__enumerator nextObject]) ) {
      status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "error", NULL);
      if (status < 0) {
        [NSException raise: @"XMLWriteError"
                     format: @"Error writing start child element {}error."];
      }

#if DEBUG_ENUNCIATE > 1
      NSLog(@"writing element {}error...");
#endif
      [__item writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
      NSLog(@"successfully wrote element {}error...");
#endif

      status = xmlTextWriterEndElement(writer);
      if (status < 0) {
        [NSException raise: @"XMLWriteError"
                     format: @"Error writing end child element {}error."];
      }
    } //end item iterator.

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end wrapper element {}validationErrors."];
    }
  }
  if ([self validationWarnings]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "validationWarnings", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start wrapper element {}validationWarnings."];
    }
    __enumerator = [[self validationWarnings] objectEnumerator];

    while ( (__item = [__enumerator nextObject]) ) {
      status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "warning", NULL);
      if (status < 0) {
        [NSException raise: @"XMLWriteError"
                     format: @"Error writing start child element {}warning."];
      }

#if DEBUG_ENUNCIATE > 1
      NSLog(@"writing element {}warning...");
#endif
      [__item writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
      NSLog(@"successfully wrote element {}warning...");
#endif

      status = xmlTextWriterEndElement(writer);
      if (status < 0) {
        [NSException raise: @"XMLWriteError"
                     format: @"Error writing end child element {}warning."];
      }
    } //end item iterator.

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end wrapper element {}validationWarnings."];
    }
  }
}
@end /* implementation NEXUS_REST_APINS0StatusConfigurationValidationResponse (JAXB) */

#endif /* DEF_NEXUS_REST_APINS0StatusConfigurationValidationResponse_M */
#ifndef DEF_NEXUS_REST_APINS0ScheduledServiceBaseResource_M
#define DEF_NEXUS_REST_APINS0ScheduledServiceBaseResource_M

/**
 *  The scheduled service configuration.
 
 @version $Revision$ $Date$

 */
@implementation NEXUS_REST_APINS0ScheduledServiceBaseResource

/**
 * The id of the service.
 */
- (NSString *) id
{
  return _id;
}

/**
 * The id of the service.
 */
- (void) setId: (NSString *) newId
{
  [newId retain];
  [_id release];
  _id = newId;
}

/**
 * The name of the service.
 */
- (NSString *) name
{
  return _name;
}

/**
 * The name of the service.
 */
- (void) setName: (NSString *) newName
{
  [newName retain];
  [_name release];
  _name = newName;
}

/**
 * Flag that states if the service is enabled.
 */
- (BOOL) enabled
{
  return _enabled;
}

/**
 * Flag that states if the service is enabled.
 */
- (void) setEnabled: (BOOL) newEnabled
{
  _enabled = newEnabled;
}

/**
 * The type id of the service.
 */
- (NSString *) typeId
{
  return _typeId;
}

/**
 * The type id of the service.
 */
- (void) setTypeId: (NSString *) newTypeId
{
  [newTypeId retain];
  [_typeId release];
  _typeId = newTypeId;
}

/**
 * The email to send notifications to if the service fails.
 */
- (NSString *) alertEmail
{
  return _alertEmail;
}

/**
 * The email to send notifications to if the service fails.
 */
- (void) setAlertEmail: (NSString *) newAlertEmail
{
  [newAlertEmail retain];
  [_alertEmail release];
  _alertEmail = newAlertEmail;
}

/**
 * The schedule the service is run on.
 */
- (NSString *) schedule
{
  return _schedule;
}

/**
 * The schedule the service is run on.
 */
- (void) setSchedule: (NSString *) newSchedule
{
  [newSchedule retain];
  [_schedule release];
  _schedule = newSchedule;
}

/**
 * Field properties.
 */
- (NSArray *) properties
{
  return _properties;
}

/**
 * Field properties.
 */
- (void) setProperties: (NSArray *) newProperties
{
  [newProperties retain];
  [_properties release];
  _properties = newProperties;
}

- (void) dealloc
{
  [self setId: nil];
  [self setName: nil];
  [self setTypeId: nil];
  [self setAlertEmail: nil];
  [self setSchedule: nil];
  [self setProperties: nil];
  [super dealloc];
}
@end /* implementation NEXUS_REST_APINS0ScheduledServiceBaseResource */

/**
 * Internal, private interface for JAXB reading and writing.
 */
@interface NEXUS_REST_APINS0ScheduledServiceBaseResource (JAXB) <JAXBReading, JAXBWriting, JAXBType>

@end /*interface NEXUS_REST_APINS0ScheduledServiceBaseResource (JAXB)*/

/**
 * Internal, private implementation for JAXB reading and writing.
 */
@implementation NEXUS_REST_APINS0ScheduledServiceBaseResource (JAXB)

/**
 * Read an instance of NEXUS_REST_APINS0ScheduledServiceBaseResource from an XML reader.
 *
 * @param reader The reader.
 * @return An instance of NEXUS_REST_APINS0ScheduledServiceBaseResource defined by the XML reader.
 */
+ (id<JAXBType>) readXMLType: (xmlTextReaderPtr) reader
{
  NEXUS_REST_APINS0ScheduledServiceBaseResource *_nEXUS_REST_APINS0ScheduledServiceBaseResource = [[NEXUS_REST_APINS0ScheduledServiceBaseResource alloc] init];
  NS_DURING
  {
    [_nEXUS_REST_APINS0ScheduledServiceBaseResource initWithReader: reader];
  }
  NS_HANDLER
  {
    [_nEXUS_REST_APINS0ScheduledServiceBaseResource dealloc];
    _nEXUS_REST_APINS0ScheduledServiceBaseResource = nil;
    [localException raise];
  }
  NS_ENDHANDLER

  [_nEXUS_REST_APINS0ScheduledServiceBaseResource autorelease];
  return _nEXUS_REST_APINS0ScheduledServiceBaseResource;
}

/**
 * Initialize this instance of NEXUS_REST_APINS0ScheduledServiceBaseResource according to
 * the XML being read from the reader.
 *
 * @param reader The reader.
 */
- (id) initWithReader: (xmlTextReaderPtr) reader
{
  return [super initWithReader: reader];
}

/**
 * Write the XML for this instance of NEXUS_REST_APINS0ScheduledServiceBaseResource to the writer.
 * Note that since we're only writing the XML type,
 * No start/end element will be written.
 *
 * @param reader The reader.
 */
- (void) writeXMLType: (xmlTextWriterPtr) writer
{
  [super writeXMLType:writer];
}

//documentation inherited.
- (BOOL) readJAXBAttribute: (xmlTextReaderPtr) reader
{
  void *_child_accessor;

  if ([super readJAXBAttribute: reader]) {
    return YES;
  }

  return NO;
}

//documentation inherited.
- (BOOL) readJAXBValue: (xmlTextReaderPtr) reader
{
  return [super readJAXBValue: reader];
}

//documentation inherited.
- (BOOL) readJAXBChildElement: (xmlTextReaderPtr) reader
{
  id __child;
  void *_child_accessor;
  int status, depth;

  if ([super readJAXBChildElement: reader]) {
    return YES;
  }
  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "id", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}id of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}id of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setId: __child];
    return YES;
  } //end "if choice"

  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "name", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}name of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}name of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setName: __child];
    return YES;
  } //end "if choice"


  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "enabled", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

    _child_accessor = xmlTextReaderReadBooleanType(reader);
    if (_child_accessor == NULL) {
      //panic: unable to return the value for some reason.
      [self dealloc];
      [NSException raise: @"XMLReadError"
                   format: @"Error reading element value."];
    }
    [self setEnabled: *((BOOL*) _child_accessor)];
    free(_child_accessor);
    return YES;
  }
  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "typeId", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}typeId of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}typeId of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setTypeId: __child];
    return YES;
  } //end "if choice"

  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "alertEmail", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}alertEmail of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}alertEmail of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setAlertEmail: __child];
    return YES;
  } //end "if choice"

  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "schedule", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}schedule of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}schedule of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setSchedule: __child];
    return YES;
  } //end "if choice"

  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "properties", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

    if (xmlTextReaderIsEmptyElement(reader) == 0) {
#if DEBUG_ENUNCIATE > 1
      NSLog(@"Unwrapping wrapper element {}properties...");
#endif
      //start wrapper element "{}properties"
      depth = xmlTextReaderDepth(reader);
      status = xmlTextReaderAdvanceToNextStartOrEndElement(reader);
      while (xmlTextReaderDepth(reader) > depth) {
        if (status < 1) {
          //panic: XML read error.
          [self dealloc];
          [NSException raise: @"XMLReadError"
                       format: @"Failure to advance to next wrapped child element."];
        }
  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "scheduled-task-property", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}scheduled-task-property of type {}scheduled-service-property-resource.");
#endif

    __child = [NEXUS_REST_APINS0ScheduledServicePropertyResource readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}scheduled-task-property of type {}scheduled-service-property-resource.");
#endif

    if ([self properties]) {
      [self setProperties: [[self properties] arrayByAddingObject: __child]];
    }
    else {
      [self setProperties: [NSArray arrayWithObject: __child]];
    }
    continue; //continue "while in wrapper element" loop
  } //end "if choice"

        status = xmlTextReaderAdvanceToNextStartOrEndElement(reader);
#if DEBUG_ENUNCIATE > 1
        NSLog(@"successfully unwrapped wrapper element {}properties...");
#endif
      } // end "while in wrapper element" loop

      if (status < 1) {
        //panic: XML read error.
        [self dealloc];
        [NSException raise: @"XMLReadError"
                     format: @"Failure to advance to end wrapper element."];
      }
      else {
        //end wrapper element "{}properties"
        status = xmlTextReaderAdvanceToNextStartOrEndElement(reader);
      }
    } //end "if empty element" clause
    else {
      __child = [NSArray array];
      [self setProperties: (NSArray*) __child];
    }

    return YES;
  } // end "if wrapper element" clause

  return NO;
}

//documentation inherited.
- (int) readUnknownJAXBChildElement: (xmlTextReaderPtr) reader
{
  return [super readUnknownJAXBChildElement: reader];
}

//documentation inherited.
- (void) readUnknownJAXBAttribute: (xmlTextReaderPtr) reader
{
  [super readUnknownJAXBAttribute: reader];
}

//documentation inherited.
- (void) writeJAXBAttributes: (xmlTextWriterPtr) writer
{
  int status;

  [super writeJAXBAttributes: writer];

}

//documentation inherited.
- (void) writeJAXBValue: (xmlTextWriterPtr) writer
{
  [super writeJAXBValue: writer];
}

/**
 * Method for writing the child elements.
 *
 * @param writer The writer.
 */
- (void) writeJAXBChildElements: (xmlTextWriterPtr) writer
{
  int status;
  id __item;
  NSEnumerator *__enumerator;

  [super writeJAXBChildElements: writer];

  if ([self id]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "id", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}id."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}id...");
#endif
    [[self id] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}id...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}id."];
    }
  }
  if ([self name]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "name", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}name."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}name...");
#endif
    [[self name] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}name...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}name."];
    }
  }
  if (YES) { //always write the primitive element...
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "enabled", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}enabled."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}enabled...");
#endif
    status = xmlTextWriterWriteBooleanType(writer, &_enabled);
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}enabled...");
#endif
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing child element {}enabled."];
    }

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}enabled."];
    }
  }
  if ([self typeId]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "typeId", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}typeId."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}typeId...");
#endif
    [[self typeId] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}typeId...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}typeId."];
    }
  }
  if ([self alertEmail]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "alertEmail", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}alertEmail."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}alertEmail...");
#endif
    [[self alertEmail] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}alertEmail...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}alertEmail."];
    }
  }
  if ([self schedule]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "schedule", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}schedule."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}schedule...");
#endif
    [[self schedule] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}schedule...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}schedule."];
    }
  }
  if ([self properties]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "properties", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start wrapper element {}properties."];
    }
    __enumerator = [[self properties] objectEnumerator];

    while ( (__item = [__enumerator nextObject]) ) {
      status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "scheduled-task-property", NULL);
      if (status < 0) {
        [NSException raise: @"XMLWriteError"
                     format: @"Error writing start child element {}scheduled-task-property."];
      }

#if DEBUG_ENUNCIATE > 1
      NSLog(@"writing element {}scheduled-task-property...");
#endif
      [__item writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
      NSLog(@"successfully wrote element {}scheduled-task-property...");
#endif

      status = xmlTextWriterEndElement(writer);
      if (status < 0) {
        [NSException raise: @"XMLWriteError"
                     format: @"Error writing end child element {}scheduled-task-property."];
      }
    } //end item iterator.

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end wrapper element {}properties."];
    }
  }
}
@end /* implementation NEXUS_REST_APINS0ScheduledServiceBaseResource (JAXB) */

#endif /* DEF_NEXUS_REST_APINS0ScheduledServiceBaseResource_M */
#ifndef DEF_NEXUS_REST_APINS0RemoteHttpProxySettings_M
#define DEF_NEXUS_REST_APINS0RemoteHttpProxySettings_M

/**
 *  The HTTP Proxy defines proxies used to access the internet.
 
 @version $Revision$ $Date$

 */
@implementation NEXUS_REST_APINS0RemoteHttpProxySettings

/**
 * The proxy hostname.
 */
- (NSString *) proxyHostname
{
  return _proxyHostname;
}

/**
 * The proxy hostname.
 */
- (void) setProxyHostname: (NSString *) newProxyHostname
{
  [newProxyHostname retain];
  [_proxyHostname release];
  _proxyHostname = newProxyHostname;
}

/**
 * The proxy port.
 */
- (int) proxyPort
{
  return _proxyPort;
}

/**
 * The proxy port.
 */
- (void) setProxyPort: (int) newProxyPort
{
  _proxyPort = newProxyPort;
}

/**
 * Authentication used to connect with proxy server.
 */
- (NEXUS_REST_APINS0AuthenticationSettings *) authentication
{
  return _authentication;
}

/**
 * Authentication used to connect with proxy server.
 */
- (void) setAuthentication: (NEXUS_REST_APINS0AuthenticationSettings *) newAuthentication
{
  [newAuthentication retain];
  [_authentication release];
  _authentication = newAuthentication;
}

/**
 * Field nonProxyHosts.
 */
- (NSArray *) nonProxyHosts
{
  return _nonProxyHosts;
}

/**
 * Field nonProxyHosts.
 */
- (void) setNonProxyHosts: (NSArray *) newNonProxyHosts
{
  [newNonProxyHosts retain];
  [_nonProxyHosts release];
  _nonProxyHosts = newNonProxyHosts;
}

- (void) dealloc
{
  [self setProxyHostname: nil];
  [self setAuthentication: nil];
  [self setNonProxyHosts: nil];
  [super dealloc];
}
@end /* implementation NEXUS_REST_APINS0RemoteHttpProxySettings */

/**
 * Internal, private interface for JAXB reading and writing.
 */
@interface NEXUS_REST_APINS0RemoteHttpProxySettings (JAXB) <JAXBReading, JAXBWriting, JAXBType>

@end /*interface NEXUS_REST_APINS0RemoteHttpProxySettings (JAXB)*/

/**
 * Internal, private implementation for JAXB reading and writing.
 */
@implementation NEXUS_REST_APINS0RemoteHttpProxySettings (JAXB)

/**
 * Read an instance of NEXUS_REST_APINS0RemoteHttpProxySettings from an XML reader.
 *
 * @param reader The reader.
 * @return An instance of NEXUS_REST_APINS0RemoteHttpProxySettings defined by the XML reader.
 */
+ (id<JAXBType>) readXMLType: (xmlTextReaderPtr) reader
{
  NEXUS_REST_APINS0RemoteHttpProxySettings *_nEXUS_REST_APINS0RemoteHttpProxySettings = [[NEXUS_REST_APINS0RemoteHttpProxySettings alloc] init];
  NS_DURING
  {
    [_nEXUS_REST_APINS0RemoteHttpProxySettings initWithReader: reader];
  }
  NS_HANDLER
  {
    [_nEXUS_REST_APINS0RemoteHttpProxySettings dealloc];
    _nEXUS_REST_APINS0RemoteHttpProxySettings = nil;
    [localException raise];
  }
  NS_ENDHANDLER

  [_nEXUS_REST_APINS0RemoteHttpProxySettings autorelease];
  return _nEXUS_REST_APINS0RemoteHttpProxySettings;
}

/**
 * Initialize this instance of NEXUS_REST_APINS0RemoteHttpProxySettings according to
 * the XML being read from the reader.
 *
 * @param reader The reader.
 */
- (id) initWithReader: (xmlTextReaderPtr) reader
{
  return [super initWithReader: reader];
}

/**
 * Write the XML for this instance of NEXUS_REST_APINS0RemoteHttpProxySettings to the writer.
 * Note that since we're only writing the XML type,
 * No start/end element will be written.
 *
 * @param reader The reader.
 */
- (void) writeXMLType: (xmlTextWriterPtr) writer
{
  [super writeXMLType:writer];
}

//documentation inherited.
- (BOOL) readJAXBAttribute: (xmlTextReaderPtr) reader
{
  void *_child_accessor;

  if ([super readJAXBAttribute: reader]) {
    return YES;
  }

  return NO;
}

//documentation inherited.
- (BOOL) readJAXBValue: (xmlTextReaderPtr) reader
{
  return [super readJAXBValue: reader];
}

//documentation inherited.
- (BOOL) readJAXBChildElement: (xmlTextReaderPtr) reader
{
  id __child;
  void *_child_accessor;
  int status, depth;

  if ([super readJAXBChildElement: reader]) {
    return YES;
  }
  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "proxyHostname", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}proxyHostname of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}proxyHostname of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setProxyHostname: __child];
    return YES;
  } //end "if choice"


  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "proxyPort", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

    _child_accessor = xmlTextReaderReadIntType(reader);
    if (_child_accessor == NULL) {
      //panic: unable to return the value for some reason.
      [self dealloc];
      [NSException raise: @"XMLReadError"
                   format: @"Error reading element value."];
    }
    [self setProxyPort: *((int*) _child_accessor)];
    free(_child_accessor);
    return YES;
  }
  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "authentication", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}authentication of type {}authentication-settings.");
#endif
    __child = [NEXUS_REST_APINS0AuthenticationSettings readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}authentication of type {}authentication-settings.");
#endif

    [self setAuthentication: __child];
    return YES;
  } //end "if choice"

  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "nonProxyHosts", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}nonProxyHosts of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}nonProxyHosts of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    if ([self nonProxyHosts]) {
      [self setNonProxyHosts: [[self nonProxyHosts] arrayByAddingObject: __child]];
    }
    else {
      [self setNonProxyHosts: [NSArray arrayWithObject: __child]];
    }
    return YES;
  } //end "if choice"


  return NO;
}

//documentation inherited.
- (int) readUnknownJAXBChildElement: (xmlTextReaderPtr) reader
{
  return [super readUnknownJAXBChildElement: reader];
}

//documentation inherited.
- (void) readUnknownJAXBAttribute: (xmlTextReaderPtr) reader
{
  [super readUnknownJAXBAttribute: reader];
}

//documentation inherited.
- (void) writeJAXBAttributes: (xmlTextWriterPtr) writer
{
  int status;

  [super writeJAXBAttributes: writer];

}

//documentation inherited.
- (void) writeJAXBValue: (xmlTextWriterPtr) writer
{
  [super writeJAXBValue: writer];
}

/**
 * Method for writing the child elements.
 *
 * @param writer The writer.
 */
- (void) writeJAXBChildElements: (xmlTextWriterPtr) writer
{
  int status;
  id __item;
  NSEnumerator *__enumerator;

  [super writeJAXBChildElements: writer];

  if ([self proxyHostname]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "proxyHostname", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}proxyHostname."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}proxyHostname...");
#endif
    [[self proxyHostname] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}proxyHostname...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}proxyHostname."];
    }
  }
  if (YES) { //always write the primitive element...
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "proxyPort", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}proxyPort."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}proxyPort...");
#endif
    status = xmlTextWriterWriteIntType(writer, &_proxyPort);
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}proxyPort...");
#endif
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing child element {}proxyPort."];
    }

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}proxyPort."];
    }
  }
  if ([self authentication]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "authentication", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}authentication."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}authentication...");
#endif
    [[self authentication] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}authentication...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}authentication."];
    }
  }
  if ([self nonProxyHosts]) {
    __enumerator = [[self nonProxyHosts] objectEnumerator];

    while ( (__item = [__enumerator nextObject]) ) {
      status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "nonProxyHosts", NULL);
      if (status < 0) {
        [NSException raise: @"XMLWriteError"
                     format: @"Error writing start child element {}nonProxyHosts."];
      }

#if DEBUG_ENUNCIATE > 1
      NSLog(@"writing element {}nonProxyHosts...");
#endif
      [__item writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
      NSLog(@"successfully wrote element {}nonProxyHosts...");
#endif

      status = xmlTextWriterEndElement(writer);
      if (status < 0) {
        [NSException raise: @"XMLWriteError"
                     format: @"Error writing end child element {}nonProxyHosts."];
      }
    } //end item iterator.
  }
}
@end /* implementation NEXUS_REST_APINS0RemoteHttpProxySettings (JAXB) */

#endif /* DEF_NEXUS_REST_APINS0RemoteHttpProxySettings_M */
#ifndef DEF_NEXUS_REST_APINS0PrivilegeResourceRequest_M
#define DEF_NEXUS_REST_APINS0PrivilegeResourceRequest_M

/**
 *  REST response object to persist a privilege.
 
 @version $Revision$ $Date$

 */
@implementation NEXUS_REST_APINS0PrivilegeResourceRequest

/**
 * Privilege details.
 */
- (NEXUS_REST_APINS0PrivilegeResource *) data
{
  return _data;
}

/**
 * Privilege details.
 */
- (void) setData: (NEXUS_REST_APINS0PrivilegeResource *) newData
{
  [newData retain];
  [_data release];
  _data = newData;
}

- (void) dealloc
{
  [self setData: nil];
  [super dealloc];
}

//documentation inherited.
+ (id<EnunciateXML>) readFromXML: (NSData *) xml
{
  NEXUS_REST_APINS0PrivilegeResourceRequest *_nEXUS_REST_APINS0PrivilegeResourceRequest;
  xmlTextReaderPtr reader = xmlReaderForMemory([xml bytes], [xml length], NULL, NULL, 0);
  if (reader == NULL) {
    [NSException raise: @"XMLReadError"
                 format: @"Error instantiating an XML reader."];
    return nil;
  }

  _nEXUS_REST_APINS0PrivilegeResourceRequest = (NEXUS_REST_APINS0PrivilegeResourceRequest *) [NEXUS_REST_APINS0PrivilegeResourceRequest readXMLElement: reader];
  xmlFreeTextReader(reader); //free the reader
  return _nEXUS_REST_APINS0PrivilegeResourceRequest;
}

//documentation inherited.
- (NSData *) writeToXML
{
  xmlBufferPtr buf;
  xmlTextWriterPtr writer;
  int rc;
  NSData *data;

  buf = xmlBufferCreate();
  if (buf == NULL) {
    [NSException raise: @"XMLWriteError"
                 format: @"Error creating an XML buffer."];
    return nil;
  }

  writer = xmlNewTextWriterMemory(buf, 0);
  if (writer == NULL) {
    xmlBufferFree(buf);
    [NSException raise: @"XMLWriteError"
                 format: @"Error creating an XML writer."];
    return nil;
  }

  rc = xmlTextWriterStartDocument(writer, NULL, "utf-8", NULL);
  if (rc < 0) {
    xmlFreeTextWriter(writer);
    xmlBufferFree(buf);
    [NSException raise: @"XMLWriteError"
                 format: @"Error writing XML start document."];
    return nil;
  }

  NS_DURING
  {
    [self writeXMLElement: writer];
  }
  NS_HANDLER
  {
    xmlFreeTextWriter(writer);
    xmlBufferFree(buf);
    [localException raise];
  }
  NS_ENDHANDLER

  rc = xmlTextWriterEndDocument(writer);
  if (rc < 0) {
    xmlFreeTextWriter(writer);
    xmlBufferFree(buf);
    [NSException raise: @"XMLWriteError"
                 format: @"Error writing XML end document."];
    return nil;
  }

  xmlFreeTextWriter(writer);
  data = [NSData dataWithBytes: buf->content length: buf->use];
  xmlBufferFree(buf);
  return data;
}
@end /* implementation NEXUS_REST_APINS0PrivilegeResourceRequest */

/**
 * Internal, private interface for JAXB reading and writing.
 */
@interface NEXUS_REST_APINS0PrivilegeResourceRequest (JAXB) <JAXBReading, JAXBWriting, JAXBType, JAXBElement>

@end /*interface NEXUS_REST_APINS0PrivilegeResourceRequest (JAXB)*/

/**
 * Internal, private implementation for JAXB reading and writing.
 */
@implementation NEXUS_REST_APINS0PrivilegeResourceRequest (JAXB)

/**
 * Read an instance of NEXUS_REST_APINS0PrivilegeResourceRequest from an XML reader.
 *
 * @param reader The reader.
 * @return An instance of NEXUS_REST_APINS0PrivilegeResourceRequest defined by the XML reader.
 */
+ (id<JAXBType>) readXMLType: (xmlTextReaderPtr) reader
{
  NEXUS_REST_APINS0PrivilegeResourceRequest *_nEXUS_REST_APINS0PrivilegeResourceRequest = [[NEXUS_REST_APINS0PrivilegeResourceRequest alloc] init];
  NS_DURING
  {
    [_nEXUS_REST_APINS0PrivilegeResourceRequest initWithReader: reader];
  }
  NS_HANDLER
  {
    [_nEXUS_REST_APINS0PrivilegeResourceRequest dealloc];
    _nEXUS_REST_APINS0PrivilegeResourceRequest = nil;
    [localException raise];
  }
  NS_ENDHANDLER

  [_nEXUS_REST_APINS0PrivilegeResourceRequest autorelease];
  return _nEXUS_REST_APINS0PrivilegeResourceRequest;
}

/**
 * Initialize this instance of NEXUS_REST_APINS0PrivilegeResourceRequest according to
 * the XML being read from the reader.
 *
 * @param reader The reader.
 */
- (id) initWithReader: (xmlTextReaderPtr) reader
{
  return [super initWithReader: reader];
}

/**
 * Write the XML for this instance of NEXUS_REST_APINS0PrivilegeResourceRequest to the writer.
 * Note that since we're only writing the XML type,
 * No start/end element will be written.
 *
 * @param reader The reader.
 */
- (void) writeXMLType: (xmlTextWriterPtr) writer
{
  [super writeXMLType:writer];
}

/**
 * Reads a NEXUS_REST_APINS0PrivilegeResourceRequest from an XML reader. The element to be read is
 * "privilege-request".
 *
 * @param reader The XML reader.
 * @return The NEXUS_REST_APINS0PrivilegeResourceRequest.
 */
+ (id<JAXBElement>) readXMLElement: (xmlTextReaderPtr) reader {
  int status;
  NEXUS_REST_APINS0PrivilegeResourceRequest *_privilegeResourceRequest = nil;

  if (xmlTextReaderNodeType(reader) != XML_READER_TYPE_ELEMENT) {
    status = xmlTextReaderAdvanceToNextStartOrEndElement(reader);
    if (status < 1) {
      [NSException raise: @"XMLReadError"
                   format: @"Error advancing the reader to start element privilege-request."];
    }
  }

  if (xmlStrcmp(BAD_CAST "privilege-request", xmlTextReaderConstLocalName(reader)) == 0
      && xmlTextReaderConstNamespaceUri(reader) == NULL) {
#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read root element {}privilege-request.");
#endif
    _privilegeResourceRequest = (NEXUS_REST_APINS0PrivilegeResourceRequest *)[NEXUS_REST_APINS0PrivilegeResourceRequest readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"Successfully read root element {}privilege-request.");
#endif
  }
  else {
    if (xmlTextReaderConstNamespaceUri(reader) == NULL) {
      [NSException raise: @"XMLReadError"
                   format: @"Unable to read NEXUS_REST_APINS0PrivilegeResourceRequest. Expected element privilege-request. Current element: {}%s", xmlTextReaderConstLocalName(reader)];
    }
    else {
      [NSException raise: @"XMLReadError"
                   format: @"Unable to read NEXUS_REST_APINS0PrivilegeResourceRequest. Expected element privilege-request. Current element: {%s}%s\n", xmlTextReaderConstNamespaceUri(reader), xmlTextReaderConstLocalName(reader)];
    }
  }

  return _privilegeResourceRequest;
}

/**
 * Writes this NEXUS_REST_APINS0PrivilegeResourceRequest to XML under element name "privilege-request".
 * The namespace declarations for the element will be written.
 *
 * @param writer The XML writer.
 * @param _privilegeResourceRequest The PrivilegeResourceRequest to write.
 * @return 1 if successful, 0 otherwise.
 */
- (void) writeXMLElement: (xmlTextWriterPtr) writer
{
  [self writeXMLElement: writer writeNamespaces: YES];
}

/**
 * Writes this NEXUS_REST_APINS0PrivilegeResourceRequest to an XML writer.
 *
 * @param writer The writer.
 * @param writeNs Whether to write the namespaces for this element to the xml writer.
 */
- (void) writeXMLElement: (xmlTextWriterPtr) writer writeNamespaces: (BOOL) writeNs
{
  int rc = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "privilege-request", NULL);
  if (rc < 0) {
    [NSException raise: @"XMLWriteError"
                 format: @"Error writing start element {}privilege-request. XML writer status: %i\n", rc];
  }

#if DEBUG_ENUNCIATE > 1
  NSLog(@"writing type {}privilegeResourceRequest for root element {}privilege-request...");
#endif
  [self writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
  NSLog(@"successfully wrote type {}privilegeResourceRequest for root element {}privilege-request...");
#endif
  rc = xmlTextWriterEndElement(writer);
  if (rc < 0) {
    [NSException raise: @"XMLWriteError"
                 format: @"Error writing end element {}privilege-request. XML writer status: %i\n", rc];
  }
}

//documentation inherited.
- (BOOL) readJAXBAttribute: (xmlTextReaderPtr) reader
{
  void *_child_accessor;

  if ([super readJAXBAttribute: reader]) {
    return YES;
  }

  return NO;
}

//documentation inherited.
- (BOOL) readJAXBValue: (xmlTextReaderPtr) reader
{
  return [super readJAXBValue: reader];
}

//documentation inherited.
- (BOOL) readJAXBChildElement: (xmlTextReaderPtr) reader
{
  id __child;
  void *_child_accessor;
  int status, depth;

  if ([super readJAXBChildElement: reader]) {
    return YES;
  }
  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "data", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}data of type {}privilege.");
#endif
    __child = [NEXUS_REST_APINS0PrivilegeResource readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}data of type {}privilege.");
#endif

    [self setData: __child];
    return YES;
  } //end "if choice"


  return NO;
}

//documentation inherited.
- (int) readUnknownJAXBChildElement: (xmlTextReaderPtr) reader
{
  return [super readUnknownJAXBChildElement: reader];
}

//documentation inherited.
- (void) readUnknownJAXBAttribute: (xmlTextReaderPtr) reader
{
  [super readUnknownJAXBAttribute: reader];
}

//documentation inherited.
- (void) writeJAXBAttributes: (xmlTextWriterPtr) writer
{
  int status;

  [super writeJAXBAttributes: writer];

}

//documentation inherited.
- (void) writeJAXBValue: (xmlTextWriterPtr) writer
{
  [super writeJAXBValue: writer];
}

/**
 * Method for writing the child elements.
 *
 * @param writer The writer.
 */
- (void) writeJAXBChildElements: (xmlTextWriterPtr) writer
{
  int status;
  id __item;
  NSEnumerator *__enumerator;

  [super writeJAXBChildElements: writer];

  if ([self data]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "data", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}data."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}data...");
#endif
    [[self data] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}data...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}data."];
    }
  }
}
@end /* implementation NEXUS_REST_APINS0PrivilegeResourceRequest (JAXB) */

#endif /* DEF_NEXUS_REST_APINS0PrivilegeResourceRequest_M */
#ifndef DEF_NEXUS_REST_APINS0PlexusComponentListResourceResponse_M
#define DEF_NEXUS_REST_APINS0PlexusComponentListResourceResponse_M

/**
 *  REST Response object for a list of plexus components, contains
 the typical 'data' parameter, which is the plexus components.
 
 @version $Revision$ $Date$

 */
@implementation NEXUS_REST_APINS0PlexusComponentListResourceResponse

/**
 * Field data.
 */
- (NSArray *) data
{
  return _data;
}

/**
 * Field data.
 */
- (void) setData: (NSArray *) newData
{
  [newData retain];
  [_data release];
  _data = newData;
}

- (void) dealloc
{
  [self setData: nil];
  [super dealloc];
}

//documentation inherited.
+ (id<EnunciateXML>) readFromXML: (NSData *) xml
{
  NEXUS_REST_APINS0PlexusComponentListResourceResponse *_nEXUS_REST_APINS0PlexusComponentListResourceResponse;
  xmlTextReaderPtr reader = xmlReaderForMemory([xml bytes], [xml length], NULL, NULL, 0);
  if (reader == NULL) {
    [NSException raise: @"XMLReadError"
                 format: @"Error instantiating an XML reader."];
    return nil;
  }

  _nEXUS_REST_APINS0PlexusComponentListResourceResponse = (NEXUS_REST_APINS0PlexusComponentListResourceResponse *) [NEXUS_REST_APINS0PlexusComponentListResourceResponse readXMLElement: reader];
  xmlFreeTextReader(reader); //free the reader
  return _nEXUS_REST_APINS0PlexusComponentListResourceResponse;
}

//documentation inherited.
- (NSData *) writeToXML
{
  xmlBufferPtr buf;
  xmlTextWriterPtr writer;
  int rc;
  NSData *data;

  buf = xmlBufferCreate();
  if (buf == NULL) {
    [NSException raise: @"XMLWriteError"
                 format: @"Error creating an XML buffer."];
    return nil;
  }

  writer = xmlNewTextWriterMemory(buf, 0);
  if (writer == NULL) {
    xmlBufferFree(buf);
    [NSException raise: @"XMLWriteError"
                 format: @"Error creating an XML writer."];
    return nil;
  }

  rc = xmlTextWriterStartDocument(writer, NULL, "utf-8", NULL);
  if (rc < 0) {
    xmlFreeTextWriter(writer);
    xmlBufferFree(buf);
    [NSException raise: @"XMLWriteError"
                 format: @"Error writing XML start document."];
    return nil;
  }

  NS_DURING
  {
    [self writeXMLElement: writer];
  }
  NS_HANDLER
  {
    xmlFreeTextWriter(writer);
    xmlBufferFree(buf);
    [localException raise];
  }
  NS_ENDHANDLER

  rc = xmlTextWriterEndDocument(writer);
  if (rc < 0) {
    xmlFreeTextWriter(writer);
    xmlBufferFree(buf);
    [NSException raise: @"XMLWriteError"
                 format: @"Error writing XML end document."];
    return nil;
  }

  xmlFreeTextWriter(writer);
  data = [NSData dataWithBytes: buf->content length: buf->use];
  xmlBufferFree(buf);
  return data;
}
@end /* implementation NEXUS_REST_APINS0PlexusComponentListResourceResponse */

/**
 * Internal, private interface for JAXB reading and writing.
 */
@interface NEXUS_REST_APINS0PlexusComponentListResourceResponse (JAXB) <JAXBReading, JAXBWriting, JAXBType, JAXBElement>

@end /*interface NEXUS_REST_APINS0PlexusComponentListResourceResponse (JAXB)*/

/**
 * Internal, private implementation for JAXB reading and writing.
 */
@implementation NEXUS_REST_APINS0PlexusComponentListResourceResponse (JAXB)

/**
 * Read an instance of NEXUS_REST_APINS0PlexusComponentListResourceResponse from an XML reader.
 *
 * @param reader The reader.
 * @return An instance of NEXUS_REST_APINS0PlexusComponentListResourceResponse defined by the XML reader.
 */
+ (id<JAXBType>) readXMLType: (xmlTextReaderPtr) reader
{
  NEXUS_REST_APINS0PlexusComponentListResourceResponse *_nEXUS_REST_APINS0PlexusComponentListResourceResponse = [[NEXUS_REST_APINS0PlexusComponentListResourceResponse alloc] init];
  NS_DURING
  {
    [_nEXUS_REST_APINS0PlexusComponentListResourceResponse initWithReader: reader];
  }
  NS_HANDLER
  {
    [_nEXUS_REST_APINS0PlexusComponentListResourceResponse dealloc];
    _nEXUS_REST_APINS0PlexusComponentListResourceResponse = nil;
    [localException raise];
  }
  NS_ENDHANDLER

  [_nEXUS_REST_APINS0PlexusComponentListResourceResponse autorelease];
  return _nEXUS_REST_APINS0PlexusComponentListResourceResponse;
}

/**
 * Initialize this instance of NEXUS_REST_APINS0PlexusComponentListResourceResponse according to
 * the XML being read from the reader.
 *
 * @param reader The reader.
 */
- (id) initWithReader: (xmlTextReaderPtr) reader
{
  return [super initWithReader: reader];
}

/**
 * Write the XML for this instance of NEXUS_REST_APINS0PlexusComponentListResourceResponse to the writer.
 * Note that since we're only writing the XML type,
 * No start/end element will be written.
 *
 * @param reader The reader.
 */
- (void) writeXMLType: (xmlTextWriterPtr) writer
{
  [super writeXMLType:writer];
}

/**
 * Reads a NEXUS_REST_APINS0PlexusComponentListResourceResponse from an XML reader. The element to be read is
 * "components-list".
 *
 * @param reader The XML reader.
 * @return The NEXUS_REST_APINS0PlexusComponentListResourceResponse.
 */
+ (id<JAXBElement>) readXMLElement: (xmlTextReaderPtr) reader {
  int status;
  NEXUS_REST_APINS0PlexusComponentListResourceResponse *_plexusComponentListResourceResponse = nil;

  if (xmlTextReaderNodeType(reader) != XML_READER_TYPE_ELEMENT) {
    status = xmlTextReaderAdvanceToNextStartOrEndElement(reader);
    if (status < 1) {
      [NSException raise: @"XMLReadError"
                   format: @"Error advancing the reader to start element components-list."];
    }
  }

  if (xmlStrcmp(BAD_CAST "components-list", xmlTextReaderConstLocalName(reader)) == 0
      && xmlTextReaderConstNamespaceUri(reader) == NULL) {
#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read root element {}components-list.");
#endif
    _plexusComponentListResourceResponse = (NEXUS_REST_APINS0PlexusComponentListResourceResponse *)[NEXUS_REST_APINS0PlexusComponentListResourceResponse readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"Successfully read root element {}components-list.");
#endif
  }
  else {
    if (xmlTextReaderConstNamespaceUri(reader) == NULL) {
      [NSException raise: @"XMLReadError"
                   format: @"Unable to read NEXUS_REST_APINS0PlexusComponentListResourceResponse. Expected element components-list. Current element: {}%s", xmlTextReaderConstLocalName(reader)];
    }
    else {
      [NSException raise: @"XMLReadError"
                   format: @"Unable to read NEXUS_REST_APINS0PlexusComponentListResourceResponse. Expected element components-list. Current element: {%s}%s\n", xmlTextReaderConstNamespaceUri(reader), xmlTextReaderConstLocalName(reader)];
    }
  }

  return _plexusComponentListResourceResponse;
}

/**
 * Writes this NEXUS_REST_APINS0PlexusComponentListResourceResponse to XML under element name "components-list".
 * The namespace declarations for the element will be written.
 *
 * @param writer The XML writer.
 * @param _plexusComponentListResourceResponse The PlexusComponentListResourceResponse to write.
 * @return 1 if successful, 0 otherwise.
 */
- (void) writeXMLElement: (xmlTextWriterPtr) writer
{
  [self writeXMLElement: writer writeNamespaces: YES];
}

/**
 * Writes this NEXUS_REST_APINS0PlexusComponentListResourceResponse to an XML writer.
 *
 * @param writer The writer.
 * @param writeNs Whether to write the namespaces for this element to the xml writer.
 */
- (void) writeXMLElement: (xmlTextWriterPtr) writer writeNamespaces: (BOOL) writeNs
{
  int rc = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "components-list", NULL);
  if (rc < 0) {
    [NSException raise: @"XMLWriteError"
                 format: @"Error writing start element {}components-list. XML writer status: %i\n", rc];
  }

#if DEBUG_ENUNCIATE > 1
  NSLog(@"writing type {}plexusComponentListResourceResponse for root element {}components-list...");
#endif
  [self writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
  NSLog(@"successfully wrote type {}plexusComponentListResourceResponse for root element {}components-list...");
#endif
  rc = xmlTextWriterEndElement(writer);
  if (rc < 0) {
    [NSException raise: @"XMLWriteError"
                 format: @"Error writing end element {}components-list. XML writer status: %i\n", rc];
  }
}

//documentation inherited.
- (BOOL) readJAXBAttribute: (xmlTextReaderPtr) reader
{
  void *_child_accessor;

  if ([super readJAXBAttribute: reader]) {
    return YES;
  }

  return NO;
}

//documentation inherited.
- (BOOL) readJAXBValue: (xmlTextReaderPtr) reader
{
  return [super readJAXBValue: reader];
}

//documentation inherited.
- (BOOL) readJAXBChildElement: (xmlTextReaderPtr) reader
{
  id __child;
  void *_child_accessor;
  int status, depth;

  if ([super readJAXBChildElement: reader]) {
    return YES;
  }
  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "data", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

    if (xmlTextReaderIsEmptyElement(reader) == 0) {
#if DEBUG_ENUNCIATE > 1
      NSLog(@"Unwrapping wrapper element {}data...");
#endif
      //start wrapper element "{}data"
      depth = xmlTextReaderDepth(reader);
      status = xmlTextReaderAdvanceToNextStartOrEndElement(reader);
      while (xmlTextReaderDepth(reader) > depth) {
        if (status < 1) {
          //panic: XML read error.
          [self dealloc];
          [NSException raise: @"XMLReadError"
                       format: @"Failure to advance to next wrapped child element."];
        }
  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "component", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}component of type {}plexus-component-list-resource.");
#endif

    __child = [NEXUS_REST_APINS0PlexusComponentListResource readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}component of type {}plexus-component-list-resource.");
#endif

    if ([self data]) {
      [self setData: [[self data] arrayByAddingObject: __child]];
    }
    else {
      [self setData: [NSArray arrayWithObject: __child]];
    }
    continue; //continue "while in wrapper element" loop
  } //end "if choice"

        status = xmlTextReaderAdvanceToNextStartOrEndElement(reader);
#if DEBUG_ENUNCIATE > 1
        NSLog(@"successfully unwrapped wrapper element {}data...");
#endif
      } // end "while in wrapper element" loop

      if (status < 1) {
        //panic: XML read error.
        [self dealloc];
        [NSException raise: @"XMLReadError"
                     format: @"Failure to advance to end wrapper element."];
      }
      else {
        //end wrapper element "{}data"
        status = xmlTextReaderAdvanceToNextStartOrEndElement(reader);
      }
    } //end "if empty element" clause
    else {
      __child = [NSArray array];
      [self setData: (NSArray*) __child];
    }

    return YES;
  } // end "if wrapper element" clause

  return NO;
}

//documentation inherited.
- (int) readUnknownJAXBChildElement: (xmlTextReaderPtr) reader
{
  return [super readUnknownJAXBChildElement: reader];
}

//documentation inherited.
- (void) readUnknownJAXBAttribute: (xmlTextReaderPtr) reader
{
  [super readUnknownJAXBAttribute: reader];
}

//documentation inherited.
- (void) writeJAXBAttributes: (xmlTextWriterPtr) writer
{
  int status;

  [super writeJAXBAttributes: writer];

}

//documentation inherited.
- (void) writeJAXBValue: (xmlTextWriterPtr) writer
{
  [super writeJAXBValue: writer];
}

/**
 * Method for writing the child elements.
 *
 * @param writer The writer.
 */
- (void) writeJAXBChildElements: (xmlTextWriterPtr) writer
{
  int status;
  id __item;
  NSEnumerator *__enumerator;

  [super writeJAXBChildElements: writer];

  if ([self data]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "data", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start wrapper element {}data."];
    }
    __enumerator = [[self data] objectEnumerator];

    while ( (__item = [__enumerator nextObject]) ) {
      status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "component", NULL);
      if (status < 0) {
        [NSException raise: @"XMLWriteError"
                     format: @"Error writing start child element {}component."];
      }

#if DEBUG_ENUNCIATE > 1
      NSLog(@"writing element {}component...");
#endif
      [__item writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
      NSLog(@"successfully wrote element {}component...");
#endif

      status = xmlTextWriterEndElement(writer);
      if (status < 0) {
        [NSException raise: @"XMLWriteError"
                     format: @"Error writing end child element {}component."];
      }
    } //end item iterator.

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end wrapper element {}data."];
    }
  }
}
@end /* implementation NEXUS_REST_APINS0PlexusComponentListResourceResponse (JAXB) */

#endif /* DEF_NEXUS_REST_APINS0PlexusComponentListResourceResponse_M */
#ifndef DEF_NEXUS_REST_APINS0NexusResponse_M
#define DEF_NEXUS_REST_APINS0NexusResponse_M

/**
 *  Class NexusResponse.
 
 @version $Revision$ $Date$

 */
@implementation NEXUS_REST_APINS0NexusResponse

- (void) dealloc
{
  [super dealloc];
}
@end /* implementation NEXUS_REST_APINS0NexusResponse */

/**
 * Internal, private interface for JAXB reading and writing.
 */
@interface NEXUS_REST_APINS0NexusResponse (JAXB) <JAXBReading, JAXBWriting, JAXBType>

@end /*interface NEXUS_REST_APINS0NexusResponse (JAXB)*/

/**
 * Internal, private implementation for JAXB reading and writing.
 */
@implementation NEXUS_REST_APINS0NexusResponse (JAXB)

/**
 * Read an instance of NEXUS_REST_APINS0NexusResponse from an XML reader.
 *
 * @param reader The reader.
 * @return An instance of NEXUS_REST_APINS0NexusResponse defined by the XML reader.
 */
+ (id<JAXBType>) readXMLType: (xmlTextReaderPtr) reader
{
  NEXUS_REST_APINS0NexusResponse *_nEXUS_REST_APINS0NexusResponse = [[NEXUS_REST_APINS0NexusResponse alloc] init];
  NS_DURING
  {
    [_nEXUS_REST_APINS0NexusResponse initWithReader: reader];
  }
  NS_HANDLER
  {
    [_nEXUS_REST_APINS0NexusResponse dealloc];
    _nEXUS_REST_APINS0NexusResponse = nil;
    [localException raise];
  }
  NS_ENDHANDLER

  [_nEXUS_REST_APINS0NexusResponse autorelease];
  return _nEXUS_REST_APINS0NexusResponse;
}

/**
 * Initialize this instance of NEXUS_REST_APINS0NexusResponse according to
 * the XML being read from the reader.
 *
 * @param reader The reader.
 */
- (id) initWithReader: (xmlTextReaderPtr) reader
{
  return [super initWithReader: reader];
}

/**
 * Write the XML for this instance of NEXUS_REST_APINS0NexusResponse to the writer.
 * Note that since we're only writing the XML type,
 * No start/end element will be written.
 *
 * @param reader The reader.
 */
- (void) writeXMLType: (xmlTextWriterPtr) writer
{
  [super writeXMLType:writer];
}

//documentation inherited.
- (BOOL) readJAXBAttribute: (xmlTextReaderPtr) reader
{
  void *_child_accessor;

  if ([super readJAXBAttribute: reader]) {
    return YES;
  }

  return NO;
}

//documentation inherited.
- (BOOL) readJAXBValue: (xmlTextReaderPtr) reader
{
  return [super readJAXBValue: reader];
}

//documentation inherited.
- (BOOL) readJAXBChildElement: (xmlTextReaderPtr) reader
{
  id __child;
  void *_child_accessor;
  int status, depth;

  if ([super readJAXBChildElement: reader]) {
    return YES;
  }

  return NO;
}

//documentation inherited.
- (int) readUnknownJAXBChildElement: (xmlTextReaderPtr) reader
{
  return [super readUnknownJAXBChildElement: reader];
}

//documentation inherited.
- (void) readUnknownJAXBAttribute: (xmlTextReaderPtr) reader
{
  [super readUnknownJAXBAttribute: reader];
}

//documentation inherited.
- (void) writeJAXBAttributes: (xmlTextWriterPtr) writer
{
  int status;

  [super writeJAXBAttributes: writer];

}

//documentation inherited.
- (void) writeJAXBValue: (xmlTextWriterPtr) writer
{
  [super writeJAXBValue: writer];
}

/**
 * Method for writing the child elements.
 *
 * @param writer The writer.
 */
- (void) writeJAXBChildElements: (xmlTextWriterPtr) writer
{
  int status;
  id __item;
  NSEnumerator *__enumerator;

  [super writeJAXBChildElements: writer];

}
@end /* implementation NEXUS_REST_APINS0NexusResponse (JAXB) */

#endif /* DEF_NEXUS_REST_APINS0NexusResponse_M */
#ifndef DEF_NEXUS_REST_APINS0NexusRepositoryTypeListResource_M
#define DEF_NEXUS_REST_APINS0NexusRepositoryTypeListResource_M

/**
 *  Repository type definition.
 
 @version $Revision$ $Date$

 */
@implementation NEXUS_REST_APINS0NexusRepositoryTypeListResource

/**
 * The repository provider.
 */
- (NSString *) provider
{
  return _provider;
}

/**
 * The repository provider.
 */
- (void) setProvider: (NSString *) newProvider
{
  [newProvider retain];
  [_provider release];
  _provider = newProvider;
}

/**
 * The repository provider role.
 */
- (NSString *) providerRole
{
  return _providerRole;
}

/**
 * The repository provider role.
 */
- (void) setProviderRole: (NSString *) newProviderRole
{
  [newProviderRole retain];
  [_providerRole release];
  _providerRole = newProviderRole;
}

/**
 * The repository format.
 */
- (NSString *) format
{
  return _format;
}

/**
 * The repository format.
 */
- (void) setFormat: (NSString *) newFormat
{
  [newFormat retain];
  [_format release];
  _format = newFormat;
}

/**
 * The repository type description.
 */
- (NSString *) description
{
  return _description;
}

/**
 * The repository type description.
 */
- (void) setDescription: (NSString *) newDescription
{
  [newDescription retain];
  [_description release];
  _description = newDescription;
}

- (void) dealloc
{
  [self setProvider: nil];
  [self setProviderRole: nil];
  [self setFormat: nil];
  [self setDescription: nil];
  [super dealloc];
}
@end /* implementation NEXUS_REST_APINS0NexusRepositoryTypeListResource */

/**
 * Internal, private interface for JAXB reading and writing.
 */
@interface NEXUS_REST_APINS0NexusRepositoryTypeListResource (JAXB) <JAXBReading, JAXBWriting, JAXBType>

@end /*interface NEXUS_REST_APINS0NexusRepositoryTypeListResource (JAXB)*/

/**
 * Internal, private implementation for JAXB reading and writing.
 */
@implementation NEXUS_REST_APINS0NexusRepositoryTypeListResource (JAXB)

/**
 * Read an instance of NEXUS_REST_APINS0NexusRepositoryTypeListResource from an XML reader.
 *
 * @param reader The reader.
 * @return An instance of NEXUS_REST_APINS0NexusRepositoryTypeListResource defined by the XML reader.
 */
+ (id<JAXBType>) readXMLType: (xmlTextReaderPtr) reader
{
  NEXUS_REST_APINS0NexusRepositoryTypeListResource *_nEXUS_REST_APINS0NexusRepositoryTypeListResource = [[NEXUS_REST_APINS0NexusRepositoryTypeListResource alloc] init];
  NS_DURING
  {
    [_nEXUS_REST_APINS0NexusRepositoryTypeListResource initWithReader: reader];
  }
  NS_HANDLER
  {
    [_nEXUS_REST_APINS0NexusRepositoryTypeListResource dealloc];
    _nEXUS_REST_APINS0NexusRepositoryTypeListResource = nil;
    [localException raise];
  }
  NS_ENDHANDLER

  [_nEXUS_REST_APINS0NexusRepositoryTypeListResource autorelease];
  return _nEXUS_REST_APINS0NexusRepositoryTypeListResource;
}

/**
 * Initialize this instance of NEXUS_REST_APINS0NexusRepositoryTypeListResource according to
 * the XML being read from the reader.
 *
 * @param reader The reader.
 */
- (id) initWithReader: (xmlTextReaderPtr) reader
{
  return [super initWithReader: reader];
}

/**
 * Write the XML for this instance of NEXUS_REST_APINS0NexusRepositoryTypeListResource to the writer.
 * Note that since we're only writing the XML type,
 * No start/end element will be written.
 *
 * @param reader The reader.
 */
- (void) writeXMLType: (xmlTextWriterPtr) writer
{
  [super writeXMLType:writer];
}

//documentation inherited.
- (BOOL) readJAXBAttribute: (xmlTextReaderPtr) reader
{
  void *_child_accessor;

  if ([super readJAXBAttribute: reader]) {
    return YES;
  }

  return NO;
}

//documentation inherited.
- (BOOL) readJAXBValue: (xmlTextReaderPtr) reader
{
  return [super readJAXBValue: reader];
}

//documentation inherited.
- (BOOL) readJAXBChildElement: (xmlTextReaderPtr) reader
{
  id __child;
  void *_child_accessor;
  int status, depth;

  if ([super readJAXBChildElement: reader]) {
    return YES;
  }
  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "provider", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}provider of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}provider of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setProvider: __child];
    return YES;
  } //end "if choice"

  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "providerRole", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}providerRole of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}providerRole of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setProviderRole: __child];
    return YES;
  } //end "if choice"

  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "format", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}format of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}format of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setFormat: __child];
    return YES;
  } //end "if choice"

  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "description", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}description of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}description of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setDescription: __child];
    return YES;
  } //end "if choice"


  return NO;
}

//documentation inherited.
- (int) readUnknownJAXBChildElement: (xmlTextReaderPtr) reader
{
  return [super readUnknownJAXBChildElement: reader];
}

//documentation inherited.
- (void) readUnknownJAXBAttribute: (xmlTextReaderPtr) reader
{
  [super readUnknownJAXBAttribute: reader];
}

//documentation inherited.
- (void) writeJAXBAttributes: (xmlTextWriterPtr) writer
{
  int status;

  [super writeJAXBAttributes: writer];

}

//documentation inherited.
- (void) writeJAXBValue: (xmlTextWriterPtr) writer
{
  [super writeJAXBValue: writer];
}

/**
 * Method for writing the child elements.
 *
 * @param writer The writer.
 */
- (void) writeJAXBChildElements: (xmlTextWriterPtr) writer
{
  int status;
  id __item;
  NSEnumerator *__enumerator;

  [super writeJAXBChildElements: writer];

  if ([self provider]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "provider", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}provider."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}provider...");
#endif
    [[self provider] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}provider...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}provider."];
    }
  }
  if ([self providerRole]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "providerRole", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}providerRole."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}providerRole...");
#endif
    [[self providerRole] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}providerRole...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}providerRole."];
    }
  }
  if ([self format]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "format", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}format."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}format...");
#endif
    [[self format] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}format...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}format."];
    }
  }
  if ([self description]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "description", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}description."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}description...");
#endif
    [[self description] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}description...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}description."];
    }
  }
}
@end /* implementation NEXUS_REST_APINS0NexusRepositoryTypeListResource (JAXB) */

#endif /* DEF_NEXUS_REST_APINS0NexusRepositoryTypeListResource_M */
#ifndef DEF_NEXUS_REST_APINS0ErrorReportingSettings_M
#define DEF_NEXUS_REST_APINS0ErrorReportingSettings_M

/**
 *  Connection parameters to allow Nexus to report errors to the
 Sonatype JIRA server.
 
 @version $Revision$ $Date$

 */
@implementation NEXUS_REST_APINS0ErrorReportingSettings

/**
 * Username of a valid jira account (if empty will use the
default error reporting username).
 */
- (NSString *) jiraUsername
{
  return _jiraUsername;
}

/**
 * Username of a valid jira account (if empty will use the
default error reporting username).
 */
- (void) setJiraUsername: (NSString *) newJiraUsername
{
  [newJiraUsername retain];
  [_jiraUsername release];
  _jiraUsername = newJiraUsername;
}

/**
 * Password of a valid jira account (if empty will use the
default error reporting password).
 */
- (NSString *) jiraPassword
{
  return _jiraPassword;
}

/**
 * Password of a valid jira account (if empty will use the
default error reporting password).
 */
- (void) setJiraPassword: (NSString *) newJiraPassword
{
  [newJiraPassword retain];
  [_jiraPassword release];
  _jiraPassword = newJiraPassword;
}

/**
 * Flag that states whether to use the global proxy
configuration in Nexus.
 */
- (BOOL) useGlobalProxy
{
  return _useGlobalProxy;
}

/**
 * Flag that states whether to use the global proxy
configuration in Nexus.
 */
- (void) setUseGlobalProxy: (BOOL) newUseGlobalProxy
{
  _useGlobalProxy = newUseGlobalProxy;
}

/**
 * Flag if Nexus should automatically report any problem found.
 */
- (BOOL) reportErrorsAutomatically
{
  return _reportErrorsAutomatically;
}

/**
 * Flag if Nexus should automatically report any problem found.
 */
- (void) setReportErrorsAutomatically: (BOOL) newReportErrorsAutomatically
{
  _reportErrorsAutomatically = newReportErrorsAutomatically;
}

- (void) dealloc
{
  [self setJiraUsername: nil];
  [self setJiraPassword: nil];
  [super dealloc];
}
@end /* implementation NEXUS_REST_APINS0ErrorReportingSettings */

/**
 * Internal, private interface for JAXB reading and writing.
 */
@interface NEXUS_REST_APINS0ErrorReportingSettings (JAXB) <JAXBReading, JAXBWriting, JAXBType>

@end /*interface NEXUS_REST_APINS0ErrorReportingSettings (JAXB)*/

/**
 * Internal, private implementation for JAXB reading and writing.
 */
@implementation NEXUS_REST_APINS0ErrorReportingSettings (JAXB)

/**
 * Read an instance of NEXUS_REST_APINS0ErrorReportingSettings from an XML reader.
 *
 * @param reader The reader.
 * @return An instance of NEXUS_REST_APINS0ErrorReportingSettings defined by the XML reader.
 */
+ (id<JAXBType>) readXMLType: (xmlTextReaderPtr) reader
{
  NEXUS_REST_APINS0ErrorReportingSettings *_nEXUS_REST_APINS0ErrorReportingSettings = [[NEXUS_REST_APINS0ErrorReportingSettings alloc] init];
  NS_DURING
  {
    [_nEXUS_REST_APINS0ErrorReportingSettings initWithReader: reader];
  }
  NS_HANDLER
  {
    [_nEXUS_REST_APINS0ErrorReportingSettings dealloc];
    _nEXUS_REST_APINS0ErrorReportingSettings = nil;
    [localException raise];
  }
  NS_ENDHANDLER

  [_nEXUS_REST_APINS0ErrorReportingSettings autorelease];
  return _nEXUS_REST_APINS0ErrorReportingSettings;
}

/**
 * Initialize this instance of NEXUS_REST_APINS0ErrorReportingSettings according to
 * the XML being read from the reader.
 *
 * @param reader The reader.
 */
- (id) initWithReader: (xmlTextReaderPtr) reader
{
  return [super initWithReader: reader];
}

/**
 * Write the XML for this instance of NEXUS_REST_APINS0ErrorReportingSettings to the writer.
 * Note that since we're only writing the XML type,
 * No start/end element will be written.
 *
 * @param reader The reader.
 */
- (void) writeXMLType: (xmlTextWriterPtr) writer
{
  [super writeXMLType:writer];
}

//documentation inherited.
- (BOOL) readJAXBAttribute: (xmlTextReaderPtr) reader
{
  void *_child_accessor;

  if ([super readJAXBAttribute: reader]) {
    return YES;
  }

  return NO;
}

//documentation inherited.
- (BOOL) readJAXBValue: (xmlTextReaderPtr) reader
{
  return [super readJAXBValue: reader];
}

//documentation inherited.
- (BOOL) readJAXBChildElement: (xmlTextReaderPtr) reader
{
  id __child;
  void *_child_accessor;
  int status, depth;

  if ([super readJAXBChildElement: reader]) {
    return YES;
  }
  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "jiraUsername", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}jiraUsername of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}jiraUsername of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setJiraUsername: __child];
    return YES;
  } //end "if choice"

  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "jiraPassword", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}jiraPassword of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}jiraPassword of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setJiraPassword: __child];
    return YES;
  } //end "if choice"


  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "useGlobalProxy", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

    _child_accessor = xmlTextReaderReadBooleanType(reader);
    if (_child_accessor == NULL) {
      //panic: unable to return the value for some reason.
      [self dealloc];
      [NSException raise: @"XMLReadError"
                   format: @"Error reading element value."];
    }
    [self setUseGlobalProxy: *((BOOL*) _child_accessor)];
    free(_child_accessor);
    return YES;
  }

  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "reportErrorsAutomatically", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

    _child_accessor = xmlTextReaderReadBooleanType(reader);
    if (_child_accessor == NULL) {
      //panic: unable to return the value for some reason.
      [self dealloc];
      [NSException raise: @"XMLReadError"
                   format: @"Error reading element value."];
    }
    [self setReportErrorsAutomatically: *((BOOL*) _child_accessor)];
    free(_child_accessor);
    return YES;
  }

  return NO;
}

//documentation inherited.
- (int) readUnknownJAXBChildElement: (xmlTextReaderPtr) reader
{
  return [super readUnknownJAXBChildElement: reader];
}

//documentation inherited.
- (void) readUnknownJAXBAttribute: (xmlTextReaderPtr) reader
{
  [super readUnknownJAXBAttribute: reader];
}

//documentation inherited.
- (void) writeJAXBAttributes: (xmlTextWriterPtr) writer
{
  int status;

  [super writeJAXBAttributes: writer];

}

//documentation inherited.
- (void) writeJAXBValue: (xmlTextWriterPtr) writer
{
  [super writeJAXBValue: writer];
}

/**
 * Method for writing the child elements.
 *
 * @param writer The writer.
 */
- (void) writeJAXBChildElements: (xmlTextWriterPtr) writer
{
  int status;
  id __item;
  NSEnumerator *__enumerator;

  [super writeJAXBChildElements: writer];

  if ([self jiraUsername]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "jiraUsername", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}jiraUsername."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}jiraUsername...");
#endif
    [[self jiraUsername] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}jiraUsername...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}jiraUsername."];
    }
  }
  if ([self jiraPassword]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "jiraPassword", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}jiraPassword."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}jiraPassword...");
#endif
    [[self jiraPassword] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}jiraPassword...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}jiraPassword."];
    }
  }
  if (YES) { //always write the primitive element...
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "useGlobalProxy", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}useGlobalProxy."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}useGlobalProxy...");
#endif
    status = xmlTextWriterWriteBooleanType(writer, &_useGlobalProxy);
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}useGlobalProxy...");
#endif
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing child element {}useGlobalProxy."];
    }

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}useGlobalProxy."];
    }
  }
  if (YES) { //always write the primitive element...
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "reportErrorsAutomatically", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}reportErrorsAutomatically."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}reportErrorsAutomatically...");
#endif
    status = xmlTextWriterWriteBooleanType(writer, &_reportErrorsAutomatically);
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}reportErrorsAutomatically...");
#endif
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing child element {}reportErrorsAutomatically."];
    }

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}reportErrorsAutomatically."];
    }
  }
}
@end /* implementation NEXUS_REST_APINS0ErrorReportingSettings (JAXB) */

#endif /* DEF_NEXUS_REST_APINS0ErrorReportingSettings_M */
#ifndef DEF_NEXUS_REST_APINS0ErrorReportResponse_M
#define DEF_NEXUS_REST_APINS0ErrorReportResponse_M

/**
 *  REST Response object received after generating an error report,
 contains the typical 'data' parameter, which is the error report
 response item.
 
 @version $Revision$ $Date$

 */
@implementation NEXUS_REST_APINS0ErrorReportResponse

/**
 * The error report response object.
 */
- (NEXUS_REST_APINS0ErrorReportResponseDTO *) data
{
  return _data;
}

/**
 * The error report response object.
 */
- (void) setData: (NEXUS_REST_APINS0ErrorReportResponseDTO *) newData
{
  [newData retain];
  [_data release];
  _data = newData;
}

- (void) dealloc
{
  [self setData: nil];
  [super dealloc];
}

//documentation inherited.
+ (id<EnunciateXML>) readFromXML: (NSData *) xml
{
  NEXUS_REST_APINS0ErrorReportResponse *_nEXUS_REST_APINS0ErrorReportResponse;
  xmlTextReaderPtr reader = xmlReaderForMemory([xml bytes], [xml length], NULL, NULL, 0);
  if (reader == NULL) {
    [NSException raise: @"XMLReadError"
                 format: @"Error instantiating an XML reader."];
    return nil;
  }

  _nEXUS_REST_APINS0ErrorReportResponse = (NEXUS_REST_APINS0ErrorReportResponse *) [NEXUS_REST_APINS0ErrorReportResponse readXMLElement: reader];
  xmlFreeTextReader(reader); //free the reader
  return _nEXUS_REST_APINS0ErrorReportResponse;
}

//documentation inherited.
- (NSData *) writeToXML
{
  xmlBufferPtr buf;
  xmlTextWriterPtr writer;
  int rc;
  NSData *data;

  buf = xmlBufferCreate();
  if (buf == NULL) {
    [NSException raise: @"XMLWriteError"
                 format: @"Error creating an XML buffer."];
    return nil;
  }

  writer = xmlNewTextWriterMemory(buf, 0);
  if (writer == NULL) {
    xmlBufferFree(buf);
    [NSException raise: @"XMLWriteError"
                 format: @"Error creating an XML writer."];
    return nil;
  }

  rc = xmlTextWriterStartDocument(writer, NULL, "utf-8", NULL);
  if (rc < 0) {
    xmlFreeTextWriter(writer);
    xmlBufferFree(buf);
    [NSException raise: @"XMLWriteError"
                 format: @"Error writing XML start document."];
    return nil;
  }

  NS_DURING
  {
    [self writeXMLElement: writer];
  }
  NS_HANDLER
  {
    xmlFreeTextWriter(writer);
    xmlBufferFree(buf);
    [localException raise];
  }
  NS_ENDHANDLER

  rc = xmlTextWriterEndDocument(writer);
  if (rc < 0) {
    xmlFreeTextWriter(writer);
    xmlBufferFree(buf);
    [NSException raise: @"XMLWriteError"
                 format: @"Error writing XML end document."];
    return nil;
  }

  xmlFreeTextWriter(writer);
  data = [NSData dataWithBytes: buf->content length: buf->use];
  xmlBufferFree(buf);
  return data;
}
@end /* implementation NEXUS_REST_APINS0ErrorReportResponse */

/**
 * Internal, private interface for JAXB reading and writing.
 */
@interface NEXUS_REST_APINS0ErrorReportResponse (JAXB) <JAXBReading, JAXBWriting, JAXBType, JAXBElement>

@end /*interface NEXUS_REST_APINS0ErrorReportResponse (JAXB)*/

/**
 * Internal, private implementation for JAXB reading and writing.
 */
@implementation NEXUS_REST_APINS0ErrorReportResponse (JAXB)

/**
 * Read an instance of NEXUS_REST_APINS0ErrorReportResponse from an XML reader.
 *
 * @param reader The reader.
 * @return An instance of NEXUS_REST_APINS0ErrorReportResponse defined by the XML reader.
 */
+ (id<JAXBType>) readXMLType: (xmlTextReaderPtr) reader
{
  NEXUS_REST_APINS0ErrorReportResponse *_nEXUS_REST_APINS0ErrorReportResponse = [[NEXUS_REST_APINS0ErrorReportResponse alloc] init];
  NS_DURING
  {
    [_nEXUS_REST_APINS0ErrorReportResponse initWithReader: reader];
  }
  NS_HANDLER
  {
    [_nEXUS_REST_APINS0ErrorReportResponse dealloc];
    _nEXUS_REST_APINS0ErrorReportResponse = nil;
    [localException raise];
  }
  NS_ENDHANDLER

  [_nEXUS_REST_APINS0ErrorReportResponse autorelease];
  return _nEXUS_REST_APINS0ErrorReportResponse;
}

/**
 * Initialize this instance of NEXUS_REST_APINS0ErrorReportResponse according to
 * the XML being read from the reader.
 *
 * @param reader The reader.
 */
- (id) initWithReader: (xmlTextReaderPtr) reader
{
  return [super initWithReader: reader];
}

/**
 * Write the XML for this instance of NEXUS_REST_APINS0ErrorReportResponse to the writer.
 * Note that since we're only writing the XML type,
 * No start/end element will be written.
 *
 * @param reader The reader.
 */
- (void) writeXMLType: (xmlTextWriterPtr) writer
{
  [super writeXMLType:writer];
}

/**
 * Reads a NEXUS_REST_APINS0ErrorReportResponse from an XML reader. The element to be read is
 * "error-report-response".
 *
 * @param reader The XML reader.
 * @return The NEXUS_REST_APINS0ErrorReportResponse.
 */
+ (id<JAXBElement>) readXMLElement: (xmlTextReaderPtr) reader {
  int status;
  NEXUS_REST_APINS0ErrorReportResponse *_errorReportResponse = nil;

  if (xmlTextReaderNodeType(reader) != XML_READER_TYPE_ELEMENT) {
    status = xmlTextReaderAdvanceToNextStartOrEndElement(reader);
    if (status < 1) {
      [NSException raise: @"XMLReadError"
                   format: @"Error advancing the reader to start element error-report-response."];
    }
  }

  if (xmlStrcmp(BAD_CAST "error-report-response", xmlTextReaderConstLocalName(reader)) == 0
      && xmlTextReaderConstNamespaceUri(reader) == NULL) {
#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read root element {}error-report-response.");
#endif
    _errorReportResponse = (NEXUS_REST_APINS0ErrorReportResponse *)[NEXUS_REST_APINS0ErrorReportResponse readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"Successfully read root element {}error-report-response.");
#endif
  }
  else {
    if (xmlTextReaderConstNamespaceUri(reader) == NULL) {
      [NSException raise: @"XMLReadError"
                   format: @"Unable to read NEXUS_REST_APINS0ErrorReportResponse. Expected element error-report-response. Current element: {}%s", xmlTextReaderConstLocalName(reader)];
    }
    else {
      [NSException raise: @"XMLReadError"
                   format: @"Unable to read NEXUS_REST_APINS0ErrorReportResponse. Expected element error-report-response. Current element: {%s}%s\n", xmlTextReaderConstNamespaceUri(reader), xmlTextReaderConstLocalName(reader)];
    }
  }

  return _errorReportResponse;
}

/**
 * Writes this NEXUS_REST_APINS0ErrorReportResponse to XML under element name "error-report-response".
 * The namespace declarations for the element will be written.
 *
 * @param writer The XML writer.
 * @param _errorReportResponse The ErrorReportResponse to write.
 * @return 1 if successful, 0 otherwise.
 */
- (void) writeXMLElement: (xmlTextWriterPtr) writer
{
  [self writeXMLElement: writer writeNamespaces: YES];
}

/**
 * Writes this NEXUS_REST_APINS0ErrorReportResponse to an XML writer.
 *
 * @param writer The writer.
 * @param writeNs Whether to write the namespaces for this element to the xml writer.
 */
- (void) writeXMLElement: (xmlTextWriterPtr) writer writeNamespaces: (BOOL) writeNs
{
  int rc = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "error-report-response", NULL);
  if (rc < 0) {
    [NSException raise: @"XMLWriteError"
                 format: @"Error writing start element {}error-report-response. XML writer status: %i\n", rc];
  }

#if DEBUG_ENUNCIATE > 1
  NSLog(@"writing type {}errorReportResponse for root element {}error-report-response...");
#endif
  [self writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
  NSLog(@"successfully wrote type {}errorReportResponse for root element {}error-report-response...");
#endif
  rc = xmlTextWriterEndElement(writer);
  if (rc < 0) {
    [NSException raise: @"XMLWriteError"
                 format: @"Error writing end element {}error-report-response. XML writer status: %i\n", rc];
  }
}

//documentation inherited.
- (BOOL) readJAXBAttribute: (xmlTextReaderPtr) reader
{
  void *_child_accessor;

  if ([super readJAXBAttribute: reader]) {
    return YES;
  }

  return NO;
}

//documentation inherited.
- (BOOL) readJAXBValue: (xmlTextReaderPtr) reader
{
  return [super readJAXBValue: reader];
}

//documentation inherited.
- (BOOL) readJAXBChildElement: (xmlTextReaderPtr) reader
{
  id __child;
  void *_child_accessor;
  int status, depth;

  if ([super readJAXBChildElement: reader]) {
    return YES;
  }
  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "data", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}data of type {}error-report-response-dto.");
#endif
    __child = [NEXUS_REST_APINS0ErrorReportResponseDTO readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}data of type {}error-report-response-dto.");
#endif

    [self setData: __child];
    return YES;
  } //end "if choice"


  return NO;
}

//documentation inherited.
- (int) readUnknownJAXBChildElement: (xmlTextReaderPtr) reader
{
  return [super readUnknownJAXBChildElement: reader];
}

//documentation inherited.
- (void) readUnknownJAXBAttribute: (xmlTextReaderPtr) reader
{
  [super readUnknownJAXBAttribute: reader];
}

//documentation inherited.
- (void) writeJAXBAttributes: (xmlTextWriterPtr) writer
{
  int status;

  [super writeJAXBAttributes: writer];

}

//documentation inherited.
- (void) writeJAXBValue: (xmlTextWriterPtr) writer
{
  [super writeJAXBValue: writer];
}

/**
 * Method for writing the child elements.
 *
 * @param writer The writer.
 */
- (void) writeJAXBChildElements: (xmlTextWriterPtr) writer
{
  int status;
  id __item;
  NSEnumerator *__enumerator;

  [super writeJAXBChildElements: writer];

  if ([self data]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "data", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}data."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}data...");
#endif
    [[self data] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}data...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}data."];
    }
  }
}
@end /* implementation NEXUS_REST_APINS0ErrorReportResponse (JAXB) */

#endif /* DEF_NEXUS_REST_APINS0ErrorReportResponse_M */
#ifndef DEF_NEXUS_REST_APINS0ErrorReportRequest_M
#define DEF_NEXUS_REST_APINS0ErrorReportRequest_M

/**
 *  REST Request object for generating an error report, contains the
 typical 'data' parameter, which is an error report item.
 
 @version $Revision$ $Date$

 */
@implementation NEXUS_REST_APINS0ErrorReportRequest

/**
 * The error report object.
 */
- (NEXUS_REST_APINS0ErrorReportRequestDTO *) data
{
  return _data;
}

/**
 * The error report object.
 */
- (void) setData: (NEXUS_REST_APINS0ErrorReportRequestDTO *) newData
{
  [newData retain];
  [_data release];
  _data = newData;
}

- (void) dealloc
{
  [self setData: nil];
  [super dealloc];
}

//documentation inherited.
+ (id<EnunciateXML>) readFromXML: (NSData *) xml
{
  NEXUS_REST_APINS0ErrorReportRequest *_nEXUS_REST_APINS0ErrorReportRequest;
  xmlTextReaderPtr reader = xmlReaderForMemory([xml bytes], [xml length], NULL, NULL, 0);
  if (reader == NULL) {
    [NSException raise: @"XMLReadError"
                 format: @"Error instantiating an XML reader."];
    return nil;
  }

  _nEXUS_REST_APINS0ErrorReportRequest = (NEXUS_REST_APINS0ErrorReportRequest *) [NEXUS_REST_APINS0ErrorReportRequest readXMLElement: reader];
  xmlFreeTextReader(reader); //free the reader
  return _nEXUS_REST_APINS0ErrorReportRequest;
}

//documentation inherited.
- (NSData *) writeToXML
{
  xmlBufferPtr buf;
  xmlTextWriterPtr writer;
  int rc;
  NSData *data;

  buf = xmlBufferCreate();
  if (buf == NULL) {
    [NSException raise: @"XMLWriteError"
                 format: @"Error creating an XML buffer."];
    return nil;
  }

  writer = xmlNewTextWriterMemory(buf, 0);
  if (writer == NULL) {
    xmlBufferFree(buf);
    [NSException raise: @"XMLWriteError"
                 format: @"Error creating an XML writer."];
    return nil;
  }

  rc = xmlTextWriterStartDocument(writer, NULL, "utf-8", NULL);
  if (rc < 0) {
    xmlFreeTextWriter(writer);
    xmlBufferFree(buf);
    [NSException raise: @"XMLWriteError"
                 format: @"Error writing XML start document."];
    return nil;
  }

  NS_DURING
  {
    [self writeXMLElement: writer];
  }
  NS_HANDLER
  {
    xmlFreeTextWriter(writer);
    xmlBufferFree(buf);
    [localException raise];
  }
  NS_ENDHANDLER

  rc = xmlTextWriterEndDocument(writer);
  if (rc < 0) {
    xmlFreeTextWriter(writer);
    xmlBufferFree(buf);
    [NSException raise: @"XMLWriteError"
                 format: @"Error writing XML end document."];
    return nil;
  }

  xmlFreeTextWriter(writer);
  data = [NSData dataWithBytes: buf->content length: buf->use];
  xmlBufferFree(buf);
  return data;
}
@end /* implementation NEXUS_REST_APINS0ErrorReportRequest */

/**
 * Internal, private interface for JAXB reading and writing.
 */
@interface NEXUS_REST_APINS0ErrorReportRequest (JAXB) <JAXBReading, JAXBWriting, JAXBType, JAXBElement>

@end /*interface NEXUS_REST_APINS0ErrorReportRequest (JAXB)*/

/**
 * Internal, private implementation for JAXB reading and writing.
 */
@implementation NEXUS_REST_APINS0ErrorReportRequest (JAXB)

/**
 * Read an instance of NEXUS_REST_APINS0ErrorReportRequest from an XML reader.
 *
 * @param reader The reader.
 * @return An instance of NEXUS_REST_APINS0ErrorReportRequest defined by the XML reader.
 */
+ (id<JAXBType>) readXMLType: (xmlTextReaderPtr) reader
{
  NEXUS_REST_APINS0ErrorReportRequest *_nEXUS_REST_APINS0ErrorReportRequest = [[NEXUS_REST_APINS0ErrorReportRequest alloc] init];
  NS_DURING
  {
    [_nEXUS_REST_APINS0ErrorReportRequest initWithReader: reader];
  }
  NS_HANDLER
  {
    [_nEXUS_REST_APINS0ErrorReportRequest dealloc];
    _nEXUS_REST_APINS0ErrorReportRequest = nil;
    [localException raise];
  }
  NS_ENDHANDLER

  [_nEXUS_REST_APINS0ErrorReportRequest autorelease];
  return _nEXUS_REST_APINS0ErrorReportRequest;
}

/**
 * Initialize this instance of NEXUS_REST_APINS0ErrorReportRequest according to
 * the XML being read from the reader.
 *
 * @param reader The reader.
 */
- (id) initWithReader: (xmlTextReaderPtr) reader
{
  return [super initWithReader: reader];
}

/**
 * Write the XML for this instance of NEXUS_REST_APINS0ErrorReportRequest to the writer.
 * Note that since we're only writing the XML type,
 * No start/end element will be written.
 *
 * @param reader The reader.
 */
- (void) writeXMLType: (xmlTextWriterPtr) writer
{
  [super writeXMLType:writer];
}

/**
 * Reads a NEXUS_REST_APINS0ErrorReportRequest from an XML reader. The element to be read is
 * "error-report-request".
 *
 * @param reader The XML reader.
 * @return The NEXUS_REST_APINS0ErrorReportRequest.
 */
+ (id<JAXBElement>) readXMLElement: (xmlTextReaderPtr) reader {
  int status;
  NEXUS_REST_APINS0ErrorReportRequest *_errorReportRequest = nil;

  if (xmlTextReaderNodeType(reader) != XML_READER_TYPE_ELEMENT) {
    status = xmlTextReaderAdvanceToNextStartOrEndElement(reader);
    if (status < 1) {
      [NSException raise: @"XMLReadError"
                   format: @"Error advancing the reader to start element error-report-request."];
    }
  }

  if (xmlStrcmp(BAD_CAST "error-report-request", xmlTextReaderConstLocalName(reader)) == 0
      && xmlTextReaderConstNamespaceUri(reader) == NULL) {
#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read root element {}error-report-request.");
#endif
    _errorReportRequest = (NEXUS_REST_APINS0ErrorReportRequest *)[NEXUS_REST_APINS0ErrorReportRequest readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"Successfully read root element {}error-report-request.");
#endif
  }
  else {
    if (xmlTextReaderConstNamespaceUri(reader) == NULL) {
      [NSException raise: @"XMLReadError"
                   format: @"Unable to read NEXUS_REST_APINS0ErrorReportRequest. Expected element error-report-request. Current element: {}%s", xmlTextReaderConstLocalName(reader)];
    }
    else {
      [NSException raise: @"XMLReadError"
                   format: @"Unable to read NEXUS_REST_APINS0ErrorReportRequest. Expected element error-report-request. Current element: {%s}%s\n", xmlTextReaderConstNamespaceUri(reader), xmlTextReaderConstLocalName(reader)];
    }
  }

  return _errorReportRequest;
}

/**
 * Writes this NEXUS_REST_APINS0ErrorReportRequest to XML under element name "error-report-request".
 * The namespace declarations for the element will be written.
 *
 * @param writer The XML writer.
 * @param _errorReportRequest The ErrorReportRequest to write.
 * @return 1 if successful, 0 otherwise.
 */
- (void) writeXMLElement: (xmlTextWriterPtr) writer
{
  [self writeXMLElement: writer writeNamespaces: YES];
}

/**
 * Writes this NEXUS_REST_APINS0ErrorReportRequest to an XML writer.
 *
 * @param writer The writer.
 * @param writeNs Whether to write the namespaces for this element to the xml writer.
 */
- (void) writeXMLElement: (xmlTextWriterPtr) writer writeNamespaces: (BOOL) writeNs
{
  int rc = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "error-report-request", NULL);
  if (rc < 0) {
    [NSException raise: @"XMLWriteError"
                 format: @"Error writing start element {}error-report-request. XML writer status: %i\n", rc];
  }

#if DEBUG_ENUNCIATE > 1
  NSLog(@"writing type {}errorReportRequest for root element {}error-report-request...");
#endif
  [self writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
  NSLog(@"successfully wrote type {}errorReportRequest for root element {}error-report-request...");
#endif
  rc = xmlTextWriterEndElement(writer);
  if (rc < 0) {
    [NSException raise: @"XMLWriteError"
                 format: @"Error writing end element {}error-report-request. XML writer status: %i\n", rc];
  }
}

//documentation inherited.
- (BOOL) readJAXBAttribute: (xmlTextReaderPtr) reader
{
  void *_child_accessor;

  if ([super readJAXBAttribute: reader]) {
    return YES;
  }

  return NO;
}

//documentation inherited.
- (BOOL) readJAXBValue: (xmlTextReaderPtr) reader
{
  return [super readJAXBValue: reader];
}

//documentation inherited.
- (BOOL) readJAXBChildElement: (xmlTextReaderPtr) reader
{
  id __child;
  void *_child_accessor;
  int status, depth;

  if ([super readJAXBChildElement: reader]) {
    return YES;
  }
  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "data", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}data of type {}error-report-request-dto.");
#endif
    __child = [NEXUS_REST_APINS0ErrorReportRequestDTO readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}data of type {}error-report-request-dto.");
#endif

    [self setData: __child];
    return YES;
  } //end "if choice"


  return NO;
}

//documentation inherited.
- (int) readUnknownJAXBChildElement: (xmlTextReaderPtr) reader
{
  return [super readUnknownJAXBChildElement: reader];
}

//documentation inherited.
- (void) readUnknownJAXBAttribute: (xmlTextReaderPtr) reader
{
  [super readUnknownJAXBAttribute: reader];
}

//documentation inherited.
- (void) writeJAXBAttributes: (xmlTextWriterPtr) writer
{
  int status;

  [super writeJAXBAttributes: writer];

}

//documentation inherited.
- (void) writeJAXBValue: (xmlTextWriterPtr) writer
{
  [super writeJAXBValue: writer];
}

/**
 * Method for writing the child elements.
 *
 * @param writer The writer.
 */
- (void) writeJAXBChildElements: (xmlTextWriterPtr) writer
{
  int status;
  id __item;
  NSEnumerator *__enumerator;

  [super writeJAXBChildElements: writer];

  if ([self data]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "data", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}data."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}data...");
#endif
    [[self data] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}data...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}data."];
    }
  }
}
@end /* implementation NEXUS_REST_APINS0ErrorReportRequest (JAXB) */

#endif /* DEF_NEXUS_REST_APINS0ErrorReportRequest_M */
#ifndef DEF_NEXUS_REST_APINS0ContentListDescribeRequestResource_M
#define DEF_NEXUS_REST_APINS0ContentListDescribeRequestResource_M

/**
 *  A set of request parameters that were used to retrieve the item.
 
 @version $Revision$ $Date$

 */
@implementation NEXUS_REST_APINS0ContentListDescribeRequestResource

/**
 * The request url that initially generated this request.
 */
- (NSString *) requestUrl
{
  return _requestUrl;
}

/**
 * The request url that initially generated this request.
 */
- (void) setRequestUrl: (NSString *) newRequestUrl
{
  [newRequestUrl retain];
  [_requestUrl release];
  _requestUrl = newRequestUrl;
}

/**
 * The path on the server that was requested.
 */
- (NSString *) requestPath
{
  return _requestPath;
}

/**
 * The path on the server that was requested.
 */
- (void) setRequestPath: (NSString *) newRequestPath
{
  [newRequestPath retain];
  [_requestPath release];
  _requestPath = newRequestPath;
}

/**
 * Field requestContext.
 */
- (NSArray *) requestContext
{
  return _requestContext;
}

/**
 * Field requestContext.
 */
- (void) setRequestContext: (NSArray *) newRequestContext
{
  [newRequestContext retain];
  [_requestContext release];
  _requestContext = newRequestContext;
}

- (void) dealloc
{
  [self setRequestUrl: nil];
  [self setRequestPath: nil];
  [self setRequestContext: nil];
  [super dealloc];
}
@end /* implementation NEXUS_REST_APINS0ContentListDescribeRequestResource */

/**
 * Internal, private interface for JAXB reading and writing.
 */
@interface NEXUS_REST_APINS0ContentListDescribeRequestResource (JAXB) <JAXBReading, JAXBWriting, JAXBType>

@end /*interface NEXUS_REST_APINS0ContentListDescribeRequestResource (JAXB)*/

/**
 * Internal, private implementation for JAXB reading and writing.
 */
@implementation NEXUS_REST_APINS0ContentListDescribeRequestResource (JAXB)

/**
 * Read an instance of NEXUS_REST_APINS0ContentListDescribeRequestResource from an XML reader.
 *
 * @param reader The reader.
 * @return An instance of NEXUS_REST_APINS0ContentListDescribeRequestResource defined by the XML reader.
 */
+ (id<JAXBType>) readXMLType: (xmlTextReaderPtr) reader
{
  NEXUS_REST_APINS0ContentListDescribeRequestResource *_nEXUS_REST_APINS0ContentListDescribeRequestResource = [[NEXUS_REST_APINS0ContentListDescribeRequestResource alloc] init];
  NS_DURING
  {
    [_nEXUS_REST_APINS0ContentListDescribeRequestResource initWithReader: reader];
  }
  NS_HANDLER
  {
    [_nEXUS_REST_APINS0ContentListDescribeRequestResource dealloc];
    _nEXUS_REST_APINS0ContentListDescribeRequestResource = nil;
    [localException raise];
  }
  NS_ENDHANDLER

  [_nEXUS_REST_APINS0ContentListDescribeRequestResource autorelease];
  return _nEXUS_REST_APINS0ContentListDescribeRequestResource;
}

/**
 * Initialize this instance of NEXUS_REST_APINS0ContentListDescribeRequestResource according to
 * the XML being read from the reader.
 *
 * @param reader The reader.
 */
- (id) initWithReader: (xmlTextReaderPtr) reader
{
  return [super initWithReader: reader];
}

/**
 * Write the XML for this instance of NEXUS_REST_APINS0ContentListDescribeRequestResource to the writer.
 * Note that since we're only writing the XML type,
 * No start/end element will be written.
 *
 * @param reader The reader.
 */
- (void) writeXMLType: (xmlTextWriterPtr) writer
{
  [super writeXMLType:writer];
}

//documentation inherited.
- (BOOL) readJAXBAttribute: (xmlTextReaderPtr) reader
{
  void *_child_accessor;

  if ([super readJAXBAttribute: reader]) {
    return YES;
  }

  return NO;
}

//documentation inherited.
- (BOOL) readJAXBValue: (xmlTextReaderPtr) reader
{
  return [super readJAXBValue: reader];
}

//documentation inherited.
- (BOOL) readJAXBChildElement: (xmlTextReaderPtr) reader
{
  id __child;
  void *_child_accessor;
  int status, depth;

  if ([super readJAXBChildElement: reader]) {
    return YES;
  }
  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "requestUrl", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}requestUrl of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}requestUrl of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setRequestUrl: __child];
    return YES;
  } //end "if choice"

  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "requestPath", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}requestPath of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}requestPath of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setRequestPath: __child];
    return YES;
  } //end "if choice"

  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "requestContext", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

    if (xmlTextReaderIsEmptyElement(reader) == 0) {
#if DEBUG_ENUNCIATE > 1
      NSLog(@"Unwrapping wrapper element {}requestContext...");
#endif
      //start wrapper element "{}requestContext"
      depth = xmlTextReaderDepth(reader);
      status = xmlTextReaderAdvanceToNextStartOrEndElement(reader);
      while (xmlTextReaderDepth(reader) > depth) {
        if (status < 1) {
          //panic: XML read error.
          [self dealloc];
          [NSException raise: @"XMLReadError"
                       format: @"Failure to advance to next wrapped child element."];
        }
  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "requestContextItem", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}requestContextItem of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}requestContextItem of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    if ([self requestContext]) {
      [self setRequestContext: [[self requestContext] arrayByAddingObject: __child]];
    }
    else {
      [self setRequestContext: [NSArray arrayWithObject: __child]];
    }
    continue; //continue "while in wrapper element" loop
  } //end "if choice"

        status = xmlTextReaderAdvanceToNextStartOrEndElement(reader);
#if DEBUG_ENUNCIATE > 1
        NSLog(@"successfully unwrapped wrapper element {}requestContext...");
#endif
      } // end "while in wrapper element" loop

      if (status < 1) {
        //panic: XML read error.
        [self dealloc];
        [NSException raise: @"XMLReadError"
                     format: @"Failure to advance to end wrapper element."];
      }
      else {
        //end wrapper element "{}requestContext"
        status = xmlTextReaderAdvanceToNextStartOrEndElement(reader);
      }
    } //end "if empty element" clause
    else {
      __child = [NSArray array];
      [self setRequestContext: (NSArray*) __child];
    }

    return YES;
  } // end "if wrapper element" clause

  return NO;
}

//documentation inherited.
- (int) readUnknownJAXBChildElement: (xmlTextReaderPtr) reader
{
  return [super readUnknownJAXBChildElement: reader];
}

//documentation inherited.
- (void) readUnknownJAXBAttribute: (xmlTextReaderPtr) reader
{
  [super readUnknownJAXBAttribute: reader];
}

//documentation inherited.
- (void) writeJAXBAttributes: (xmlTextWriterPtr) writer
{
  int status;

  [super writeJAXBAttributes: writer];

}

//documentation inherited.
- (void) writeJAXBValue: (xmlTextWriterPtr) writer
{
  [super writeJAXBValue: writer];
}

/**
 * Method for writing the child elements.
 *
 * @param writer The writer.
 */
- (void) writeJAXBChildElements: (xmlTextWriterPtr) writer
{
  int status;
  id __item;
  NSEnumerator *__enumerator;

  [super writeJAXBChildElements: writer];

  if ([self requestUrl]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "requestUrl", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}requestUrl."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}requestUrl...");
#endif
    [[self requestUrl] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}requestUrl...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}requestUrl."];
    }
  }
  if ([self requestPath]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "requestPath", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}requestPath."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}requestPath...");
#endif
    [[self requestPath] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}requestPath...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}requestPath."];
    }
  }
  if ([self requestContext]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "requestContext", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start wrapper element {}requestContext."];
    }
    __enumerator = [[self requestContext] objectEnumerator];

    while ( (__item = [__enumerator nextObject]) ) {
      status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "requestContextItem", NULL);
      if (status < 0) {
        [NSException raise: @"XMLWriteError"
                     format: @"Error writing start child element {}requestContextItem."];
      }

#if DEBUG_ENUNCIATE > 1
      NSLog(@"writing element {}requestContextItem...");
#endif
      [__item writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
      NSLog(@"successfully wrote element {}requestContextItem...");
#endif

      status = xmlTextWriterEndElement(writer);
      if (status < 0) {
        [NSException raise: @"XMLWriteError"
                     format: @"Error writing end child element {}requestContextItem."];
      }
    } //end item iterator.

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end wrapper element {}requestContext."];
    }
  }
}
@end /* implementation NEXUS_REST_APINS0ContentListDescribeRequestResource (JAXB) */

#endif /* DEF_NEXUS_REST_APINS0ContentListDescribeRequestResource_M */
#ifndef DEF_NEXUS_REST_APINS0ArtifactResolveResourceResponse_M
#define DEF_NEXUS_REST_APINS0ArtifactResolveResourceResponse_M

/**
 *  REST Response object received after requesting an artifact
 resolve, contains the typical 'data' parameter, which is the
 artifact resolve details.
 
 @version $Revision$ $Date$

 */
@implementation NEXUS_REST_APINS0ArtifactResolveResourceResponse

/**
 * The artifact details requested.
 */
- (NEXUS_REST_APINS0ArtifactResolveResource *) data
{
  return _data;
}

/**
 * The artifact details requested.
 */
- (void) setData: (NEXUS_REST_APINS0ArtifactResolveResource *) newData
{
  [newData retain];
  [_data release];
  _data = newData;
}

- (void) dealloc
{
  [self setData: nil];
  [super dealloc];
}

//documentation inherited.
+ (id<EnunciateXML>) readFromXML: (NSData *) xml
{
  NEXUS_REST_APINS0ArtifactResolveResourceResponse *_nEXUS_REST_APINS0ArtifactResolveResourceResponse;
  xmlTextReaderPtr reader = xmlReaderForMemory([xml bytes], [xml length], NULL, NULL, 0);
  if (reader == NULL) {
    [NSException raise: @"XMLReadError"
                 format: @"Error instantiating an XML reader."];
    return nil;
  }

  _nEXUS_REST_APINS0ArtifactResolveResourceResponse = (NEXUS_REST_APINS0ArtifactResolveResourceResponse *) [NEXUS_REST_APINS0ArtifactResolveResourceResponse readXMLElement: reader];
  xmlFreeTextReader(reader); //free the reader
  return _nEXUS_REST_APINS0ArtifactResolveResourceResponse;
}

//documentation inherited.
- (NSData *) writeToXML
{
  xmlBufferPtr buf;
  xmlTextWriterPtr writer;
  int rc;
  NSData *data;

  buf = xmlBufferCreate();
  if (buf == NULL) {
    [NSException raise: @"XMLWriteError"
                 format: @"Error creating an XML buffer."];
    return nil;
  }

  writer = xmlNewTextWriterMemory(buf, 0);
  if (writer == NULL) {
    xmlBufferFree(buf);
    [NSException raise: @"XMLWriteError"
                 format: @"Error creating an XML writer."];
    return nil;
  }

  rc = xmlTextWriterStartDocument(writer, NULL, "utf-8", NULL);
  if (rc < 0) {
    xmlFreeTextWriter(writer);
    xmlBufferFree(buf);
    [NSException raise: @"XMLWriteError"
                 format: @"Error writing XML start document."];
    return nil;
  }

  NS_DURING
  {
    [self writeXMLElement: writer];
  }
  NS_HANDLER
  {
    xmlFreeTextWriter(writer);
    xmlBufferFree(buf);
    [localException raise];
  }
  NS_ENDHANDLER

  rc = xmlTextWriterEndDocument(writer);
  if (rc < 0) {
    xmlFreeTextWriter(writer);
    xmlBufferFree(buf);
    [NSException raise: @"XMLWriteError"
                 format: @"Error writing XML end document."];
    return nil;
  }

  xmlFreeTextWriter(writer);
  data = [NSData dataWithBytes: buf->content length: buf->use];
  xmlBufferFree(buf);
  return data;
}
@end /* implementation NEXUS_REST_APINS0ArtifactResolveResourceResponse */

/**
 * Internal, private interface for JAXB reading and writing.
 */
@interface NEXUS_REST_APINS0ArtifactResolveResourceResponse (JAXB) <JAXBReading, JAXBWriting, JAXBType, JAXBElement>

@end /*interface NEXUS_REST_APINS0ArtifactResolveResourceResponse (JAXB)*/

/**
 * Internal, private implementation for JAXB reading and writing.
 */
@implementation NEXUS_REST_APINS0ArtifactResolveResourceResponse (JAXB)

/**
 * Read an instance of NEXUS_REST_APINS0ArtifactResolveResourceResponse from an XML reader.
 *
 * @param reader The reader.
 * @return An instance of NEXUS_REST_APINS0ArtifactResolveResourceResponse defined by the XML reader.
 */
+ (id<JAXBType>) readXMLType: (xmlTextReaderPtr) reader
{
  NEXUS_REST_APINS0ArtifactResolveResourceResponse *_nEXUS_REST_APINS0ArtifactResolveResourceResponse = [[NEXUS_REST_APINS0ArtifactResolveResourceResponse alloc] init];
  NS_DURING
  {
    [_nEXUS_REST_APINS0ArtifactResolveResourceResponse initWithReader: reader];
  }
  NS_HANDLER
  {
    [_nEXUS_REST_APINS0ArtifactResolveResourceResponse dealloc];
    _nEXUS_REST_APINS0ArtifactResolveResourceResponse = nil;
    [localException raise];
  }
  NS_ENDHANDLER

  [_nEXUS_REST_APINS0ArtifactResolveResourceResponse autorelease];
  return _nEXUS_REST_APINS0ArtifactResolveResourceResponse;
}

/**
 * Initialize this instance of NEXUS_REST_APINS0ArtifactResolveResourceResponse according to
 * the XML being read from the reader.
 *
 * @param reader The reader.
 */
- (id) initWithReader: (xmlTextReaderPtr) reader
{
  return [super initWithReader: reader];
}

/**
 * Write the XML for this instance of NEXUS_REST_APINS0ArtifactResolveResourceResponse to the writer.
 * Note that since we're only writing the XML type,
 * No start/end element will be written.
 *
 * @param reader The reader.
 */
- (void) writeXMLType: (xmlTextWriterPtr) writer
{
  [super writeXMLType:writer];
}

/**
 * Reads a NEXUS_REST_APINS0ArtifactResolveResourceResponse from an XML reader. The element to be read is
 * "artifact-resolution".
 *
 * @param reader The XML reader.
 * @return The NEXUS_REST_APINS0ArtifactResolveResourceResponse.
 */
+ (id<JAXBElement>) readXMLElement: (xmlTextReaderPtr) reader {
  int status;
  NEXUS_REST_APINS0ArtifactResolveResourceResponse *_artifactResolveResourceResponse = nil;

  if (xmlTextReaderNodeType(reader) != XML_READER_TYPE_ELEMENT) {
    status = xmlTextReaderAdvanceToNextStartOrEndElement(reader);
    if (status < 1) {
      [NSException raise: @"XMLReadError"
                   format: @"Error advancing the reader to start element artifact-resolution."];
    }
  }

  if (xmlStrcmp(BAD_CAST "artifact-resolution", xmlTextReaderConstLocalName(reader)) == 0
      && xmlTextReaderConstNamespaceUri(reader) == NULL) {
#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read root element {}artifact-resolution.");
#endif
    _artifactResolveResourceResponse = (NEXUS_REST_APINS0ArtifactResolveResourceResponse *)[NEXUS_REST_APINS0ArtifactResolveResourceResponse readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"Successfully read root element {}artifact-resolution.");
#endif
  }
  else {
    if (xmlTextReaderConstNamespaceUri(reader) == NULL) {
      [NSException raise: @"XMLReadError"
                   format: @"Unable to read NEXUS_REST_APINS0ArtifactResolveResourceResponse. Expected element artifact-resolution. Current element: {}%s", xmlTextReaderConstLocalName(reader)];
    }
    else {
      [NSException raise: @"XMLReadError"
                   format: @"Unable to read NEXUS_REST_APINS0ArtifactResolveResourceResponse. Expected element artifact-resolution. Current element: {%s}%s\n", xmlTextReaderConstNamespaceUri(reader), xmlTextReaderConstLocalName(reader)];
    }
  }

  return _artifactResolveResourceResponse;
}

/**
 * Writes this NEXUS_REST_APINS0ArtifactResolveResourceResponse to XML under element name "artifact-resolution".
 * The namespace declarations for the element will be written.
 *
 * @param writer The XML writer.
 * @param _artifactResolveResourceResponse The ArtifactResolveResourceResponse to write.
 * @return 1 if successful, 0 otherwise.
 */
- (void) writeXMLElement: (xmlTextWriterPtr) writer
{
  [self writeXMLElement: writer writeNamespaces: YES];
}

/**
 * Writes this NEXUS_REST_APINS0ArtifactResolveResourceResponse to an XML writer.
 *
 * @param writer The writer.
 * @param writeNs Whether to write the namespaces for this element to the xml writer.
 */
- (void) writeXMLElement: (xmlTextWriterPtr) writer writeNamespaces: (BOOL) writeNs
{
  int rc = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "artifact-resolution", NULL);
  if (rc < 0) {
    [NSException raise: @"XMLWriteError"
                 format: @"Error writing start element {}artifact-resolution. XML writer status: %i\n", rc];
  }

#if DEBUG_ENUNCIATE > 1
  NSLog(@"writing type {}artifactResolveResourceResponse for root element {}artifact-resolution...");
#endif
  [self writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
  NSLog(@"successfully wrote type {}artifactResolveResourceResponse for root element {}artifact-resolution...");
#endif
  rc = xmlTextWriterEndElement(writer);
  if (rc < 0) {
    [NSException raise: @"XMLWriteError"
                 format: @"Error writing end element {}artifact-resolution. XML writer status: %i\n", rc];
  }
}

//documentation inherited.
- (BOOL) readJAXBAttribute: (xmlTextReaderPtr) reader
{
  void *_child_accessor;

  if ([super readJAXBAttribute: reader]) {
    return YES;
  }

  return NO;
}

//documentation inherited.
- (BOOL) readJAXBValue: (xmlTextReaderPtr) reader
{
  return [super readJAXBValue: reader];
}

//documentation inherited.
- (BOOL) readJAXBChildElement: (xmlTextReaderPtr) reader
{
  id __child;
  void *_child_accessor;
  int status, depth;

  if ([super readJAXBChildElement: reader]) {
    return YES;
  }
  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "data", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}data of type {}artifact-resolve-resource.");
#endif
    __child = [NEXUS_REST_APINS0ArtifactResolveResource readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}data of type {}artifact-resolve-resource.");
#endif

    [self setData: __child];
    return YES;
  } //end "if choice"


  return NO;
}

//documentation inherited.
- (int) readUnknownJAXBChildElement: (xmlTextReaderPtr) reader
{
  return [super readUnknownJAXBChildElement: reader];
}

//documentation inherited.
- (void) readUnknownJAXBAttribute: (xmlTextReaderPtr) reader
{
  [super readUnknownJAXBAttribute: reader];
}

//documentation inherited.
- (void) writeJAXBAttributes: (xmlTextWriterPtr) writer
{
  int status;

  [super writeJAXBAttributes: writer];

}

//documentation inherited.
- (void) writeJAXBValue: (xmlTextWriterPtr) writer
{
  [super writeJAXBValue: writer];
}

/**
 * Method for writing the child elements.
 *
 * @param writer The writer.
 */
- (void) writeJAXBChildElements: (xmlTextWriterPtr) writer
{
  int status;
  id __item;
  NSEnumerator *__enumerator;

  [super writeJAXBChildElements: writer];

  if ([self data]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "data", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}data."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}data...");
#endif
    [[self data] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}data...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}data."];
    }
  }
}
@end /* implementation NEXUS_REST_APINS0ArtifactResolveResourceResponse (JAXB) */

#endif /* DEF_NEXUS_REST_APINS0ArtifactResolveResourceResponse_M */
#ifndef DEF_NEXUS_REST_APINS0ArtifactResolveResource_M
#define DEF_NEXUS_REST_APINS0ArtifactResolveResource_M

/**
 *  A resource which contains full maven details of the requested
 artifact.
 
 @version $Revision$ $Date$

 */
@implementation NEXUS_REST_APINS0ArtifactResolveResource

/**
 * True if item is present in local storage.
 */
- (BOOL) presentLocally
{
  return _presentLocally;
}

/**
 * True if item is present in local storage.
 */
- (void) setPresentLocally: (BOOL) newPresentLocally
{
  _presentLocally = newPresentLocally;
}

/**
 * The groupId of the requested artifact.
 */
- (NSString *) groupId
{
  return _groupId;
}

/**
 * The groupId of the requested artifact.
 */
- (void) setGroupId: (NSString *) newGroupId
{
  [newGroupId retain];
  [_groupId release];
  _groupId = newGroupId;
}

/**
 * The artifactId of the requested artifact.
 */
- (NSString *) artifactId
{
  return _artifactId;
}

/**
 * The artifactId of the requested artifact.
 */
- (void) setArtifactId: (NSString *) newArtifactId
{
  [newArtifactId retain];
  [_artifactId release];
  _artifactId = newArtifactId;
}

/**
 * The version of the requested artifact.
 */
- (NSString *) version
{
  return _version;
}

/**
 * The version of the requested artifact.
 */
- (void) setVersion: (NSString *) newVersion
{
  [newVersion retain];
  [_version release];
  _version = newVersion;
}

/**
 * The base version of the requested artifact.
 */
- (NSString *) baseVersion
{
  return _baseVersion;
}

/**
 * The base version of the requested artifact.
 */
- (void) setBaseVersion: (NSString *) newBaseVersion
{
  [newBaseVersion retain];
  [_baseVersion release];
  _baseVersion = newBaseVersion;
}

/**
 * The classifier of the requested artifact.
 */
- (NSString *) classifier
{
  return _classifier;
}

/**
 * The classifier of the requested artifact.
 */
- (void) setClassifier: (NSString *) newClassifier
{
  [newClassifier retain];
  [_classifier release];
  _classifier = newClassifier;
}

/**
 * The file extension of the requested artifact.
 */
- (NSString *) extension
{
  return _extension;
}

/**
 * The file extension of the requested artifact.
 */
- (void) setExtension: (NSString *) newExtension
{
  [newExtension retain];
  [_extension release];
  _extension = newExtension;
}

/**
 * Flag that states if requested artifact is a snapshot.
 */
- (BOOL) snapshot
{
  return _snapshot;
}

/**
 * Flag that states if requested artifact is a snapshot.
 */
- (void) setSnapshot: (BOOL) newSnapshot
{
  _snapshot = newSnapshot;
}

/**
 * The build number of the snapshot version of the requested
artifact.
 */
- (long) snapshotBuildNumber
{
  return _snapshotBuildNumber;
}

/**
 * The build number of the snapshot version of the requested
artifact.
 */
- (void) setSnapshotBuildNumber: (long) newSnapshotBuildNumber
{
  _snapshotBuildNumber = newSnapshotBuildNumber;
}

/**
 * The timestamp portion of the snapshot version of the
requested artifact.
 */
- (long) snapshotTimeStamp
{
  return _snapshotTimeStamp;
}

/**
 * The timestamp portion of the snapshot version of the
requested artifact.
 */
- (void) setSnapshotTimeStamp: (long) newSnapshotTimeStamp
{
  _snapshotTimeStamp = newSnapshotTimeStamp;
}

/**
 * The filename of the requested artifact.
 */
- (NSString *) fileName
{
  return _fileName;
}

/**
 * The filename of the requested artifact.
 */
- (void) setFileName: (NSString *) newFileName
{
  [newFileName retain];
  [_fileName release];
  _fileName = newFileName;
}

/**
 * The sha1 hash of the requested artifact.
 */
- (NSString *) sha1
{
  return _sha1;
}

/**
 * The sha1 hash of the requested artifact.
 */
- (void) setSha1: (NSString *) newSha1
{
  [newSha1 retain];
  [_sha1 release];
  _sha1 = newSha1;
}

/**
 * The path in the repository of the requested artifact.
 */
- (NSString *) repositoryPath
{
  return _repositoryPath;
}

/**
 * The path in the repository of the requested artifact.
 */
- (void) setRepositoryPath: (NSString *) newRepositoryPath
{
  [newRepositoryPath retain];
  [_repositoryPath release];
  _repositoryPath = newRepositoryPath;
}

- (void) dealloc
{
  [self setGroupId: nil];
  [self setArtifactId: nil];
  [self setVersion: nil];
  [self setBaseVersion: nil];
  [self setClassifier: nil];
  [self setExtension: nil];
  [self setFileName: nil];
  [self setSha1: nil];
  [self setRepositoryPath: nil];
  [super dealloc];
}
@end /* implementation NEXUS_REST_APINS0ArtifactResolveResource */

/**
 * Internal, private interface for JAXB reading and writing.
 */
@interface NEXUS_REST_APINS0ArtifactResolveResource (JAXB) <JAXBReading, JAXBWriting, JAXBType>

@end /*interface NEXUS_REST_APINS0ArtifactResolveResource (JAXB)*/

/**
 * Internal, private implementation for JAXB reading and writing.
 */
@implementation NEXUS_REST_APINS0ArtifactResolveResource (JAXB)

/**
 * Read an instance of NEXUS_REST_APINS0ArtifactResolveResource from an XML reader.
 *
 * @param reader The reader.
 * @return An instance of NEXUS_REST_APINS0ArtifactResolveResource defined by the XML reader.
 */
+ (id<JAXBType>) readXMLType: (xmlTextReaderPtr) reader
{
  NEXUS_REST_APINS0ArtifactResolveResource *_nEXUS_REST_APINS0ArtifactResolveResource = [[NEXUS_REST_APINS0ArtifactResolveResource alloc] init];
  NS_DURING
  {
    [_nEXUS_REST_APINS0ArtifactResolveResource initWithReader: reader];
  }
  NS_HANDLER
  {
    [_nEXUS_REST_APINS0ArtifactResolveResource dealloc];
    _nEXUS_REST_APINS0ArtifactResolveResource = nil;
    [localException raise];
  }
  NS_ENDHANDLER

  [_nEXUS_REST_APINS0ArtifactResolveResource autorelease];
  return _nEXUS_REST_APINS0ArtifactResolveResource;
}

/**
 * Initialize this instance of NEXUS_REST_APINS0ArtifactResolveResource according to
 * the XML being read from the reader.
 *
 * @param reader The reader.
 */
- (id) initWithReader: (xmlTextReaderPtr) reader
{
  return [super initWithReader: reader];
}

/**
 * Write the XML for this instance of NEXUS_REST_APINS0ArtifactResolveResource to the writer.
 * Note that since we're only writing the XML type,
 * No start/end element will be written.
 *
 * @param reader The reader.
 */
- (void) writeXMLType: (xmlTextWriterPtr) writer
{
  [super writeXMLType:writer];
}

//documentation inherited.
- (BOOL) readJAXBAttribute: (xmlTextReaderPtr) reader
{
  void *_child_accessor;

  if ([super readJAXBAttribute: reader]) {
    return YES;
  }

  return NO;
}

//documentation inherited.
- (BOOL) readJAXBValue: (xmlTextReaderPtr) reader
{
  return [super readJAXBValue: reader];
}

//documentation inherited.
- (BOOL) readJAXBChildElement: (xmlTextReaderPtr) reader
{
  id __child;
  void *_child_accessor;
  int status, depth;

  if ([super readJAXBChildElement: reader]) {
    return YES;
  }

  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "presentLocally", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

    _child_accessor = xmlTextReaderReadBooleanType(reader);
    if (_child_accessor == NULL) {
      //panic: unable to return the value for some reason.
      [self dealloc];
      [NSException raise: @"XMLReadError"
                   format: @"Error reading element value."];
    }
    [self setPresentLocally: *((BOOL*) _child_accessor)];
    free(_child_accessor);
    return YES;
  }
  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "groupId", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}groupId of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}groupId of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setGroupId: __child];
    return YES;
  } //end "if choice"

  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "artifactId", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}artifactId of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}artifactId of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setArtifactId: __child];
    return YES;
  } //end "if choice"

  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "version", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}version of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}version of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setVersion: __child];
    return YES;
  } //end "if choice"

  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "baseVersion", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}baseVersion of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}baseVersion of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setBaseVersion: __child];
    return YES;
  } //end "if choice"

  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "classifier", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}classifier of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}classifier of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setClassifier: __child];
    return YES;
  } //end "if choice"

  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "extension", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}extension of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}extension of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setExtension: __child];
    return YES;
  } //end "if choice"


  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "snapshot", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

    _child_accessor = xmlTextReaderReadBooleanType(reader);
    if (_child_accessor == NULL) {
      //panic: unable to return the value for some reason.
      [self dealloc];
      [NSException raise: @"XMLReadError"
                   format: @"Error reading element value."];
    }
    [self setSnapshot: *((BOOL*) _child_accessor)];
    free(_child_accessor);
    return YES;
  }

  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "snapshotBuildNumber", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

    _child_accessor = xmlTextReaderReadLongType(reader);
    if (_child_accessor == NULL) {
      //panic: unable to return the value for some reason.
      [self dealloc];
      [NSException raise: @"XMLReadError"
                   format: @"Error reading element value."];
    }
    [self setSnapshotBuildNumber: *((long*) _child_accessor)];
    free(_child_accessor);
    return YES;
  }

  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "snapshotTimeStamp", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

    _child_accessor = xmlTextReaderReadLongType(reader);
    if (_child_accessor == NULL) {
      //panic: unable to return the value for some reason.
      [self dealloc];
      [NSException raise: @"XMLReadError"
                   format: @"Error reading element value."];
    }
    [self setSnapshotTimeStamp: *((long*) _child_accessor)];
    free(_child_accessor);
    return YES;
  }
  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "fileName", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}fileName of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}fileName of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setFileName: __child];
    return YES;
  } //end "if choice"

  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "sha1", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}sha1 of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}sha1 of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setSha1: __child];
    return YES;
  } //end "if choice"

  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "repositoryPath", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}repositoryPath of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}repositoryPath of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setRepositoryPath: __child];
    return YES;
  } //end "if choice"


  return NO;
}

//documentation inherited.
- (int) readUnknownJAXBChildElement: (xmlTextReaderPtr) reader
{
  return [super readUnknownJAXBChildElement: reader];
}

//documentation inherited.
- (void) readUnknownJAXBAttribute: (xmlTextReaderPtr) reader
{
  [super readUnknownJAXBAttribute: reader];
}

//documentation inherited.
- (void) writeJAXBAttributes: (xmlTextWriterPtr) writer
{
  int status;

  [super writeJAXBAttributes: writer];

}

//documentation inherited.
- (void) writeJAXBValue: (xmlTextWriterPtr) writer
{
  [super writeJAXBValue: writer];
}

/**
 * Method for writing the child elements.
 *
 * @param writer The writer.
 */
- (void) writeJAXBChildElements: (xmlTextWriterPtr) writer
{
  int status;
  id __item;
  NSEnumerator *__enumerator;

  [super writeJAXBChildElements: writer];

  if (YES) { //always write the primitive element...
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "presentLocally", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}presentLocally."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}presentLocally...");
#endif
    status = xmlTextWriterWriteBooleanType(writer, &_presentLocally);
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}presentLocally...");
#endif
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing child element {}presentLocally."];
    }

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}presentLocally."];
    }
  }
  if ([self groupId]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "groupId", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}groupId."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}groupId...");
#endif
    [[self groupId] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}groupId...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}groupId."];
    }
  }
  if ([self artifactId]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "artifactId", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}artifactId."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}artifactId...");
#endif
    [[self artifactId] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}artifactId...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}artifactId."];
    }
  }
  if ([self version]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "version", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}version."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}version...");
#endif
    [[self version] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}version...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}version."];
    }
  }
  if ([self baseVersion]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "baseVersion", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}baseVersion."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}baseVersion...");
#endif
    [[self baseVersion] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}baseVersion...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}baseVersion."];
    }
  }
  if ([self classifier]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "classifier", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}classifier."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}classifier...");
#endif
    [[self classifier] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}classifier...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}classifier."];
    }
  }
  if ([self extension]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "extension", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}extension."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}extension...");
#endif
    [[self extension] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}extension...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}extension."];
    }
  }
  if (YES) { //always write the primitive element...
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "snapshot", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}snapshot."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}snapshot...");
#endif
    status = xmlTextWriterWriteBooleanType(writer, &_snapshot);
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}snapshot...");
#endif
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing child element {}snapshot."];
    }

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}snapshot."];
    }
  }
  if (YES) { //always write the primitive element...
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "snapshotBuildNumber", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}snapshotBuildNumber."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}snapshotBuildNumber...");
#endif
    status = xmlTextWriterWriteLongType(writer, &_snapshotBuildNumber);
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}snapshotBuildNumber...");
#endif
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing child element {}snapshotBuildNumber."];
    }

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}snapshotBuildNumber."];
    }
  }
  if (YES) { //always write the primitive element...
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "snapshotTimeStamp", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}snapshotTimeStamp."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}snapshotTimeStamp...");
#endif
    status = xmlTextWriterWriteLongType(writer, &_snapshotTimeStamp);
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}snapshotTimeStamp...");
#endif
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing child element {}snapshotTimeStamp."];
    }

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}snapshotTimeStamp."];
    }
  }
  if ([self fileName]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "fileName", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}fileName."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}fileName...");
#endif
    [[self fileName] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}fileName...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}fileName."];
    }
  }
  if ([self sha1]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "sha1", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}sha1."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}sha1...");
#endif
    [[self sha1] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}sha1...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}sha1."];
    }
  }
  if ([self repositoryPath]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "repositoryPath", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}repositoryPath."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}repositoryPath...");
#endif
    [[self repositoryPath] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}repositoryPath...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}repositoryPath."];
    }
  }
}
@end /* implementation NEXUS_REST_APINS0ArtifactResolveResource (JAXB) */

#endif /* DEF_NEXUS_REST_APINS0ArtifactResolveResource_M */
#ifndef DEF_NEXUS_REST_APINS0MirrorResourceListRequest_M
#define DEF_NEXUS_REST_APINS0MirrorResourceListRequest_M

/**
 *  REST Request object to persist list of mirrors associated with a
 repository, contains the typical 'data' parameter, which is the
 list of mirrors.
 
 @version $Revision$ $Date$

 */
@implementation NEXUS_REST_APINS0MirrorResourceListRequest

/**
 * Field data.
 */
- (NSArray *) data
{
  return _data;
}

/**
 * Field data.
 */
- (void) setData: (NSArray *) newData
{
  [newData retain];
  [_data release];
  _data = newData;
}

- (void) dealloc
{
  [self setData: nil];
  [super dealloc];
}

//documentation inherited.
+ (id<EnunciateXML>) readFromXML: (NSData *) xml
{
  NEXUS_REST_APINS0MirrorResourceListRequest *_nEXUS_REST_APINS0MirrorResourceListRequest;
  xmlTextReaderPtr reader = xmlReaderForMemory([xml bytes], [xml length], NULL, NULL, 0);
  if (reader == NULL) {
    [NSException raise: @"XMLReadError"
                 format: @"Error instantiating an XML reader."];
    return nil;
  }

  _nEXUS_REST_APINS0MirrorResourceListRequest = (NEXUS_REST_APINS0MirrorResourceListRequest *) [NEXUS_REST_APINS0MirrorResourceListRequest readXMLElement: reader];
  xmlFreeTextReader(reader); //free the reader
  return _nEXUS_REST_APINS0MirrorResourceListRequest;
}

//documentation inherited.
- (NSData *) writeToXML
{
  xmlBufferPtr buf;
  xmlTextWriterPtr writer;
  int rc;
  NSData *data;

  buf = xmlBufferCreate();
  if (buf == NULL) {
    [NSException raise: @"XMLWriteError"
                 format: @"Error creating an XML buffer."];
    return nil;
  }

  writer = xmlNewTextWriterMemory(buf, 0);
  if (writer == NULL) {
    xmlBufferFree(buf);
    [NSException raise: @"XMLWriteError"
                 format: @"Error creating an XML writer."];
    return nil;
  }

  rc = xmlTextWriterStartDocument(writer, NULL, "utf-8", NULL);
  if (rc < 0) {
    xmlFreeTextWriter(writer);
    xmlBufferFree(buf);
    [NSException raise: @"XMLWriteError"
                 format: @"Error writing XML start document."];
    return nil;
  }

  NS_DURING
  {
    [self writeXMLElement: writer];
  }
  NS_HANDLER
  {
    xmlFreeTextWriter(writer);
    xmlBufferFree(buf);
    [localException raise];
  }
  NS_ENDHANDLER

  rc = xmlTextWriterEndDocument(writer);
  if (rc < 0) {
    xmlFreeTextWriter(writer);
    xmlBufferFree(buf);
    [NSException raise: @"XMLWriteError"
                 format: @"Error writing XML end document."];
    return nil;
  }

  xmlFreeTextWriter(writer);
  data = [NSData dataWithBytes: buf->content length: buf->use];
  xmlBufferFree(buf);
  return data;
}
@end /* implementation NEXUS_REST_APINS0MirrorResourceListRequest */

/**
 * Internal, private interface for JAXB reading and writing.
 */
@interface NEXUS_REST_APINS0MirrorResourceListRequest (JAXB) <JAXBReading, JAXBWriting, JAXBType, JAXBElement>

@end /*interface NEXUS_REST_APINS0MirrorResourceListRequest (JAXB)*/

/**
 * Internal, private implementation for JAXB reading and writing.
 */
@implementation NEXUS_REST_APINS0MirrorResourceListRequest (JAXB)

/**
 * Read an instance of NEXUS_REST_APINS0MirrorResourceListRequest from an XML reader.
 *
 * @param reader The reader.
 * @return An instance of NEXUS_REST_APINS0MirrorResourceListRequest defined by the XML reader.
 */
+ (id<JAXBType>) readXMLType: (xmlTextReaderPtr) reader
{
  NEXUS_REST_APINS0MirrorResourceListRequest *_nEXUS_REST_APINS0MirrorResourceListRequest = [[NEXUS_REST_APINS0MirrorResourceListRequest alloc] init];
  NS_DURING
  {
    [_nEXUS_REST_APINS0MirrorResourceListRequest initWithReader: reader];
  }
  NS_HANDLER
  {
    [_nEXUS_REST_APINS0MirrorResourceListRequest dealloc];
    _nEXUS_REST_APINS0MirrorResourceListRequest = nil;
    [localException raise];
  }
  NS_ENDHANDLER

  [_nEXUS_REST_APINS0MirrorResourceListRequest autorelease];
  return _nEXUS_REST_APINS0MirrorResourceListRequest;
}

/**
 * Initialize this instance of NEXUS_REST_APINS0MirrorResourceListRequest according to
 * the XML being read from the reader.
 *
 * @param reader The reader.
 */
- (id) initWithReader: (xmlTextReaderPtr) reader
{
  return [super initWithReader: reader];
}

/**
 * Write the XML for this instance of NEXUS_REST_APINS0MirrorResourceListRequest to the writer.
 * Note that since we're only writing the XML type,
 * No start/end element will be written.
 *
 * @param reader The reader.
 */
- (void) writeXMLType: (xmlTextWriterPtr) writer
{
  [super writeXMLType:writer];
}

/**
 * Reads a NEXUS_REST_APINS0MirrorResourceListRequest from an XML reader. The element to be read is
 * "mirror-list-request".
 *
 * @param reader The XML reader.
 * @return The NEXUS_REST_APINS0MirrorResourceListRequest.
 */
+ (id<JAXBElement>) readXMLElement: (xmlTextReaderPtr) reader {
  int status;
  NEXUS_REST_APINS0MirrorResourceListRequest *_mirrorResourceListRequest = nil;

  if (xmlTextReaderNodeType(reader) != XML_READER_TYPE_ELEMENT) {
    status = xmlTextReaderAdvanceToNextStartOrEndElement(reader);
    if (status < 1) {
      [NSException raise: @"XMLReadError"
                   format: @"Error advancing the reader to start element mirror-list-request."];
    }
  }

  if (xmlStrcmp(BAD_CAST "mirror-list-request", xmlTextReaderConstLocalName(reader)) == 0
      && xmlTextReaderConstNamespaceUri(reader) == NULL) {
#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read root element {}mirror-list-request.");
#endif
    _mirrorResourceListRequest = (NEXUS_REST_APINS0MirrorResourceListRequest *)[NEXUS_REST_APINS0MirrorResourceListRequest readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"Successfully read root element {}mirror-list-request.");
#endif
  }
  else {
    if (xmlTextReaderConstNamespaceUri(reader) == NULL) {
      [NSException raise: @"XMLReadError"
                   format: @"Unable to read NEXUS_REST_APINS0MirrorResourceListRequest. Expected element mirror-list-request. Current element: {}%s", xmlTextReaderConstLocalName(reader)];
    }
    else {
      [NSException raise: @"XMLReadError"
                   format: @"Unable to read NEXUS_REST_APINS0MirrorResourceListRequest. Expected element mirror-list-request. Current element: {%s}%s\n", xmlTextReaderConstNamespaceUri(reader), xmlTextReaderConstLocalName(reader)];
    }
  }

  return _mirrorResourceListRequest;
}

/**
 * Writes this NEXUS_REST_APINS0MirrorResourceListRequest to XML under element name "mirror-list-request".
 * The namespace declarations for the element will be written.
 *
 * @param writer The XML writer.
 * @param _mirrorResourceListRequest The MirrorResourceListRequest to write.
 * @return 1 if successful, 0 otherwise.
 */
- (void) writeXMLElement: (xmlTextWriterPtr) writer
{
  [self writeXMLElement: writer writeNamespaces: YES];
}

/**
 * Writes this NEXUS_REST_APINS0MirrorResourceListRequest to an XML writer.
 *
 * @param writer The writer.
 * @param writeNs Whether to write the namespaces for this element to the xml writer.
 */
- (void) writeXMLElement: (xmlTextWriterPtr) writer writeNamespaces: (BOOL) writeNs
{
  int rc = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "mirror-list-request", NULL);
  if (rc < 0) {
    [NSException raise: @"XMLWriteError"
                 format: @"Error writing start element {}mirror-list-request. XML writer status: %i\n", rc];
  }

#if DEBUG_ENUNCIATE > 1
  NSLog(@"writing type {}mirrorResourceListRequest for root element {}mirror-list-request...");
#endif
  [self writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
  NSLog(@"successfully wrote type {}mirrorResourceListRequest for root element {}mirror-list-request...");
#endif
  rc = xmlTextWriterEndElement(writer);
  if (rc < 0) {
    [NSException raise: @"XMLWriteError"
                 format: @"Error writing end element {}mirror-list-request. XML writer status: %i\n", rc];
  }
}

//documentation inherited.
- (BOOL) readJAXBAttribute: (xmlTextReaderPtr) reader
{
  void *_child_accessor;

  if ([super readJAXBAttribute: reader]) {
    return YES;
  }

  return NO;
}

//documentation inherited.
- (BOOL) readJAXBValue: (xmlTextReaderPtr) reader
{
  return [super readJAXBValue: reader];
}

//documentation inherited.
- (BOOL) readJAXBChildElement: (xmlTextReaderPtr) reader
{
  id __child;
  void *_child_accessor;
  int status, depth;

  if ([super readJAXBChildElement: reader]) {
    return YES;
  }
  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "data", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

    if (xmlTextReaderIsEmptyElement(reader) == 0) {
#if DEBUG_ENUNCIATE > 1
      NSLog(@"Unwrapping wrapper element {}data...");
#endif
      //start wrapper element "{}data"
      depth = xmlTextReaderDepth(reader);
      status = xmlTextReaderAdvanceToNextStartOrEndElement(reader);
      while (xmlTextReaderDepth(reader) > depth) {
        if (status < 1) {
          //panic: XML read error.
          [self dealloc];
          [NSException raise: @"XMLReadError"
                       format: @"Failure to advance to next wrapped child element."];
        }
  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "mirrorResource", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}mirrorResource of type {}mirror-resource.");
#endif

    __child = [NEXUS_REST_APINS0MirrorResource readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}mirrorResource of type {}mirror-resource.");
#endif

    if ([self data]) {
      [self setData: [[self data] arrayByAddingObject: __child]];
    }
    else {
      [self setData: [NSArray arrayWithObject: __child]];
    }
    continue; //continue "while in wrapper element" loop
  } //end "if choice"

        status = xmlTextReaderAdvanceToNextStartOrEndElement(reader);
#if DEBUG_ENUNCIATE > 1
        NSLog(@"successfully unwrapped wrapper element {}data...");
#endif
      } // end "while in wrapper element" loop

      if (status < 1) {
        //panic: XML read error.
        [self dealloc];
        [NSException raise: @"XMLReadError"
                     format: @"Failure to advance to end wrapper element."];
      }
      else {
        //end wrapper element "{}data"
        status = xmlTextReaderAdvanceToNextStartOrEndElement(reader);
      }
    } //end "if empty element" clause
    else {
      __child = [NSArray array];
      [self setData: (NSArray*) __child];
    }

    return YES;
  } // end "if wrapper element" clause

  return NO;
}

//documentation inherited.
- (int) readUnknownJAXBChildElement: (xmlTextReaderPtr) reader
{
  return [super readUnknownJAXBChildElement: reader];
}

//documentation inherited.
- (void) readUnknownJAXBAttribute: (xmlTextReaderPtr) reader
{
  [super readUnknownJAXBAttribute: reader];
}

//documentation inherited.
- (void) writeJAXBAttributes: (xmlTextWriterPtr) writer
{
  int status;

  [super writeJAXBAttributes: writer];

}

//documentation inherited.
- (void) writeJAXBValue: (xmlTextWriterPtr) writer
{
  [super writeJAXBValue: writer];
}

/**
 * Method for writing the child elements.
 *
 * @param writer The writer.
 */
- (void) writeJAXBChildElements: (xmlTextWriterPtr) writer
{
  int status;
  id __item;
  NSEnumerator *__enumerator;

  [super writeJAXBChildElements: writer];

  if ([self data]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "data", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start wrapper element {}data."];
    }
    __enumerator = [[self data] objectEnumerator];

    while ( (__item = [__enumerator nextObject]) ) {
      status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "mirrorResource", NULL);
      if (status < 0) {
        [NSException raise: @"XMLWriteError"
                     format: @"Error writing start child element {}mirrorResource."];
      }

#if DEBUG_ENUNCIATE > 1
      NSLog(@"writing element {}mirrorResource...");
#endif
      [__item writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
      NSLog(@"successfully wrote element {}mirrorResource...");
#endif

      status = xmlTextWriterEndElement(writer);
      if (status < 0) {
        [NSException raise: @"XMLWriteError"
                     format: @"Error writing end child element {}mirrorResource."];
      }
    } //end item iterator.

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end wrapper element {}data."];
    }
  }
}
@end /* implementation NEXUS_REST_APINS0MirrorResourceListRequest (JAXB) */

#endif /* DEF_NEXUS_REST_APINS0MirrorResourceListRequest_M */
#ifndef DEF_NEXUS_REST_APINS0RepositoryGroupListResourceResponse_M
#define DEF_NEXUS_REST_APINS0RepositoryGroupListResourceResponse_M

/**
 *  REST Response object for a repository group list request,
 contains the typical 'data' parameter, which is the list of
 repository group objects.
 
 @version $Revision$ $Date$

 */
@implementation NEXUS_REST_APINS0RepositoryGroupListResourceResponse

/**
 * Field data.
 */
- (NSArray *) data
{
  return _data;
}

/**
 * Field data.
 */
- (void) setData: (NSArray *) newData
{
  [newData retain];
  [_data release];
  _data = newData;
}

- (void) dealloc
{
  [self setData: nil];
  [super dealloc];
}

//documentation inherited.
+ (id<EnunciateXML>) readFromXML: (NSData *) xml
{
  NEXUS_REST_APINS0RepositoryGroupListResourceResponse *_nEXUS_REST_APINS0RepositoryGroupListResourceResponse;
  xmlTextReaderPtr reader = xmlReaderForMemory([xml bytes], [xml length], NULL, NULL, 0);
  if (reader == NULL) {
    [NSException raise: @"XMLReadError"
                 format: @"Error instantiating an XML reader."];
    return nil;
  }

  _nEXUS_REST_APINS0RepositoryGroupListResourceResponse = (NEXUS_REST_APINS0RepositoryGroupListResourceResponse *) [NEXUS_REST_APINS0RepositoryGroupListResourceResponse readXMLElement: reader];
  xmlFreeTextReader(reader); //free the reader
  return _nEXUS_REST_APINS0RepositoryGroupListResourceResponse;
}

//documentation inherited.
- (NSData *) writeToXML
{
  xmlBufferPtr buf;
  xmlTextWriterPtr writer;
  int rc;
  NSData *data;

  buf = xmlBufferCreate();
  if (buf == NULL) {
    [NSException raise: @"XMLWriteError"
                 format: @"Error creating an XML buffer."];
    return nil;
  }

  writer = xmlNewTextWriterMemory(buf, 0);
  if (writer == NULL) {
    xmlBufferFree(buf);
    [NSException raise: @"XMLWriteError"
                 format: @"Error creating an XML writer."];
    return nil;
  }

  rc = xmlTextWriterStartDocument(writer, NULL, "utf-8", NULL);
  if (rc < 0) {
    xmlFreeTextWriter(writer);
    xmlBufferFree(buf);
    [NSException raise: @"XMLWriteError"
                 format: @"Error writing XML start document."];
    return nil;
  }

  NS_DURING
  {
    [self writeXMLElement: writer];
  }
  NS_HANDLER
  {
    xmlFreeTextWriter(writer);
    xmlBufferFree(buf);
    [localException raise];
  }
  NS_ENDHANDLER

  rc = xmlTextWriterEndDocument(writer);
  if (rc < 0) {
    xmlFreeTextWriter(writer);
    xmlBufferFree(buf);
    [NSException raise: @"XMLWriteError"
                 format: @"Error writing XML end document."];
    return nil;
  }

  xmlFreeTextWriter(writer);
  data = [NSData dataWithBytes: buf->content length: buf->use];
  xmlBufferFree(buf);
  return data;
}
@end /* implementation NEXUS_REST_APINS0RepositoryGroupListResourceResponse */

/**
 * Internal, private interface for JAXB reading and writing.
 */
@interface NEXUS_REST_APINS0RepositoryGroupListResourceResponse (JAXB) <JAXBReading, JAXBWriting, JAXBType, JAXBElement>

@end /*interface NEXUS_REST_APINS0RepositoryGroupListResourceResponse (JAXB)*/

/**
 * Internal, private implementation for JAXB reading and writing.
 */
@implementation NEXUS_REST_APINS0RepositoryGroupListResourceResponse (JAXB)

/**
 * Read an instance of NEXUS_REST_APINS0RepositoryGroupListResourceResponse from an XML reader.
 *
 * @param reader The reader.
 * @return An instance of NEXUS_REST_APINS0RepositoryGroupListResourceResponse defined by the XML reader.
 */
+ (id<JAXBType>) readXMLType: (xmlTextReaderPtr) reader
{
  NEXUS_REST_APINS0RepositoryGroupListResourceResponse *_nEXUS_REST_APINS0RepositoryGroupListResourceResponse = [[NEXUS_REST_APINS0RepositoryGroupListResourceResponse alloc] init];
  NS_DURING
  {
    [_nEXUS_REST_APINS0RepositoryGroupListResourceResponse initWithReader: reader];
  }
  NS_HANDLER
  {
    [_nEXUS_REST_APINS0RepositoryGroupListResourceResponse dealloc];
    _nEXUS_REST_APINS0RepositoryGroupListResourceResponse = nil;
    [localException raise];
  }
  NS_ENDHANDLER

  [_nEXUS_REST_APINS0RepositoryGroupListResourceResponse autorelease];
  return _nEXUS_REST_APINS0RepositoryGroupListResourceResponse;
}

/**
 * Initialize this instance of NEXUS_REST_APINS0RepositoryGroupListResourceResponse according to
 * the XML being read from the reader.
 *
 * @param reader The reader.
 */
- (id) initWithReader: (xmlTextReaderPtr) reader
{
  return [super initWithReader: reader];
}

/**
 * Write the XML for this instance of NEXUS_REST_APINS0RepositoryGroupListResourceResponse to the writer.
 * Note that since we're only writing the XML type,
 * No start/end element will be written.
 *
 * @param reader The reader.
 */
- (void) writeXMLType: (xmlTextWriterPtr) writer
{
  [super writeXMLType:writer];
}

/**
 * Reads a NEXUS_REST_APINS0RepositoryGroupListResourceResponse from an XML reader. The element to be read is
 * "repo-group-list".
 *
 * @param reader The XML reader.
 * @return The NEXUS_REST_APINS0RepositoryGroupListResourceResponse.
 */
+ (id<JAXBElement>) readXMLElement: (xmlTextReaderPtr) reader {
  int status;
  NEXUS_REST_APINS0RepositoryGroupListResourceResponse *_repositoryGroupListResourceResponse = nil;

  if (xmlTextReaderNodeType(reader) != XML_READER_TYPE_ELEMENT) {
    status = xmlTextReaderAdvanceToNextStartOrEndElement(reader);
    if (status < 1) {
      [NSException raise: @"XMLReadError"
                   format: @"Error advancing the reader to start element repo-group-list."];
    }
  }

  if (xmlStrcmp(BAD_CAST "repo-group-list", xmlTextReaderConstLocalName(reader)) == 0
      && xmlTextReaderConstNamespaceUri(reader) == NULL) {
#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read root element {}repo-group-list.");
#endif
    _repositoryGroupListResourceResponse = (NEXUS_REST_APINS0RepositoryGroupListResourceResponse *)[NEXUS_REST_APINS0RepositoryGroupListResourceResponse readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"Successfully read root element {}repo-group-list.");
#endif
  }
  else {
    if (xmlTextReaderConstNamespaceUri(reader) == NULL) {
      [NSException raise: @"XMLReadError"
                   format: @"Unable to read NEXUS_REST_APINS0RepositoryGroupListResourceResponse. Expected element repo-group-list. Current element: {}%s", xmlTextReaderConstLocalName(reader)];
    }
    else {
      [NSException raise: @"XMLReadError"
                   format: @"Unable to read NEXUS_REST_APINS0RepositoryGroupListResourceResponse. Expected element repo-group-list. Current element: {%s}%s\n", xmlTextReaderConstNamespaceUri(reader), xmlTextReaderConstLocalName(reader)];
    }
  }

  return _repositoryGroupListResourceResponse;
}

/**
 * Writes this NEXUS_REST_APINS0RepositoryGroupListResourceResponse to XML under element name "repo-group-list".
 * The namespace declarations for the element will be written.
 *
 * @param writer The XML writer.
 * @param _repositoryGroupListResourceResponse The RepositoryGroupListResourceResponse to write.
 * @return 1 if successful, 0 otherwise.
 */
- (void) writeXMLElement: (xmlTextWriterPtr) writer
{
  [self writeXMLElement: writer writeNamespaces: YES];
}

/**
 * Writes this NEXUS_REST_APINS0RepositoryGroupListResourceResponse to an XML writer.
 *
 * @param writer The writer.
 * @param writeNs Whether to write the namespaces for this element to the xml writer.
 */
- (void) writeXMLElement: (xmlTextWriterPtr) writer writeNamespaces: (BOOL) writeNs
{
  int rc = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "repo-group-list", NULL);
  if (rc < 0) {
    [NSException raise: @"XMLWriteError"
                 format: @"Error writing start element {}repo-group-list. XML writer status: %i\n", rc];
  }

#if DEBUG_ENUNCIATE > 1
  NSLog(@"writing type {}repositoryGroupListResourceResponse for root element {}repo-group-list...");
#endif
  [self writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
  NSLog(@"successfully wrote type {}repositoryGroupListResourceResponse for root element {}repo-group-list...");
#endif
  rc = xmlTextWriterEndElement(writer);
  if (rc < 0) {
    [NSException raise: @"XMLWriteError"
                 format: @"Error writing end element {}repo-group-list. XML writer status: %i\n", rc];
  }
}

//documentation inherited.
- (BOOL) readJAXBAttribute: (xmlTextReaderPtr) reader
{
  void *_child_accessor;

  if ([super readJAXBAttribute: reader]) {
    return YES;
  }

  return NO;
}

//documentation inherited.
- (BOOL) readJAXBValue: (xmlTextReaderPtr) reader
{
  return [super readJAXBValue: reader];
}

//documentation inherited.
- (BOOL) readJAXBChildElement: (xmlTextReaderPtr) reader
{
  id __child;
  void *_child_accessor;
  int status, depth;

  if ([super readJAXBChildElement: reader]) {
    return YES;
  }
  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "data", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

    if (xmlTextReaderIsEmptyElement(reader) == 0) {
#if DEBUG_ENUNCIATE > 1
      NSLog(@"Unwrapping wrapper element {}data...");
#endif
      //start wrapper element "{}data"
      depth = xmlTextReaderDepth(reader);
      status = xmlTextReaderAdvanceToNextStartOrEndElement(reader);
      while (xmlTextReaderDepth(reader) > depth) {
        if (status < 1) {
          //panic: XML read error.
          [self dealloc];
          [NSException raise: @"XMLReadError"
                       format: @"Failure to advance to next wrapped child element."];
        }
  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "repo-group-list-item", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}repo-group-list-item of type {}repository-group-list-resource.");
#endif

    __child = [NEXUS_REST_APINS0RepositoryGroupListResource readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}repo-group-list-item of type {}repository-group-list-resource.");
#endif

    if ([self data]) {
      [self setData: [[self data] arrayByAddingObject: __child]];
    }
    else {
      [self setData: [NSArray arrayWithObject: __child]];
    }
    continue; //continue "while in wrapper element" loop
  } //end "if choice"

        status = xmlTextReaderAdvanceToNextStartOrEndElement(reader);
#if DEBUG_ENUNCIATE > 1
        NSLog(@"successfully unwrapped wrapper element {}data...");
#endif
      } // end "while in wrapper element" loop

      if (status < 1) {
        //panic: XML read error.
        [self dealloc];
        [NSException raise: @"XMLReadError"
                     format: @"Failure to advance to end wrapper element."];
      }
      else {
        //end wrapper element "{}data"
        status = xmlTextReaderAdvanceToNextStartOrEndElement(reader);
      }
    } //end "if empty element" clause
    else {
      __child = [NSArray array];
      [self setData: (NSArray*) __child];
    }

    return YES;
  } // end "if wrapper element" clause

  return NO;
}

//documentation inherited.
- (int) readUnknownJAXBChildElement: (xmlTextReaderPtr) reader
{
  return [super readUnknownJAXBChildElement: reader];
}

//documentation inherited.
- (void) readUnknownJAXBAttribute: (xmlTextReaderPtr) reader
{
  [super readUnknownJAXBAttribute: reader];
}

//documentation inherited.
- (void) writeJAXBAttributes: (xmlTextWriterPtr) writer
{
  int status;

  [super writeJAXBAttributes: writer];

}

//documentation inherited.
- (void) writeJAXBValue: (xmlTextWriterPtr) writer
{
  [super writeJAXBValue: writer];
}

/**
 * Method for writing the child elements.
 *
 * @param writer The writer.
 */
- (void) writeJAXBChildElements: (xmlTextWriterPtr) writer
{
  int status;
  id __item;
  NSEnumerator *__enumerator;

  [super writeJAXBChildElements: writer];

  if ([self data]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "data", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start wrapper element {}data."];
    }
    __enumerator = [[self data] objectEnumerator];

    while ( (__item = [__enumerator nextObject]) ) {
      status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "repo-group-list-item", NULL);
      if (status < 0) {
        [NSException raise: @"XMLWriteError"
                     format: @"Error writing start child element {}repo-group-list-item."];
      }

#if DEBUG_ENUNCIATE > 1
      NSLog(@"writing element {}repo-group-list-item...");
#endif
      [__item writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
      NSLog(@"successfully wrote element {}repo-group-list-item...");
#endif

      status = xmlTextWriterEndElement(writer);
      if (status < 0) {
        [NSException raise: @"XMLWriteError"
                     format: @"Error writing end child element {}repo-group-list-item."];
      }
    } //end item iterator.

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end wrapper element {}data."];
    }
  }
}
@end /* implementation NEXUS_REST_APINS0RepositoryGroupListResourceResponse (JAXB) */

#endif /* DEF_NEXUS_REST_APINS0RepositoryGroupListResourceResponse_M */
#ifndef DEF_NEXUS_REST_APINS0RepositoryGroupResourceResponse_M
#define DEF_NEXUS_REST_APINS0RepositoryGroupResourceResponse_M

/**
 *  REST Response object for a repository group request, contains
 the typical 'data' parameter, which is the repository group
 object.
 
 @version $Revision$ $Date$

 */
@implementation NEXUS_REST_APINS0RepositoryGroupResourceResponse

/**
 * The repository group object.
 */
- (NEXUS_REST_APINS0RepositoryGroupResource *) data
{
  return _data;
}

/**
 * The repository group object.
 */
- (void) setData: (NEXUS_REST_APINS0RepositoryGroupResource *) newData
{
  [newData retain];
  [_data release];
  _data = newData;
}

- (void) dealloc
{
  [self setData: nil];
  [super dealloc];
}

//documentation inherited.
+ (id<EnunciateXML>) readFromXML: (NSData *) xml
{
  NEXUS_REST_APINS0RepositoryGroupResourceResponse *_nEXUS_REST_APINS0RepositoryGroupResourceResponse;
  xmlTextReaderPtr reader = xmlReaderForMemory([xml bytes], [xml length], NULL, NULL, 0);
  if (reader == NULL) {
    [NSException raise: @"XMLReadError"
                 format: @"Error instantiating an XML reader."];
    return nil;
  }

  _nEXUS_REST_APINS0RepositoryGroupResourceResponse = (NEXUS_REST_APINS0RepositoryGroupResourceResponse *) [NEXUS_REST_APINS0RepositoryGroupResourceResponse readXMLElement: reader];
  xmlFreeTextReader(reader); //free the reader
  return _nEXUS_REST_APINS0RepositoryGroupResourceResponse;
}

//documentation inherited.
- (NSData *) writeToXML
{
  xmlBufferPtr buf;
  xmlTextWriterPtr writer;
  int rc;
  NSData *data;

  buf = xmlBufferCreate();
  if (buf == NULL) {
    [NSException raise: @"XMLWriteError"
                 format: @"Error creating an XML buffer."];
    return nil;
  }

  writer = xmlNewTextWriterMemory(buf, 0);
  if (writer == NULL) {
    xmlBufferFree(buf);
    [NSException raise: @"XMLWriteError"
                 format: @"Error creating an XML writer."];
    return nil;
  }

  rc = xmlTextWriterStartDocument(writer, NULL, "utf-8", NULL);
  if (rc < 0) {
    xmlFreeTextWriter(writer);
    xmlBufferFree(buf);
    [NSException raise: @"XMLWriteError"
                 format: @"Error writing XML start document."];
    return nil;
  }

  NS_DURING
  {
    [self writeXMLElement: writer];
  }
  NS_HANDLER
  {
    xmlFreeTextWriter(writer);
    xmlBufferFree(buf);
    [localException raise];
  }
  NS_ENDHANDLER

  rc = xmlTextWriterEndDocument(writer);
  if (rc < 0) {
    xmlFreeTextWriter(writer);
    xmlBufferFree(buf);
    [NSException raise: @"XMLWriteError"
                 format: @"Error writing XML end document."];
    return nil;
  }

  xmlFreeTextWriter(writer);
  data = [NSData dataWithBytes: buf->content length: buf->use];
  xmlBufferFree(buf);
  return data;
}
@end /* implementation NEXUS_REST_APINS0RepositoryGroupResourceResponse */

/**
 * Internal, private interface for JAXB reading and writing.
 */
@interface NEXUS_REST_APINS0RepositoryGroupResourceResponse (JAXB) <JAXBReading, JAXBWriting, JAXBType, JAXBElement>

@end /*interface NEXUS_REST_APINS0RepositoryGroupResourceResponse (JAXB)*/

/**
 * Internal, private implementation for JAXB reading and writing.
 */
@implementation NEXUS_REST_APINS0RepositoryGroupResourceResponse (JAXB)

/**
 * Read an instance of NEXUS_REST_APINS0RepositoryGroupResourceResponse from an XML reader.
 *
 * @param reader The reader.
 * @return An instance of NEXUS_REST_APINS0RepositoryGroupResourceResponse defined by the XML reader.
 */
+ (id<JAXBType>) readXMLType: (xmlTextReaderPtr) reader
{
  NEXUS_REST_APINS0RepositoryGroupResourceResponse *_nEXUS_REST_APINS0RepositoryGroupResourceResponse = [[NEXUS_REST_APINS0RepositoryGroupResourceResponse alloc] init];
  NS_DURING
  {
    [_nEXUS_REST_APINS0RepositoryGroupResourceResponse initWithReader: reader];
  }
  NS_HANDLER
  {
    [_nEXUS_REST_APINS0RepositoryGroupResourceResponse dealloc];
    _nEXUS_REST_APINS0RepositoryGroupResourceResponse = nil;
    [localException raise];
  }
  NS_ENDHANDLER

  [_nEXUS_REST_APINS0RepositoryGroupResourceResponse autorelease];
  return _nEXUS_REST_APINS0RepositoryGroupResourceResponse;
}

/**
 * Initialize this instance of NEXUS_REST_APINS0RepositoryGroupResourceResponse according to
 * the XML being read from the reader.
 *
 * @param reader The reader.
 */
- (id) initWithReader: (xmlTextReaderPtr) reader
{
  return [super initWithReader: reader];
}

/**
 * Write the XML for this instance of NEXUS_REST_APINS0RepositoryGroupResourceResponse to the writer.
 * Note that since we're only writing the XML type,
 * No start/end element will be written.
 *
 * @param reader The reader.
 */
- (void) writeXMLType: (xmlTextWriterPtr) writer
{
  [super writeXMLType:writer];
}

/**
 * Reads a NEXUS_REST_APINS0RepositoryGroupResourceResponse from an XML reader. The element to be read is
 * "repo-group".
 *
 * @param reader The XML reader.
 * @return The NEXUS_REST_APINS0RepositoryGroupResourceResponse.
 */
+ (id<JAXBElement>) readXMLElement: (xmlTextReaderPtr) reader {
  int status;
  NEXUS_REST_APINS0RepositoryGroupResourceResponse *_repositoryGroupResourceResponse = nil;

  if (xmlTextReaderNodeType(reader) != XML_READER_TYPE_ELEMENT) {
    status = xmlTextReaderAdvanceToNextStartOrEndElement(reader);
    if (status < 1) {
      [NSException raise: @"XMLReadError"
                   format: @"Error advancing the reader to start element repo-group."];
    }
  }

  if (xmlStrcmp(BAD_CAST "repo-group", xmlTextReaderConstLocalName(reader)) == 0
      && xmlTextReaderConstNamespaceUri(reader) == NULL) {
#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read root element {}repo-group.");
#endif
    _repositoryGroupResourceResponse = (NEXUS_REST_APINS0RepositoryGroupResourceResponse *)[NEXUS_REST_APINS0RepositoryGroupResourceResponse readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"Successfully read root element {}repo-group.");
#endif
  }
  else {
    if (xmlTextReaderConstNamespaceUri(reader) == NULL) {
      [NSException raise: @"XMLReadError"
                   format: @"Unable to read NEXUS_REST_APINS0RepositoryGroupResourceResponse. Expected element repo-group. Current element: {}%s", xmlTextReaderConstLocalName(reader)];
    }
    else {
      [NSException raise: @"XMLReadError"
                   format: @"Unable to read NEXUS_REST_APINS0RepositoryGroupResourceResponse. Expected element repo-group. Current element: {%s}%s\n", xmlTextReaderConstNamespaceUri(reader), xmlTextReaderConstLocalName(reader)];
    }
  }

  return _repositoryGroupResourceResponse;
}

/**
 * Writes this NEXUS_REST_APINS0RepositoryGroupResourceResponse to XML under element name "repo-group".
 * The namespace declarations for the element will be written.
 *
 * @param writer The XML writer.
 * @param _repositoryGroupResourceResponse The RepositoryGroupResourceResponse to write.
 * @return 1 if successful, 0 otherwise.
 */
- (void) writeXMLElement: (xmlTextWriterPtr) writer
{
  [self writeXMLElement: writer writeNamespaces: YES];
}

/**
 * Writes this NEXUS_REST_APINS0RepositoryGroupResourceResponse to an XML writer.
 *
 * @param writer The writer.
 * @param writeNs Whether to write the namespaces for this element to the xml writer.
 */
- (void) writeXMLElement: (xmlTextWriterPtr) writer writeNamespaces: (BOOL) writeNs
{
  int rc = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "repo-group", NULL);
  if (rc < 0) {
    [NSException raise: @"XMLWriteError"
                 format: @"Error writing start element {}repo-group. XML writer status: %i\n", rc];
  }

#if DEBUG_ENUNCIATE > 1
  NSLog(@"writing type {}repositoryGroupResourceResponse for root element {}repo-group...");
#endif
  [self writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
  NSLog(@"successfully wrote type {}repositoryGroupResourceResponse for root element {}repo-group...");
#endif
  rc = xmlTextWriterEndElement(writer);
  if (rc < 0) {
    [NSException raise: @"XMLWriteError"
                 format: @"Error writing end element {}repo-group. XML writer status: %i\n", rc];
  }
}

//documentation inherited.
- (BOOL) readJAXBAttribute: (xmlTextReaderPtr) reader
{
  void *_child_accessor;

  if ([super readJAXBAttribute: reader]) {
    return YES;
  }

  return NO;
}

//documentation inherited.
- (BOOL) readJAXBValue: (xmlTextReaderPtr) reader
{
  return [super readJAXBValue: reader];
}

//documentation inherited.
- (BOOL) readJAXBChildElement: (xmlTextReaderPtr) reader
{
  id __child;
  void *_child_accessor;
  int status, depth;

  if ([super readJAXBChildElement: reader]) {
    return YES;
  }
  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "data", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}data of type {}repository-group-resource.");
#endif
    __child = [NEXUS_REST_APINS0RepositoryGroupResource readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}data of type {}repository-group-resource.");
#endif

    [self setData: __child];
    return YES;
  } //end "if choice"


  return NO;
}

//documentation inherited.
- (int) readUnknownJAXBChildElement: (xmlTextReaderPtr) reader
{
  return [super readUnknownJAXBChildElement: reader];
}

//documentation inherited.
- (void) readUnknownJAXBAttribute: (xmlTextReaderPtr) reader
{
  [super readUnknownJAXBAttribute: reader];
}

//documentation inherited.
- (void) writeJAXBAttributes: (xmlTextWriterPtr) writer
{
  int status;

  [super writeJAXBAttributes: writer];

}

//documentation inherited.
- (void) writeJAXBValue: (xmlTextWriterPtr) writer
{
  [super writeJAXBValue: writer];
}

/**
 * Method for writing the child elements.
 *
 * @param writer The writer.
 */
- (void) writeJAXBChildElements: (xmlTextWriterPtr) writer
{
  int status;
  id __item;
  NSEnumerator *__enumerator;

  [super writeJAXBChildElements: writer];

  if ([self data]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "data", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}data."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}data...");
#endif
    [[self data] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}data...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}data."];
    }
  }
}
@end /* implementation NEXUS_REST_APINS0RepositoryGroupResourceResponse (JAXB) */

#endif /* DEF_NEXUS_REST_APINS0RepositoryGroupResourceResponse_M */
#ifndef DEF_NEXUS_REST_APINS0RepositoryMetaResourceResponse_M
#define DEF_NEXUS_REST_APINS0RepositoryMetaResourceResponse_M

/**
 *  REST Response object for a repository metadata request, contains
 the typical 'data' parameter, which is the repository metadata
 object.
 
 @version $Revision$ $Date$

 */
@implementation NEXUS_REST_APINS0RepositoryMetaResourceResponse

/**
 * The repository metadata parameters.
 */
- (NEXUS_REST_APINS0RepositoryMetaResource *) data
{
  return _data;
}

/**
 * The repository metadata parameters.
 */
- (void) setData: (NEXUS_REST_APINS0RepositoryMetaResource *) newData
{
  [newData retain];
  [_data release];
  _data = newData;
}

- (void) dealloc
{
  [self setData: nil];
  [super dealloc];
}

//documentation inherited.
+ (id<EnunciateXML>) readFromXML: (NSData *) xml
{
  NEXUS_REST_APINS0RepositoryMetaResourceResponse *_nEXUS_REST_APINS0RepositoryMetaResourceResponse;
  xmlTextReaderPtr reader = xmlReaderForMemory([xml bytes], [xml length], NULL, NULL, 0);
  if (reader == NULL) {
    [NSException raise: @"XMLReadError"
                 format: @"Error instantiating an XML reader."];
    return nil;
  }

  _nEXUS_REST_APINS0RepositoryMetaResourceResponse = (NEXUS_REST_APINS0RepositoryMetaResourceResponse *) [NEXUS_REST_APINS0RepositoryMetaResourceResponse readXMLElement: reader];
  xmlFreeTextReader(reader); //free the reader
  return _nEXUS_REST_APINS0RepositoryMetaResourceResponse;
}

//documentation inherited.
- (NSData *) writeToXML
{
  xmlBufferPtr buf;
  xmlTextWriterPtr writer;
  int rc;
  NSData *data;

  buf = xmlBufferCreate();
  if (buf == NULL) {
    [NSException raise: @"XMLWriteError"
                 format: @"Error creating an XML buffer."];
    return nil;
  }

  writer = xmlNewTextWriterMemory(buf, 0);
  if (writer == NULL) {
    xmlBufferFree(buf);
    [NSException raise: @"XMLWriteError"
                 format: @"Error creating an XML writer."];
    return nil;
  }

  rc = xmlTextWriterStartDocument(writer, NULL, "utf-8", NULL);
  if (rc < 0) {
    xmlFreeTextWriter(writer);
    xmlBufferFree(buf);
    [NSException raise: @"XMLWriteError"
                 format: @"Error writing XML start document."];
    return nil;
  }

  NS_DURING
  {
    [self writeXMLElement: writer];
  }
  NS_HANDLER
  {
    xmlFreeTextWriter(writer);
    xmlBufferFree(buf);
    [localException raise];
  }
  NS_ENDHANDLER

  rc = xmlTextWriterEndDocument(writer);
  if (rc < 0) {
    xmlFreeTextWriter(writer);
    xmlBufferFree(buf);
    [NSException raise: @"XMLWriteError"
                 format: @"Error writing XML end document."];
    return nil;
  }

  xmlFreeTextWriter(writer);
  data = [NSData dataWithBytes: buf->content length: buf->use];
  xmlBufferFree(buf);
  return data;
}
@end /* implementation NEXUS_REST_APINS0RepositoryMetaResourceResponse */

/**
 * Internal, private interface for JAXB reading and writing.
 */
@interface NEXUS_REST_APINS0RepositoryMetaResourceResponse (JAXB) <JAXBReading, JAXBWriting, JAXBType, JAXBElement>

@end /*interface NEXUS_REST_APINS0RepositoryMetaResourceResponse (JAXB)*/

/**
 * Internal, private implementation for JAXB reading and writing.
 */
@implementation NEXUS_REST_APINS0RepositoryMetaResourceResponse (JAXB)

/**
 * Read an instance of NEXUS_REST_APINS0RepositoryMetaResourceResponse from an XML reader.
 *
 * @param reader The reader.
 * @return An instance of NEXUS_REST_APINS0RepositoryMetaResourceResponse defined by the XML reader.
 */
+ (id<JAXBType>) readXMLType: (xmlTextReaderPtr) reader
{
  NEXUS_REST_APINS0RepositoryMetaResourceResponse *_nEXUS_REST_APINS0RepositoryMetaResourceResponse = [[NEXUS_REST_APINS0RepositoryMetaResourceResponse alloc] init];
  NS_DURING
  {
    [_nEXUS_REST_APINS0RepositoryMetaResourceResponse initWithReader: reader];
  }
  NS_HANDLER
  {
    [_nEXUS_REST_APINS0RepositoryMetaResourceResponse dealloc];
    _nEXUS_REST_APINS0RepositoryMetaResourceResponse = nil;
    [localException raise];
  }
  NS_ENDHANDLER

  [_nEXUS_REST_APINS0RepositoryMetaResourceResponse autorelease];
  return _nEXUS_REST_APINS0RepositoryMetaResourceResponse;
}

/**
 * Initialize this instance of NEXUS_REST_APINS0RepositoryMetaResourceResponse according to
 * the XML being read from the reader.
 *
 * @param reader The reader.
 */
- (id) initWithReader: (xmlTextReaderPtr) reader
{
  return [super initWithReader: reader];
}

/**
 * Write the XML for this instance of NEXUS_REST_APINS0RepositoryMetaResourceResponse to the writer.
 * Note that since we're only writing the XML type,
 * No start/end element will be written.
 *
 * @param reader The reader.
 */
- (void) writeXMLType: (xmlTextWriterPtr) writer
{
  [super writeXMLType:writer];
}

/**
 * Reads a NEXUS_REST_APINS0RepositoryMetaResourceResponse from an XML reader. The element to be read is
 * "repository-meta-data".
 *
 * @param reader The XML reader.
 * @return The NEXUS_REST_APINS0RepositoryMetaResourceResponse.
 */
+ (id<JAXBElement>) readXMLElement: (xmlTextReaderPtr) reader {
  int status;
  NEXUS_REST_APINS0RepositoryMetaResourceResponse *_repositoryMetaResourceResponse = nil;

  if (xmlTextReaderNodeType(reader) != XML_READER_TYPE_ELEMENT) {
    status = xmlTextReaderAdvanceToNextStartOrEndElement(reader);
    if (status < 1) {
      [NSException raise: @"XMLReadError"
                   format: @"Error advancing the reader to start element repository-meta-data."];
    }
  }

  if (xmlStrcmp(BAD_CAST "repository-meta-data", xmlTextReaderConstLocalName(reader)) == 0
      && xmlTextReaderConstNamespaceUri(reader) == NULL) {
#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read root element {}repository-meta-data.");
#endif
    _repositoryMetaResourceResponse = (NEXUS_REST_APINS0RepositoryMetaResourceResponse *)[NEXUS_REST_APINS0RepositoryMetaResourceResponse readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"Successfully read root element {}repository-meta-data.");
#endif
  }
  else {
    if (xmlTextReaderConstNamespaceUri(reader) == NULL) {
      [NSException raise: @"XMLReadError"
                   format: @"Unable to read NEXUS_REST_APINS0RepositoryMetaResourceResponse. Expected element repository-meta-data. Current element: {}%s", xmlTextReaderConstLocalName(reader)];
    }
    else {
      [NSException raise: @"XMLReadError"
                   format: @"Unable to read NEXUS_REST_APINS0RepositoryMetaResourceResponse. Expected element repository-meta-data. Current element: {%s}%s\n", xmlTextReaderConstNamespaceUri(reader), xmlTextReaderConstLocalName(reader)];
    }
  }

  return _repositoryMetaResourceResponse;
}

/**
 * Writes this NEXUS_REST_APINS0RepositoryMetaResourceResponse to XML under element name "repository-meta-data".
 * The namespace declarations for the element will be written.
 *
 * @param writer The XML writer.
 * @param _repositoryMetaResourceResponse The RepositoryMetaResourceResponse to write.
 * @return 1 if successful, 0 otherwise.
 */
- (void) writeXMLElement: (xmlTextWriterPtr) writer
{
  [self writeXMLElement: writer writeNamespaces: YES];
}

/**
 * Writes this NEXUS_REST_APINS0RepositoryMetaResourceResponse to an XML writer.
 *
 * @param writer The writer.
 * @param writeNs Whether to write the namespaces for this element to the xml writer.
 */
- (void) writeXMLElement: (xmlTextWriterPtr) writer writeNamespaces: (BOOL) writeNs
{
  int rc = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "repository-meta-data", NULL);
  if (rc < 0) {
    [NSException raise: @"XMLWriteError"
                 format: @"Error writing start element {}repository-meta-data. XML writer status: %i\n", rc];
  }

#if DEBUG_ENUNCIATE > 1
  NSLog(@"writing type {}repositoryMetaResourceResponse for root element {}repository-meta-data...");
#endif
  [self writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
  NSLog(@"successfully wrote type {}repositoryMetaResourceResponse for root element {}repository-meta-data...");
#endif
  rc = xmlTextWriterEndElement(writer);
  if (rc < 0) {
    [NSException raise: @"XMLWriteError"
                 format: @"Error writing end element {}repository-meta-data. XML writer status: %i\n", rc];
  }
}

//documentation inherited.
- (BOOL) readJAXBAttribute: (xmlTextReaderPtr) reader
{
  void *_child_accessor;

  if ([super readJAXBAttribute: reader]) {
    return YES;
  }

  return NO;
}

//documentation inherited.
- (BOOL) readJAXBValue: (xmlTextReaderPtr) reader
{
  return [super readJAXBValue: reader];
}

//documentation inherited.
- (BOOL) readJAXBChildElement: (xmlTextReaderPtr) reader
{
  id __child;
  void *_child_accessor;
  int status, depth;

  if ([super readJAXBChildElement: reader]) {
    return YES;
  }
  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "data", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}data of type {}repository-meta-resource.");
#endif
    __child = [NEXUS_REST_APINS0RepositoryMetaResource readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}data of type {}repository-meta-resource.");
#endif

    [self setData: __child];
    return YES;
  } //end "if choice"


  return NO;
}

//documentation inherited.
- (int) readUnknownJAXBChildElement: (xmlTextReaderPtr) reader
{
  return [super readUnknownJAXBChildElement: reader];
}

//documentation inherited.
- (void) readUnknownJAXBAttribute: (xmlTextReaderPtr) reader
{
  [super readUnknownJAXBAttribute: reader];
}

//documentation inherited.
- (void) writeJAXBAttributes: (xmlTextWriterPtr) writer
{
  int status;

  [super writeJAXBAttributes: writer];

}

//documentation inherited.
- (void) writeJAXBValue: (xmlTextWriterPtr) writer
{
  [super writeJAXBValue: writer];
}

/**
 * Method for writing the child elements.
 *
 * @param writer The writer.
 */
- (void) writeJAXBChildElements: (xmlTextWriterPtr) writer
{
  int status;
  id __item;
  NSEnumerator *__enumerator;

  [super writeJAXBChildElements: writer];

  if ([self data]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "data", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}data."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}data...");
#endif
    [[self data] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}data...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}data."];
    }
  }
}
@end /* implementation NEXUS_REST_APINS0RepositoryMetaResourceResponse (JAXB) */

#endif /* DEF_NEXUS_REST_APINS0RepositoryMetaResourceResponse_M */
#ifndef DEF_NEXUS_REST_APINS0RepositoryResourceResponse_M
#define DEF_NEXUS_REST_APINS0RepositoryResourceResponse_M

/**
 *  REST Response object for a repository request, contains the
 typical 'data' parameter, which is the repository object.
 
 @version $Revision$ $Date$

 */
@implementation NEXUS_REST_APINS0RepositoryResourceResponse

/**
 * The repository object.
 */
- (NEXUS_REST_APINS0RepositoryBaseResource *) data
{
  return _data;
}

/**
 * The repository object.
 */
- (void) setData: (NEXUS_REST_APINS0RepositoryBaseResource *) newData
{
  [newData retain];
  [_data release];
  _data = newData;
}

- (void) dealloc
{
  [self setData: nil];
  [super dealloc];
}

//documentation inherited.
+ (id<EnunciateXML>) readFromXML: (NSData *) xml
{
  NEXUS_REST_APINS0RepositoryResourceResponse *_nEXUS_REST_APINS0RepositoryResourceResponse;
  xmlTextReaderPtr reader = xmlReaderForMemory([xml bytes], [xml length], NULL, NULL, 0);
  if (reader == NULL) {
    [NSException raise: @"XMLReadError"
                 format: @"Error instantiating an XML reader."];
    return nil;
  }

  _nEXUS_REST_APINS0RepositoryResourceResponse = (NEXUS_REST_APINS0RepositoryResourceResponse *) [NEXUS_REST_APINS0RepositoryResourceResponse readXMLElement: reader];
  xmlFreeTextReader(reader); //free the reader
  return _nEXUS_REST_APINS0RepositoryResourceResponse;
}

//documentation inherited.
- (NSData *) writeToXML
{
  xmlBufferPtr buf;
  xmlTextWriterPtr writer;
  int rc;
  NSData *data;

  buf = xmlBufferCreate();
  if (buf == NULL) {
    [NSException raise: @"XMLWriteError"
                 format: @"Error creating an XML buffer."];
    return nil;
  }

  writer = xmlNewTextWriterMemory(buf, 0);
  if (writer == NULL) {
    xmlBufferFree(buf);
    [NSException raise: @"XMLWriteError"
                 format: @"Error creating an XML writer."];
    return nil;
  }

  rc = xmlTextWriterStartDocument(writer, NULL, "utf-8", NULL);
  if (rc < 0) {
    xmlFreeTextWriter(writer);
    xmlBufferFree(buf);
    [NSException raise: @"XMLWriteError"
                 format: @"Error writing XML start document."];
    return nil;
  }

  NS_DURING
  {
    [self writeXMLElement: writer];
  }
  NS_HANDLER
  {
    xmlFreeTextWriter(writer);
    xmlBufferFree(buf);
    [localException raise];
  }
  NS_ENDHANDLER

  rc = xmlTextWriterEndDocument(writer);
  if (rc < 0) {
    xmlFreeTextWriter(writer);
    xmlBufferFree(buf);
    [NSException raise: @"XMLWriteError"
                 format: @"Error writing XML end document."];
    return nil;
  }

  xmlFreeTextWriter(writer);
  data = [NSData dataWithBytes: buf->content length: buf->use];
  xmlBufferFree(buf);
  return data;
}
@end /* implementation NEXUS_REST_APINS0RepositoryResourceResponse */

/**
 * Internal, private interface for JAXB reading and writing.
 */
@interface NEXUS_REST_APINS0RepositoryResourceResponse (JAXB) <JAXBReading, JAXBWriting, JAXBType, JAXBElement>

@end /*interface NEXUS_REST_APINS0RepositoryResourceResponse (JAXB)*/

/**
 * Internal, private implementation for JAXB reading and writing.
 */
@implementation NEXUS_REST_APINS0RepositoryResourceResponse (JAXB)

/**
 * Read an instance of NEXUS_REST_APINS0RepositoryResourceResponse from an XML reader.
 *
 * @param reader The reader.
 * @return An instance of NEXUS_REST_APINS0RepositoryResourceResponse defined by the XML reader.
 */
+ (id<JAXBType>) readXMLType: (xmlTextReaderPtr) reader
{
  NEXUS_REST_APINS0RepositoryResourceResponse *_nEXUS_REST_APINS0RepositoryResourceResponse = [[NEXUS_REST_APINS0RepositoryResourceResponse alloc] init];
  NS_DURING
  {
    [_nEXUS_REST_APINS0RepositoryResourceResponse initWithReader: reader];
  }
  NS_HANDLER
  {
    [_nEXUS_REST_APINS0RepositoryResourceResponse dealloc];
    _nEXUS_REST_APINS0RepositoryResourceResponse = nil;
    [localException raise];
  }
  NS_ENDHANDLER

  [_nEXUS_REST_APINS0RepositoryResourceResponse autorelease];
  return _nEXUS_REST_APINS0RepositoryResourceResponse;
}

/**
 * Initialize this instance of NEXUS_REST_APINS0RepositoryResourceResponse according to
 * the XML being read from the reader.
 *
 * @param reader The reader.
 */
- (id) initWithReader: (xmlTextReaderPtr) reader
{
  return [super initWithReader: reader];
}

/**
 * Write the XML for this instance of NEXUS_REST_APINS0RepositoryResourceResponse to the writer.
 * Note that since we're only writing the XML type,
 * No start/end element will be written.
 *
 * @param reader The reader.
 */
- (void) writeXMLType: (xmlTextWriterPtr) writer
{
  [super writeXMLType:writer];
}

/**
 * Reads a NEXUS_REST_APINS0RepositoryResourceResponse from an XML reader. The element to be read is
 * "repository".
 *
 * @param reader The XML reader.
 * @return The NEXUS_REST_APINS0RepositoryResourceResponse.
 */
+ (id<JAXBElement>) readXMLElement: (xmlTextReaderPtr) reader {
  int status;
  NEXUS_REST_APINS0RepositoryResourceResponse *_repositoryResourceResponse = nil;

  if (xmlTextReaderNodeType(reader) != XML_READER_TYPE_ELEMENT) {
    status = xmlTextReaderAdvanceToNextStartOrEndElement(reader);
    if (status < 1) {
      [NSException raise: @"XMLReadError"
                   format: @"Error advancing the reader to start element repository."];
    }
  }

  if (xmlStrcmp(BAD_CAST "repository", xmlTextReaderConstLocalName(reader)) == 0
      && xmlTextReaderConstNamespaceUri(reader) == NULL) {
#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read root element {}repository.");
#endif
    _repositoryResourceResponse = (NEXUS_REST_APINS0RepositoryResourceResponse *)[NEXUS_REST_APINS0RepositoryResourceResponse readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"Successfully read root element {}repository.");
#endif
  }
  else {
    if (xmlTextReaderConstNamespaceUri(reader) == NULL) {
      [NSException raise: @"XMLReadError"
                   format: @"Unable to read NEXUS_REST_APINS0RepositoryResourceResponse. Expected element repository. Current element: {}%s", xmlTextReaderConstLocalName(reader)];
    }
    else {
      [NSException raise: @"XMLReadError"
                   format: @"Unable to read NEXUS_REST_APINS0RepositoryResourceResponse. Expected element repository. Current element: {%s}%s\n", xmlTextReaderConstNamespaceUri(reader), xmlTextReaderConstLocalName(reader)];
    }
  }

  return _repositoryResourceResponse;
}

/**
 * Writes this NEXUS_REST_APINS0RepositoryResourceResponse to XML under element name "repository".
 * The namespace declarations for the element will be written.
 *
 * @param writer The XML writer.
 * @param _repositoryResourceResponse The RepositoryResourceResponse to write.
 * @return 1 if successful, 0 otherwise.
 */
- (void) writeXMLElement: (xmlTextWriterPtr) writer
{
  [self writeXMLElement: writer writeNamespaces: YES];
}

/**
 * Writes this NEXUS_REST_APINS0RepositoryResourceResponse to an XML writer.
 *
 * @param writer The writer.
 * @param writeNs Whether to write the namespaces for this element to the xml writer.
 */
- (void) writeXMLElement: (xmlTextWriterPtr) writer writeNamespaces: (BOOL) writeNs
{
  int rc = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "repository", NULL);
  if (rc < 0) {
    [NSException raise: @"XMLWriteError"
                 format: @"Error writing start element {}repository. XML writer status: %i\n", rc];
  }

#if DEBUG_ENUNCIATE > 1
  NSLog(@"writing type {}repositoryResourceResponse for root element {}repository...");
#endif
  [self writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
  NSLog(@"successfully wrote type {}repositoryResourceResponse for root element {}repository...");
#endif
  rc = xmlTextWriterEndElement(writer);
  if (rc < 0) {
    [NSException raise: @"XMLWriteError"
                 format: @"Error writing end element {}repository. XML writer status: %i\n", rc];
  }
}

//documentation inherited.
- (BOOL) readJAXBAttribute: (xmlTextReaderPtr) reader
{
  void *_child_accessor;

  if ([super readJAXBAttribute: reader]) {
    return YES;
  }

  return NO;
}

//documentation inherited.
- (BOOL) readJAXBValue: (xmlTextReaderPtr) reader
{
  return [super readJAXBValue: reader];
}

//documentation inherited.
- (BOOL) readJAXBChildElement: (xmlTextReaderPtr) reader
{
  id __child;
  void *_child_accessor;
  int status, depth;

  if ([super readJAXBChildElement: reader]) {
    return YES;
  }
  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "data", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}data of type {}base-repository.");
#endif
    __child = [NEXUS_REST_APINS0RepositoryBaseResource readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}data of type {}base-repository.");
#endif

    [self setData: __child];
    return YES;
  } //end "if choice"


  return NO;
}

//documentation inherited.
- (int) readUnknownJAXBChildElement: (xmlTextReaderPtr) reader
{
  return [super readUnknownJAXBChildElement: reader];
}

//documentation inherited.
- (void) readUnknownJAXBAttribute: (xmlTextReaderPtr) reader
{
  [super readUnknownJAXBAttribute: reader];
}

//documentation inherited.
- (void) writeJAXBAttributes: (xmlTextWriterPtr) writer
{
  int status;

  [super writeJAXBAttributes: writer];

}

//documentation inherited.
- (void) writeJAXBValue: (xmlTextWriterPtr) writer
{
  [super writeJAXBValue: writer];
}

/**
 * Method for writing the child elements.
 *
 * @param writer The writer.
 */
- (void) writeJAXBChildElements: (xmlTextWriterPtr) writer
{
  int status;
  id __item;
  NSEnumerator *__enumerator;

  [super writeJAXBChildElements: writer];

  if ([self data]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "data", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}data."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}data...");
#endif
    [[self data] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}data...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}data."];
    }
  }
}
@end /* implementation NEXUS_REST_APINS0RepositoryResourceResponse (JAXB) */

#endif /* DEF_NEXUS_REST_APINS0RepositoryResourceResponse_M */
#ifndef DEF_NEXUS_REST_APINS0RepositoryStatusListResourceResponse_M
#define DEF_NEXUS_REST_APINS0RepositoryStatusListResourceResponse_M

/**
 *  REST Response object for a repository status list request,
 contains the typical 'data' parameter, which is the list of
 repository status objects.
 
 @version $Revision$ $Date$

 */
@implementation NEXUS_REST_APINS0RepositoryStatusListResourceResponse

/**
 * Field data.
 */
- (NSArray *) data
{
  return _data;
}

/**
 * Field data.
 */
- (void) setData: (NSArray *) newData
{
  [newData retain];
  [_data release];
  _data = newData;
}

- (void) dealloc
{
  [self setData: nil];
  [super dealloc];
}

//documentation inherited.
+ (id<EnunciateXML>) readFromXML: (NSData *) xml
{
  NEXUS_REST_APINS0RepositoryStatusListResourceResponse *_nEXUS_REST_APINS0RepositoryStatusListResourceResponse;
  xmlTextReaderPtr reader = xmlReaderForMemory([xml bytes], [xml length], NULL, NULL, 0);
  if (reader == NULL) {
    [NSException raise: @"XMLReadError"
                 format: @"Error instantiating an XML reader."];
    return nil;
  }

  _nEXUS_REST_APINS0RepositoryStatusListResourceResponse = (NEXUS_REST_APINS0RepositoryStatusListResourceResponse *) [NEXUS_REST_APINS0RepositoryStatusListResourceResponse readXMLElement: reader];
  xmlFreeTextReader(reader); //free the reader
  return _nEXUS_REST_APINS0RepositoryStatusListResourceResponse;
}

//documentation inherited.
- (NSData *) writeToXML
{
  xmlBufferPtr buf;
  xmlTextWriterPtr writer;
  int rc;
  NSData *data;

  buf = xmlBufferCreate();
  if (buf == NULL) {
    [NSException raise: @"XMLWriteError"
                 format: @"Error creating an XML buffer."];
    return nil;
  }

  writer = xmlNewTextWriterMemory(buf, 0);
  if (writer == NULL) {
    xmlBufferFree(buf);
    [NSException raise: @"XMLWriteError"
                 format: @"Error creating an XML writer."];
    return nil;
  }

  rc = xmlTextWriterStartDocument(writer, NULL, "utf-8", NULL);
  if (rc < 0) {
    xmlFreeTextWriter(writer);
    xmlBufferFree(buf);
    [NSException raise: @"XMLWriteError"
                 format: @"Error writing XML start document."];
    return nil;
  }

  NS_DURING
  {
    [self writeXMLElement: writer];
  }
  NS_HANDLER
  {
    xmlFreeTextWriter(writer);
    xmlBufferFree(buf);
    [localException raise];
  }
  NS_ENDHANDLER

  rc = xmlTextWriterEndDocument(writer);
  if (rc < 0) {
    xmlFreeTextWriter(writer);
    xmlBufferFree(buf);
    [NSException raise: @"XMLWriteError"
                 format: @"Error writing XML end document."];
    return nil;
  }

  xmlFreeTextWriter(writer);
  data = [NSData dataWithBytes: buf->content length: buf->use];
  xmlBufferFree(buf);
  return data;
}
@end /* implementation NEXUS_REST_APINS0RepositoryStatusListResourceResponse */

/**
 * Internal, private interface for JAXB reading and writing.
 */
@interface NEXUS_REST_APINS0RepositoryStatusListResourceResponse (JAXB) <JAXBReading, JAXBWriting, JAXBType, JAXBElement>

@end /*interface NEXUS_REST_APINS0RepositoryStatusListResourceResponse (JAXB)*/

/**
 * Internal, private implementation for JAXB reading and writing.
 */
@implementation NEXUS_REST_APINS0RepositoryStatusListResourceResponse (JAXB)

/**
 * Read an instance of NEXUS_REST_APINS0RepositoryStatusListResourceResponse from an XML reader.
 *
 * @param reader The reader.
 * @return An instance of NEXUS_REST_APINS0RepositoryStatusListResourceResponse defined by the XML reader.
 */
+ (id<JAXBType>) readXMLType: (xmlTextReaderPtr) reader
{
  NEXUS_REST_APINS0RepositoryStatusListResourceResponse *_nEXUS_REST_APINS0RepositoryStatusListResourceResponse = [[NEXUS_REST_APINS0RepositoryStatusListResourceResponse alloc] init];
  NS_DURING
  {
    [_nEXUS_REST_APINS0RepositoryStatusListResourceResponse initWithReader: reader];
  }
  NS_HANDLER
  {
    [_nEXUS_REST_APINS0RepositoryStatusListResourceResponse dealloc];
    _nEXUS_REST_APINS0RepositoryStatusListResourceResponse = nil;
    [localException raise];
  }
  NS_ENDHANDLER

  [_nEXUS_REST_APINS0RepositoryStatusListResourceResponse autorelease];
  return _nEXUS_REST_APINS0RepositoryStatusListResourceResponse;
}

/**
 * Initialize this instance of NEXUS_REST_APINS0RepositoryStatusListResourceResponse according to
 * the XML being read from the reader.
 *
 * @param reader The reader.
 */
- (id) initWithReader: (xmlTextReaderPtr) reader
{
  return [super initWithReader: reader];
}

/**
 * Write the XML for this instance of NEXUS_REST_APINS0RepositoryStatusListResourceResponse to the writer.
 * Note that since we're only writing the XML type,
 * No start/end element will be written.
 *
 * @param reader The reader.
 */
- (void) writeXMLType: (xmlTextWriterPtr) writer
{
  [super writeXMLType:writer];
}

/**
 * Reads a NEXUS_REST_APINS0RepositoryStatusListResourceResponse from an XML reader. The element to be read is
 * "repository-status-list".
 *
 * @param reader The XML reader.
 * @return The NEXUS_REST_APINS0RepositoryStatusListResourceResponse.
 */
+ (id<JAXBElement>) readXMLElement: (xmlTextReaderPtr) reader {
  int status;
  NEXUS_REST_APINS0RepositoryStatusListResourceResponse *_repositoryStatusListResourceResponse = nil;

  if (xmlTextReaderNodeType(reader) != XML_READER_TYPE_ELEMENT) {
    status = xmlTextReaderAdvanceToNextStartOrEndElement(reader);
    if (status < 1) {
      [NSException raise: @"XMLReadError"
                   format: @"Error advancing the reader to start element repository-status-list."];
    }
  }

  if (xmlStrcmp(BAD_CAST "repository-status-list", xmlTextReaderConstLocalName(reader)) == 0
      && xmlTextReaderConstNamespaceUri(reader) == NULL) {
#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read root element {}repository-status-list.");
#endif
    _repositoryStatusListResourceResponse = (NEXUS_REST_APINS0RepositoryStatusListResourceResponse *)[NEXUS_REST_APINS0RepositoryStatusListResourceResponse readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"Successfully read root element {}repository-status-list.");
#endif
  }
  else {
    if (xmlTextReaderConstNamespaceUri(reader) == NULL) {
      [NSException raise: @"XMLReadError"
                   format: @"Unable to read NEXUS_REST_APINS0RepositoryStatusListResourceResponse. Expected element repository-status-list. Current element: {}%s", xmlTextReaderConstLocalName(reader)];
    }
    else {
      [NSException raise: @"XMLReadError"
                   format: @"Unable to read NEXUS_REST_APINS0RepositoryStatusListResourceResponse. Expected element repository-status-list. Current element: {%s}%s\n", xmlTextReaderConstNamespaceUri(reader), xmlTextReaderConstLocalName(reader)];
    }
  }

  return _repositoryStatusListResourceResponse;
}

/**
 * Writes this NEXUS_REST_APINS0RepositoryStatusListResourceResponse to XML under element name "repository-status-list".
 * The namespace declarations for the element will be written.
 *
 * @param writer The XML writer.
 * @param _repositoryStatusListResourceResponse The RepositoryStatusListResourceResponse to write.
 * @return 1 if successful, 0 otherwise.
 */
- (void) writeXMLElement: (xmlTextWriterPtr) writer
{
  [self writeXMLElement: writer writeNamespaces: YES];
}

/**
 * Writes this NEXUS_REST_APINS0RepositoryStatusListResourceResponse to an XML writer.
 *
 * @param writer The writer.
 * @param writeNs Whether to write the namespaces for this element to the xml writer.
 */
- (void) writeXMLElement: (xmlTextWriterPtr) writer writeNamespaces: (BOOL) writeNs
{
  int rc = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "repository-status-list", NULL);
  if (rc < 0) {
    [NSException raise: @"XMLWriteError"
                 format: @"Error writing start element {}repository-status-list. XML writer status: %i\n", rc];
  }

#if DEBUG_ENUNCIATE > 1
  NSLog(@"writing type {}repositoryStatusListResourceResponse for root element {}repository-status-list...");
#endif
  [self writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
  NSLog(@"successfully wrote type {}repositoryStatusListResourceResponse for root element {}repository-status-list...");
#endif
  rc = xmlTextWriterEndElement(writer);
  if (rc < 0) {
    [NSException raise: @"XMLWriteError"
                 format: @"Error writing end element {}repository-status-list. XML writer status: %i\n", rc];
  }
}

//documentation inherited.
- (BOOL) readJAXBAttribute: (xmlTextReaderPtr) reader
{
  void *_child_accessor;

  if ([super readJAXBAttribute: reader]) {
    return YES;
  }

  return NO;
}

//documentation inherited.
- (BOOL) readJAXBValue: (xmlTextReaderPtr) reader
{
  return [super readJAXBValue: reader];
}

//documentation inherited.
- (BOOL) readJAXBChildElement: (xmlTextReaderPtr) reader
{
  id __child;
  void *_child_accessor;
  int status, depth;

  if ([super readJAXBChildElement: reader]) {
    return YES;
  }
  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "data", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

    if (xmlTextReaderIsEmptyElement(reader) == 0) {
#if DEBUG_ENUNCIATE > 1
      NSLog(@"Unwrapping wrapper element {}data...");
#endif
      //start wrapper element "{}data"
      depth = xmlTextReaderDepth(reader);
      status = xmlTextReaderAdvanceToNextStartOrEndElement(reader);
      while (xmlTextReaderDepth(reader) > depth) {
        if (status < 1) {
          //panic: XML read error.
          [self dealloc];
          [NSException raise: @"XMLReadError"
                       format: @"Failure to advance to next wrapped child element."];
        }
  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "repository-status-list-item", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}repository-status-list-item of type {}repository-status-list-item.");
#endif

    __child = [NEXUS_REST_APINS0RepositoryStatusListResource readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}repository-status-list-item of type {}repository-status-list-item.");
#endif

    if ([self data]) {
      [self setData: [[self data] arrayByAddingObject: __child]];
    }
    else {
      [self setData: [NSArray arrayWithObject: __child]];
    }
    continue; //continue "while in wrapper element" loop
  } //end "if choice"

        status = xmlTextReaderAdvanceToNextStartOrEndElement(reader);
#if DEBUG_ENUNCIATE > 1
        NSLog(@"successfully unwrapped wrapper element {}data...");
#endif
      } // end "while in wrapper element" loop

      if (status < 1) {
        //panic: XML read error.
        [self dealloc];
        [NSException raise: @"XMLReadError"
                     format: @"Failure to advance to end wrapper element."];
      }
      else {
        //end wrapper element "{}data"
        status = xmlTextReaderAdvanceToNextStartOrEndElement(reader);
      }
    } //end "if empty element" clause
    else {
      __child = [NSArray array];
      [self setData: (NSArray*) __child];
    }

    return YES;
  } // end "if wrapper element" clause

  return NO;
}

//documentation inherited.
- (int) readUnknownJAXBChildElement: (xmlTextReaderPtr) reader
{
  return [super readUnknownJAXBChildElement: reader];
}

//documentation inherited.
- (void) readUnknownJAXBAttribute: (xmlTextReaderPtr) reader
{
  [super readUnknownJAXBAttribute: reader];
}

//documentation inherited.
- (void) writeJAXBAttributes: (xmlTextWriterPtr) writer
{
  int status;

  [super writeJAXBAttributes: writer];

}

//documentation inherited.
- (void) writeJAXBValue: (xmlTextWriterPtr) writer
{
  [super writeJAXBValue: writer];
}

/**
 * Method for writing the child elements.
 *
 * @param writer The writer.
 */
- (void) writeJAXBChildElements: (xmlTextWriterPtr) writer
{
  int status;
  id __item;
  NSEnumerator *__enumerator;

  [super writeJAXBChildElements: writer];

  if ([self data]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "data", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start wrapper element {}data."];
    }
    __enumerator = [[self data] objectEnumerator];

    while ( (__item = [__enumerator nextObject]) ) {
      status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "repository-status-list-item", NULL);
      if (status < 0) {
        [NSException raise: @"XMLWriteError"
                     format: @"Error writing start child element {}repository-status-list-item."];
      }

#if DEBUG_ENUNCIATE > 1
      NSLog(@"writing element {}repository-status-list-item...");
#endif
      [__item writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
      NSLog(@"successfully wrote element {}repository-status-list-item...");
#endif

      status = xmlTextWriterEndElement(writer);
      if (status < 0) {
        [NSException raise: @"XMLWriteError"
                     format: @"Error writing end child element {}repository-status-list-item."];
      }
    } //end item iterator.

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end wrapper element {}data."];
    }
  }
}
@end /* implementation NEXUS_REST_APINS0RepositoryStatusListResourceResponse (JAXB) */

#endif /* DEF_NEXUS_REST_APINS0RepositoryStatusListResourceResponse_M */
#ifndef DEF_NEXUS_REST_APINS0RepositoryTargetListResourceResponse_M
#define DEF_NEXUS_REST_APINS0RepositoryTargetListResourceResponse_M

/**
 *  REST Response object for a list of repository targets, contains
 the typical 'data' parameter, which is the list of repository
 targets.
 
 @version $Revision$ $Date$

 */
@implementation NEXUS_REST_APINS0RepositoryTargetListResourceResponse

/**
 * Field data.
 */
- (NSArray *) data
{
  return _data;
}

/**
 * Field data.
 */
- (void) setData: (NSArray *) newData
{
  [newData retain];
  [_data release];
  _data = newData;
}

- (void) dealloc
{
  [self setData: nil];
  [super dealloc];
}

//documentation inherited.
+ (id<EnunciateXML>) readFromXML: (NSData *) xml
{
  NEXUS_REST_APINS0RepositoryTargetListResourceResponse *_nEXUS_REST_APINS0RepositoryTargetListResourceResponse;
  xmlTextReaderPtr reader = xmlReaderForMemory([xml bytes], [xml length], NULL, NULL, 0);
  if (reader == NULL) {
    [NSException raise: @"XMLReadError"
                 format: @"Error instantiating an XML reader."];
    return nil;
  }

  _nEXUS_REST_APINS0RepositoryTargetListResourceResponse = (NEXUS_REST_APINS0RepositoryTargetListResourceResponse *) [NEXUS_REST_APINS0RepositoryTargetListResourceResponse readXMLElement: reader];
  xmlFreeTextReader(reader); //free the reader
  return _nEXUS_REST_APINS0RepositoryTargetListResourceResponse;
}

//documentation inherited.
- (NSData *) writeToXML
{
  xmlBufferPtr buf;
  xmlTextWriterPtr writer;
  int rc;
  NSData *data;

  buf = xmlBufferCreate();
  if (buf == NULL) {
    [NSException raise: @"XMLWriteError"
                 format: @"Error creating an XML buffer."];
    return nil;
  }

  writer = xmlNewTextWriterMemory(buf, 0);
  if (writer == NULL) {
    xmlBufferFree(buf);
    [NSException raise: @"XMLWriteError"
                 format: @"Error creating an XML writer."];
    return nil;
  }

  rc = xmlTextWriterStartDocument(writer, NULL, "utf-8", NULL);
  if (rc < 0) {
    xmlFreeTextWriter(writer);
    xmlBufferFree(buf);
    [NSException raise: @"XMLWriteError"
                 format: @"Error writing XML start document."];
    return nil;
  }

  NS_DURING
  {
    [self writeXMLElement: writer];
  }
  NS_HANDLER
  {
    xmlFreeTextWriter(writer);
    xmlBufferFree(buf);
    [localException raise];
  }
  NS_ENDHANDLER

  rc = xmlTextWriterEndDocument(writer);
  if (rc < 0) {
    xmlFreeTextWriter(writer);
    xmlBufferFree(buf);
    [NSException raise: @"XMLWriteError"
                 format: @"Error writing XML end document."];
    return nil;
  }

  xmlFreeTextWriter(writer);
  data = [NSData dataWithBytes: buf->content length: buf->use];
  xmlBufferFree(buf);
  return data;
}
@end /* implementation NEXUS_REST_APINS0RepositoryTargetListResourceResponse */

/**
 * Internal, private interface for JAXB reading and writing.
 */
@interface NEXUS_REST_APINS0RepositoryTargetListResourceResponse (JAXB) <JAXBReading, JAXBWriting, JAXBType, JAXBElement>

@end /*interface NEXUS_REST_APINS0RepositoryTargetListResourceResponse (JAXB)*/

/**
 * Internal, private implementation for JAXB reading and writing.
 */
@implementation NEXUS_REST_APINS0RepositoryTargetListResourceResponse (JAXB)

/**
 * Read an instance of NEXUS_REST_APINS0RepositoryTargetListResourceResponse from an XML reader.
 *
 * @param reader The reader.
 * @return An instance of NEXUS_REST_APINS0RepositoryTargetListResourceResponse defined by the XML reader.
 */
+ (id<JAXBType>) readXMLType: (xmlTextReaderPtr) reader
{
  NEXUS_REST_APINS0RepositoryTargetListResourceResponse *_nEXUS_REST_APINS0RepositoryTargetListResourceResponse = [[NEXUS_REST_APINS0RepositoryTargetListResourceResponse alloc] init];
  NS_DURING
  {
    [_nEXUS_REST_APINS0RepositoryTargetListResourceResponse initWithReader: reader];
  }
  NS_HANDLER
  {
    [_nEXUS_REST_APINS0RepositoryTargetListResourceResponse dealloc];
    _nEXUS_REST_APINS0RepositoryTargetListResourceResponse = nil;
    [localException raise];
  }
  NS_ENDHANDLER

  [_nEXUS_REST_APINS0RepositoryTargetListResourceResponse autorelease];
  return _nEXUS_REST_APINS0RepositoryTargetListResourceResponse;
}

/**
 * Initialize this instance of NEXUS_REST_APINS0RepositoryTargetListResourceResponse according to
 * the XML being read from the reader.
 *
 * @param reader The reader.
 */
- (id) initWithReader: (xmlTextReaderPtr) reader
{
  return [super initWithReader: reader];
}

/**
 * Write the XML for this instance of NEXUS_REST_APINS0RepositoryTargetListResourceResponse to the writer.
 * Note that since we're only writing the XML type,
 * No start/end element will be written.
 *
 * @param reader The reader.
 */
- (void) writeXMLType: (xmlTextWriterPtr) writer
{
  [super writeXMLType:writer];
}

/**
 * Reads a NEXUS_REST_APINS0RepositoryTargetListResourceResponse from an XML reader. The element to be read is
 * "repo-targets-list".
 *
 * @param reader The XML reader.
 * @return The NEXUS_REST_APINS0RepositoryTargetListResourceResponse.
 */
+ (id<JAXBElement>) readXMLElement: (xmlTextReaderPtr) reader {
  int status;
  NEXUS_REST_APINS0RepositoryTargetListResourceResponse *_repositoryTargetListResourceResponse = nil;

  if (xmlTextReaderNodeType(reader) != XML_READER_TYPE_ELEMENT) {
    status = xmlTextReaderAdvanceToNextStartOrEndElement(reader);
    if (status < 1) {
      [NSException raise: @"XMLReadError"
                   format: @"Error advancing the reader to start element repo-targets-list."];
    }
  }

  if (xmlStrcmp(BAD_CAST "repo-targets-list", xmlTextReaderConstLocalName(reader)) == 0
      && xmlTextReaderConstNamespaceUri(reader) == NULL) {
#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read root element {}repo-targets-list.");
#endif
    _repositoryTargetListResourceResponse = (NEXUS_REST_APINS0RepositoryTargetListResourceResponse *)[NEXUS_REST_APINS0RepositoryTargetListResourceResponse readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"Successfully read root element {}repo-targets-list.");
#endif
  }
  else {
    if (xmlTextReaderConstNamespaceUri(reader) == NULL) {
      [NSException raise: @"XMLReadError"
                   format: @"Unable to read NEXUS_REST_APINS0RepositoryTargetListResourceResponse. Expected element repo-targets-list. Current element: {}%s", xmlTextReaderConstLocalName(reader)];
    }
    else {
      [NSException raise: @"XMLReadError"
                   format: @"Unable to read NEXUS_REST_APINS0RepositoryTargetListResourceResponse. Expected element repo-targets-list. Current element: {%s}%s\n", xmlTextReaderConstNamespaceUri(reader), xmlTextReaderConstLocalName(reader)];
    }
  }

  return _repositoryTargetListResourceResponse;
}

/**
 * Writes this NEXUS_REST_APINS0RepositoryTargetListResourceResponse to XML under element name "repo-targets-list".
 * The namespace declarations for the element will be written.
 *
 * @param writer The XML writer.
 * @param _repositoryTargetListResourceResponse The RepositoryTargetListResourceResponse to write.
 * @return 1 if successful, 0 otherwise.
 */
- (void) writeXMLElement: (xmlTextWriterPtr) writer
{
  [self writeXMLElement: writer writeNamespaces: YES];
}

/**
 * Writes this NEXUS_REST_APINS0RepositoryTargetListResourceResponse to an XML writer.
 *
 * @param writer The writer.
 * @param writeNs Whether to write the namespaces for this element to the xml writer.
 */
- (void) writeXMLElement: (xmlTextWriterPtr) writer writeNamespaces: (BOOL) writeNs
{
  int rc = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "repo-targets-list", NULL);
  if (rc < 0) {
    [NSException raise: @"XMLWriteError"
                 format: @"Error writing start element {}repo-targets-list. XML writer status: %i\n", rc];
  }

#if DEBUG_ENUNCIATE > 1
  NSLog(@"writing type {}repositoryTargetListResourceResponse for root element {}repo-targets-list...");
#endif
  [self writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
  NSLog(@"successfully wrote type {}repositoryTargetListResourceResponse for root element {}repo-targets-list...");
#endif
  rc = xmlTextWriterEndElement(writer);
  if (rc < 0) {
    [NSException raise: @"XMLWriteError"
                 format: @"Error writing end element {}repo-targets-list. XML writer status: %i\n", rc];
  }
}

//documentation inherited.
- (BOOL) readJAXBAttribute: (xmlTextReaderPtr) reader
{
  void *_child_accessor;

  if ([super readJAXBAttribute: reader]) {
    return YES;
  }

  return NO;
}

//documentation inherited.
- (BOOL) readJAXBValue: (xmlTextReaderPtr) reader
{
  return [super readJAXBValue: reader];
}

//documentation inherited.
- (BOOL) readJAXBChildElement: (xmlTextReaderPtr) reader
{
  id __child;
  void *_child_accessor;
  int status, depth;

  if ([super readJAXBChildElement: reader]) {
    return YES;
  }
  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "data", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

    if (xmlTextReaderIsEmptyElement(reader) == 0) {
#if DEBUG_ENUNCIATE > 1
      NSLog(@"Unwrapping wrapper element {}data...");
#endif
      //start wrapper element "{}data"
      depth = xmlTextReaderDepth(reader);
      status = xmlTextReaderAdvanceToNextStartOrEndElement(reader);
      while (xmlTextReaderDepth(reader) > depth) {
        if (status < 1) {
          //panic: XML read error.
          [self dealloc];
          [NSException raise: @"XMLReadError"
                       format: @"Failure to advance to next wrapped child element."];
        }
  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "repo-targets-list-item", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}repo-targets-list-item of type {}repository-target-list-resource.");
#endif

    __child = [NEXUS_REST_APINS0RepositoryTargetListResource readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}repo-targets-list-item of type {}repository-target-list-resource.");
#endif

    if ([self data]) {
      [self setData: [[self data] arrayByAddingObject: __child]];
    }
    else {
      [self setData: [NSArray arrayWithObject: __child]];
    }
    continue; //continue "while in wrapper element" loop
  } //end "if choice"

        status = xmlTextReaderAdvanceToNextStartOrEndElement(reader);
#if DEBUG_ENUNCIATE > 1
        NSLog(@"successfully unwrapped wrapper element {}data...");
#endif
      } // end "while in wrapper element" loop

      if (status < 1) {
        //panic: XML read error.
        [self dealloc];
        [NSException raise: @"XMLReadError"
                     format: @"Failure to advance to end wrapper element."];
      }
      else {
        //end wrapper element "{}data"
        status = xmlTextReaderAdvanceToNextStartOrEndElement(reader);
      }
    } //end "if empty element" clause
    else {
      __child = [NSArray array];
      [self setData: (NSArray*) __child];
    }

    return YES;
  } // end "if wrapper element" clause

  return NO;
}

//documentation inherited.
- (int) readUnknownJAXBChildElement: (xmlTextReaderPtr) reader
{
  return [super readUnknownJAXBChildElement: reader];
}

//documentation inherited.
- (void) readUnknownJAXBAttribute: (xmlTextReaderPtr) reader
{
  [super readUnknownJAXBAttribute: reader];
}

//documentation inherited.
- (void) writeJAXBAttributes: (xmlTextWriterPtr) writer
{
  int status;

  [super writeJAXBAttributes: writer];

}

//documentation inherited.
- (void) writeJAXBValue: (xmlTextWriterPtr) writer
{
  [super writeJAXBValue: writer];
}

/**
 * Method for writing the child elements.
 *
 * @param writer The writer.
 */
- (void) writeJAXBChildElements: (xmlTextWriterPtr) writer
{
  int status;
  id __item;
  NSEnumerator *__enumerator;

  [super writeJAXBChildElements: writer];

  if ([self data]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "data", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start wrapper element {}data."];
    }
    __enumerator = [[self data] objectEnumerator];

    while ( (__item = [__enumerator nextObject]) ) {
      status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "repo-targets-list-item", NULL);
      if (status < 0) {
        [NSException raise: @"XMLWriteError"
                     format: @"Error writing start child element {}repo-targets-list-item."];
      }

#if DEBUG_ENUNCIATE > 1
      NSLog(@"writing element {}repo-targets-list-item...");
#endif
      [__item writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
      NSLog(@"successfully wrote element {}repo-targets-list-item...");
#endif

      status = xmlTextWriterEndElement(writer);
      if (status < 0) {
        [NSException raise: @"XMLWriteError"
                     format: @"Error writing end child element {}repo-targets-list-item."];
      }
    } //end item iterator.

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end wrapper element {}data."];
    }
  }
}
@end /* implementation NEXUS_REST_APINS0RepositoryTargetListResourceResponse (JAXB) */

#endif /* DEF_NEXUS_REST_APINS0RepositoryTargetListResourceResponse_M */
#ifndef DEF_NEXUS_REST_APINS0RepositoryTargetResourceResponse_M
#define DEF_NEXUS_REST_APINS0RepositoryTargetResourceResponse_M

/**
 *  REST Response object for a repository target, contains the
 typical 'data' parameter, which is the repository target.
 
 @version $Revision$ $Date$

 */
@implementation NEXUS_REST_APINS0RepositoryTargetResourceResponse

/**
 * The repository target details.
 */
- (NEXUS_REST_APINS0RepositoryTargetResource *) data
{
  return _data;
}

/**
 * The repository target details.
 */
- (void) setData: (NEXUS_REST_APINS0RepositoryTargetResource *) newData
{
  [newData retain];
  [_data release];
  _data = newData;
}

- (void) dealloc
{
  [self setData: nil];
  [super dealloc];
}

//documentation inherited.
+ (id<EnunciateXML>) readFromXML: (NSData *) xml
{
  NEXUS_REST_APINS0RepositoryTargetResourceResponse *_nEXUS_REST_APINS0RepositoryTargetResourceResponse;
  xmlTextReaderPtr reader = xmlReaderForMemory([xml bytes], [xml length], NULL, NULL, 0);
  if (reader == NULL) {
    [NSException raise: @"XMLReadError"
                 format: @"Error instantiating an XML reader."];
    return nil;
  }

  _nEXUS_REST_APINS0RepositoryTargetResourceResponse = (NEXUS_REST_APINS0RepositoryTargetResourceResponse *) [NEXUS_REST_APINS0RepositoryTargetResourceResponse readXMLElement: reader];
  xmlFreeTextReader(reader); //free the reader
  return _nEXUS_REST_APINS0RepositoryTargetResourceResponse;
}

//documentation inherited.
- (NSData *) writeToXML
{
  xmlBufferPtr buf;
  xmlTextWriterPtr writer;
  int rc;
  NSData *data;

  buf = xmlBufferCreate();
  if (buf == NULL) {
    [NSException raise: @"XMLWriteError"
                 format: @"Error creating an XML buffer."];
    return nil;
  }

  writer = xmlNewTextWriterMemory(buf, 0);
  if (writer == NULL) {
    xmlBufferFree(buf);
    [NSException raise: @"XMLWriteError"
                 format: @"Error creating an XML writer."];
    return nil;
  }

  rc = xmlTextWriterStartDocument(writer, NULL, "utf-8", NULL);
  if (rc < 0) {
    xmlFreeTextWriter(writer);
    xmlBufferFree(buf);
    [NSException raise: @"XMLWriteError"
                 format: @"Error writing XML start document."];
    return nil;
  }

  NS_DURING
  {
    [self writeXMLElement: writer];
  }
  NS_HANDLER
  {
    xmlFreeTextWriter(writer);
    xmlBufferFree(buf);
    [localException raise];
  }
  NS_ENDHANDLER

  rc = xmlTextWriterEndDocument(writer);
  if (rc < 0) {
    xmlFreeTextWriter(writer);
    xmlBufferFree(buf);
    [NSException raise: @"XMLWriteError"
                 format: @"Error writing XML end document."];
    return nil;
  }

  xmlFreeTextWriter(writer);
  data = [NSData dataWithBytes: buf->content length: buf->use];
  xmlBufferFree(buf);
  return data;
}
@end /* implementation NEXUS_REST_APINS0RepositoryTargetResourceResponse */

/**
 * Internal, private interface for JAXB reading and writing.
 */
@interface NEXUS_REST_APINS0RepositoryTargetResourceResponse (JAXB) <JAXBReading, JAXBWriting, JAXBType, JAXBElement>

@end /*interface NEXUS_REST_APINS0RepositoryTargetResourceResponse (JAXB)*/

/**
 * Internal, private implementation for JAXB reading and writing.
 */
@implementation NEXUS_REST_APINS0RepositoryTargetResourceResponse (JAXB)

/**
 * Read an instance of NEXUS_REST_APINS0RepositoryTargetResourceResponse from an XML reader.
 *
 * @param reader The reader.
 * @return An instance of NEXUS_REST_APINS0RepositoryTargetResourceResponse defined by the XML reader.
 */
+ (id<JAXBType>) readXMLType: (xmlTextReaderPtr) reader
{
  NEXUS_REST_APINS0RepositoryTargetResourceResponse *_nEXUS_REST_APINS0RepositoryTargetResourceResponse = [[NEXUS_REST_APINS0RepositoryTargetResourceResponse alloc] init];
  NS_DURING
  {
    [_nEXUS_REST_APINS0RepositoryTargetResourceResponse initWithReader: reader];
  }
  NS_HANDLER
  {
    [_nEXUS_REST_APINS0RepositoryTargetResourceResponse dealloc];
    _nEXUS_REST_APINS0RepositoryTargetResourceResponse = nil;
    [localException raise];
  }
  NS_ENDHANDLER

  [_nEXUS_REST_APINS0RepositoryTargetResourceResponse autorelease];
  return _nEXUS_REST_APINS0RepositoryTargetResourceResponse;
}

/**
 * Initialize this instance of NEXUS_REST_APINS0RepositoryTargetResourceResponse according to
 * the XML being read from the reader.
 *
 * @param reader The reader.
 */
- (id) initWithReader: (xmlTextReaderPtr) reader
{
  return [super initWithReader: reader];
}

/**
 * Write the XML for this instance of NEXUS_REST_APINS0RepositoryTargetResourceResponse to the writer.
 * Note that since we're only writing the XML type,
 * No start/end element will be written.
 *
 * @param reader The reader.
 */
- (void) writeXMLType: (xmlTextWriterPtr) writer
{
  [super writeXMLType:writer];
}

/**
 * Reads a NEXUS_REST_APINS0RepositoryTargetResourceResponse from an XML reader. The element to be read is
 * "repo-target".
 *
 * @param reader The XML reader.
 * @return The NEXUS_REST_APINS0RepositoryTargetResourceResponse.
 */
+ (id<JAXBElement>) readXMLElement: (xmlTextReaderPtr) reader {
  int status;
  NEXUS_REST_APINS0RepositoryTargetResourceResponse *_repositoryTargetResourceResponse = nil;

  if (xmlTextReaderNodeType(reader) != XML_READER_TYPE_ELEMENT) {
    status = xmlTextReaderAdvanceToNextStartOrEndElement(reader);
    if (status < 1) {
      [NSException raise: @"XMLReadError"
                   format: @"Error advancing the reader to start element repo-target."];
    }
  }

  if (xmlStrcmp(BAD_CAST "repo-target", xmlTextReaderConstLocalName(reader)) == 0
      && xmlTextReaderConstNamespaceUri(reader) == NULL) {
#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read root element {}repo-target.");
#endif
    _repositoryTargetResourceResponse = (NEXUS_REST_APINS0RepositoryTargetResourceResponse *)[NEXUS_REST_APINS0RepositoryTargetResourceResponse readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"Successfully read root element {}repo-target.");
#endif
  }
  else {
    if (xmlTextReaderConstNamespaceUri(reader) == NULL) {
      [NSException raise: @"XMLReadError"
                   format: @"Unable to read NEXUS_REST_APINS0RepositoryTargetResourceResponse. Expected element repo-target. Current element: {}%s", xmlTextReaderConstLocalName(reader)];
    }
    else {
      [NSException raise: @"XMLReadError"
                   format: @"Unable to read NEXUS_REST_APINS0RepositoryTargetResourceResponse. Expected element repo-target. Current element: {%s}%s\n", xmlTextReaderConstNamespaceUri(reader), xmlTextReaderConstLocalName(reader)];
    }
  }

  return _repositoryTargetResourceResponse;
}

/**
 * Writes this NEXUS_REST_APINS0RepositoryTargetResourceResponse to XML under element name "repo-target".
 * The namespace declarations for the element will be written.
 *
 * @param writer The XML writer.
 * @param _repositoryTargetResourceResponse The RepositoryTargetResourceResponse to write.
 * @return 1 if successful, 0 otherwise.
 */
- (void) writeXMLElement: (xmlTextWriterPtr) writer
{
  [self writeXMLElement: writer writeNamespaces: YES];
}

/**
 * Writes this NEXUS_REST_APINS0RepositoryTargetResourceResponse to an XML writer.
 *
 * @param writer The writer.
 * @param writeNs Whether to write the namespaces for this element to the xml writer.
 */
- (void) writeXMLElement: (xmlTextWriterPtr) writer writeNamespaces: (BOOL) writeNs
{
  int rc = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "repo-target", NULL);
  if (rc < 0) {
    [NSException raise: @"XMLWriteError"
                 format: @"Error writing start element {}repo-target. XML writer status: %i\n", rc];
  }

#if DEBUG_ENUNCIATE > 1
  NSLog(@"writing type {}repositoryTargetResourceResponse for root element {}repo-target...");
#endif
  [self writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
  NSLog(@"successfully wrote type {}repositoryTargetResourceResponse for root element {}repo-target...");
#endif
  rc = xmlTextWriterEndElement(writer);
  if (rc < 0) {
    [NSException raise: @"XMLWriteError"
                 format: @"Error writing end element {}repo-target. XML writer status: %i\n", rc];
  }
}

//documentation inherited.
- (BOOL) readJAXBAttribute: (xmlTextReaderPtr) reader
{
  void *_child_accessor;

  if ([super readJAXBAttribute: reader]) {
    return YES;
  }

  return NO;
}

//documentation inherited.
- (BOOL) readJAXBValue: (xmlTextReaderPtr) reader
{
  return [super readJAXBValue: reader];
}

//documentation inherited.
- (BOOL) readJAXBChildElement: (xmlTextReaderPtr) reader
{
  id __child;
  void *_child_accessor;
  int status, depth;

  if ([super readJAXBChildElement: reader]) {
    return YES;
  }
  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "data", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}data of type {}repository-target-resource.");
#endif
    __child = [NEXUS_REST_APINS0RepositoryTargetResource readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}data of type {}repository-target-resource.");
#endif

    [self setData: __child];
    return YES;
  } //end "if choice"


  return NO;
}

//documentation inherited.
- (int) readUnknownJAXBChildElement: (xmlTextReaderPtr) reader
{
  return [super readUnknownJAXBChildElement: reader];
}

//documentation inherited.
- (void) readUnknownJAXBAttribute: (xmlTextReaderPtr) reader
{
  [super readUnknownJAXBAttribute: reader];
}

//documentation inherited.
- (void) writeJAXBAttributes: (xmlTextWriterPtr) writer
{
  int status;

  [super writeJAXBAttributes: writer];

}

//documentation inherited.
- (void) writeJAXBValue: (xmlTextWriterPtr) writer
{
  [super writeJAXBValue: writer];
}

/**
 * Method for writing the child elements.
 *
 * @param writer The writer.
 */
- (void) writeJAXBChildElements: (xmlTextWriterPtr) writer
{
  int status;
  id __item;
  NSEnumerator *__enumerator;

  [super writeJAXBChildElements: writer];

  if ([self data]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "data", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}data."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}data...");
#endif
    [[self data] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}data...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}data."];
    }
  }
}
@end /* implementation NEXUS_REST_APINS0RepositoryTargetResourceResponse (JAXB) */

#endif /* DEF_NEXUS_REST_APINS0RepositoryTargetResourceResponse_M */
#ifndef DEF_NEXUS_REST_APINS0ScheduledServiceResourceResponse_M
#define DEF_NEXUS_REST_APINS0ScheduledServiceResourceResponse_M

/**
 *  REST Response object for a scheduled service configuration
 request, contains the typical 'data' parameter, which is the
 scheduled service configuration.
 
 @version $Revision$ $Date$

 */
@implementation NEXUS_REST_APINS0ScheduledServiceResourceResponse

/**
 * The scheduled service configuration.
 */
- (NEXUS_REST_APINS0ScheduledServiceBaseResource *) data
{
  return _data;
}

/**
 * The scheduled service configuration.
 */
- (void) setData: (NEXUS_REST_APINS0ScheduledServiceBaseResource *) newData
{
  [newData retain];
  [_data release];
  _data = newData;
}

- (void) dealloc
{
  [self setData: nil];
  [super dealloc];
}

//documentation inherited.
+ (id<EnunciateXML>) readFromXML: (NSData *) xml
{
  NEXUS_REST_APINS0ScheduledServiceResourceResponse *_nEXUS_REST_APINS0ScheduledServiceResourceResponse;
  xmlTextReaderPtr reader = xmlReaderForMemory([xml bytes], [xml length], NULL, NULL, 0);
  if (reader == NULL) {
    [NSException raise: @"XMLReadError"
                 format: @"Error instantiating an XML reader."];
    return nil;
  }

  _nEXUS_REST_APINS0ScheduledServiceResourceResponse = (NEXUS_REST_APINS0ScheduledServiceResourceResponse *) [NEXUS_REST_APINS0ScheduledServiceResourceResponse readXMLElement: reader];
  xmlFreeTextReader(reader); //free the reader
  return _nEXUS_REST_APINS0ScheduledServiceResourceResponse;
}

//documentation inherited.
- (NSData *) writeToXML
{
  xmlBufferPtr buf;
  xmlTextWriterPtr writer;
  int rc;
  NSData *data;

  buf = xmlBufferCreate();
  if (buf == NULL) {
    [NSException raise: @"XMLWriteError"
                 format: @"Error creating an XML buffer."];
    return nil;
  }

  writer = xmlNewTextWriterMemory(buf, 0);
  if (writer == NULL) {
    xmlBufferFree(buf);
    [NSException raise: @"XMLWriteError"
                 format: @"Error creating an XML writer."];
    return nil;
  }

  rc = xmlTextWriterStartDocument(writer, NULL, "utf-8", NULL);
  if (rc < 0) {
    xmlFreeTextWriter(writer);
    xmlBufferFree(buf);
    [NSException raise: @"XMLWriteError"
                 format: @"Error writing XML start document."];
    return nil;
  }

  NS_DURING
  {
    [self writeXMLElement: writer];
  }
  NS_HANDLER
  {
    xmlFreeTextWriter(writer);
    xmlBufferFree(buf);
    [localException raise];
  }
  NS_ENDHANDLER

  rc = xmlTextWriterEndDocument(writer);
  if (rc < 0) {
    xmlFreeTextWriter(writer);
    xmlBufferFree(buf);
    [NSException raise: @"XMLWriteError"
                 format: @"Error writing XML end document."];
    return nil;
  }

  xmlFreeTextWriter(writer);
  data = [NSData dataWithBytes: buf->content length: buf->use];
  xmlBufferFree(buf);
  return data;
}
@end /* implementation NEXUS_REST_APINS0ScheduledServiceResourceResponse */

/**
 * Internal, private interface for JAXB reading and writing.
 */
@interface NEXUS_REST_APINS0ScheduledServiceResourceResponse (JAXB) <JAXBReading, JAXBWriting, JAXBType, JAXBElement>

@end /*interface NEXUS_REST_APINS0ScheduledServiceResourceResponse (JAXB)*/

/**
 * Internal, private implementation for JAXB reading and writing.
 */
@implementation NEXUS_REST_APINS0ScheduledServiceResourceResponse (JAXB)

/**
 * Read an instance of NEXUS_REST_APINS0ScheduledServiceResourceResponse from an XML reader.
 *
 * @param reader The reader.
 * @return An instance of NEXUS_REST_APINS0ScheduledServiceResourceResponse defined by the XML reader.
 */
+ (id<JAXBType>) readXMLType: (xmlTextReaderPtr) reader
{
  NEXUS_REST_APINS0ScheduledServiceResourceResponse *_nEXUS_REST_APINS0ScheduledServiceResourceResponse = [[NEXUS_REST_APINS0ScheduledServiceResourceResponse alloc] init];
  NS_DURING
  {
    [_nEXUS_REST_APINS0ScheduledServiceResourceResponse initWithReader: reader];
  }
  NS_HANDLER
  {
    [_nEXUS_REST_APINS0ScheduledServiceResourceResponse dealloc];
    _nEXUS_REST_APINS0ScheduledServiceResourceResponse = nil;
    [localException raise];
  }
  NS_ENDHANDLER

  [_nEXUS_REST_APINS0ScheduledServiceResourceResponse autorelease];
  return _nEXUS_REST_APINS0ScheduledServiceResourceResponse;
}

/**
 * Initialize this instance of NEXUS_REST_APINS0ScheduledServiceResourceResponse according to
 * the XML being read from the reader.
 *
 * @param reader The reader.
 */
- (id) initWithReader: (xmlTextReaderPtr) reader
{
  return [super initWithReader: reader];
}

/**
 * Write the XML for this instance of NEXUS_REST_APINS0ScheduledServiceResourceResponse to the writer.
 * Note that since we're only writing the XML type,
 * No start/end element will be written.
 *
 * @param reader The reader.
 */
- (void) writeXMLType: (xmlTextWriterPtr) writer
{
  [super writeXMLType:writer];
}

/**
 * Reads a NEXUS_REST_APINS0ScheduledServiceResourceResponse from an XML reader. The element to be read is
 * "scheduled-task".
 *
 * @param reader The XML reader.
 * @return The NEXUS_REST_APINS0ScheduledServiceResourceResponse.
 */
+ (id<JAXBElement>) readXMLElement: (xmlTextReaderPtr) reader {
  int status;
  NEXUS_REST_APINS0ScheduledServiceResourceResponse *_scheduledServiceResourceResponse = nil;

  if (xmlTextReaderNodeType(reader) != XML_READER_TYPE_ELEMENT) {
    status = xmlTextReaderAdvanceToNextStartOrEndElement(reader);
    if (status < 1) {
      [NSException raise: @"XMLReadError"
                   format: @"Error advancing the reader to start element scheduled-task."];
    }
  }

  if (xmlStrcmp(BAD_CAST "scheduled-task", xmlTextReaderConstLocalName(reader)) == 0
      && xmlTextReaderConstNamespaceUri(reader) == NULL) {
#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read root element {}scheduled-task.");
#endif
    _scheduledServiceResourceResponse = (NEXUS_REST_APINS0ScheduledServiceResourceResponse *)[NEXUS_REST_APINS0ScheduledServiceResourceResponse readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"Successfully read root element {}scheduled-task.");
#endif
  }
  else {
    if (xmlTextReaderConstNamespaceUri(reader) == NULL) {
      [NSException raise: @"XMLReadError"
                   format: @"Unable to read NEXUS_REST_APINS0ScheduledServiceResourceResponse. Expected element scheduled-task. Current element: {}%s", xmlTextReaderConstLocalName(reader)];
    }
    else {
      [NSException raise: @"XMLReadError"
                   format: @"Unable to read NEXUS_REST_APINS0ScheduledServiceResourceResponse. Expected element scheduled-task. Current element: {%s}%s\n", xmlTextReaderConstNamespaceUri(reader), xmlTextReaderConstLocalName(reader)];
    }
  }

  return _scheduledServiceResourceResponse;
}

/**
 * Writes this NEXUS_REST_APINS0ScheduledServiceResourceResponse to XML under element name "scheduled-task".
 * The namespace declarations for the element will be written.
 *
 * @param writer The XML writer.
 * @param _scheduledServiceResourceResponse The ScheduledServiceResourceResponse to write.
 * @return 1 if successful, 0 otherwise.
 */
- (void) writeXMLElement: (xmlTextWriterPtr) writer
{
  [self writeXMLElement: writer writeNamespaces: YES];
}

/**
 * Writes this NEXUS_REST_APINS0ScheduledServiceResourceResponse to an XML writer.
 *
 * @param writer The writer.
 * @param writeNs Whether to write the namespaces for this element to the xml writer.
 */
- (void) writeXMLElement: (xmlTextWriterPtr) writer writeNamespaces: (BOOL) writeNs
{
  int rc = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "scheduled-task", NULL);
  if (rc < 0) {
    [NSException raise: @"XMLWriteError"
                 format: @"Error writing start element {}scheduled-task. XML writer status: %i\n", rc];
  }

#if DEBUG_ENUNCIATE > 1
  NSLog(@"writing type {}scheduledServiceResourceResponse for root element {}scheduled-task...");
#endif
  [self writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
  NSLog(@"successfully wrote type {}scheduledServiceResourceResponse for root element {}scheduled-task...");
#endif
  rc = xmlTextWriterEndElement(writer);
  if (rc < 0) {
    [NSException raise: @"XMLWriteError"
                 format: @"Error writing end element {}scheduled-task. XML writer status: %i\n", rc];
  }
}

//documentation inherited.
- (BOOL) readJAXBAttribute: (xmlTextReaderPtr) reader
{
  void *_child_accessor;

  if ([super readJAXBAttribute: reader]) {
    return YES;
  }

  return NO;
}

//documentation inherited.
- (BOOL) readJAXBValue: (xmlTextReaderPtr) reader
{
  return [super readJAXBValue: reader];
}

//documentation inherited.
- (BOOL) readJAXBChildElement: (xmlTextReaderPtr) reader
{
  id __child;
  void *_child_accessor;
  int status, depth;

  if ([super readJAXBChildElement: reader]) {
    return YES;
  }
  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "data", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}data of type {}scheduled-service-base-resource.");
#endif
    __child = [NEXUS_REST_APINS0ScheduledServiceBaseResource readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}data of type {}scheduled-service-base-resource.");
#endif

    [self setData: __child];
    return YES;
  } //end "if choice"


  return NO;
}

//documentation inherited.
- (int) readUnknownJAXBChildElement: (xmlTextReaderPtr) reader
{
  return [super readUnknownJAXBChildElement: reader];
}

//documentation inherited.
- (void) readUnknownJAXBAttribute: (xmlTextReaderPtr) reader
{
  [super readUnknownJAXBAttribute: reader];
}

//documentation inherited.
- (void) writeJAXBAttributes: (xmlTextWriterPtr) writer
{
  int status;

  [super writeJAXBAttributes: writer];

}

//documentation inherited.
- (void) writeJAXBValue: (xmlTextWriterPtr) writer
{
  [super writeJAXBValue: writer];
}

/**
 * Method for writing the child elements.
 *
 * @param writer The writer.
 */
- (void) writeJAXBChildElements: (xmlTextWriterPtr) writer
{
  int status;
  id __item;
  NSEnumerator *__enumerator;

  [super writeJAXBChildElements: writer];

  if ([self data]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "data", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}data."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}data...");
#endif
    [[self data] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}data...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}data."];
    }
  }
}
@end /* implementation NEXUS_REST_APINS0ScheduledServiceResourceResponse (JAXB) */

#endif /* DEF_NEXUS_REST_APINS0ScheduledServiceResourceResponse_M */
#ifndef DEF_NEXUS_REST_APINS0SmtpSettingsResourceRequest_M
#define DEF_NEXUS_REST_APINS0SmtpSettingsResourceRequest_M

/**
 *  REST Request object for validating the nexus smtp settings,
 contains the typical 'data' parameter, which is the nexus stmp
 configuration.
 
 @version $Revision$ $Date$

 */
@implementation NEXUS_REST_APINS0SmtpSettingsResourceRequest

/**
 * The nexus smtp configuration.
 */
- (NEXUS_REST_APINS0SmtpSettingsResource *) data
{
  return _data;
}

/**
 * The nexus smtp configuration.
 */
- (void) setData: (NEXUS_REST_APINS0SmtpSettingsResource *) newData
{
  [newData retain];
  [_data release];
  _data = newData;
}

- (void) dealloc
{
  [self setData: nil];
  [super dealloc];
}

//documentation inherited.
+ (id<EnunciateXML>) readFromXML: (NSData *) xml
{
  NEXUS_REST_APINS0SmtpSettingsResourceRequest *_nEXUS_REST_APINS0SmtpSettingsResourceRequest;
  xmlTextReaderPtr reader = xmlReaderForMemory([xml bytes], [xml length], NULL, NULL, 0);
  if (reader == NULL) {
    [NSException raise: @"XMLReadError"
                 format: @"Error instantiating an XML reader."];
    return nil;
  }

  _nEXUS_REST_APINS0SmtpSettingsResourceRequest = (NEXUS_REST_APINS0SmtpSettingsResourceRequest *) [NEXUS_REST_APINS0SmtpSettingsResourceRequest readXMLElement: reader];
  xmlFreeTextReader(reader); //free the reader
  return _nEXUS_REST_APINS0SmtpSettingsResourceRequest;
}

//documentation inherited.
- (NSData *) writeToXML
{
  xmlBufferPtr buf;
  xmlTextWriterPtr writer;
  int rc;
  NSData *data;

  buf = xmlBufferCreate();
  if (buf == NULL) {
    [NSException raise: @"XMLWriteError"
                 format: @"Error creating an XML buffer."];
    return nil;
  }

  writer = xmlNewTextWriterMemory(buf, 0);
  if (writer == NULL) {
    xmlBufferFree(buf);
    [NSException raise: @"XMLWriteError"
                 format: @"Error creating an XML writer."];
    return nil;
  }

  rc = xmlTextWriterStartDocument(writer, NULL, "utf-8", NULL);
  if (rc < 0) {
    xmlFreeTextWriter(writer);
    xmlBufferFree(buf);
    [NSException raise: @"XMLWriteError"
                 format: @"Error writing XML start document."];
    return nil;
  }

  NS_DURING
  {
    [self writeXMLElement: writer];
  }
  NS_HANDLER
  {
    xmlFreeTextWriter(writer);
    xmlBufferFree(buf);
    [localException raise];
  }
  NS_ENDHANDLER

  rc = xmlTextWriterEndDocument(writer);
  if (rc < 0) {
    xmlFreeTextWriter(writer);
    xmlBufferFree(buf);
    [NSException raise: @"XMLWriteError"
                 format: @"Error writing XML end document."];
    return nil;
  }

  xmlFreeTextWriter(writer);
  data = [NSData dataWithBytes: buf->content length: buf->use];
  xmlBufferFree(buf);
  return data;
}
@end /* implementation NEXUS_REST_APINS0SmtpSettingsResourceRequest */

/**
 * Internal, private interface for JAXB reading and writing.
 */
@interface NEXUS_REST_APINS0SmtpSettingsResourceRequest (JAXB) <JAXBReading, JAXBWriting, JAXBType, JAXBElement>

@end /*interface NEXUS_REST_APINS0SmtpSettingsResourceRequest (JAXB)*/

/**
 * Internal, private implementation for JAXB reading and writing.
 */
@implementation NEXUS_REST_APINS0SmtpSettingsResourceRequest (JAXB)

/**
 * Read an instance of NEXUS_REST_APINS0SmtpSettingsResourceRequest from an XML reader.
 *
 * @param reader The reader.
 * @return An instance of NEXUS_REST_APINS0SmtpSettingsResourceRequest defined by the XML reader.
 */
+ (id<JAXBType>) readXMLType: (xmlTextReaderPtr) reader
{
  NEXUS_REST_APINS0SmtpSettingsResourceRequest *_nEXUS_REST_APINS0SmtpSettingsResourceRequest = [[NEXUS_REST_APINS0SmtpSettingsResourceRequest alloc] init];
  NS_DURING
  {
    [_nEXUS_REST_APINS0SmtpSettingsResourceRequest initWithReader: reader];
  }
  NS_HANDLER
  {
    [_nEXUS_REST_APINS0SmtpSettingsResourceRequest dealloc];
    _nEXUS_REST_APINS0SmtpSettingsResourceRequest = nil;
    [localException raise];
  }
  NS_ENDHANDLER

  [_nEXUS_REST_APINS0SmtpSettingsResourceRequest autorelease];
  return _nEXUS_REST_APINS0SmtpSettingsResourceRequest;
}

/**
 * Initialize this instance of NEXUS_REST_APINS0SmtpSettingsResourceRequest according to
 * the XML being read from the reader.
 *
 * @param reader The reader.
 */
- (id) initWithReader: (xmlTextReaderPtr) reader
{
  return [super initWithReader: reader];
}

/**
 * Write the XML for this instance of NEXUS_REST_APINS0SmtpSettingsResourceRequest to the writer.
 * Note that since we're only writing the XML type,
 * No start/end element will be written.
 *
 * @param reader The reader.
 */
- (void) writeXMLType: (xmlTextWriterPtr) writer
{
  [super writeXMLType:writer];
}

/**
 * Reads a NEXUS_REST_APINS0SmtpSettingsResourceRequest from an XML reader. The element to be read is
 * "smtp-settings-request".
 *
 * @param reader The XML reader.
 * @return The NEXUS_REST_APINS0SmtpSettingsResourceRequest.
 */
+ (id<JAXBElement>) readXMLElement: (xmlTextReaderPtr) reader {
  int status;
  NEXUS_REST_APINS0SmtpSettingsResourceRequest *_smtpSettingsResourceRequest = nil;

  if (xmlTextReaderNodeType(reader) != XML_READER_TYPE_ELEMENT) {
    status = xmlTextReaderAdvanceToNextStartOrEndElement(reader);
    if (status < 1) {
      [NSException raise: @"XMLReadError"
                   format: @"Error advancing the reader to start element smtp-settings-request."];
    }
  }

  if (xmlStrcmp(BAD_CAST "smtp-settings-request", xmlTextReaderConstLocalName(reader)) == 0
      && xmlTextReaderConstNamespaceUri(reader) == NULL) {
#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read root element {}smtp-settings-request.");
#endif
    _smtpSettingsResourceRequest = (NEXUS_REST_APINS0SmtpSettingsResourceRequest *)[NEXUS_REST_APINS0SmtpSettingsResourceRequest readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"Successfully read root element {}smtp-settings-request.");
#endif
  }
  else {
    if (xmlTextReaderConstNamespaceUri(reader) == NULL) {
      [NSException raise: @"XMLReadError"
                   format: @"Unable to read NEXUS_REST_APINS0SmtpSettingsResourceRequest. Expected element smtp-settings-request. Current element: {}%s", xmlTextReaderConstLocalName(reader)];
    }
    else {
      [NSException raise: @"XMLReadError"
                   format: @"Unable to read NEXUS_REST_APINS0SmtpSettingsResourceRequest. Expected element smtp-settings-request. Current element: {%s}%s\n", xmlTextReaderConstNamespaceUri(reader), xmlTextReaderConstLocalName(reader)];
    }
  }

  return _smtpSettingsResourceRequest;
}

/**
 * Writes this NEXUS_REST_APINS0SmtpSettingsResourceRequest to XML under element name "smtp-settings-request".
 * The namespace declarations for the element will be written.
 *
 * @param writer The XML writer.
 * @param _smtpSettingsResourceRequest The SmtpSettingsResourceRequest to write.
 * @return 1 if successful, 0 otherwise.
 */
- (void) writeXMLElement: (xmlTextWriterPtr) writer
{
  [self writeXMLElement: writer writeNamespaces: YES];
}

/**
 * Writes this NEXUS_REST_APINS0SmtpSettingsResourceRequest to an XML writer.
 *
 * @param writer The writer.
 * @param writeNs Whether to write the namespaces for this element to the xml writer.
 */
- (void) writeXMLElement: (xmlTextWriterPtr) writer writeNamespaces: (BOOL) writeNs
{
  int rc = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "smtp-settings-request", NULL);
  if (rc < 0) {
    [NSException raise: @"XMLWriteError"
                 format: @"Error writing start element {}smtp-settings-request. XML writer status: %i\n", rc];
  }

#if DEBUG_ENUNCIATE > 1
  NSLog(@"writing type {}smtpSettingsResourceRequest for root element {}smtp-settings-request...");
#endif
  [self writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
  NSLog(@"successfully wrote type {}smtpSettingsResourceRequest for root element {}smtp-settings-request...");
#endif
  rc = xmlTextWriterEndElement(writer);
  if (rc < 0) {
    [NSException raise: @"XMLWriteError"
                 format: @"Error writing end element {}smtp-settings-request. XML writer status: %i\n", rc];
  }
}

//documentation inherited.
- (BOOL) readJAXBAttribute: (xmlTextReaderPtr) reader
{
  void *_child_accessor;

  if ([super readJAXBAttribute: reader]) {
    return YES;
  }

  return NO;
}

//documentation inherited.
- (BOOL) readJAXBValue: (xmlTextReaderPtr) reader
{
  return [super readJAXBValue: reader];
}

//documentation inherited.
- (BOOL) readJAXBChildElement: (xmlTextReaderPtr) reader
{
  id __child;
  void *_child_accessor;
  int status, depth;

  if ([super readJAXBChildElement: reader]) {
    return YES;
  }
  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "data", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}data of type {}smtp-settings-resource.");
#endif
    __child = [NEXUS_REST_APINS0SmtpSettingsResource readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}data of type {}smtp-settings-resource.");
#endif

    [self setData: __child];
    return YES;
  } //end "if choice"


  return NO;
}

//documentation inherited.
- (int) readUnknownJAXBChildElement: (xmlTextReaderPtr) reader
{
  return [super readUnknownJAXBChildElement: reader];
}

//documentation inherited.
- (void) readUnknownJAXBAttribute: (xmlTextReaderPtr) reader
{
  [super readUnknownJAXBAttribute: reader];
}

//documentation inherited.
- (void) writeJAXBAttributes: (xmlTextWriterPtr) writer
{
  int status;

  [super writeJAXBAttributes: writer];

}

//documentation inherited.
- (void) writeJAXBValue: (xmlTextWriterPtr) writer
{
  [super writeJAXBValue: writer];
}

/**
 * Method for writing the child elements.
 *
 * @param writer The writer.
 */
- (void) writeJAXBChildElements: (xmlTextWriterPtr) writer
{
  int status;
  id __item;
  NSEnumerator *__enumerator;

  [super writeJAXBChildElements: writer];

  if ([self data]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "data", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}data."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}data...");
#endif
    [[self data] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}data...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}data."];
    }
  }
}
@end /* implementation NEXUS_REST_APINS0SmtpSettingsResourceRequest (JAXB) */

#endif /* DEF_NEXUS_REST_APINS0SmtpSettingsResourceRequest_M */
#ifndef DEF_NEXUS_REST_APINS0WastebasketResourceResponse_M
#define DEF_NEXUS_REST_APINS0WastebasketResourceResponse_M

/**
 *  REST Response object for the nexus wastebasket info, contains
 the typical 'data' parameter, which is the nexus wastebasket
 info.
 
 @version $Revision$ $Date$

 */
@implementation NEXUS_REST_APINS0WastebasketResourceResponse

/**
 * The wastebasket information.
 */
- (NEXUS_REST_APINS0WastebasketResource *) data
{
  return _data;
}

/**
 * The wastebasket information.
 */
- (void) setData: (NEXUS_REST_APINS0WastebasketResource *) newData
{
  [newData retain];
  [_data release];
  _data = newData;
}

- (void) dealloc
{
  [self setData: nil];
  [super dealloc];
}

//documentation inherited.
+ (id<EnunciateXML>) readFromXML: (NSData *) xml
{
  NEXUS_REST_APINS0WastebasketResourceResponse *_nEXUS_REST_APINS0WastebasketResourceResponse;
  xmlTextReaderPtr reader = xmlReaderForMemory([xml bytes], [xml length], NULL, NULL, 0);
  if (reader == NULL) {
    [NSException raise: @"XMLReadError"
                 format: @"Error instantiating an XML reader."];
    return nil;
  }

  _nEXUS_REST_APINS0WastebasketResourceResponse = (NEXUS_REST_APINS0WastebasketResourceResponse *) [NEXUS_REST_APINS0WastebasketResourceResponse readXMLElement: reader];
  xmlFreeTextReader(reader); //free the reader
  return _nEXUS_REST_APINS0WastebasketResourceResponse;
}

//documentation inherited.
- (NSData *) writeToXML
{
  xmlBufferPtr buf;
  xmlTextWriterPtr writer;
  int rc;
  NSData *data;

  buf = xmlBufferCreate();
  if (buf == NULL) {
    [NSException raise: @"XMLWriteError"
                 format: @"Error creating an XML buffer."];
    return nil;
  }

  writer = xmlNewTextWriterMemory(buf, 0);
  if (writer == NULL) {
    xmlBufferFree(buf);
    [NSException raise: @"XMLWriteError"
                 format: @"Error creating an XML writer."];
    return nil;
  }

  rc = xmlTextWriterStartDocument(writer, NULL, "utf-8", NULL);
  if (rc < 0) {
    xmlFreeTextWriter(writer);
    xmlBufferFree(buf);
    [NSException raise: @"XMLWriteError"
                 format: @"Error writing XML start document."];
    return nil;
  }

  NS_DURING
  {
    [self writeXMLElement: writer];
  }
  NS_HANDLER
  {
    xmlFreeTextWriter(writer);
    xmlBufferFree(buf);
    [localException raise];
  }
  NS_ENDHANDLER

  rc = xmlTextWriterEndDocument(writer);
  if (rc < 0) {
    xmlFreeTextWriter(writer);
    xmlBufferFree(buf);
    [NSException raise: @"XMLWriteError"
                 format: @"Error writing XML end document."];
    return nil;
  }

  xmlFreeTextWriter(writer);
  data = [NSData dataWithBytes: buf->content length: buf->use];
  xmlBufferFree(buf);
  return data;
}
@end /* implementation NEXUS_REST_APINS0WastebasketResourceResponse */

/**
 * Internal, private interface for JAXB reading and writing.
 */
@interface NEXUS_REST_APINS0WastebasketResourceResponse (JAXB) <JAXBReading, JAXBWriting, JAXBType, JAXBElement>

@end /*interface NEXUS_REST_APINS0WastebasketResourceResponse (JAXB)*/

/**
 * Internal, private implementation for JAXB reading and writing.
 */
@implementation NEXUS_REST_APINS0WastebasketResourceResponse (JAXB)

/**
 * Read an instance of NEXUS_REST_APINS0WastebasketResourceResponse from an XML reader.
 *
 * @param reader The reader.
 * @return An instance of NEXUS_REST_APINS0WastebasketResourceResponse defined by the XML reader.
 */
+ (id<JAXBType>) readXMLType: (xmlTextReaderPtr) reader
{
  NEXUS_REST_APINS0WastebasketResourceResponse *_nEXUS_REST_APINS0WastebasketResourceResponse = [[NEXUS_REST_APINS0WastebasketResourceResponse alloc] init];
  NS_DURING
  {
    [_nEXUS_REST_APINS0WastebasketResourceResponse initWithReader: reader];
  }
  NS_HANDLER
  {
    [_nEXUS_REST_APINS0WastebasketResourceResponse dealloc];
    _nEXUS_REST_APINS0WastebasketResourceResponse = nil;
    [localException raise];
  }
  NS_ENDHANDLER

  [_nEXUS_REST_APINS0WastebasketResourceResponse autorelease];
  return _nEXUS_REST_APINS0WastebasketResourceResponse;
}

/**
 * Initialize this instance of NEXUS_REST_APINS0WastebasketResourceResponse according to
 * the XML being read from the reader.
 *
 * @param reader The reader.
 */
- (id) initWithReader: (xmlTextReaderPtr) reader
{
  return [super initWithReader: reader];
}

/**
 * Write the XML for this instance of NEXUS_REST_APINS0WastebasketResourceResponse to the writer.
 * Note that since we're only writing the XML type,
 * No start/end element will be written.
 *
 * @param reader The reader.
 */
- (void) writeXMLType: (xmlTextWriterPtr) writer
{
  [super writeXMLType:writer];
}

/**
 * Reads a NEXUS_REST_APINS0WastebasketResourceResponse from an XML reader. The element to be read is
 * "wastebasket".
 *
 * @param reader The XML reader.
 * @return The NEXUS_REST_APINS0WastebasketResourceResponse.
 */
+ (id<JAXBElement>) readXMLElement: (xmlTextReaderPtr) reader {
  int status;
  NEXUS_REST_APINS0WastebasketResourceResponse *_wastebasketResourceResponse = nil;

  if (xmlTextReaderNodeType(reader) != XML_READER_TYPE_ELEMENT) {
    status = xmlTextReaderAdvanceToNextStartOrEndElement(reader);
    if (status < 1) {
      [NSException raise: @"XMLReadError"
                   format: @"Error advancing the reader to start element wastebasket."];
    }
  }

  if (xmlStrcmp(BAD_CAST "wastebasket", xmlTextReaderConstLocalName(reader)) == 0
      && xmlTextReaderConstNamespaceUri(reader) == NULL) {
#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read root element {}wastebasket.");
#endif
    _wastebasketResourceResponse = (NEXUS_REST_APINS0WastebasketResourceResponse *)[NEXUS_REST_APINS0WastebasketResourceResponse readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"Successfully read root element {}wastebasket.");
#endif
  }
  else {
    if (xmlTextReaderConstNamespaceUri(reader) == NULL) {
      [NSException raise: @"XMLReadError"
                   format: @"Unable to read NEXUS_REST_APINS0WastebasketResourceResponse. Expected element wastebasket. Current element: {}%s", xmlTextReaderConstLocalName(reader)];
    }
    else {
      [NSException raise: @"XMLReadError"
                   format: @"Unable to read NEXUS_REST_APINS0WastebasketResourceResponse. Expected element wastebasket. Current element: {%s}%s\n", xmlTextReaderConstNamespaceUri(reader), xmlTextReaderConstLocalName(reader)];
    }
  }

  return _wastebasketResourceResponse;
}

/**
 * Writes this NEXUS_REST_APINS0WastebasketResourceResponse to XML under element name "wastebasket".
 * The namespace declarations for the element will be written.
 *
 * @param writer The XML writer.
 * @param _wastebasketResourceResponse The WastebasketResourceResponse to write.
 * @return 1 if successful, 0 otherwise.
 */
- (void) writeXMLElement: (xmlTextWriterPtr) writer
{
  [self writeXMLElement: writer writeNamespaces: YES];
}

/**
 * Writes this NEXUS_REST_APINS0WastebasketResourceResponse to an XML writer.
 *
 * @param writer The writer.
 * @param writeNs Whether to write the namespaces for this element to the xml writer.
 */
- (void) writeXMLElement: (xmlTextWriterPtr) writer writeNamespaces: (BOOL) writeNs
{
  int rc = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "wastebasket", NULL);
  if (rc < 0) {
    [NSException raise: @"XMLWriteError"
                 format: @"Error writing start element {}wastebasket. XML writer status: %i\n", rc];
  }

#if DEBUG_ENUNCIATE > 1
  NSLog(@"writing type {}wastebasketResourceResponse for root element {}wastebasket...");
#endif
  [self writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
  NSLog(@"successfully wrote type {}wastebasketResourceResponse for root element {}wastebasket...");
#endif
  rc = xmlTextWriterEndElement(writer);
  if (rc < 0) {
    [NSException raise: @"XMLWriteError"
                 format: @"Error writing end element {}wastebasket. XML writer status: %i\n", rc];
  }
}

//documentation inherited.
- (BOOL) readJAXBAttribute: (xmlTextReaderPtr) reader
{
  void *_child_accessor;

  if ([super readJAXBAttribute: reader]) {
    return YES;
  }

  return NO;
}

//documentation inherited.
- (BOOL) readJAXBValue: (xmlTextReaderPtr) reader
{
  return [super readJAXBValue: reader];
}

//documentation inherited.
- (BOOL) readJAXBChildElement: (xmlTextReaderPtr) reader
{
  id __child;
  void *_child_accessor;
  int status, depth;

  if ([super readJAXBChildElement: reader]) {
    return YES;
  }
  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "data", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}data of type {}wastebasket-resource.");
#endif
    __child = [NEXUS_REST_APINS0WastebasketResource readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}data of type {}wastebasket-resource.");
#endif

    [self setData: __child];
    return YES;
  } //end "if choice"


  return NO;
}

//documentation inherited.
- (int) readUnknownJAXBChildElement: (xmlTextReaderPtr) reader
{
  return [super readUnknownJAXBChildElement: reader];
}

//documentation inherited.
- (void) readUnknownJAXBAttribute: (xmlTextReaderPtr) reader
{
  [super readUnknownJAXBAttribute: reader];
}

//documentation inherited.
- (void) writeJAXBAttributes: (xmlTextWriterPtr) writer
{
  int status;

  [super writeJAXBAttributes: writer];

}

//documentation inherited.
- (void) writeJAXBValue: (xmlTextWriterPtr) writer
{
  [super writeJAXBValue: writer];
}

/**
 * Method for writing the child elements.
 *
 * @param writer The writer.
 */
- (void) writeJAXBChildElements: (xmlTextWriterPtr) writer
{
  int status;
  id __item;
  NSEnumerator *__enumerator;

  [super writeJAXBChildElements: writer];

  if ([self data]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "data", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}data."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}data...");
#endif
    [[self data] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}data...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}data."];
    }
  }
}
@end /* implementation NEXUS_REST_APINS0WastebasketResourceResponse (JAXB) */

#endif /* DEF_NEXUS_REST_APINS0WastebasketResourceResponse_M */
#ifndef DEF_NEXUS_REST_APINS0StatusResourceResponse_M
#define DEF_NEXUS_REST_APINS0StatusResourceResponse_M

/**
 *  REST Response object for the nexus status, contains the typical
 'data' parameter, which is the nexus status.
 
 @version $Revision$ $Date$

 */
@implementation NEXUS_REST_APINS0StatusResourceResponse

/**
 * Nexus status details.
 */
- (NEXUS_REST_APINS0StatusResource *) data
{
  return _data;
}

/**
 * Nexus status details.
 */
- (void) setData: (NEXUS_REST_APINS0StatusResource *) newData
{
  [newData retain];
  [_data release];
  _data = newData;
}

- (void) dealloc
{
  [self setData: nil];
  [super dealloc];
}

//documentation inherited.
+ (id<EnunciateXML>) readFromXML: (NSData *) xml
{
  NEXUS_REST_APINS0StatusResourceResponse *_nEXUS_REST_APINS0StatusResourceResponse;
  xmlTextReaderPtr reader = xmlReaderForMemory([xml bytes], [xml length], NULL, NULL, 0);
  if (reader == NULL) {
    [NSException raise: @"XMLReadError"
                 format: @"Error instantiating an XML reader."];
    return nil;
  }

  _nEXUS_REST_APINS0StatusResourceResponse = (NEXUS_REST_APINS0StatusResourceResponse *) [NEXUS_REST_APINS0StatusResourceResponse readXMLElement: reader];
  xmlFreeTextReader(reader); //free the reader
  return _nEXUS_REST_APINS0StatusResourceResponse;
}

//documentation inherited.
- (NSData *) writeToXML
{
  xmlBufferPtr buf;
  xmlTextWriterPtr writer;
  int rc;
  NSData *data;

  buf = xmlBufferCreate();
  if (buf == NULL) {
    [NSException raise: @"XMLWriteError"
                 format: @"Error creating an XML buffer."];
    return nil;
  }

  writer = xmlNewTextWriterMemory(buf, 0);
  if (writer == NULL) {
    xmlBufferFree(buf);
    [NSException raise: @"XMLWriteError"
                 format: @"Error creating an XML writer."];
    return nil;
  }

  rc = xmlTextWriterStartDocument(writer, NULL, "utf-8", NULL);
  if (rc < 0) {
    xmlFreeTextWriter(writer);
    xmlBufferFree(buf);
    [NSException raise: @"XMLWriteError"
                 format: @"Error writing XML start document."];
    return nil;
  }

  NS_DURING
  {
    [self writeXMLElement: writer];
  }
  NS_HANDLER
  {
    xmlFreeTextWriter(writer);
    xmlBufferFree(buf);
    [localException raise];
  }
  NS_ENDHANDLER

  rc = xmlTextWriterEndDocument(writer);
  if (rc < 0) {
    xmlFreeTextWriter(writer);
    xmlBufferFree(buf);
    [NSException raise: @"XMLWriteError"
                 format: @"Error writing XML end document."];
    return nil;
  }

  xmlFreeTextWriter(writer);
  data = [NSData dataWithBytes: buf->content length: buf->use];
  xmlBufferFree(buf);
  return data;
}
@end /* implementation NEXUS_REST_APINS0StatusResourceResponse */

/**
 * Internal, private interface for JAXB reading and writing.
 */
@interface NEXUS_REST_APINS0StatusResourceResponse (JAXB) <JAXBReading, JAXBWriting, JAXBType, JAXBElement>

@end /*interface NEXUS_REST_APINS0StatusResourceResponse (JAXB)*/

/**
 * Internal, private implementation for JAXB reading and writing.
 */
@implementation NEXUS_REST_APINS0StatusResourceResponse (JAXB)

/**
 * Read an instance of NEXUS_REST_APINS0StatusResourceResponse from an XML reader.
 *
 * @param reader The reader.
 * @return An instance of NEXUS_REST_APINS0StatusResourceResponse defined by the XML reader.
 */
+ (id<JAXBType>) readXMLType: (xmlTextReaderPtr) reader
{
  NEXUS_REST_APINS0StatusResourceResponse *_nEXUS_REST_APINS0StatusResourceResponse = [[NEXUS_REST_APINS0StatusResourceResponse alloc] init];
  NS_DURING
  {
    [_nEXUS_REST_APINS0StatusResourceResponse initWithReader: reader];
  }
  NS_HANDLER
  {
    [_nEXUS_REST_APINS0StatusResourceResponse dealloc];
    _nEXUS_REST_APINS0StatusResourceResponse = nil;
    [localException raise];
  }
  NS_ENDHANDLER

  [_nEXUS_REST_APINS0StatusResourceResponse autorelease];
  return _nEXUS_REST_APINS0StatusResourceResponse;
}

/**
 * Initialize this instance of NEXUS_REST_APINS0StatusResourceResponse according to
 * the XML being read from the reader.
 *
 * @param reader The reader.
 */
- (id) initWithReader: (xmlTextReaderPtr) reader
{
  return [super initWithReader: reader];
}

/**
 * Write the XML for this instance of NEXUS_REST_APINS0StatusResourceResponse to the writer.
 * Note that since we're only writing the XML type,
 * No start/end element will be written.
 *
 * @param reader The reader.
 */
- (void) writeXMLType: (xmlTextWriterPtr) writer
{
  [super writeXMLType:writer];
}

/**
 * Reads a NEXUS_REST_APINS0StatusResourceResponse from an XML reader. The element to be read is
 * "status".
 *
 * @param reader The XML reader.
 * @return The NEXUS_REST_APINS0StatusResourceResponse.
 */
+ (id<JAXBElement>) readXMLElement: (xmlTextReaderPtr) reader {
  int status;
  NEXUS_REST_APINS0StatusResourceResponse *_statusResourceResponse = nil;

  if (xmlTextReaderNodeType(reader) != XML_READER_TYPE_ELEMENT) {
    status = xmlTextReaderAdvanceToNextStartOrEndElement(reader);
    if (status < 1) {
      [NSException raise: @"XMLReadError"
                   format: @"Error advancing the reader to start element status."];
    }
  }

  if (xmlStrcmp(BAD_CAST "status", xmlTextReaderConstLocalName(reader)) == 0
      && xmlTextReaderConstNamespaceUri(reader) == NULL) {
#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read root element {}status.");
#endif
    _statusResourceResponse = (NEXUS_REST_APINS0StatusResourceResponse *)[NEXUS_REST_APINS0StatusResourceResponse readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"Successfully read root element {}status.");
#endif
  }
  else {
    if (xmlTextReaderConstNamespaceUri(reader) == NULL) {
      [NSException raise: @"XMLReadError"
                   format: @"Unable to read NEXUS_REST_APINS0StatusResourceResponse. Expected element status. Current element: {}%s", xmlTextReaderConstLocalName(reader)];
    }
    else {
      [NSException raise: @"XMLReadError"
                   format: @"Unable to read NEXUS_REST_APINS0StatusResourceResponse. Expected element status. Current element: {%s}%s\n", xmlTextReaderConstNamespaceUri(reader), xmlTextReaderConstLocalName(reader)];
    }
  }

  return _statusResourceResponse;
}

/**
 * Writes this NEXUS_REST_APINS0StatusResourceResponse to XML under element name "status".
 * The namespace declarations for the element will be written.
 *
 * @param writer The XML writer.
 * @param _statusResourceResponse The StatusResourceResponse to write.
 * @return 1 if successful, 0 otherwise.
 */
- (void) writeXMLElement: (xmlTextWriterPtr) writer
{
  [self writeXMLElement: writer writeNamespaces: YES];
}

/**
 * Writes this NEXUS_REST_APINS0StatusResourceResponse to an XML writer.
 *
 * @param writer The writer.
 * @param writeNs Whether to write the namespaces for this element to the xml writer.
 */
- (void) writeXMLElement: (xmlTextWriterPtr) writer writeNamespaces: (BOOL) writeNs
{
  int rc = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "status", NULL);
  if (rc < 0) {
    [NSException raise: @"XMLWriteError"
                 format: @"Error writing start element {}status. XML writer status: %i\n", rc];
  }

#if DEBUG_ENUNCIATE > 1
  NSLog(@"writing type {}statusResourceResponse for root element {}status...");
#endif
  [self writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
  NSLog(@"successfully wrote type {}statusResourceResponse for root element {}status...");
#endif
  rc = xmlTextWriterEndElement(writer);
  if (rc < 0) {
    [NSException raise: @"XMLWriteError"
                 format: @"Error writing end element {}status. XML writer status: %i\n", rc];
  }
}

//documentation inherited.
- (BOOL) readJAXBAttribute: (xmlTextReaderPtr) reader
{
  void *_child_accessor;

  if ([super readJAXBAttribute: reader]) {
    return YES;
  }

  return NO;
}

//documentation inherited.
- (BOOL) readJAXBValue: (xmlTextReaderPtr) reader
{
  return [super readJAXBValue: reader];
}

//documentation inherited.
- (BOOL) readJAXBChildElement: (xmlTextReaderPtr) reader
{
  id __child;
  void *_child_accessor;
  int status, depth;

  if ([super readJAXBChildElement: reader]) {
    return YES;
  }
  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "data", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}data of type {}status-resource.");
#endif
    __child = [NEXUS_REST_APINS0StatusResource readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}data of type {}status-resource.");
#endif

    [self setData: __child];
    return YES;
  } //end "if choice"


  return NO;
}

//documentation inherited.
- (int) readUnknownJAXBChildElement: (xmlTextReaderPtr) reader
{
  return [super readUnknownJAXBChildElement: reader];
}

//documentation inherited.
- (void) readUnknownJAXBAttribute: (xmlTextReaderPtr) reader
{
  [super readUnknownJAXBAttribute: reader];
}

//documentation inherited.
- (void) writeJAXBAttributes: (xmlTextWriterPtr) writer
{
  int status;

  [super writeJAXBAttributes: writer];

}

//documentation inherited.
- (void) writeJAXBValue: (xmlTextWriterPtr) writer
{
  [super writeJAXBValue: writer];
}

/**
 * Method for writing the child elements.
 *
 * @param writer The writer.
 */
- (void) writeJAXBChildElements: (xmlTextWriterPtr) writer
{
  int status;
  id __item;
  NSEnumerator *__enumerator;

  [super writeJAXBChildElements: writer];

  if ([self data]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "data", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}data."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}data...");
#endif
    [[self data] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}data...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}data."];
    }
  }
}
@end /* implementation NEXUS_REST_APINS0StatusResourceResponse (JAXB) */

#endif /* DEF_NEXUS_REST_APINS0StatusResourceResponse_M */
#ifndef DEF_NEXUS_REST_APINS0ScheduledServiceTypeResourceResponse_M
#define DEF_NEXUS_REST_APINS0ScheduledServiceTypeResourceResponse_M

/**
 *  REST Response object for a scheduled service type list request,
 contains the typical 'data' parameter, which is the scheduled
 service type details.
 
 @version $Revision$ $Date$

 */
@implementation NEXUS_REST_APINS0ScheduledServiceTypeResourceResponse

/**
 * Field data.
 */
- (NSArray *) data
{
  return _data;
}

/**
 * Field data.
 */
- (void) setData: (NSArray *) newData
{
  [newData retain];
  [_data release];
  _data = newData;
}

- (void) dealloc
{
  [self setData: nil];
  [super dealloc];
}

//documentation inherited.
+ (id<EnunciateXML>) readFromXML: (NSData *) xml
{
  NEXUS_REST_APINS0ScheduledServiceTypeResourceResponse *_nEXUS_REST_APINS0ScheduledServiceTypeResourceResponse;
  xmlTextReaderPtr reader = xmlReaderForMemory([xml bytes], [xml length], NULL, NULL, 0);
  if (reader == NULL) {
    [NSException raise: @"XMLReadError"
                 format: @"Error instantiating an XML reader."];
    return nil;
  }

  _nEXUS_REST_APINS0ScheduledServiceTypeResourceResponse = (NEXUS_REST_APINS0ScheduledServiceTypeResourceResponse *) [NEXUS_REST_APINS0ScheduledServiceTypeResourceResponse readXMLElement: reader];
  xmlFreeTextReader(reader); //free the reader
  return _nEXUS_REST_APINS0ScheduledServiceTypeResourceResponse;
}

//documentation inherited.
- (NSData *) writeToXML
{
  xmlBufferPtr buf;
  xmlTextWriterPtr writer;
  int rc;
  NSData *data;

  buf = xmlBufferCreate();
  if (buf == NULL) {
    [NSException raise: @"XMLWriteError"
                 format: @"Error creating an XML buffer."];
    return nil;
  }

  writer = xmlNewTextWriterMemory(buf, 0);
  if (writer == NULL) {
    xmlBufferFree(buf);
    [NSException raise: @"XMLWriteError"
                 format: @"Error creating an XML writer."];
    return nil;
  }

  rc = xmlTextWriterStartDocument(writer, NULL, "utf-8", NULL);
  if (rc < 0) {
    xmlFreeTextWriter(writer);
    xmlBufferFree(buf);
    [NSException raise: @"XMLWriteError"
                 format: @"Error writing XML start document."];
    return nil;
  }

  NS_DURING
  {
    [self writeXMLElement: writer];
  }
  NS_HANDLER
  {
    xmlFreeTextWriter(writer);
    xmlBufferFree(buf);
    [localException raise];
  }
  NS_ENDHANDLER

  rc = xmlTextWriterEndDocument(writer);
  if (rc < 0) {
    xmlFreeTextWriter(writer);
    xmlBufferFree(buf);
    [NSException raise: @"XMLWriteError"
                 format: @"Error writing XML end document."];
    return nil;
  }

  xmlFreeTextWriter(writer);
  data = [NSData dataWithBytes: buf->content length: buf->use];
  xmlBufferFree(buf);
  return data;
}
@end /* implementation NEXUS_REST_APINS0ScheduledServiceTypeResourceResponse */

/**
 * Internal, private interface for JAXB reading and writing.
 */
@interface NEXUS_REST_APINS0ScheduledServiceTypeResourceResponse (JAXB) <JAXBReading, JAXBWriting, JAXBType, JAXBElement>

@end /*interface NEXUS_REST_APINS0ScheduledServiceTypeResourceResponse (JAXB)*/

/**
 * Internal, private implementation for JAXB reading and writing.
 */
@implementation NEXUS_REST_APINS0ScheduledServiceTypeResourceResponse (JAXB)

/**
 * Read an instance of NEXUS_REST_APINS0ScheduledServiceTypeResourceResponse from an XML reader.
 *
 * @param reader The reader.
 * @return An instance of NEXUS_REST_APINS0ScheduledServiceTypeResourceResponse defined by the XML reader.
 */
+ (id<JAXBType>) readXMLType: (xmlTextReaderPtr) reader
{
  NEXUS_REST_APINS0ScheduledServiceTypeResourceResponse *_nEXUS_REST_APINS0ScheduledServiceTypeResourceResponse = [[NEXUS_REST_APINS0ScheduledServiceTypeResourceResponse alloc] init];
  NS_DURING
  {
    [_nEXUS_REST_APINS0ScheduledServiceTypeResourceResponse initWithReader: reader];
  }
  NS_HANDLER
  {
    [_nEXUS_REST_APINS0ScheduledServiceTypeResourceResponse dealloc];
    _nEXUS_REST_APINS0ScheduledServiceTypeResourceResponse = nil;
    [localException raise];
  }
  NS_ENDHANDLER

  [_nEXUS_REST_APINS0ScheduledServiceTypeResourceResponse autorelease];
  return _nEXUS_REST_APINS0ScheduledServiceTypeResourceResponse;
}

/**
 * Initialize this instance of NEXUS_REST_APINS0ScheduledServiceTypeResourceResponse according to
 * the XML being read from the reader.
 *
 * @param reader The reader.
 */
- (id) initWithReader: (xmlTextReaderPtr) reader
{
  return [super initWithReader: reader];
}

/**
 * Write the XML for this instance of NEXUS_REST_APINS0ScheduledServiceTypeResourceResponse to the writer.
 * Note that since we're only writing the XML type,
 * No start/end element will be written.
 *
 * @param reader The reader.
 */
- (void) writeXMLType: (xmlTextWriterPtr) writer
{
  [super writeXMLType:writer];
}

/**
 * Reads a NEXUS_REST_APINS0ScheduledServiceTypeResourceResponse from an XML reader. The element to be read is
 * "schedule-types".
 *
 * @param reader The XML reader.
 * @return The NEXUS_REST_APINS0ScheduledServiceTypeResourceResponse.
 */
+ (id<JAXBElement>) readXMLElement: (xmlTextReaderPtr) reader {
  int status;
  NEXUS_REST_APINS0ScheduledServiceTypeResourceResponse *_scheduledServiceTypeResourceResponse = nil;

  if (xmlTextReaderNodeType(reader) != XML_READER_TYPE_ELEMENT) {
    status = xmlTextReaderAdvanceToNextStartOrEndElement(reader);
    if (status < 1) {
      [NSException raise: @"XMLReadError"
                   format: @"Error advancing the reader to start element schedule-types."];
    }
  }

  if (xmlStrcmp(BAD_CAST "schedule-types", xmlTextReaderConstLocalName(reader)) == 0
      && xmlTextReaderConstNamespaceUri(reader) == NULL) {
#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read root element {}schedule-types.");
#endif
    _scheduledServiceTypeResourceResponse = (NEXUS_REST_APINS0ScheduledServiceTypeResourceResponse *)[NEXUS_REST_APINS0ScheduledServiceTypeResourceResponse readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"Successfully read root element {}schedule-types.");
#endif
  }
  else {
    if (xmlTextReaderConstNamespaceUri(reader) == NULL) {
      [NSException raise: @"XMLReadError"
                   format: @"Unable to read NEXUS_REST_APINS0ScheduledServiceTypeResourceResponse. Expected element schedule-types. Current element: {}%s", xmlTextReaderConstLocalName(reader)];
    }
    else {
      [NSException raise: @"XMLReadError"
                   format: @"Unable to read NEXUS_REST_APINS0ScheduledServiceTypeResourceResponse. Expected element schedule-types. Current element: {%s}%s\n", xmlTextReaderConstNamespaceUri(reader), xmlTextReaderConstLocalName(reader)];
    }
  }

  return _scheduledServiceTypeResourceResponse;
}

/**
 * Writes this NEXUS_REST_APINS0ScheduledServiceTypeResourceResponse to XML under element name "schedule-types".
 * The namespace declarations for the element will be written.
 *
 * @param writer The XML writer.
 * @param _scheduledServiceTypeResourceResponse The ScheduledServiceTypeResourceResponse to write.
 * @return 1 if successful, 0 otherwise.
 */
- (void) writeXMLElement: (xmlTextWriterPtr) writer
{
  [self writeXMLElement: writer writeNamespaces: YES];
}

/**
 * Writes this NEXUS_REST_APINS0ScheduledServiceTypeResourceResponse to an XML writer.
 *
 * @param writer The writer.
 * @param writeNs Whether to write the namespaces for this element to the xml writer.
 */
- (void) writeXMLElement: (xmlTextWriterPtr) writer writeNamespaces: (BOOL) writeNs
{
  int rc = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "schedule-types", NULL);
  if (rc < 0) {
    [NSException raise: @"XMLWriteError"
                 format: @"Error writing start element {}schedule-types. XML writer status: %i\n", rc];
  }

#if DEBUG_ENUNCIATE > 1
  NSLog(@"writing type {}scheduledServiceTypeResourceResponse for root element {}schedule-types...");
#endif
  [self writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
  NSLog(@"successfully wrote type {}scheduledServiceTypeResourceResponse for root element {}schedule-types...");
#endif
  rc = xmlTextWriterEndElement(writer);
  if (rc < 0) {
    [NSException raise: @"XMLWriteError"
                 format: @"Error writing end element {}schedule-types. XML writer status: %i\n", rc];
  }
}

//documentation inherited.
- (BOOL) readJAXBAttribute: (xmlTextReaderPtr) reader
{
  void *_child_accessor;

  if ([super readJAXBAttribute: reader]) {
    return YES;
  }

  return NO;
}

//documentation inherited.
- (BOOL) readJAXBValue: (xmlTextReaderPtr) reader
{
  return [super readJAXBValue: reader];
}

//documentation inherited.
- (BOOL) readJAXBChildElement: (xmlTextReaderPtr) reader
{
  id __child;
  void *_child_accessor;
  int status, depth;

  if ([super readJAXBChildElement: reader]) {
    return YES;
  }
  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "data", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

    if (xmlTextReaderIsEmptyElement(reader) == 0) {
#if DEBUG_ENUNCIATE > 1
      NSLog(@"Unwrapping wrapper element {}data...");
#endif
      //start wrapper element "{}data"
      depth = xmlTextReaderDepth(reader);
      status = xmlTextReaderAdvanceToNextStartOrEndElement(reader);
      while (xmlTextReaderDepth(reader) > depth) {
        if (status < 1) {
          //panic: XML read error.
          [self dealloc];
          [NSException raise: @"XMLReadError"
                       format: @"Failure to advance to next wrapped child element."];
        }
  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "schedule-type", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}schedule-type of type {}scheduled-service-type-resource.");
#endif

    __child = [NEXUS_REST_APINS0ScheduledServiceTypeResource readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}schedule-type of type {}scheduled-service-type-resource.");
#endif

    if ([self data]) {
      [self setData: [[self data] arrayByAddingObject: __child]];
    }
    else {
      [self setData: [NSArray arrayWithObject: __child]];
    }
    continue; //continue "while in wrapper element" loop
  } //end "if choice"

        status = xmlTextReaderAdvanceToNextStartOrEndElement(reader);
#if DEBUG_ENUNCIATE > 1
        NSLog(@"successfully unwrapped wrapper element {}data...");
#endif
      } // end "while in wrapper element" loop

      if (status < 1) {
        //panic: XML read error.
        [self dealloc];
        [NSException raise: @"XMLReadError"
                     format: @"Failure to advance to end wrapper element."];
      }
      else {
        //end wrapper element "{}data"
        status = xmlTextReaderAdvanceToNextStartOrEndElement(reader);
      }
    } //end "if empty element" clause
    else {
      __child = [NSArray array];
      [self setData: (NSArray*) __child];
    }

    return YES;
  } // end "if wrapper element" clause

  return NO;
}

//documentation inherited.
- (int) readUnknownJAXBChildElement: (xmlTextReaderPtr) reader
{
  return [super readUnknownJAXBChildElement: reader];
}

//documentation inherited.
- (void) readUnknownJAXBAttribute: (xmlTextReaderPtr) reader
{
  [super readUnknownJAXBAttribute: reader];
}

//documentation inherited.
- (void) writeJAXBAttributes: (xmlTextWriterPtr) writer
{
  int status;

  [super writeJAXBAttributes: writer];

}

//documentation inherited.
- (void) writeJAXBValue: (xmlTextWriterPtr) writer
{
  [super writeJAXBValue: writer];
}

/**
 * Method for writing the child elements.
 *
 * @param writer The writer.
 */
- (void) writeJAXBChildElements: (xmlTextWriterPtr) writer
{
  int status;
  id __item;
  NSEnumerator *__enumerator;

  [super writeJAXBChildElements: writer];

  if ([self data]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "data", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start wrapper element {}data."];
    }
    __enumerator = [[self data] objectEnumerator];

    while ( (__item = [__enumerator nextObject]) ) {
      status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "schedule-type", NULL);
      if (status < 0) {
        [NSException raise: @"XMLWriteError"
                     format: @"Error writing start child element {}schedule-type."];
      }

#if DEBUG_ENUNCIATE > 1
      NSLog(@"writing element {}schedule-type...");
#endif
      [__item writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
      NSLog(@"successfully wrote element {}schedule-type...");
#endif

      status = xmlTextWriterEndElement(writer);
      if (status < 0) {
        [NSException raise: @"XMLWriteError"
                     format: @"Error writing end child element {}schedule-type."];
      }
    } //end item iterator.

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end wrapper element {}data."];
    }
  }
}
@end /* implementation NEXUS_REST_APINS0ScheduledServiceTypeResourceResponse (JAXB) */

#endif /* DEF_NEXUS_REST_APINS0ScheduledServiceTypeResourceResponse_M */
#ifndef DEF_NEXUS_REST_APINS0ScheduledServiceResourceStatusResponse_M
#define DEF_NEXUS_REST_APINS0ScheduledServiceResourceStatusResponse_M

/**
 *  REST Response object for a scheduled service status request,
 contains the typical 'data' parameter, which is the scheduled
 service status.
 
 @version $Revision$ $Date$

 */
@implementation NEXUS_REST_APINS0ScheduledServiceResourceStatusResponse

/**
 * The scheduled service status details.
 */
- (NEXUS_REST_APINS0ScheduledServiceResourceStatus *) data
{
  return _data;
}

/**
 * The scheduled service status details.
 */
- (void) setData: (NEXUS_REST_APINS0ScheduledServiceResourceStatus *) newData
{
  [newData retain];
  [_data release];
  _data = newData;
}

- (void) dealloc
{
  [self setData: nil];
  [super dealloc];
}

//documentation inherited.
+ (id<EnunciateXML>) readFromXML: (NSData *) xml
{
  NEXUS_REST_APINS0ScheduledServiceResourceStatusResponse *_nEXUS_REST_APINS0ScheduledServiceResourceStatusResponse;
  xmlTextReaderPtr reader = xmlReaderForMemory([xml bytes], [xml length], NULL, NULL, 0);
  if (reader == NULL) {
    [NSException raise: @"XMLReadError"
                 format: @"Error instantiating an XML reader."];
    return nil;
  }

  _nEXUS_REST_APINS0ScheduledServiceResourceStatusResponse = (NEXUS_REST_APINS0ScheduledServiceResourceStatusResponse *) [NEXUS_REST_APINS0ScheduledServiceResourceStatusResponse readXMLElement: reader];
  xmlFreeTextReader(reader); //free the reader
  return _nEXUS_REST_APINS0ScheduledServiceResourceStatusResponse;
}

//documentation inherited.
- (NSData *) writeToXML
{
  xmlBufferPtr buf;
  xmlTextWriterPtr writer;
  int rc;
  NSData *data;

  buf = xmlBufferCreate();
  if (buf == NULL) {
    [NSException raise: @"XMLWriteError"
                 format: @"Error creating an XML buffer."];
    return nil;
  }

  writer = xmlNewTextWriterMemory(buf, 0);
  if (writer == NULL) {
    xmlBufferFree(buf);
    [NSException raise: @"XMLWriteError"
                 format: @"Error creating an XML writer."];
    return nil;
  }

  rc = xmlTextWriterStartDocument(writer, NULL, "utf-8", NULL);
  if (rc < 0) {
    xmlFreeTextWriter(writer);
    xmlBufferFree(buf);
    [NSException raise: @"XMLWriteError"
                 format: @"Error writing XML start document."];
    return nil;
  }

  NS_DURING
  {
    [self writeXMLElement: writer];
  }
  NS_HANDLER
  {
    xmlFreeTextWriter(writer);
    xmlBufferFree(buf);
    [localException raise];
  }
  NS_ENDHANDLER

  rc = xmlTextWriterEndDocument(writer);
  if (rc < 0) {
    xmlFreeTextWriter(writer);
    xmlBufferFree(buf);
    [NSException raise: @"XMLWriteError"
                 format: @"Error writing XML end document."];
    return nil;
  }

  xmlFreeTextWriter(writer);
  data = [NSData dataWithBytes: buf->content length: buf->use];
  xmlBufferFree(buf);
  return data;
}
@end /* implementation NEXUS_REST_APINS0ScheduledServiceResourceStatusResponse */

/**
 * Internal, private interface for JAXB reading and writing.
 */
@interface NEXUS_REST_APINS0ScheduledServiceResourceStatusResponse (JAXB) <JAXBReading, JAXBWriting, JAXBType, JAXBElement>

@end /*interface NEXUS_REST_APINS0ScheduledServiceResourceStatusResponse (JAXB)*/

/**
 * Internal, private implementation for JAXB reading and writing.
 */
@implementation NEXUS_REST_APINS0ScheduledServiceResourceStatusResponse (JAXB)

/**
 * Read an instance of NEXUS_REST_APINS0ScheduledServiceResourceStatusResponse from an XML reader.
 *
 * @param reader The reader.
 * @return An instance of NEXUS_REST_APINS0ScheduledServiceResourceStatusResponse defined by the XML reader.
 */
+ (id<JAXBType>) readXMLType: (xmlTextReaderPtr) reader
{
  NEXUS_REST_APINS0ScheduledServiceResourceStatusResponse *_nEXUS_REST_APINS0ScheduledServiceResourceStatusResponse = [[NEXUS_REST_APINS0ScheduledServiceResourceStatusResponse alloc] init];
  NS_DURING
  {
    [_nEXUS_REST_APINS0ScheduledServiceResourceStatusResponse initWithReader: reader];
  }
  NS_HANDLER
  {
    [_nEXUS_REST_APINS0ScheduledServiceResourceStatusResponse dealloc];
    _nEXUS_REST_APINS0ScheduledServiceResourceStatusResponse = nil;
    [localException raise];
  }
  NS_ENDHANDLER

  [_nEXUS_REST_APINS0ScheduledServiceResourceStatusResponse autorelease];
  return _nEXUS_REST_APINS0ScheduledServiceResourceStatusResponse;
}

/**
 * Initialize this instance of NEXUS_REST_APINS0ScheduledServiceResourceStatusResponse according to
 * the XML being read from the reader.
 *
 * @param reader The reader.
 */
- (id) initWithReader: (xmlTextReaderPtr) reader
{
  return [super initWithReader: reader];
}

/**
 * Write the XML for this instance of NEXUS_REST_APINS0ScheduledServiceResourceStatusResponse to the writer.
 * Note that since we're only writing the XML type,
 * No start/end element will be written.
 *
 * @param reader The reader.
 */
- (void) writeXMLType: (xmlTextWriterPtr) writer
{
  [super writeXMLType:writer];
}

/**
 * Reads a NEXUS_REST_APINS0ScheduledServiceResourceStatusResponse from an XML reader. The element to be read is
 * "schedule-service-status".
 *
 * @param reader The XML reader.
 * @return The NEXUS_REST_APINS0ScheduledServiceResourceStatusResponse.
 */
+ (id<JAXBElement>) readXMLElement: (xmlTextReaderPtr) reader {
  int status;
  NEXUS_REST_APINS0ScheduledServiceResourceStatusResponse *_scheduledServiceResourceStatusResponse = nil;

  if (xmlTextReaderNodeType(reader) != XML_READER_TYPE_ELEMENT) {
    status = xmlTextReaderAdvanceToNextStartOrEndElement(reader);
    if (status < 1) {
      [NSException raise: @"XMLReadError"
                   format: @"Error advancing the reader to start element schedule-service-status."];
    }
  }

  if (xmlStrcmp(BAD_CAST "schedule-service-status", xmlTextReaderConstLocalName(reader)) == 0
      && xmlTextReaderConstNamespaceUri(reader) == NULL) {
#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read root element {}schedule-service-status.");
#endif
    _scheduledServiceResourceStatusResponse = (NEXUS_REST_APINS0ScheduledServiceResourceStatusResponse *)[NEXUS_REST_APINS0ScheduledServiceResourceStatusResponse readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"Successfully read root element {}schedule-service-status.");
#endif
  }
  else {
    if (xmlTextReaderConstNamespaceUri(reader) == NULL) {
      [NSException raise: @"XMLReadError"
                   format: @"Unable to read NEXUS_REST_APINS0ScheduledServiceResourceStatusResponse. Expected element schedule-service-status. Current element: {}%s", xmlTextReaderConstLocalName(reader)];
    }
    else {
      [NSException raise: @"XMLReadError"
                   format: @"Unable to read NEXUS_REST_APINS0ScheduledServiceResourceStatusResponse. Expected element schedule-service-status. Current element: {%s}%s\n", xmlTextReaderConstNamespaceUri(reader), xmlTextReaderConstLocalName(reader)];
    }
  }

  return _scheduledServiceResourceStatusResponse;
}

/**
 * Writes this NEXUS_REST_APINS0ScheduledServiceResourceStatusResponse to XML under element name "schedule-service-status".
 * The namespace declarations for the element will be written.
 *
 * @param writer The XML writer.
 * @param _scheduledServiceResourceStatusResponse The ScheduledServiceResourceStatusResponse to write.
 * @return 1 if successful, 0 otherwise.
 */
- (void) writeXMLElement: (xmlTextWriterPtr) writer
{
  [self writeXMLElement: writer writeNamespaces: YES];
}

/**
 * Writes this NEXUS_REST_APINS0ScheduledServiceResourceStatusResponse to an XML writer.
 *
 * @param writer The writer.
 * @param writeNs Whether to write the namespaces for this element to the xml writer.
 */
- (void) writeXMLElement: (xmlTextWriterPtr) writer writeNamespaces: (BOOL) writeNs
{
  int rc = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "schedule-service-status", NULL);
  if (rc < 0) {
    [NSException raise: @"XMLWriteError"
                 format: @"Error writing start element {}schedule-service-status. XML writer status: %i\n", rc];
  }

#if DEBUG_ENUNCIATE > 1
  NSLog(@"writing type {}scheduledServiceResourceStatusResponse for root element {}schedule-service-status...");
#endif
  [self writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
  NSLog(@"successfully wrote type {}scheduledServiceResourceStatusResponse for root element {}schedule-service-status...");
#endif
  rc = xmlTextWriterEndElement(writer);
  if (rc < 0) {
    [NSException raise: @"XMLWriteError"
                 format: @"Error writing end element {}schedule-service-status. XML writer status: %i\n", rc];
  }
}

//documentation inherited.
- (BOOL) readJAXBAttribute: (xmlTextReaderPtr) reader
{
  void *_child_accessor;

  if ([super readJAXBAttribute: reader]) {
    return YES;
  }

  return NO;
}

//documentation inherited.
- (BOOL) readJAXBValue: (xmlTextReaderPtr) reader
{
  return [super readJAXBValue: reader];
}

//documentation inherited.
- (BOOL) readJAXBChildElement: (xmlTextReaderPtr) reader
{
  id __child;
  void *_child_accessor;
  int status, depth;

  if ([super readJAXBChildElement: reader]) {
    return YES;
  }
  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "data", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}data of type {}scheduled-service-resource-status.");
#endif
    __child = [NEXUS_REST_APINS0ScheduledServiceResourceStatus readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}data of type {}scheduled-service-resource-status.");
#endif

    [self setData: __child];
    return YES;
  } //end "if choice"


  return NO;
}

//documentation inherited.
- (int) readUnknownJAXBChildElement: (xmlTextReaderPtr) reader
{
  return [super readUnknownJAXBChildElement: reader];
}

//documentation inherited.
- (void) readUnknownJAXBAttribute: (xmlTextReaderPtr) reader
{
  [super readUnknownJAXBAttribute: reader];
}

//documentation inherited.
- (void) writeJAXBAttributes: (xmlTextWriterPtr) writer
{
  int status;

  [super writeJAXBAttributes: writer];

}

//documentation inherited.
- (void) writeJAXBValue: (xmlTextWriterPtr) writer
{
  [super writeJAXBValue: writer];
}

/**
 * Method for writing the child elements.
 *
 * @param writer The writer.
 */
- (void) writeJAXBChildElements: (xmlTextWriterPtr) writer
{
  int status;
  id __item;
  NSEnumerator *__enumerator;

  [super writeJAXBChildElements: writer];

  if ([self data]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "data", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}data."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}data...");
#endif
    [[self data] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}data...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}data."];
    }
  }
}
@end /* implementation NEXUS_REST_APINS0ScheduledServiceResourceStatusResponse (JAXB) */

#endif /* DEF_NEXUS_REST_APINS0ScheduledServiceResourceStatusResponse_M */
#ifndef DEF_NEXUS_REST_APINS0ScheduledServiceListResourceResponse_M
#define DEF_NEXUS_REST_APINS0ScheduledServiceListResourceResponse_M

/**
 *  REST Response object for a list of scheduled service items,
 contains the typical 'data' parameter, which is the list of
 scheduled services..
 
 @version $Revision$ $Date$

 */
@implementation NEXUS_REST_APINS0ScheduledServiceListResourceResponse

/**
 * Field data.
 */
- (NSArray *) data
{
  return _data;
}

/**
 * Field data.
 */
- (void) setData: (NSArray *) newData
{
  [newData retain];
  [_data release];
  _data = newData;
}

- (void) dealloc
{
  [self setData: nil];
  [super dealloc];
}

//documentation inherited.
+ (id<EnunciateXML>) readFromXML: (NSData *) xml
{
  NEXUS_REST_APINS0ScheduledServiceListResourceResponse *_nEXUS_REST_APINS0ScheduledServiceListResourceResponse;
  xmlTextReaderPtr reader = xmlReaderForMemory([xml bytes], [xml length], NULL, NULL, 0);
  if (reader == NULL) {
    [NSException raise: @"XMLReadError"
                 format: @"Error instantiating an XML reader."];
    return nil;
  }

  _nEXUS_REST_APINS0ScheduledServiceListResourceResponse = (NEXUS_REST_APINS0ScheduledServiceListResourceResponse *) [NEXUS_REST_APINS0ScheduledServiceListResourceResponse readXMLElement: reader];
  xmlFreeTextReader(reader); //free the reader
  return _nEXUS_REST_APINS0ScheduledServiceListResourceResponse;
}

//documentation inherited.
- (NSData *) writeToXML
{
  xmlBufferPtr buf;
  xmlTextWriterPtr writer;
  int rc;
  NSData *data;

  buf = xmlBufferCreate();
  if (buf == NULL) {
    [NSException raise: @"XMLWriteError"
                 format: @"Error creating an XML buffer."];
    return nil;
  }

  writer = xmlNewTextWriterMemory(buf, 0);
  if (writer == NULL) {
    xmlBufferFree(buf);
    [NSException raise: @"XMLWriteError"
                 format: @"Error creating an XML writer."];
    return nil;
  }

  rc = xmlTextWriterStartDocument(writer, NULL, "utf-8", NULL);
  if (rc < 0) {
    xmlFreeTextWriter(writer);
    xmlBufferFree(buf);
    [NSException raise: @"XMLWriteError"
                 format: @"Error writing XML start document."];
    return nil;
  }

  NS_DURING
  {
    [self writeXMLElement: writer];
  }
  NS_HANDLER
  {
    xmlFreeTextWriter(writer);
    xmlBufferFree(buf);
    [localException raise];
  }
  NS_ENDHANDLER

  rc = xmlTextWriterEndDocument(writer);
  if (rc < 0) {
    xmlFreeTextWriter(writer);
    xmlBufferFree(buf);
    [NSException raise: @"XMLWriteError"
                 format: @"Error writing XML end document."];
    return nil;
  }

  xmlFreeTextWriter(writer);
  data = [NSData dataWithBytes: buf->content length: buf->use];
  xmlBufferFree(buf);
  return data;
}
@end /* implementation NEXUS_REST_APINS0ScheduledServiceListResourceResponse */

/**
 * Internal, private interface for JAXB reading and writing.
 */
@interface NEXUS_REST_APINS0ScheduledServiceListResourceResponse (JAXB) <JAXBReading, JAXBWriting, JAXBType, JAXBElement>

@end /*interface NEXUS_REST_APINS0ScheduledServiceListResourceResponse (JAXB)*/

/**
 * Internal, private implementation for JAXB reading and writing.
 */
@implementation NEXUS_REST_APINS0ScheduledServiceListResourceResponse (JAXB)

/**
 * Read an instance of NEXUS_REST_APINS0ScheduledServiceListResourceResponse from an XML reader.
 *
 * @param reader The reader.
 * @return An instance of NEXUS_REST_APINS0ScheduledServiceListResourceResponse defined by the XML reader.
 */
+ (id<JAXBType>) readXMLType: (xmlTextReaderPtr) reader
{
  NEXUS_REST_APINS0ScheduledServiceListResourceResponse *_nEXUS_REST_APINS0ScheduledServiceListResourceResponse = [[NEXUS_REST_APINS0ScheduledServiceListResourceResponse alloc] init];
  NS_DURING
  {
    [_nEXUS_REST_APINS0ScheduledServiceListResourceResponse initWithReader: reader];
  }
  NS_HANDLER
  {
    [_nEXUS_REST_APINS0ScheduledServiceListResourceResponse dealloc];
    _nEXUS_REST_APINS0ScheduledServiceListResourceResponse = nil;
    [localException raise];
  }
  NS_ENDHANDLER

  [_nEXUS_REST_APINS0ScheduledServiceListResourceResponse autorelease];
  return _nEXUS_REST_APINS0ScheduledServiceListResourceResponse;
}

/**
 * Initialize this instance of NEXUS_REST_APINS0ScheduledServiceListResourceResponse according to
 * the XML being read from the reader.
 *
 * @param reader The reader.
 */
- (id) initWithReader: (xmlTextReaderPtr) reader
{
  return [super initWithReader: reader];
}

/**
 * Write the XML for this instance of NEXUS_REST_APINS0ScheduledServiceListResourceResponse to the writer.
 * Note that since we're only writing the XML type,
 * No start/end element will be written.
 *
 * @param reader The reader.
 */
- (void) writeXMLType: (xmlTextWriterPtr) writer
{
  [super writeXMLType:writer];
}

/**
 * Reads a NEXUS_REST_APINS0ScheduledServiceListResourceResponse from an XML reader. The element to be read is
 * "schedules-list".
 *
 * @param reader The XML reader.
 * @return The NEXUS_REST_APINS0ScheduledServiceListResourceResponse.
 */
+ (id<JAXBElement>) readXMLElement: (xmlTextReaderPtr) reader {
  int status;
  NEXUS_REST_APINS0ScheduledServiceListResourceResponse *_scheduledServiceListResourceResponse = nil;

  if (xmlTextReaderNodeType(reader) != XML_READER_TYPE_ELEMENT) {
    status = xmlTextReaderAdvanceToNextStartOrEndElement(reader);
    if (status < 1) {
      [NSException raise: @"XMLReadError"
                   format: @"Error advancing the reader to start element schedules-list."];
    }
  }

  if (xmlStrcmp(BAD_CAST "schedules-list", xmlTextReaderConstLocalName(reader)) == 0
      && xmlTextReaderConstNamespaceUri(reader) == NULL) {
#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read root element {}schedules-list.");
#endif
    _scheduledServiceListResourceResponse = (NEXUS_REST_APINS0ScheduledServiceListResourceResponse *)[NEXUS_REST_APINS0ScheduledServiceListResourceResponse readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"Successfully read root element {}schedules-list.");
#endif
  }
  else {
    if (xmlTextReaderConstNamespaceUri(reader) == NULL) {
      [NSException raise: @"XMLReadError"
                   format: @"Unable to read NEXUS_REST_APINS0ScheduledServiceListResourceResponse. Expected element schedules-list. Current element: {}%s", xmlTextReaderConstLocalName(reader)];
    }
    else {
      [NSException raise: @"XMLReadError"
                   format: @"Unable to read NEXUS_REST_APINS0ScheduledServiceListResourceResponse. Expected element schedules-list. Current element: {%s}%s\n", xmlTextReaderConstNamespaceUri(reader), xmlTextReaderConstLocalName(reader)];
    }
  }

  return _scheduledServiceListResourceResponse;
}

/**
 * Writes this NEXUS_REST_APINS0ScheduledServiceListResourceResponse to XML under element name "schedules-list".
 * The namespace declarations for the element will be written.
 *
 * @param writer The XML writer.
 * @param _scheduledServiceListResourceResponse The ScheduledServiceListResourceResponse to write.
 * @return 1 if successful, 0 otherwise.
 */
- (void) writeXMLElement: (xmlTextWriterPtr) writer
{
  [self writeXMLElement: writer writeNamespaces: YES];
}

/**
 * Writes this NEXUS_REST_APINS0ScheduledServiceListResourceResponse to an XML writer.
 *
 * @param writer The writer.
 * @param writeNs Whether to write the namespaces for this element to the xml writer.
 */
- (void) writeXMLElement: (xmlTextWriterPtr) writer writeNamespaces: (BOOL) writeNs
{
  int rc = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "schedules-list", NULL);
  if (rc < 0) {
    [NSException raise: @"XMLWriteError"
                 format: @"Error writing start element {}schedules-list. XML writer status: %i\n", rc];
  }

#if DEBUG_ENUNCIATE > 1
  NSLog(@"writing type {}scheduledServiceListResourceResponse for root element {}schedules-list...");
#endif
  [self writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
  NSLog(@"successfully wrote type {}scheduledServiceListResourceResponse for root element {}schedules-list...");
#endif
  rc = xmlTextWriterEndElement(writer);
  if (rc < 0) {
    [NSException raise: @"XMLWriteError"
                 format: @"Error writing end element {}schedules-list. XML writer status: %i\n", rc];
  }
}

//documentation inherited.
- (BOOL) readJAXBAttribute: (xmlTextReaderPtr) reader
{
  void *_child_accessor;

  if ([super readJAXBAttribute: reader]) {
    return YES;
  }

  return NO;
}

//documentation inherited.
- (BOOL) readJAXBValue: (xmlTextReaderPtr) reader
{
  return [super readJAXBValue: reader];
}

//documentation inherited.
- (BOOL) readJAXBChildElement: (xmlTextReaderPtr) reader
{
  id __child;
  void *_child_accessor;
  int status, depth;

  if ([super readJAXBChildElement: reader]) {
    return YES;
  }
  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "data", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

    if (xmlTextReaderIsEmptyElement(reader) == 0) {
#if DEBUG_ENUNCIATE > 1
      NSLog(@"Unwrapping wrapper element {}data...");
#endif
      //start wrapper element "{}data"
      depth = xmlTextReaderDepth(reader);
      status = xmlTextReaderAdvanceToNextStartOrEndElement(reader);
      while (xmlTextReaderDepth(reader) > depth) {
        if (status < 1) {
          //panic: XML read error.
          [self dealloc];
          [NSException raise: @"XMLReadError"
                       format: @"Failure to advance to next wrapped child element."];
        }
  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "schedules-list-item", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}schedules-list-item of type {}scheduled-service-list-resource.");
#endif

    __child = [NEXUS_REST_APINS0ScheduledServiceListResource readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}schedules-list-item of type {}scheduled-service-list-resource.");
#endif

    if ([self data]) {
      [self setData: [[self data] arrayByAddingObject: __child]];
    }
    else {
      [self setData: [NSArray arrayWithObject: __child]];
    }
    continue; //continue "while in wrapper element" loop
  } //end "if choice"

        status = xmlTextReaderAdvanceToNextStartOrEndElement(reader);
#if DEBUG_ENUNCIATE > 1
        NSLog(@"successfully unwrapped wrapper element {}data...");
#endif
      } // end "while in wrapper element" loop

      if (status < 1) {
        //panic: XML read error.
        [self dealloc];
        [NSException raise: @"XMLReadError"
                     format: @"Failure to advance to end wrapper element."];
      }
      else {
        //end wrapper element "{}data"
        status = xmlTextReaderAdvanceToNextStartOrEndElement(reader);
      }
    } //end "if empty element" clause
    else {
      __child = [NSArray array];
      [self setData: (NSArray*) __child];
    }

    return YES;
  } // end "if wrapper element" clause

  return NO;
}

//documentation inherited.
- (int) readUnknownJAXBChildElement: (xmlTextReaderPtr) reader
{
  return [super readUnknownJAXBChildElement: reader];
}

//documentation inherited.
- (void) readUnknownJAXBAttribute: (xmlTextReaderPtr) reader
{
  [super readUnknownJAXBAttribute: reader];
}

//documentation inherited.
- (void) writeJAXBAttributes: (xmlTextWriterPtr) writer
{
  int status;

  [super writeJAXBAttributes: writer];

}

//documentation inherited.
- (void) writeJAXBValue: (xmlTextWriterPtr) writer
{
  [super writeJAXBValue: writer];
}

/**
 * Method for writing the child elements.
 *
 * @param writer The writer.
 */
- (void) writeJAXBChildElements: (xmlTextWriterPtr) writer
{
  int status;
  id __item;
  NSEnumerator *__enumerator;

  [super writeJAXBChildElements: writer];

  if ([self data]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "data", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start wrapper element {}data."];
    }
    __enumerator = [[self data] objectEnumerator];

    while ( (__item = [__enumerator nextObject]) ) {
      status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "schedules-list-item", NULL);
      if (status < 0) {
        [NSException raise: @"XMLWriteError"
                     format: @"Error writing start child element {}schedules-list-item."];
      }

#if DEBUG_ENUNCIATE > 1
      NSLog(@"writing element {}schedules-list-item...");
#endif
      [__item writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
      NSLog(@"successfully wrote element {}schedules-list-item...");
#endif

      status = xmlTextWriterEndElement(writer);
      if (status < 0) {
        [NSException raise: @"XMLWriteError"
                     format: @"Error writing end child element {}schedules-list-item."];
      }
    } //end item iterator.

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end wrapper element {}data."];
    }
  }
}
@end /* implementation NEXUS_REST_APINS0ScheduledServiceListResourceResponse (JAXB) */

#endif /* DEF_NEXUS_REST_APINS0ScheduledServiceListResourceResponse_M */
#ifndef DEF_NEXUS_REST_APINS0RestApiResourceResponse_M
#define DEF_NEXUS_REST_APINS0RestApiResourceResponse_M

/**
 *  REST Response object for a rest api settings request, contains
 the typical 'data' parameter, which is the rest settings
 requested.
 
 @version $Revision$ $Date$

 */
@implementation NEXUS_REST_APINS0RestApiResourceResponse

/**
 * The rest api configuration settings.
 */
- (NEXUS_REST_APINS0RestApiSettings *) data
{
  return _data;
}

/**
 * The rest api configuration settings.
 */
- (void) setData: (NEXUS_REST_APINS0RestApiSettings *) newData
{
  [newData retain];
  [_data release];
  _data = newData;
}

- (void) dealloc
{
  [self setData: nil];
  [super dealloc];
}

//documentation inherited.
+ (id<EnunciateXML>) readFromXML: (NSData *) xml
{
  NEXUS_REST_APINS0RestApiResourceResponse *_nEXUS_REST_APINS0RestApiResourceResponse;
  xmlTextReaderPtr reader = xmlReaderForMemory([xml bytes], [xml length], NULL, NULL, 0);
  if (reader == NULL) {
    [NSException raise: @"XMLReadError"
                 format: @"Error instantiating an XML reader."];
    return nil;
  }

  _nEXUS_REST_APINS0RestApiResourceResponse = (NEXUS_REST_APINS0RestApiResourceResponse *) [NEXUS_REST_APINS0RestApiResourceResponse readXMLElement: reader];
  xmlFreeTextReader(reader); //free the reader
  return _nEXUS_REST_APINS0RestApiResourceResponse;
}

//documentation inherited.
- (NSData *) writeToXML
{
  xmlBufferPtr buf;
  xmlTextWriterPtr writer;
  int rc;
  NSData *data;

  buf = xmlBufferCreate();
  if (buf == NULL) {
    [NSException raise: @"XMLWriteError"
                 format: @"Error creating an XML buffer."];
    return nil;
  }

  writer = xmlNewTextWriterMemory(buf, 0);
  if (writer == NULL) {
    xmlBufferFree(buf);
    [NSException raise: @"XMLWriteError"
                 format: @"Error creating an XML writer."];
    return nil;
  }

  rc = xmlTextWriterStartDocument(writer, NULL, "utf-8", NULL);
  if (rc < 0) {
    xmlFreeTextWriter(writer);
    xmlBufferFree(buf);
    [NSException raise: @"XMLWriteError"
                 format: @"Error writing XML start document."];
    return nil;
  }

  NS_DURING
  {
    [self writeXMLElement: writer];
  }
  NS_HANDLER
  {
    xmlFreeTextWriter(writer);
    xmlBufferFree(buf);
    [localException raise];
  }
  NS_ENDHANDLER

  rc = xmlTextWriterEndDocument(writer);
  if (rc < 0) {
    xmlFreeTextWriter(writer);
    xmlBufferFree(buf);
    [NSException raise: @"XMLWriteError"
                 format: @"Error writing XML end document."];
    return nil;
  }

  xmlFreeTextWriter(writer);
  data = [NSData dataWithBytes: buf->content length: buf->use];
  xmlBufferFree(buf);
  return data;
}
@end /* implementation NEXUS_REST_APINS0RestApiResourceResponse */

/**
 * Internal, private interface for JAXB reading and writing.
 */
@interface NEXUS_REST_APINS0RestApiResourceResponse (JAXB) <JAXBReading, JAXBWriting, JAXBType, JAXBElement>

@end /*interface NEXUS_REST_APINS0RestApiResourceResponse (JAXB)*/

/**
 * Internal, private implementation for JAXB reading and writing.
 */
@implementation NEXUS_REST_APINS0RestApiResourceResponse (JAXB)

/**
 * Read an instance of NEXUS_REST_APINS0RestApiResourceResponse from an XML reader.
 *
 * @param reader The reader.
 * @return An instance of NEXUS_REST_APINS0RestApiResourceResponse defined by the XML reader.
 */
+ (id<JAXBType>) readXMLType: (xmlTextReaderPtr) reader
{
  NEXUS_REST_APINS0RestApiResourceResponse *_nEXUS_REST_APINS0RestApiResourceResponse = [[NEXUS_REST_APINS0RestApiResourceResponse alloc] init];
  NS_DURING
  {
    [_nEXUS_REST_APINS0RestApiResourceResponse initWithReader: reader];
  }
  NS_HANDLER
  {
    [_nEXUS_REST_APINS0RestApiResourceResponse dealloc];
    _nEXUS_REST_APINS0RestApiResourceResponse = nil;
    [localException raise];
  }
  NS_ENDHANDLER

  [_nEXUS_REST_APINS0RestApiResourceResponse autorelease];
  return _nEXUS_REST_APINS0RestApiResourceResponse;
}

/**
 * Initialize this instance of NEXUS_REST_APINS0RestApiResourceResponse according to
 * the XML being read from the reader.
 *
 * @param reader The reader.
 */
- (id) initWithReader: (xmlTextReaderPtr) reader
{
  return [super initWithReader: reader];
}

/**
 * Write the XML for this instance of NEXUS_REST_APINS0RestApiResourceResponse to the writer.
 * Note that since we're only writing the XML type,
 * No start/end element will be written.
 *
 * @param reader The reader.
 */
- (void) writeXMLType: (xmlTextWriterPtr) writer
{
  [super writeXMLType:writer];
}

/**
 * Reads a NEXUS_REST_APINS0RestApiResourceResponse from an XML reader. The element to be read is
 * "rest-api-response".
 *
 * @param reader The XML reader.
 * @return The NEXUS_REST_APINS0RestApiResourceResponse.
 */
+ (id<JAXBElement>) readXMLElement: (xmlTextReaderPtr) reader {
  int status;
  NEXUS_REST_APINS0RestApiResourceResponse *_restApiResourceResponse = nil;

  if (xmlTextReaderNodeType(reader) != XML_READER_TYPE_ELEMENT) {
    status = xmlTextReaderAdvanceToNextStartOrEndElement(reader);
    if (status < 1) {
      [NSException raise: @"XMLReadError"
                   format: @"Error advancing the reader to start element rest-api-response."];
    }
  }

  if (xmlStrcmp(BAD_CAST "rest-api-response", xmlTextReaderConstLocalName(reader)) == 0
      && xmlTextReaderConstNamespaceUri(reader) == NULL) {
#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read root element {}rest-api-response.");
#endif
    _restApiResourceResponse = (NEXUS_REST_APINS0RestApiResourceResponse *)[NEXUS_REST_APINS0RestApiResourceResponse readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"Successfully read root element {}rest-api-response.");
#endif
  }
  else {
    if (xmlTextReaderConstNamespaceUri(reader) == NULL) {
      [NSException raise: @"XMLReadError"
                   format: @"Unable to read NEXUS_REST_APINS0RestApiResourceResponse. Expected element rest-api-response. Current element: {}%s", xmlTextReaderConstLocalName(reader)];
    }
    else {
      [NSException raise: @"XMLReadError"
                   format: @"Unable to read NEXUS_REST_APINS0RestApiResourceResponse. Expected element rest-api-response. Current element: {%s}%s\n", xmlTextReaderConstNamespaceUri(reader), xmlTextReaderConstLocalName(reader)];
    }
  }

  return _restApiResourceResponse;
}

/**
 * Writes this NEXUS_REST_APINS0RestApiResourceResponse to XML under element name "rest-api-response".
 * The namespace declarations for the element will be written.
 *
 * @param writer The XML writer.
 * @param _restApiResourceResponse The RestApiResourceResponse to write.
 * @return 1 if successful, 0 otherwise.
 */
- (void) writeXMLElement: (xmlTextWriterPtr) writer
{
  [self writeXMLElement: writer writeNamespaces: YES];
}

/**
 * Writes this NEXUS_REST_APINS0RestApiResourceResponse to an XML writer.
 *
 * @param writer The writer.
 * @param writeNs Whether to write the namespaces for this element to the xml writer.
 */
- (void) writeXMLElement: (xmlTextWriterPtr) writer writeNamespaces: (BOOL) writeNs
{
  int rc = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "rest-api-response", NULL);
  if (rc < 0) {
    [NSException raise: @"XMLWriteError"
                 format: @"Error writing start element {}rest-api-response. XML writer status: %i\n", rc];
  }

#if DEBUG_ENUNCIATE > 1
  NSLog(@"writing type {}restApiResourceResponse for root element {}rest-api-response...");
#endif
  [self writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
  NSLog(@"successfully wrote type {}restApiResourceResponse for root element {}rest-api-response...");
#endif
  rc = xmlTextWriterEndElement(writer);
  if (rc < 0) {
    [NSException raise: @"XMLWriteError"
                 format: @"Error writing end element {}rest-api-response. XML writer status: %i\n", rc];
  }
}

//documentation inherited.
- (BOOL) readJAXBAttribute: (xmlTextReaderPtr) reader
{
  void *_child_accessor;

  if ([super readJAXBAttribute: reader]) {
    return YES;
  }

  return NO;
}

//documentation inherited.
- (BOOL) readJAXBValue: (xmlTextReaderPtr) reader
{
  return [super readJAXBValue: reader];
}

//documentation inherited.
- (BOOL) readJAXBChildElement: (xmlTextReaderPtr) reader
{
  id __child;
  void *_child_accessor;
  int status, depth;

  if ([super readJAXBChildElement: reader]) {
    return YES;
  }
  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "data", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}data of type {}rest-api-settings.");
#endif
    __child = [NEXUS_REST_APINS0RestApiSettings readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}data of type {}rest-api-settings.");
#endif

    [self setData: __child];
    return YES;
  } //end "if choice"


  return NO;
}

//documentation inherited.
- (int) readUnknownJAXBChildElement: (xmlTextReaderPtr) reader
{
  return [super readUnknownJAXBChildElement: reader];
}

//documentation inherited.
- (void) readUnknownJAXBAttribute: (xmlTextReaderPtr) reader
{
  [super readUnknownJAXBAttribute: reader];
}

//documentation inherited.
- (void) writeJAXBAttributes: (xmlTextWriterPtr) writer
{
  int status;

  [super writeJAXBAttributes: writer];

}

//documentation inherited.
- (void) writeJAXBValue: (xmlTextWriterPtr) writer
{
  [super writeJAXBValue: writer];
}

/**
 * Method for writing the child elements.
 *
 * @param writer The writer.
 */
- (void) writeJAXBChildElements: (xmlTextWriterPtr) writer
{
  int status;
  id __item;
  NSEnumerator *__enumerator;

  [super writeJAXBChildElements: writer];

  if ([self data]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "data", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}data."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}data...");
#endif
    [[self data] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}data...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}data."];
    }
  }
}
@end /* implementation NEXUS_REST_APINS0RestApiResourceResponse (JAXB) */

#endif /* DEF_NEXUS_REST_APINS0RestApiResourceResponse_M */
#ifndef DEF_NEXUS_REST_APINS0RepositoryStatusResourceResponse_M
#define DEF_NEXUS_REST_APINS0RepositoryStatusResourceResponse_M

/**
 *  REST Response object for a repository status request, contains
 the typical 'data' parameter, which is the repository status
 objects.
 
 @version $Revision$ $Date$

 */
@implementation NEXUS_REST_APINS0RepositoryStatusResourceResponse

/**
 * Repository status details.
 */
- (NEXUS_REST_APINS0RepositoryStatusResource *) data
{
  return _data;
}

/**
 * Repository status details.
 */
- (void) setData: (NEXUS_REST_APINS0RepositoryStatusResource *) newData
{
  [newData retain];
  [_data release];
  _data = newData;
}

- (void) dealloc
{
  [self setData: nil];
  [super dealloc];
}

//documentation inherited.
+ (id<EnunciateXML>) readFromXML: (NSData *) xml
{
  NEXUS_REST_APINS0RepositoryStatusResourceResponse *_nEXUS_REST_APINS0RepositoryStatusResourceResponse;
  xmlTextReaderPtr reader = xmlReaderForMemory([xml bytes], [xml length], NULL, NULL, 0);
  if (reader == NULL) {
    [NSException raise: @"XMLReadError"
                 format: @"Error instantiating an XML reader."];
    return nil;
  }

  _nEXUS_REST_APINS0RepositoryStatusResourceResponse = (NEXUS_REST_APINS0RepositoryStatusResourceResponse *) [NEXUS_REST_APINS0RepositoryStatusResourceResponse readXMLElement: reader];
  xmlFreeTextReader(reader); //free the reader
  return _nEXUS_REST_APINS0RepositoryStatusResourceResponse;
}

//documentation inherited.
- (NSData *) writeToXML
{
  xmlBufferPtr buf;
  xmlTextWriterPtr writer;
  int rc;
  NSData *data;

  buf = xmlBufferCreate();
  if (buf == NULL) {
    [NSException raise: @"XMLWriteError"
                 format: @"Error creating an XML buffer."];
    return nil;
  }

  writer = xmlNewTextWriterMemory(buf, 0);
  if (writer == NULL) {
    xmlBufferFree(buf);
    [NSException raise: @"XMLWriteError"
                 format: @"Error creating an XML writer."];
    return nil;
  }

  rc = xmlTextWriterStartDocument(writer, NULL, "utf-8", NULL);
  if (rc < 0) {
    xmlFreeTextWriter(writer);
    xmlBufferFree(buf);
    [NSException raise: @"XMLWriteError"
                 format: @"Error writing XML start document."];
    return nil;
  }

  NS_DURING
  {
    [self writeXMLElement: writer];
  }
  NS_HANDLER
  {
    xmlFreeTextWriter(writer);
    xmlBufferFree(buf);
    [localException raise];
  }
  NS_ENDHANDLER

  rc = xmlTextWriterEndDocument(writer);
  if (rc < 0) {
    xmlFreeTextWriter(writer);
    xmlBufferFree(buf);
    [NSException raise: @"XMLWriteError"
                 format: @"Error writing XML end document."];
    return nil;
  }

  xmlFreeTextWriter(writer);
  data = [NSData dataWithBytes: buf->content length: buf->use];
  xmlBufferFree(buf);
  return data;
}
@end /* implementation NEXUS_REST_APINS0RepositoryStatusResourceResponse */

/**
 * Internal, private interface for JAXB reading and writing.
 */
@interface NEXUS_REST_APINS0RepositoryStatusResourceResponse (JAXB) <JAXBReading, JAXBWriting, JAXBType, JAXBElement>

@end /*interface NEXUS_REST_APINS0RepositoryStatusResourceResponse (JAXB)*/

/**
 * Internal, private implementation for JAXB reading and writing.
 */
@implementation NEXUS_REST_APINS0RepositoryStatusResourceResponse (JAXB)

/**
 * Read an instance of NEXUS_REST_APINS0RepositoryStatusResourceResponse from an XML reader.
 *
 * @param reader The reader.
 * @return An instance of NEXUS_REST_APINS0RepositoryStatusResourceResponse defined by the XML reader.
 */
+ (id<JAXBType>) readXMLType: (xmlTextReaderPtr) reader
{
  NEXUS_REST_APINS0RepositoryStatusResourceResponse *_nEXUS_REST_APINS0RepositoryStatusResourceResponse = [[NEXUS_REST_APINS0RepositoryStatusResourceResponse alloc] init];
  NS_DURING
  {
    [_nEXUS_REST_APINS0RepositoryStatusResourceResponse initWithReader: reader];
  }
  NS_HANDLER
  {
    [_nEXUS_REST_APINS0RepositoryStatusResourceResponse dealloc];
    _nEXUS_REST_APINS0RepositoryStatusResourceResponse = nil;
    [localException raise];
  }
  NS_ENDHANDLER

  [_nEXUS_REST_APINS0RepositoryStatusResourceResponse autorelease];
  return _nEXUS_REST_APINS0RepositoryStatusResourceResponse;
}

/**
 * Initialize this instance of NEXUS_REST_APINS0RepositoryStatusResourceResponse according to
 * the XML being read from the reader.
 *
 * @param reader The reader.
 */
- (id) initWithReader: (xmlTextReaderPtr) reader
{
  return [super initWithReader: reader];
}

/**
 * Write the XML for this instance of NEXUS_REST_APINS0RepositoryStatusResourceResponse to the writer.
 * Note that since we're only writing the XML type,
 * No start/end element will be written.
 *
 * @param reader The reader.
 */
- (void) writeXMLType: (xmlTextWriterPtr) writer
{
  [super writeXMLType:writer];
}

/**
 * Reads a NEXUS_REST_APINS0RepositoryStatusResourceResponse from an XML reader. The element to be read is
 * "repository-status".
 *
 * @param reader The XML reader.
 * @return The NEXUS_REST_APINS0RepositoryStatusResourceResponse.
 */
+ (id<JAXBElement>) readXMLElement: (xmlTextReaderPtr) reader {
  int status;
  NEXUS_REST_APINS0RepositoryStatusResourceResponse *_repositoryStatusResourceResponse = nil;

  if (xmlTextReaderNodeType(reader) != XML_READER_TYPE_ELEMENT) {
    status = xmlTextReaderAdvanceToNextStartOrEndElement(reader);
    if (status < 1) {
      [NSException raise: @"XMLReadError"
                   format: @"Error advancing the reader to start element repository-status."];
    }
  }

  if (xmlStrcmp(BAD_CAST "repository-status", xmlTextReaderConstLocalName(reader)) == 0
      && xmlTextReaderConstNamespaceUri(reader) == NULL) {
#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read root element {}repository-status.");
#endif
    _repositoryStatusResourceResponse = (NEXUS_REST_APINS0RepositoryStatusResourceResponse *)[NEXUS_REST_APINS0RepositoryStatusResourceResponse readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"Successfully read root element {}repository-status.");
#endif
  }
  else {
    if (xmlTextReaderConstNamespaceUri(reader) == NULL) {
      [NSException raise: @"XMLReadError"
                   format: @"Unable to read NEXUS_REST_APINS0RepositoryStatusResourceResponse. Expected element repository-status. Current element: {}%s", xmlTextReaderConstLocalName(reader)];
    }
    else {
      [NSException raise: @"XMLReadError"
                   format: @"Unable to read NEXUS_REST_APINS0RepositoryStatusResourceResponse. Expected element repository-status. Current element: {%s}%s\n", xmlTextReaderConstNamespaceUri(reader), xmlTextReaderConstLocalName(reader)];
    }
  }

  return _repositoryStatusResourceResponse;
}

/**
 * Writes this NEXUS_REST_APINS0RepositoryStatusResourceResponse to XML under element name "repository-status".
 * The namespace declarations for the element will be written.
 *
 * @param writer The XML writer.
 * @param _repositoryStatusResourceResponse The RepositoryStatusResourceResponse to write.
 * @return 1 if successful, 0 otherwise.
 */
- (void) writeXMLElement: (xmlTextWriterPtr) writer
{
  [self writeXMLElement: writer writeNamespaces: YES];
}

/**
 * Writes this NEXUS_REST_APINS0RepositoryStatusResourceResponse to an XML writer.
 *
 * @param writer The writer.
 * @param writeNs Whether to write the namespaces for this element to the xml writer.
 */
- (void) writeXMLElement: (xmlTextWriterPtr) writer writeNamespaces: (BOOL) writeNs
{
  int rc = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "repository-status", NULL);
  if (rc < 0) {
    [NSException raise: @"XMLWriteError"
                 format: @"Error writing start element {}repository-status. XML writer status: %i\n", rc];
  }

#if DEBUG_ENUNCIATE > 1
  NSLog(@"writing type {}repositoryStatusResourceResponse for root element {}repository-status...");
#endif
  [self writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
  NSLog(@"successfully wrote type {}repositoryStatusResourceResponse for root element {}repository-status...");
#endif
  rc = xmlTextWriterEndElement(writer);
  if (rc < 0) {
    [NSException raise: @"XMLWriteError"
                 format: @"Error writing end element {}repository-status. XML writer status: %i\n", rc];
  }
}

//documentation inherited.
- (BOOL) readJAXBAttribute: (xmlTextReaderPtr) reader
{
  void *_child_accessor;

  if ([super readJAXBAttribute: reader]) {
    return YES;
  }

  return NO;
}

//documentation inherited.
- (BOOL) readJAXBValue: (xmlTextReaderPtr) reader
{
  return [super readJAXBValue: reader];
}

//documentation inherited.
- (BOOL) readJAXBChildElement: (xmlTextReaderPtr) reader
{
  id __child;
  void *_child_accessor;
  int status, depth;

  if ([super readJAXBChildElement: reader]) {
    return YES;
  }
  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "data", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}data of type {}repository-status.");
#endif
    __child = [NEXUS_REST_APINS0RepositoryStatusResource readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}data of type {}repository-status.");
#endif

    [self setData: __child];
    return YES;
  } //end "if choice"


  return NO;
}

//documentation inherited.
- (int) readUnknownJAXBChildElement: (xmlTextReaderPtr) reader
{
  return [super readUnknownJAXBChildElement: reader];
}

//documentation inherited.
- (void) readUnknownJAXBAttribute: (xmlTextReaderPtr) reader
{
  [super readUnknownJAXBAttribute: reader];
}

//documentation inherited.
- (void) writeJAXBAttributes: (xmlTextWriterPtr) writer
{
  int status;

  [super writeJAXBAttributes: writer];

}

//documentation inherited.
- (void) writeJAXBValue: (xmlTextWriterPtr) writer
{
  [super writeJAXBValue: writer];
}

/**
 * Method for writing the child elements.
 *
 * @param writer The writer.
 */
- (void) writeJAXBChildElements: (xmlTextWriterPtr) writer
{
  int status;
  id __item;
  NSEnumerator *__enumerator;

  [super writeJAXBChildElements: writer];

  if ([self data]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "data", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}data."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}data...");
#endif
    [[self data] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}data...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}data."];
    }
  }
}
@end /* implementation NEXUS_REST_APINS0RepositoryStatusResourceResponse (JAXB) */

#endif /* DEF_NEXUS_REST_APINS0RepositoryStatusResourceResponse_M */
#ifndef DEF_NEXUS_REST_APINS0RepositoryRouteResourceResponse_M
#define DEF_NEXUS_REST_APINS0RepositoryRouteResourceResponse_M

/**
 *  REST Response object for a repository route request, contains
 the typical 'data' parameter, which is the repository route
 object.
 
 @version $Revision$ $Date$

 */
@implementation NEXUS_REST_APINS0RepositoryRouteResourceResponse

/**
 * Repository Route details.
 */
- (NEXUS_REST_APINS0RepositoryRouteResource *) data
{
  return _data;
}

/**
 * Repository Route details.
 */
- (void) setData: (NEXUS_REST_APINS0RepositoryRouteResource *) newData
{
  [newData retain];
  [_data release];
  _data = newData;
}

- (void) dealloc
{
  [self setData: nil];
  [super dealloc];
}

//documentation inherited.
+ (id<EnunciateXML>) readFromXML: (NSData *) xml
{
  NEXUS_REST_APINS0RepositoryRouteResourceResponse *_nEXUS_REST_APINS0RepositoryRouteResourceResponse;
  xmlTextReaderPtr reader = xmlReaderForMemory([xml bytes], [xml length], NULL, NULL, 0);
  if (reader == NULL) {
    [NSException raise: @"XMLReadError"
                 format: @"Error instantiating an XML reader."];
    return nil;
  }

  _nEXUS_REST_APINS0RepositoryRouteResourceResponse = (NEXUS_REST_APINS0RepositoryRouteResourceResponse *) [NEXUS_REST_APINS0RepositoryRouteResourceResponse readXMLElement: reader];
  xmlFreeTextReader(reader); //free the reader
  return _nEXUS_REST_APINS0RepositoryRouteResourceResponse;
}

//documentation inherited.
- (NSData *) writeToXML
{
  xmlBufferPtr buf;
  xmlTextWriterPtr writer;
  int rc;
  NSData *data;

  buf = xmlBufferCreate();
  if (buf == NULL) {
    [NSException raise: @"XMLWriteError"
                 format: @"Error creating an XML buffer."];
    return nil;
  }

  writer = xmlNewTextWriterMemory(buf, 0);
  if (writer == NULL) {
    xmlBufferFree(buf);
    [NSException raise: @"XMLWriteError"
                 format: @"Error creating an XML writer."];
    return nil;
  }

  rc = xmlTextWriterStartDocument(writer, NULL, "utf-8", NULL);
  if (rc < 0) {
    xmlFreeTextWriter(writer);
    xmlBufferFree(buf);
    [NSException raise: @"XMLWriteError"
                 format: @"Error writing XML start document."];
    return nil;
  }

  NS_DURING
  {
    [self writeXMLElement: writer];
  }
  NS_HANDLER
  {
    xmlFreeTextWriter(writer);
    xmlBufferFree(buf);
    [localException raise];
  }
  NS_ENDHANDLER

  rc = xmlTextWriterEndDocument(writer);
  if (rc < 0) {
    xmlFreeTextWriter(writer);
    xmlBufferFree(buf);
    [NSException raise: @"XMLWriteError"
                 format: @"Error writing XML end document."];
    return nil;
  }

  xmlFreeTextWriter(writer);
  data = [NSData dataWithBytes: buf->content length: buf->use];
  xmlBufferFree(buf);
  return data;
}
@end /* implementation NEXUS_REST_APINS0RepositoryRouteResourceResponse */

/**
 * Internal, private interface for JAXB reading and writing.
 */
@interface NEXUS_REST_APINS0RepositoryRouteResourceResponse (JAXB) <JAXBReading, JAXBWriting, JAXBType, JAXBElement>

@end /*interface NEXUS_REST_APINS0RepositoryRouteResourceResponse (JAXB)*/

/**
 * Internal, private implementation for JAXB reading and writing.
 */
@implementation NEXUS_REST_APINS0RepositoryRouteResourceResponse (JAXB)

/**
 * Read an instance of NEXUS_REST_APINS0RepositoryRouteResourceResponse from an XML reader.
 *
 * @param reader The reader.
 * @return An instance of NEXUS_REST_APINS0RepositoryRouteResourceResponse defined by the XML reader.
 */
+ (id<JAXBType>) readXMLType: (xmlTextReaderPtr) reader
{
  NEXUS_REST_APINS0RepositoryRouteResourceResponse *_nEXUS_REST_APINS0RepositoryRouteResourceResponse = [[NEXUS_REST_APINS0RepositoryRouteResourceResponse alloc] init];
  NS_DURING
  {
    [_nEXUS_REST_APINS0RepositoryRouteResourceResponse initWithReader: reader];
  }
  NS_HANDLER
  {
    [_nEXUS_REST_APINS0RepositoryRouteResourceResponse dealloc];
    _nEXUS_REST_APINS0RepositoryRouteResourceResponse = nil;
    [localException raise];
  }
  NS_ENDHANDLER

  [_nEXUS_REST_APINS0RepositoryRouteResourceResponse autorelease];
  return _nEXUS_REST_APINS0RepositoryRouteResourceResponse;
}

/**
 * Initialize this instance of NEXUS_REST_APINS0RepositoryRouteResourceResponse according to
 * the XML being read from the reader.
 *
 * @param reader The reader.
 */
- (id) initWithReader: (xmlTextReaderPtr) reader
{
  return [super initWithReader: reader];
}

/**
 * Write the XML for this instance of NEXUS_REST_APINS0RepositoryRouteResourceResponse to the writer.
 * Note that since we're only writing the XML type,
 * No start/end element will be written.
 *
 * @param reader The reader.
 */
- (void) writeXMLType: (xmlTextWriterPtr) writer
{
  [super writeXMLType:writer];
}

/**
 * Reads a NEXUS_REST_APINS0RepositoryRouteResourceResponse from an XML reader. The element to be read is
 * "repo-route".
 *
 * @param reader The XML reader.
 * @return The NEXUS_REST_APINS0RepositoryRouteResourceResponse.
 */
+ (id<JAXBElement>) readXMLElement: (xmlTextReaderPtr) reader {
  int status;
  NEXUS_REST_APINS0RepositoryRouteResourceResponse *_repositoryRouteResourceResponse = nil;

  if (xmlTextReaderNodeType(reader) != XML_READER_TYPE_ELEMENT) {
    status = xmlTextReaderAdvanceToNextStartOrEndElement(reader);
    if (status < 1) {
      [NSException raise: @"XMLReadError"
                   format: @"Error advancing the reader to start element repo-route."];
    }
  }

  if (xmlStrcmp(BAD_CAST "repo-route", xmlTextReaderConstLocalName(reader)) == 0
      && xmlTextReaderConstNamespaceUri(reader) == NULL) {
#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read root element {}repo-route.");
#endif
    _repositoryRouteResourceResponse = (NEXUS_REST_APINS0RepositoryRouteResourceResponse *)[NEXUS_REST_APINS0RepositoryRouteResourceResponse readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"Successfully read root element {}repo-route.");
#endif
  }
  else {
    if (xmlTextReaderConstNamespaceUri(reader) == NULL) {
      [NSException raise: @"XMLReadError"
                   format: @"Unable to read NEXUS_REST_APINS0RepositoryRouteResourceResponse. Expected element repo-route. Current element: {}%s", xmlTextReaderConstLocalName(reader)];
    }
    else {
      [NSException raise: @"XMLReadError"
                   format: @"Unable to read NEXUS_REST_APINS0RepositoryRouteResourceResponse. Expected element repo-route. Current element: {%s}%s\n", xmlTextReaderConstNamespaceUri(reader), xmlTextReaderConstLocalName(reader)];
    }
  }

  return _repositoryRouteResourceResponse;
}

/**
 * Writes this NEXUS_REST_APINS0RepositoryRouteResourceResponse to XML under element name "repo-route".
 * The namespace declarations for the element will be written.
 *
 * @param writer The XML writer.
 * @param _repositoryRouteResourceResponse The RepositoryRouteResourceResponse to write.
 * @return 1 if successful, 0 otherwise.
 */
- (void) writeXMLElement: (xmlTextWriterPtr) writer
{
  [self writeXMLElement: writer writeNamespaces: YES];
}

/**
 * Writes this NEXUS_REST_APINS0RepositoryRouteResourceResponse to an XML writer.
 *
 * @param writer The writer.
 * @param writeNs Whether to write the namespaces for this element to the xml writer.
 */
- (void) writeXMLElement: (xmlTextWriterPtr) writer writeNamespaces: (BOOL) writeNs
{
  int rc = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "repo-route", NULL);
  if (rc < 0) {
    [NSException raise: @"XMLWriteError"
                 format: @"Error writing start element {}repo-route. XML writer status: %i\n", rc];
  }

#if DEBUG_ENUNCIATE > 1
  NSLog(@"writing type {}repositoryRouteResourceResponse for root element {}repo-route...");
#endif
  [self writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
  NSLog(@"successfully wrote type {}repositoryRouteResourceResponse for root element {}repo-route...");
#endif
  rc = xmlTextWriterEndElement(writer);
  if (rc < 0) {
    [NSException raise: @"XMLWriteError"
                 format: @"Error writing end element {}repo-route. XML writer status: %i\n", rc];
  }
}

//documentation inherited.
- (BOOL) readJAXBAttribute: (xmlTextReaderPtr) reader
{
  void *_child_accessor;

  if ([super readJAXBAttribute: reader]) {
    return YES;
  }

  return NO;
}

//documentation inherited.
- (BOOL) readJAXBValue: (xmlTextReaderPtr) reader
{
  return [super readJAXBValue: reader];
}

//documentation inherited.
- (BOOL) readJAXBChildElement: (xmlTextReaderPtr) reader
{
  id __child;
  void *_child_accessor;
  int status, depth;

  if ([super readJAXBChildElement: reader]) {
    return YES;
  }
  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "data", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}data of type {}repository-route-resource.");
#endif
    __child = [NEXUS_REST_APINS0RepositoryRouteResource readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}data of type {}repository-route-resource.");
#endif

    [self setData: __child];
    return YES;
  } //end "if choice"


  return NO;
}

//documentation inherited.
- (int) readUnknownJAXBChildElement: (xmlTextReaderPtr) reader
{
  return [super readUnknownJAXBChildElement: reader];
}

//documentation inherited.
- (void) readUnknownJAXBAttribute: (xmlTextReaderPtr) reader
{
  [super readUnknownJAXBAttribute: reader];
}

//documentation inherited.
- (void) writeJAXBAttributes: (xmlTextWriterPtr) writer
{
  int status;

  [super writeJAXBAttributes: writer];

}

//documentation inherited.
- (void) writeJAXBValue: (xmlTextWriterPtr) writer
{
  [super writeJAXBValue: writer];
}

/**
 * Method for writing the child elements.
 *
 * @param writer The writer.
 */
- (void) writeJAXBChildElements: (xmlTextWriterPtr) writer
{
  int status;
  id __item;
  NSEnumerator *__enumerator;

  [super writeJAXBChildElements: writer];

  if ([self data]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "data", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}data."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}data...");
#endif
    [[self data] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}data...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}data."];
    }
  }
}
@end /* implementation NEXUS_REST_APINS0RepositoryRouteResourceResponse (JAXB) */

#endif /* DEF_NEXUS_REST_APINS0RepositoryRouteResourceResponse_M */
#ifndef DEF_NEXUS_REST_APINS0RepositoryRouteListResourceResponse_M
#define DEF_NEXUS_REST_APINS0RepositoryRouteListResourceResponse_M

/**
 *  REST Response object for a repository route list request,
 contains the typical 'data' parameter, which is the list of
 repository route objects.
 
 @version $Revision$ $Date$

 */
@implementation NEXUS_REST_APINS0RepositoryRouteListResourceResponse

/**
 * Field data.
 */
- (NSArray *) data
{
  return _data;
}

/**
 * Field data.
 */
- (void) setData: (NSArray *) newData
{
  [newData retain];
  [_data release];
  _data = newData;
}

- (void) dealloc
{
  [self setData: nil];
  [super dealloc];
}

//documentation inherited.
+ (id<EnunciateXML>) readFromXML: (NSData *) xml
{
  NEXUS_REST_APINS0RepositoryRouteListResourceResponse *_nEXUS_REST_APINS0RepositoryRouteListResourceResponse;
  xmlTextReaderPtr reader = xmlReaderForMemory([xml bytes], [xml length], NULL, NULL, 0);
  if (reader == NULL) {
    [NSException raise: @"XMLReadError"
                 format: @"Error instantiating an XML reader."];
    return nil;
  }

  _nEXUS_REST_APINS0RepositoryRouteListResourceResponse = (NEXUS_REST_APINS0RepositoryRouteListResourceResponse *) [NEXUS_REST_APINS0RepositoryRouteListResourceResponse readXMLElement: reader];
  xmlFreeTextReader(reader); //free the reader
  return _nEXUS_REST_APINS0RepositoryRouteListResourceResponse;
}

//documentation inherited.
- (NSData *) writeToXML
{
  xmlBufferPtr buf;
  xmlTextWriterPtr writer;
  int rc;
  NSData *data;

  buf = xmlBufferCreate();
  if (buf == NULL) {
    [NSException raise: @"XMLWriteError"
                 format: @"Error creating an XML buffer."];
    return nil;
  }

  writer = xmlNewTextWriterMemory(buf, 0);
  if (writer == NULL) {
    xmlBufferFree(buf);
    [NSException raise: @"XMLWriteError"
                 format: @"Error creating an XML writer."];
    return nil;
  }

  rc = xmlTextWriterStartDocument(writer, NULL, "utf-8", NULL);
  if (rc < 0) {
    xmlFreeTextWriter(writer);
    xmlBufferFree(buf);
    [NSException raise: @"XMLWriteError"
                 format: @"Error writing XML start document."];
    return nil;
  }

  NS_DURING
  {
    [self writeXMLElement: writer];
  }
  NS_HANDLER
  {
    xmlFreeTextWriter(writer);
    xmlBufferFree(buf);
    [localException raise];
  }
  NS_ENDHANDLER

  rc = xmlTextWriterEndDocument(writer);
  if (rc < 0) {
    xmlFreeTextWriter(writer);
    xmlBufferFree(buf);
    [NSException raise: @"XMLWriteError"
                 format: @"Error writing XML end document."];
    return nil;
  }

  xmlFreeTextWriter(writer);
  data = [NSData dataWithBytes: buf->content length: buf->use];
  xmlBufferFree(buf);
  return data;
}
@end /* implementation NEXUS_REST_APINS0RepositoryRouteListResourceResponse */

/**
 * Internal, private interface for JAXB reading and writing.
 */
@interface NEXUS_REST_APINS0RepositoryRouteListResourceResponse (JAXB) <JAXBReading, JAXBWriting, JAXBType, JAXBElement>

@end /*interface NEXUS_REST_APINS0RepositoryRouteListResourceResponse (JAXB)*/

/**
 * Internal, private implementation for JAXB reading and writing.
 */
@implementation NEXUS_REST_APINS0RepositoryRouteListResourceResponse (JAXB)

/**
 * Read an instance of NEXUS_REST_APINS0RepositoryRouteListResourceResponse from an XML reader.
 *
 * @param reader The reader.
 * @return An instance of NEXUS_REST_APINS0RepositoryRouteListResourceResponse defined by the XML reader.
 */
+ (id<JAXBType>) readXMLType: (xmlTextReaderPtr) reader
{
  NEXUS_REST_APINS0RepositoryRouteListResourceResponse *_nEXUS_REST_APINS0RepositoryRouteListResourceResponse = [[NEXUS_REST_APINS0RepositoryRouteListResourceResponse alloc] init];
  NS_DURING
  {
    [_nEXUS_REST_APINS0RepositoryRouteListResourceResponse initWithReader: reader];
  }
  NS_HANDLER
  {
    [_nEXUS_REST_APINS0RepositoryRouteListResourceResponse dealloc];
    _nEXUS_REST_APINS0RepositoryRouteListResourceResponse = nil;
    [localException raise];
  }
  NS_ENDHANDLER

  [_nEXUS_REST_APINS0RepositoryRouteListResourceResponse autorelease];
  return _nEXUS_REST_APINS0RepositoryRouteListResourceResponse;
}

/**
 * Initialize this instance of NEXUS_REST_APINS0RepositoryRouteListResourceResponse according to
 * the XML being read from the reader.
 *
 * @param reader The reader.
 */
- (id) initWithReader: (xmlTextReaderPtr) reader
{
  return [super initWithReader: reader];
}

/**
 * Write the XML for this instance of NEXUS_REST_APINS0RepositoryRouteListResourceResponse to the writer.
 * Note that since we're only writing the XML type,
 * No start/end element will be written.
 *
 * @param reader The reader.
 */
- (void) writeXMLType: (xmlTextWriterPtr) writer
{
  [super writeXMLType:writer];
}

/**
 * Reads a NEXUS_REST_APINS0RepositoryRouteListResourceResponse from an XML reader. The element to be read is
 * "repo-routes-list".
 *
 * @param reader The XML reader.
 * @return The NEXUS_REST_APINS0RepositoryRouteListResourceResponse.
 */
+ (id<JAXBElement>) readXMLElement: (xmlTextReaderPtr) reader {
  int status;
  NEXUS_REST_APINS0RepositoryRouteListResourceResponse *_repositoryRouteListResourceResponse = nil;

  if (xmlTextReaderNodeType(reader) != XML_READER_TYPE_ELEMENT) {
    status = xmlTextReaderAdvanceToNextStartOrEndElement(reader);
    if (status < 1) {
      [NSException raise: @"XMLReadError"
                   format: @"Error advancing the reader to start element repo-routes-list."];
    }
  }

  if (xmlStrcmp(BAD_CAST "repo-routes-list", xmlTextReaderConstLocalName(reader)) == 0
      && xmlTextReaderConstNamespaceUri(reader) == NULL) {
#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read root element {}repo-routes-list.");
#endif
    _repositoryRouteListResourceResponse = (NEXUS_REST_APINS0RepositoryRouteListResourceResponse *)[NEXUS_REST_APINS0RepositoryRouteListResourceResponse readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"Successfully read root element {}repo-routes-list.");
#endif
  }
  else {
    if (xmlTextReaderConstNamespaceUri(reader) == NULL) {
      [NSException raise: @"XMLReadError"
                   format: @"Unable to read NEXUS_REST_APINS0RepositoryRouteListResourceResponse. Expected element repo-routes-list. Current element: {}%s", xmlTextReaderConstLocalName(reader)];
    }
    else {
      [NSException raise: @"XMLReadError"
                   format: @"Unable to read NEXUS_REST_APINS0RepositoryRouteListResourceResponse. Expected element repo-routes-list. Current element: {%s}%s\n", xmlTextReaderConstNamespaceUri(reader), xmlTextReaderConstLocalName(reader)];
    }
  }

  return _repositoryRouteListResourceResponse;
}

/**
 * Writes this NEXUS_REST_APINS0RepositoryRouteListResourceResponse to XML under element name "repo-routes-list".
 * The namespace declarations for the element will be written.
 *
 * @param writer The XML writer.
 * @param _repositoryRouteListResourceResponse The RepositoryRouteListResourceResponse to write.
 * @return 1 if successful, 0 otherwise.
 */
- (void) writeXMLElement: (xmlTextWriterPtr) writer
{
  [self writeXMLElement: writer writeNamespaces: YES];
}

/**
 * Writes this NEXUS_REST_APINS0RepositoryRouteListResourceResponse to an XML writer.
 *
 * @param writer The writer.
 * @param writeNs Whether to write the namespaces for this element to the xml writer.
 */
- (void) writeXMLElement: (xmlTextWriterPtr) writer writeNamespaces: (BOOL) writeNs
{
  int rc = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "repo-routes-list", NULL);
  if (rc < 0) {
    [NSException raise: @"XMLWriteError"
                 format: @"Error writing start element {}repo-routes-list. XML writer status: %i\n", rc];
  }

#if DEBUG_ENUNCIATE > 1
  NSLog(@"writing type {}repositoryRouteListResourceResponse for root element {}repo-routes-list...");
#endif
  [self writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
  NSLog(@"successfully wrote type {}repositoryRouteListResourceResponse for root element {}repo-routes-list...");
#endif
  rc = xmlTextWriterEndElement(writer);
  if (rc < 0) {
    [NSException raise: @"XMLWriteError"
                 format: @"Error writing end element {}repo-routes-list. XML writer status: %i\n", rc];
  }
}

//documentation inherited.
- (BOOL) readJAXBAttribute: (xmlTextReaderPtr) reader
{
  void *_child_accessor;

  if ([super readJAXBAttribute: reader]) {
    return YES;
  }

  return NO;
}

//documentation inherited.
- (BOOL) readJAXBValue: (xmlTextReaderPtr) reader
{
  return [super readJAXBValue: reader];
}

//documentation inherited.
- (BOOL) readJAXBChildElement: (xmlTextReaderPtr) reader
{
  id __child;
  void *_child_accessor;
  int status, depth;

  if ([super readJAXBChildElement: reader]) {
    return YES;
  }
  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "data", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

    if (xmlTextReaderIsEmptyElement(reader) == 0) {
#if DEBUG_ENUNCIATE > 1
      NSLog(@"Unwrapping wrapper element {}data...");
#endif
      //start wrapper element "{}data"
      depth = xmlTextReaderDepth(reader);
      status = xmlTextReaderAdvanceToNextStartOrEndElement(reader);
      while (xmlTextReaderDepth(reader) > depth) {
        if (status < 1) {
          //panic: XML read error.
          [self dealloc];
          [NSException raise: @"XMLReadError"
                       format: @"Failure to advance to next wrapped child element."];
        }
  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "repo-routes-list-item", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}repo-routes-list-item of type {}repository-route-list-resource.");
#endif

    __child = [NEXUS_REST_APINS0RepositoryRouteListResource readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}repo-routes-list-item of type {}repository-route-list-resource.");
#endif

    if ([self data]) {
      [self setData: [[self data] arrayByAddingObject: __child]];
    }
    else {
      [self setData: [NSArray arrayWithObject: __child]];
    }
    continue; //continue "while in wrapper element" loop
  } //end "if choice"

        status = xmlTextReaderAdvanceToNextStartOrEndElement(reader);
#if DEBUG_ENUNCIATE > 1
        NSLog(@"successfully unwrapped wrapper element {}data...");
#endif
      } // end "while in wrapper element" loop

      if (status < 1) {
        //panic: XML read error.
        [self dealloc];
        [NSException raise: @"XMLReadError"
                     format: @"Failure to advance to end wrapper element."];
      }
      else {
        //end wrapper element "{}data"
        status = xmlTextReaderAdvanceToNextStartOrEndElement(reader);
      }
    } //end "if empty element" clause
    else {
      __child = [NSArray array];
      [self setData: (NSArray*) __child];
    }

    return YES;
  } // end "if wrapper element" clause

  return NO;
}

//documentation inherited.
- (int) readUnknownJAXBChildElement: (xmlTextReaderPtr) reader
{
  return [super readUnknownJAXBChildElement: reader];
}

//documentation inherited.
- (void) readUnknownJAXBAttribute: (xmlTextReaderPtr) reader
{
  [super readUnknownJAXBAttribute: reader];
}

//documentation inherited.
- (void) writeJAXBAttributes: (xmlTextWriterPtr) writer
{
  int status;

  [super writeJAXBAttributes: writer];

}

//documentation inherited.
- (void) writeJAXBValue: (xmlTextWriterPtr) writer
{
  [super writeJAXBValue: writer];
}

/**
 * Method for writing the child elements.
 *
 * @param writer The writer.
 */
- (void) writeJAXBChildElements: (xmlTextWriterPtr) writer
{
  int status;
  id __item;
  NSEnumerator *__enumerator;

  [super writeJAXBChildElements: writer];

  if ([self data]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "data", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start wrapper element {}data."];
    }
    __enumerator = [[self data] objectEnumerator];

    while ( (__item = [__enumerator nextObject]) ) {
      status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "repo-routes-list-item", NULL);
      if (status < 0) {
        [NSException raise: @"XMLWriteError"
                     format: @"Error writing start child element {}repo-routes-list-item."];
      }

#if DEBUG_ENUNCIATE > 1
      NSLog(@"writing element {}repo-routes-list-item...");
#endif
      [__item writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
      NSLog(@"successfully wrote element {}repo-routes-list-item...");
#endif

      status = xmlTextWriterEndElement(writer);
      if (status < 0) {
        [NSException raise: @"XMLWriteError"
                     format: @"Error writing end child element {}repo-routes-list-item."];
      }
    } //end item iterator.

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end wrapper element {}data."];
    }
  }
}
@end /* implementation NEXUS_REST_APINS0RepositoryRouteListResourceResponse (JAXB) */

#endif /* DEF_NEXUS_REST_APINS0RepositoryRouteListResourceResponse_M */
#ifndef DEF_NEXUS_REST_APINS0RepositoryListResourceResponse_M
#define DEF_NEXUS_REST_APINS0RepositoryListResourceResponse_M

/**
 *  REST Response object for a repository list request, contains the
 typical 'data' parameter, which is the list of repository
 objects.
 
 @version $Revision$ $Date$

 */
@implementation NEXUS_REST_APINS0RepositoryListResourceResponse

/**
 * Field data.
 */
- (NSArray *) data
{
  return _data;
}

/**
 * Field data.
 */
- (void) setData: (NSArray *) newData
{
  [newData retain];
  [_data release];
  _data = newData;
}

- (void) dealloc
{
  [self setData: nil];
  [super dealloc];
}

//documentation inherited.
+ (id<EnunciateXML>) readFromXML: (NSData *) xml
{
  NEXUS_REST_APINS0RepositoryListResourceResponse *_nEXUS_REST_APINS0RepositoryListResourceResponse;
  xmlTextReaderPtr reader = xmlReaderForMemory([xml bytes], [xml length], NULL, NULL, 0);
  if (reader == NULL) {
    [NSException raise: @"XMLReadError"
                 format: @"Error instantiating an XML reader."];
    return nil;
  }

  _nEXUS_REST_APINS0RepositoryListResourceResponse = (NEXUS_REST_APINS0RepositoryListResourceResponse *) [NEXUS_REST_APINS0RepositoryListResourceResponse readXMLElement: reader];
  xmlFreeTextReader(reader); //free the reader
  return _nEXUS_REST_APINS0RepositoryListResourceResponse;
}

//documentation inherited.
- (NSData *) writeToXML
{
  xmlBufferPtr buf;
  xmlTextWriterPtr writer;
  int rc;
  NSData *data;

  buf = xmlBufferCreate();
  if (buf == NULL) {
    [NSException raise: @"XMLWriteError"
                 format: @"Error creating an XML buffer."];
    return nil;
  }

  writer = xmlNewTextWriterMemory(buf, 0);
  if (writer == NULL) {
    xmlBufferFree(buf);
    [NSException raise: @"XMLWriteError"
                 format: @"Error creating an XML writer."];
    return nil;
  }

  rc = xmlTextWriterStartDocument(writer, NULL, "utf-8", NULL);
  if (rc < 0) {
    xmlFreeTextWriter(writer);
    xmlBufferFree(buf);
    [NSException raise: @"XMLWriteError"
                 format: @"Error writing XML start document."];
    return nil;
  }

  NS_DURING
  {
    [self writeXMLElement: writer];
  }
  NS_HANDLER
  {
    xmlFreeTextWriter(writer);
    xmlBufferFree(buf);
    [localException raise];
  }
  NS_ENDHANDLER

  rc = xmlTextWriterEndDocument(writer);
  if (rc < 0) {
    xmlFreeTextWriter(writer);
    xmlBufferFree(buf);
    [NSException raise: @"XMLWriteError"
                 format: @"Error writing XML end document."];
    return nil;
  }

  xmlFreeTextWriter(writer);
  data = [NSData dataWithBytes: buf->content length: buf->use];
  xmlBufferFree(buf);
  return data;
}
@end /* implementation NEXUS_REST_APINS0RepositoryListResourceResponse */

/**
 * Internal, private interface for JAXB reading and writing.
 */
@interface NEXUS_REST_APINS0RepositoryListResourceResponse (JAXB) <JAXBReading, JAXBWriting, JAXBType, JAXBElement>

@end /*interface NEXUS_REST_APINS0RepositoryListResourceResponse (JAXB)*/

/**
 * Internal, private implementation for JAXB reading and writing.
 */
@implementation NEXUS_REST_APINS0RepositoryListResourceResponse (JAXB)

/**
 * Read an instance of NEXUS_REST_APINS0RepositoryListResourceResponse from an XML reader.
 *
 * @param reader The reader.
 * @return An instance of NEXUS_REST_APINS0RepositoryListResourceResponse defined by the XML reader.
 */
+ (id<JAXBType>) readXMLType: (xmlTextReaderPtr) reader
{
  NEXUS_REST_APINS0RepositoryListResourceResponse *_nEXUS_REST_APINS0RepositoryListResourceResponse = [[NEXUS_REST_APINS0RepositoryListResourceResponse alloc] init];
  NS_DURING
  {
    [_nEXUS_REST_APINS0RepositoryListResourceResponse initWithReader: reader];
  }
  NS_HANDLER
  {
    [_nEXUS_REST_APINS0RepositoryListResourceResponse dealloc];
    _nEXUS_REST_APINS0RepositoryListResourceResponse = nil;
    [localException raise];
  }
  NS_ENDHANDLER

  [_nEXUS_REST_APINS0RepositoryListResourceResponse autorelease];
  return _nEXUS_REST_APINS0RepositoryListResourceResponse;
}

/**
 * Initialize this instance of NEXUS_REST_APINS0RepositoryListResourceResponse according to
 * the XML being read from the reader.
 *
 * @param reader The reader.
 */
- (id) initWithReader: (xmlTextReaderPtr) reader
{
  return [super initWithReader: reader];
}

/**
 * Write the XML for this instance of NEXUS_REST_APINS0RepositoryListResourceResponse to the writer.
 * Note that since we're only writing the XML type,
 * No start/end element will be written.
 *
 * @param reader The reader.
 */
- (void) writeXMLType: (xmlTextWriterPtr) writer
{
  [super writeXMLType:writer];
}

/**
 * Reads a NEXUS_REST_APINS0RepositoryListResourceResponse from an XML reader. The element to be read is
 * "repositories".
 *
 * @param reader The XML reader.
 * @return The NEXUS_REST_APINS0RepositoryListResourceResponse.
 */
+ (id<JAXBElement>) readXMLElement: (xmlTextReaderPtr) reader {
  int status;
  NEXUS_REST_APINS0RepositoryListResourceResponse *_repositoryListResourceResponse = nil;

  if (xmlTextReaderNodeType(reader) != XML_READER_TYPE_ELEMENT) {
    status = xmlTextReaderAdvanceToNextStartOrEndElement(reader);
    if (status < 1) {
      [NSException raise: @"XMLReadError"
                   format: @"Error advancing the reader to start element repositories."];
    }
  }

  if (xmlStrcmp(BAD_CAST "repositories", xmlTextReaderConstLocalName(reader)) == 0
      && xmlTextReaderConstNamespaceUri(reader) == NULL) {
#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read root element {}repositories.");
#endif
    _repositoryListResourceResponse = (NEXUS_REST_APINS0RepositoryListResourceResponse *)[NEXUS_REST_APINS0RepositoryListResourceResponse readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"Successfully read root element {}repositories.");
#endif
  }
  else {
    if (xmlTextReaderConstNamespaceUri(reader) == NULL) {
      [NSException raise: @"XMLReadError"
                   format: @"Unable to read NEXUS_REST_APINS0RepositoryListResourceResponse. Expected element repositories. Current element: {}%s", xmlTextReaderConstLocalName(reader)];
    }
    else {
      [NSException raise: @"XMLReadError"
                   format: @"Unable to read NEXUS_REST_APINS0RepositoryListResourceResponse. Expected element repositories. Current element: {%s}%s\n", xmlTextReaderConstNamespaceUri(reader), xmlTextReaderConstLocalName(reader)];
    }
  }

  return _repositoryListResourceResponse;
}

/**
 * Writes this NEXUS_REST_APINS0RepositoryListResourceResponse to XML under element name "repositories".
 * The namespace declarations for the element will be written.
 *
 * @param writer The XML writer.
 * @param _repositoryListResourceResponse The RepositoryListResourceResponse to write.
 * @return 1 if successful, 0 otherwise.
 */
- (void) writeXMLElement: (xmlTextWriterPtr) writer
{
  [self writeXMLElement: writer writeNamespaces: YES];
}

/**
 * Writes this NEXUS_REST_APINS0RepositoryListResourceResponse to an XML writer.
 *
 * @param writer The writer.
 * @param writeNs Whether to write the namespaces for this element to the xml writer.
 */
- (void) writeXMLElement: (xmlTextWriterPtr) writer writeNamespaces: (BOOL) writeNs
{
  int rc = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "repositories", NULL);
  if (rc < 0) {
    [NSException raise: @"XMLWriteError"
                 format: @"Error writing start element {}repositories. XML writer status: %i\n", rc];
  }

#if DEBUG_ENUNCIATE > 1
  NSLog(@"writing type {}repositoryListResourceResponse for root element {}repositories...");
#endif
  [self writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
  NSLog(@"successfully wrote type {}repositoryListResourceResponse for root element {}repositories...");
#endif
  rc = xmlTextWriterEndElement(writer);
  if (rc < 0) {
    [NSException raise: @"XMLWriteError"
                 format: @"Error writing end element {}repositories. XML writer status: %i\n", rc];
  }
}

//documentation inherited.
- (BOOL) readJAXBAttribute: (xmlTextReaderPtr) reader
{
  void *_child_accessor;

  if ([super readJAXBAttribute: reader]) {
    return YES;
  }

  return NO;
}

//documentation inherited.
- (BOOL) readJAXBValue: (xmlTextReaderPtr) reader
{
  return [super readJAXBValue: reader];
}

//documentation inherited.
- (BOOL) readJAXBChildElement: (xmlTextReaderPtr) reader
{
  id __child;
  void *_child_accessor;
  int status, depth;

  if ([super readJAXBChildElement: reader]) {
    return YES;
  }
  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "data", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

    if (xmlTextReaderIsEmptyElement(reader) == 0) {
#if DEBUG_ENUNCIATE > 1
      NSLog(@"Unwrapping wrapper element {}data...");
#endif
      //start wrapper element "{}data"
      depth = xmlTextReaderDepth(reader);
      status = xmlTextReaderAdvanceToNextStartOrEndElement(reader);
      while (xmlTextReaderDepth(reader) > depth) {
        if (status < 1) {
          //panic: XML read error.
          [self dealloc];
          [NSException raise: @"XMLReadError"
                       format: @"Failure to advance to next wrapped child element."];
        }
  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "repositories-item", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}repositories-item of type {}repositories-item.");
#endif

    __child = [NEXUS_REST_APINS0RepositoryListResource readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}repositories-item of type {}repositories-item.");
#endif

    if ([self data]) {
      [self setData: [[self data] arrayByAddingObject: __child]];
    }
    else {
      [self setData: [NSArray arrayWithObject: __child]];
    }
    continue; //continue "while in wrapper element" loop
  } //end "if choice"

        status = xmlTextReaderAdvanceToNextStartOrEndElement(reader);
#if DEBUG_ENUNCIATE > 1
        NSLog(@"successfully unwrapped wrapper element {}data...");
#endif
      } // end "while in wrapper element" loop

      if (status < 1) {
        //panic: XML read error.
        [self dealloc];
        [NSException raise: @"XMLReadError"
                     format: @"Failure to advance to end wrapper element."];
      }
      else {
        //end wrapper element "{}data"
        status = xmlTextReaderAdvanceToNextStartOrEndElement(reader);
      }
    } //end "if empty element" clause
    else {
      __child = [NSArray array];
      [self setData: (NSArray*) __child];
    }

    return YES;
  } // end "if wrapper element" clause

  return NO;
}

//documentation inherited.
- (int) readUnknownJAXBChildElement: (xmlTextReaderPtr) reader
{
  return [super readUnknownJAXBChildElement: reader];
}

//documentation inherited.
- (void) readUnknownJAXBAttribute: (xmlTextReaderPtr) reader
{
  [super readUnknownJAXBAttribute: reader];
}

//documentation inherited.
- (void) writeJAXBAttributes: (xmlTextWriterPtr) writer
{
  int status;

  [super writeJAXBAttributes: writer];

}

//documentation inherited.
- (void) writeJAXBValue: (xmlTextWriterPtr) writer
{
  [super writeJAXBValue: writer];
}

/**
 * Method for writing the child elements.
 *
 * @param writer The writer.
 */
- (void) writeJAXBChildElements: (xmlTextWriterPtr) writer
{
  int status;
  id __item;
  NSEnumerator *__enumerator;

  [super writeJAXBChildElements: writer];

  if ([self data]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "data", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start wrapper element {}data."];
    }
    __enumerator = [[self data] objectEnumerator];

    while ( (__item = [__enumerator nextObject]) ) {
      status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "repositories-item", NULL);
      if (status < 0) {
        [NSException raise: @"XMLWriteError"
                     format: @"Error writing start child element {}repositories-item."];
      }

#if DEBUG_ENUNCIATE > 1
      NSLog(@"writing element {}repositories-item...");
#endif
      [__item writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
      NSLog(@"successfully wrote element {}repositories-item...");
#endif

      status = xmlTextWriterEndElement(writer);
      if (status < 0) {
        [NSException raise: @"XMLWriteError"
                     format: @"Error writing end child element {}repositories-item."];
      }
    } //end item iterator.

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end wrapper element {}data."];
    }
  }
}
@end /* implementation NEXUS_REST_APINS0RepositoryListResourceResponse (JAXB) */

#endif /* DEF_NEXUS_REST_APINS0RepositoryListResourceResponse_M */
#ifndef DEF_NEXUS_REST_APINS0RepositoryGroupResource_M
#define DEF_NEXUS_REST_APINS0RepositoryGroupResource_M

/**
 *  The set of items that define the repository group (extends
 repository base resource).
 
 @version $Revision$ $Date$

 */
@implementation NEXUS_REST_APINS0RepositoryGroupResource

/**
 * Field repositories.
 */
- (NSArray *) repositories
{
  return _repositories;
}

/**
 * Field repositories.
 */
- (void) setRepositories: (NSArray *) newRepositories
{
  [newRepositories retain];
  [_repositories release];
  _repositories = newRepositories;
}

- (void) dealloc
{
  [self setRepositories: nil];
  [super dealloc];
}
@end /* implementation NEXUS_REST_APINS0RepositoryGroupResource */

/**
 * Internal, private interface for JAXB reading and writing.
 */
@interface NEXUS_REST_APINS0RepositoryGroupResource (JAXB) <JAXBReading, JAXBWriting, JAXBType>

@end /*interface NEXUS_REST_APINS0RepositoryGroupResource (JAXB)*/

/**
 * Internal, private implementation for JAXB reading and writing.
 */
@implementation NEXUS_REST_APINS0RepositoryGroupResource (JAXB)

/**
 * Read an instance of NEXUS_REST_APINS0RepositoryGroupResource from an XML reader.
 *
 * @param reader The reader.
 * @return An instance of NEXUS_REST_APINS0RepositoryGroupResource defined by the XML reader.
 */
+ (id<JAXBType>) readXMLType: (xmlTextReaderPtr) reader
{
  NEXUS_REST_APINS0RepositoryGroupResource *_nEXUS_REST_APINS0RepositoryGroupResource = [[NEXUS_REST_APINS0RepositoryGroupResource alloc] init];
  NS_DURING
  {
    [_nEXUS_REST_APINS0RepositoryGroupResource initWithReader: reader];
  }
  NS_HANDLER
  {
    [_nEXUS_REST_APINS0RepositoryGroupResource dealloc];
    _nEXUS_REST_APINS0RepositoryGroupResource = nil;
    [localException raise];
  }
  NS_ENDHANDLER

  [_nEXUS_REST_APINS0RepositoryGroupResource autorelease];
  return _nEXUS_REST_APINS0RepositoryGroupResource;
}

/**
 * Initialize this instance of NEXUS_REST_APINS0RepositoryGroupResource according to
 * the XML being read from the reader.
 *
 * @param reader The reader.
 */
- (id) initWithReader: (xmlTextReaderPtr) reader
{
  return [super initWithReader: reader];
}

/**
 * Write the XML for this instance of NEXUS_REST_APINS0RepositoryGroupResource to the writer.
 * Note that since we're only writing the XML type,
 * No start/end element will be written.
 *
 * @param reader The reader.
 */
- (void) writeXMLType: (xmlTextWriterPtr) writer
{
  [super writeXMLType:writer];
}

//documentation inherited.
- (BOOL) readJAXBAttribute: (xmlTextReaderPtr) reader
{
  void *_child_accessor;

  if ([super readJAXBAttribute: reader]) {
    return YES;
  }

  return NO;
}

//documentation inherited.
- (BOOL) readJAXBValue: (xmlTextReaderPtr) reader
{
  return [super readJAXBValue: reader];
}

//documentation inherited.
- (BOOL) readJAXBChildElement: (xmlTextReaderPtr) reader
{
  id __child;
  void *_child_accessor;
  int status, depth;

  if ([super readJAXBChildElement: reader]) {
    return YES;
  }
  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "repositories", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

    if (xmlTextReaderIsEmptyElement(reader) == 0) {
#if DEBUG_ENUNCIATE > 1
      NSLog(@"Unwrapping wrapper element {}repositories...");
#endif
      //start wrapper element "{}repositories"
      depth = xmlTextReaderDepth(reader);
      status = xmlTextReaderAdvanceToNextStartOrEndElement(reader);
      while (xmlTextReaderDepth(reader) > depth) {
        if (status < 1) {
          //panic: XML read error.
          [self dealloc];
          [NSException raise: @"XMLReadError"
                       format: @"Failure to advance to next wrapped child element."];
        }
  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "repo-group-member", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}repo-group-member of type {}repository-group-member-repository.");
#endif

    __child = [NEXUS_REST_APINS0RepositoryGroupMemberRepository readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}repo-group-member of type {}repository-group-member-repository.");
#endif

    if ([self repositories]) {
      [self setRepositories: [[self repositories] arrayByAddingObject: __child]];
    }
    else {
      [self setRepositories: [NSArray arrayWithObject: __child]];
    }
    continue; //continue "while in wrapper element" loop
  } //end "if choice"

        status = xmlTextReaderAdvanceToNextStartOrEndElement(reader);
#if DEBUG_ENUNCIATE > 1
        NSLog(@"successfully unwrapped wrapper element {}repositories...");
#endif
      } // end "while in wrapper element" loop

      if (status < 1) {
        //panic: XML read error.
        [self dealloc];
        [NSException raise: @"XMLReadError"
                     format: @"Failure to advance to end wrapper element."];
      }
      else {
        //end wrapper element "{}repositories"
        status = xmlTextReaderAdvanceToNextStartOrEndElement(reader);
      }
    } //end "if empty element" clause
    else {
      __child = [NSArray array];
      [self setRepositories: (NSArray*) __child];
    }

    return YES;
  } // end "if wrapper element" clause

  return NO;
}

//documentation inherited.
- (int) readUnknownJAXBChildElement: (xmlTextReaderPtr) reader
{
  return [super readUnknownJAXBChildElement: reader];
}

//documentation inherited.
- (void) readUnknownJAXBAttribute: (xmlTextReaderPtr) reader
{
  [super readUnknownJAXBAttribute: reader];
}

//documentation inherited.
- (void) writeJAXBAttributes: (xmlTextWriterPtr) writer
{
  int status;

  [super writeJAXBAttributes: writer];

}

//documentation inherited.
- (void) writeJAXBValue: (xmlTextWriterPtr) writer
{
  [super writeJAXBValue: writer];
}

/**
 * Method for writing the child elements.
 *
 * @param writer The writer.
 */
- (void) writeJAXBChildElements: (xmlTextWriterPtr) writer
{
  int status;
  id __item;
  NSEnumerator *__enumerator;

  [super writeJAXBChildElements: writer];

  if ([self repositories]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "repositories", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start wrapper element {}repositories."];
    }
    __enumerator = [[self repositories] objectEnumerator];

    while ( (__item = [__enumerator nextObject]) ) {
      status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "repo-group-member", NULL);
      if (status < 0) {
        [NSException raise: @"XMLWriteError"
                     format: @"Error writing start child element {}repo-group-member."];
      }

#if DEBUG_ENUNCIATE > 1
      NSLog(@"writing element {}repo-group-member...");
#endif
      [__item writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
      NSLog(@"successfully wrote element {}repo-group-member...");
#endif

      status = xmlTextWriterEndElement(writer);
      if (status < 0) {
        [NSException raise: @"XMLWriteError"
                     format: @"Error writing end child element {}repo-group-member."];
      }
    } //end item iterator.

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end wrapper element {}repositories."];
    }
  }
}
@end /* implementation NEXUS_REST_APINS0RepositoryGroupResource (JAXB) */

#endif /* DEF_NEXUS_REST_APINS0RepositoryGroupResource_M */
#ifndef DEF_NEXUS_REST_APINS0RepositoryContentClassListResourceResponse_M
#define DEF_NEXUS_REST_APINS0RepositoryContentClassListResourceResponse_M

/**
 *  REST Response object for a list of repository content classes,
 contains the typical 'data' parameter, which is the repository
 content class list.
 
 @version $Revision$ $Date$

 */
@implementation NEXUS_REST_APINS0RepositoryContentClassListResourceResponse

/**
 * Field data.
 */
- (NSArray *) data
{
  return _data;
}

/**
 * Field data.
 */
- (void) setData: (NSArray *) newData
{
  [newData retain];
  [_data release];
  _data = newData;
}

- (void) dealloc
{
  [self setData: nil];
  [super dealloc];
}

//documentation inherited.
+ (id<EnunciateXML>) readFromXML: (NSData *) xml
{
  NEXUS_REST_APINS0RepositoryContentClassListResourceResponse *_nEXUS_REST_APINS0RepositoryContentClassListResourceResponse;
  xmlTextReaderPtr reader = xmlReaderForMemory([xml bytes], [xml length], NULL, NULL, 0);
  if (reader == NULL) {
    [NSException raise: @"XMLReadError"
                 format: @"Error instantiating an XML reader."];
    return nil;
  }

  _nEXUS_REST_APINS0RepositoryContentClassListResourceResponse = (NEXUS_REST_APINS0RepositoryContentClassListResourceResponse *) [NEXUS_REST_APINS0RepositoryContentClassListResourceResponse readXMLElement: reader];
  xmlFreeTextReader(reader); //free the reader
  return _nEXUS_REST_APINS0RepositoryContentClassListResourceResponse;
}

//documentation inherited.
- (NSData *) writeToXML
{
  xmlBufferPtr buf;
  xmlTextWriterPtr writer;
  int rc;
  NSData *data;

  buf = xmlBufferCreate();
  if (buf == NULL) {
    [NSException raise: @"XMLWriteError"
                 format: @"Error creating an XML buffer."];
    return nil;
  }

  writer = xmlNewTextWriterMemory(buf, 0);
  if (writer == NULL) {
    xmlBufferFree(buf);
    [NSException raise: @"XMLWriteError"
                 format: @"Error creating an XML writer."];
    return nil;
  }

  rc = xmlTextWriterStartDocument(writer, NULL, "utf-8", NULL);
  if (rc < 0) {
    xmlFreeTextWriter(writer);
    xmlBufferFree(buf);
    [NSException raise: @"XMLWriteError"
                 format: @"Error writing XML start document."];
    return nil;
  }

  NS_DURING
  {
    [self writeXMLElement: writer];
  }
  NS_HANDLER
  {
    xmlFreeTextWriter(writer);
    xmlBufferFree(buf);
    [localException raise];
  }
  NS_ENDHANDLER

  rc = xmlTextWriterEndDocument(writer);
  if (rc < 0) {
    xmlFreeTextWriter(writer);
    xmlBufferFree(buf);
    [NSException raise: @"XMLWriteError"
                 format: @"Error writing XML end document."];
    return nil;
  }

  xmlFreeTextWriter(writer);
  data = [NSData dataWithBytes: buf->content length: buf->use];
  xmlBufferFree(buf);
  return data;
}
@end /* implementation NEXUS_REST_APINS0RepositoryContentClassListResourceResponse */

/**
 * Internal, private interface for JAXB reading and writing.
 */
@interface NEXUS_REST_APINS0RepositoryContentClassListResourceResponse (JAXB) <JAXBReading, JAXBWriting, JAXBType, JAXBElement>

@end /*interface NEXUS_REST_APINS0RepositoryContentClassListResourceResponse (JAXB)*/

/**
 * Internal, private implementation for JAXB reading and writing.
 */
@implementation NEXUS_REST_APINS0RepositoryContentClassListResourceResponse (JAXB)

/**
 * Read an instance of NEXUS_REST_APINS0RepositoryContentClassListResourceResponse from an XML reader.
 *
 * @param reader The reader.
 * @return An instance of NEXUS_REST_APINS0RepositoryContentClassListResourceResponse defined by the XML reader.
 */
+ (id<JAXBType>) readXMLType: (xmlTextReaderPtr) reader
{
  NEXUS_REST_APINS0RepositoryContentClassListResourceResponse *_nEXUS_REST_APINS0RepositoryContentClassListResourceResponse = [[NEXUS_REST_APINS0RepositoryContentClassListResourceResponse alloc] init];
  NS_DURING
  {
    [_nEXUS_REST_APINS0RepositoryContentClassListResourceResponse initWithReader: reader];
  }
  NS_HANDLER
  {
    [_nEXUS_REST_APINS0RepositoryContentClassListResourceResponse dealloc];
    _nEXUS_REST_APINS0RepositoryContentClassListResourceResponse = nil;
    [localException raise];
  }
  NS_ENDHANDLER

  [_nEXUS_REST_APINS0RepositoryContentClassListResourceResponse autorelease];
  return _nEXUS_REST_APINS0RepositoryContentClassListResourceResponse;
}

/**
 * Initialize this instance of NEXUS_REST_APINS0RepositoryContentClassListResourceResponse according to
 * the XML being read from the reader.
 *
 * @param reader The reader.
 */
- (id) initWithReader: (xmlTextReaderPtr) reader
{
  return [super initWithReader: reader];
}

/**
 * Write the XML for this instance of NEXUS_REST_APINS0RepositoryContentClassListResourceResponse to the writer.
 * Note that since we're only writing the XML type,
 * No start/end element will be written.
 *
 * @param reader The reader.
 */
- (void) writeXMLType: (xmlTextWriterPtr) writer
{
  [super writeXMLType:writer];
}

/**
 * Reads a NEXUS_REST_APINS0RepositoryContentClassListResourceResponse from an XML reader. The element to be read is
 * "repo-content-classes-list".
 *
 * @param reader The XML reader.
 * @return The NEXUS_REST_APINS0RepositoryContentClassListResourceResponse.
 */
+ (id<JAXBElement>) readXMLElement: (xmlTextReaderPtr) reader {
  int status;
  NEXUS_REST_APINS0RepositoryContentClassListResourceResponse *_repositoryContentClassListResourceResponse = nil;

  if (xmlTextReaderNodeType(reader) != XML_READER_TYPE_ELEMENT) {
    status = xmlTextReaderAdvanceToNextStartOrEndElement(reader);
    if (status < 1) {
      [NSException raise: @"XMLReadError"
                   format: @"Error advancing the reader to start element repo-content-classes-list."];
    }
  }

  if (xmlStrcmp(BAD_CAST "repo-content-classes-list", xmlTextReaderConstLocalName(reader)) == 0
      && xmlTextReaderConstNamespaceUri(reader) == NULL) {
#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read root element {}repo-content-classes-list.");
#endif
    _repositoryContentClassListResourceResponse = (NEXUS_REST_APINS0RepositoryContentClassListResourceResponse *)[NEXUS_REST_APINS0RepositoryContentClassListResourceResponse readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"Successfully read root element {}repo-content-classes-list.");
#endif
  }
  else {
    if (xmlTextReaderConstNamespaceUri(reader) == NULL) {
      [NSException raise: @"XMLReadError"
                   format: @"Unable to read NEXUS_REST_APINS0RepositoryContentClassListResourceResponse. Expected element repo-content-classes-list. Current element: {}%s", xmlTextReaderConstLocalName(reader)];
    }
    else {
      [NSException raise: @"XMLReadError"
                   format: @"Unable to read NEXUS_REST_APINS0RepositoryContentClassListResourceResponse. Expected element repo-content-classes-list. Current element: {%s}%s\n", xmlTextReaderConstNamespaceUri(reader), xmlTextReaderConstLocalName(reader)];
    }
  }

  return _repositoryContentClassListResourceResponse;
}

/**
 * Writes this NEXUS_REST_APINS0RepositoryContentClassListResourceResponse to XML under element name "repo-content-classes-list".
 * The namespace declarations for the element will be written.
 *
 * @param writer The XML writer.
 * @param _repositoryContentClassListResourceResponse The RepositoryContentClassListResourceResponse to write.
 * @return 1 if successful, 0 otherwise.
 */
- (void) writeXMLElement: (xmlTextWriterPtr) writer
{
  [self writeXMLElement: writer writeNamespaces: YES];
}

/**
 * Writes this NEXUS_REST_APINS0RepositoryContentClassListResourceResponse to an XML writer.
 *
 * @param writer The writer.
 * @param writeNs Whether to write the namespaces for this element to the xml writer.
 */
- (void) writeXMLElement: (xmlTextWriterPtr) writer writeNamespaces: (BOOL) writeNs
{
  int rc = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "repo-content-classes-list", NULL);
  if (rc < 0) {
    [NSException raise: @"XMLWriteError"
                 format: @"Error writing start element {}repo-content-classes-list. XML writer status: %i\n", rc];
  }

#if DEBUG_ENUNCIATE > 1
  NSLog(@"writing type {}repositoryContentClassListResourceResponse for root element {}repo-content-classes-list...");
#endif
  [self writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
  NSLog(@"successfully wrote type {}repositoryContentClassListResourceResponse for root element {}repo-content-classes-list...");
#endif
  rc = xmlTextWriterEndElement(writer);
  if (rc < 0) {
    [NSException raise: @"XMLWriteError"
                 format: @"Error writing end element {}repo-content-classes-list. XML writer status: %i\n", rc];
  }
}

//documentation inherited.
- (BOOL) readJAXBAttribute: (xmlTextReaderPtr) reader
{
  void *_child_accessor;

  if ([super readJAXBAttribute: reader]) {
    return YES;
  }

  return NO;
}

//documentation inherited.
- (BOOL) readJAXBValue: (xmlTextReaderPtr) reader
{
  return [super readJAXBValue: reader];
}

//documentation inherited.
- (BOOL) readJAXBChildElement: (xmlTextReaderPtr) reader
{
  id __child;
  void *_child_accessor;
  int status, depth;

  if ([super readJAXBChildElement: reader]) {
    return YES;
  }
  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "data", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

    if (xmlTextReaderIsEmptyElement(reader) == 0) {
#if DEBUG_ENUNCIATE > 1
      NSLog(@"Unwrapping wrapper element {}data...");
#endif
      //start wrapper element "{}data"
      depth = xmlTextReaderDepth(reader);
      status = xmlTextReaderAdvanceToNextStartOrEndElement(reader);
      while (xmlTextReaderDepth(reader) > depth) {
        if (status < 1) {
          //panic: XML read error.
          [self dealloc];
          [NSException raise: @"XMLReadError"
                       format: @"Failure to advance to next wrapped child element."];
        }
  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "repo-content-classes-list-item", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}repo-content-classes-list-item of type {}repository-content-class-list-resource.");
#endif

    __child = [NEXUS_REST_APINS0RepositoryContentClassListResource readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}repo-content-classes-list-item of type {}repository-content-class-list-resource.");
#endif

    if ([self data]) {
      [self setData: [[self data] arrayByAddingObject: __child]];
    }
    else {
      [self setData: [NSArray arrayWithObject: __child]];
    }
    continue; //continue "while in wrapper element" loop
  } //end "if choice"

        status = xmlTextReaderAdvanceToNextStartOrEndElement(reader);
#if DEBUG_ENUNCIATE > 1
        NSLog(@"successfully unwrapped wrapper element {}data...");
#endif
      } // end "while in wrapper element" loop

      if (status < 1) {
        //panic: XML read error.
        [self dealloc];
        [NSException raise: @"XMLReadError"
                     format: @"Failure to advance to end wrapper element."];
      }
      else {
        //end wrapper element "{}data"
        status = xmlTextReaderAdvanceToNextStartOrEndElement(reader);
      }
    } //end "if empty element" clause
    else {
      __child = [NSArray array];
      [self setData: (NSArray*) __child];
    }

    return YES;
  } // end "if wrapper element" clause

  return NO;
}

//documentation inherited.
- (int) readUnknownJAXBChildElement: (xmlTextReaderPtr) reader
{
  return [super readUnknownJAXBChildElement: reader];
}

//documentation inherited.
- (void) readUnknownJAXBAttribute: (xmlTextReaderPtr) reader
{
  [super readUnknownJAXBAttribute: reader];
}

//documentation inherited.
- (void) writeJAXBAttributes: (xmlTextWriterPtr) writer
{
  int status;

  [super writeJAXBAttributes: writer];

}

//documentation inherited.
- (void) writeJAXBValue: (xmlTextWriterPtr) writer
{
  [super writeJAXBValue: writer];
}

/**
 * Method for writing the child elements.
 *
 * @param writer The writer.
 */
- (void) writeJAXBChildElements: (xmlTextWriterPtr) writer
{
  int status;
  id __item;
  NSEnumerator *__enumerator;

  [super writeJAXBChildElements: writer];

  if ([self data]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "data", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start wrapper element {}data."];
    }
    __enumerator = [[self data] objectEnumerator];

    while ( (__item = [__enumerator nextObject]) ) {
      status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "repo-content-classes-list-item", NULL);
      if (status < 0) {
        [NSException raise: @"XMLWriteError"
                     format: @"Error writing start child element {}repo-content-classes-list-item."];
      }

#if DEBUG_ENUNCIATE > 1
      NSLog(@"writing element {}repo-content-classes-list-item...");
#endif
      [__item writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
      NSLog(@"successfully wrote element {}repo-content-classes-list-item...");
#endif

      status = xmlTextWriterEndElement(writer);
      if (status < 0) {
        [NSException raise: @"XMLWriteError"
                     format: @"Error writing end child element {}repo-content-classes-list-item."];
      }
    } //end item iterator.

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end wrapper element {}data."];
    }
  }
}
@end /* implementation NEXUS_REST_APINS0RepositoryContentClassListResourceResponse (JAXB) */

#endif /* DEF_NEXUS_REST_APINS0RepositoryContentClassListResourceResponse_M */
#ifndef DEF_NEXUS_REST_APINS0MirrorStatusResource_M
#define DEF_NEXUS_REST_APINS0MirrorStatusResource_M

/**
 *  Repository mirror status.
 
 @version $Revision$ $Date$

 */
@implementation NEXUS_REST_APINS0MirrorStatusResource

/**
 * The status of the mirror.
 */
- (NSString *) status
{
  return _status;
}

/**
 * The status of the mirror.
 */
- (void) setStatus: (NSString *) newStatus
{
  [newStatus retain];
  [_status release];
  _status = newStatus;
}

- (void) dealloc
{
  [self setStatus: nil];
  [super dealloc];
}
@end /* implementation NEXUS_REST_APINS0MirrorStatusResource */

/**
 * Internal, private interface for JAXB reading and writing.
 */
@interface NEXUS_REST_APINS0MirrorStatusResource (JAXB) <JAXBReading, JAXBWriting, JAXBType>

@end /*interface NEXUS_REST_APINS0MirrorStatusResource (JAXB)*/

/**
 * Internal, private implementation for JAXB reading and writing.
 */
@implementation NEXUS_REST_APINS0MirrorStatusResource (JAXB)

/**
 * Read an instance of NEXUS_REST_APINS0MirrorStatusResource from an XML reader.
 *
 * @param reader The reader.
 * @return An instance of NEXUS_REST_APINS0MirrorStatusResource defined by the XML reader.
 */
+ (id<JAXBType>) readXMLType: (xmlTextReaderPtr) reader
{
  NEXUS_REST_APINS0MirrorStatusResource *_nEXUS_REST_APINS0MirrorStatusResource = [[NEXUS_REST_APINS0MirrorStatusResource alloc] init];
  NS_DURING
  {
    [_nEXUS_REST_APINS0MirrorStatusResource initWithReader: reader];
  }
  NS_HANDLER
  {
    [_nEXUS_REST_APINS0MirrorStatusResource dealloc];
    _nEXUS_REST_APINS0MirrorStatusResource = nil;
    [localException raise];
  }
  NS_ENDHANDLER

  [_nEXUS_REST_APINS0MirrorStatusResource autorelease];
  return _nEXUS_REST_APINS0MirrorStatusResource;
}

/**
 * Initialize this instance of NEXUS_REST_APINS0MirrorStatusResource according to
 * the XML being read from the reader.
 *
 * @param reader The reader.
 */
- (id) initWithReader: (xmlTextReaderPtr) reader
{
  return [super initWithReader: reader];
}

/**
 * Write the XML for this instance of NEXUS_REST_APINS0MirrorStatusResource to the writer.
 * Note that since we're only writing the XML type,
 * No start/end element will be written.
 *
 * @param reader The reader.
 */
- (void) writeXMLType: (xmlTextWriterPtr) writer
{
  [super writeXMLType:writer];
}

//documentation inherited.
- (BOOL) readJAXBAttribute: (xmlTextReaderPtr) reader
{
  void *_child_accessor;

  if ([super readJAXBAttribute: reader]) {
    return YES;
  }

  return NO;
}

//documentation inherited.
- (BOOL) readJAXBValue: (xmlTextReaderPtr) reader
{
  return [super readJAXBValue: reader];
}

//documentation inherited.
- (BOOL) readJAXBChildElement: (xmlTextReaderPtr) reader
{
  id __child;
  void *_child_accessor;
  int status, depth;

  if ([super readJAXBChildElement: reader]) {
    return YES;
  }
  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "status", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}status of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}status of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setStatus: __child];
    return YES;
  } //end "if choice"


  return NO;
}

//documentation inherited.
- (int) readUnknownJAXBChildElement: (xmlTextReaderPtr) reader
{
  return [super readUnknownJAXBChildElement: reader];
}

//documentation inherited.
- (void) readUnknownJAXBAttribute: (xmlTextReaderPtr) reader
{
  [super readUnknownJAXBAttribute: reader];
}

//documentation inherited.
- (void) writeJAXBAttributes: (xmlTextWriterPtr) writer
{
  int status;

  [super writeJAXBAttributes: writer];

}

//documentation inherited.
- (void) writeJAXBValue: (xmlTextWriterPtr) writer
{
  [super writeJAXBValue: writer];
}

/**
 * Method for writing the child elements.
 *
 * @param writer The writer.
 */
- (void) writeJAXBChildElements: (xmlTextWriterPtr) writer
{
  int status;
  id __item;
  NSEnumerator *__enumerator;

  [super writeJAXBChildElements: writer];

  if ([self status]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "status", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}status."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}status...");
#endif
    [[self status] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}status...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}status."];
    }
  }
}
@end /* implementation NEXUS_REST_APINS0MirrorStatusResource (JAXB) */

#endif /* DEF_NEXUS_REST_APINS0MirrorStatusResource_M */
#ifndef DEF_NEXUS_REST_APINS0NFCResourceResponse_M
#define DEF_NEXUS_REST_APINS0NFCResourceResponse_M

/**
 *  REST Response object for an NFC resource item, contains the
 typical 'data' parameter, which is the NFC resource item.
 
 @version $Revision$ $Date$

 */
@implementation NEXUS_REST_APINS0NFCResourceResponse

/**
 * An object which contains the contents of the NFC.
 */
- (NEXUS_REST_APINS0NFCResource *) data
{
  return _data;
}

/**
 * An object which contains the contents of the NFC.
 */
- (void) setData: (NEXUS_REST_APINS0NFCResource *) newData
{
  [newData retain];
  [_data release];
  _data = newData;
}

- (void) dealloc
{
  [self setData: nil];
  [super dealloc];
}

//documentation inherited.
+ (id<EnunciateXML>) readFromXML: (NSData *) xml
{
  NEXUS_REST_APINS0NFCResourceResponse *_nEXUS_REST_APINS0NFCResourceResponse;
  xmlTextReaderPtr reader = xmlReaderForMemory([xml bytes], [xml length], NULL, NULL, 0);
  if (reader == NULL) {
    [NSException raise: @"XMLReadError"
                 format: @"Error instantiating an XML reader."];
    return nil;
  }

  _nEXUS_REST_APINS0NFCResourceResponse = (NEXUS_REST_APINS0NFCResourceResponse *) [NEXUS_REST_APINS0NFCResourceResponse readXMLElement: reader];
  xmlFreeTextReader(reader); //free the reader
  return _nEXUS_REST_APINS0NFCResourceResponse;
}

//documentation inherited.
- (NSData *) writeToXML
{
  xmlBufferPtr buf;
  xmlTextWriterPtr writer;
  int rc;
  NSData *data;

  buf = xmlBufferCreate();
  if (buf == NULL) {
    [NSException raise: @"XMLWriteError"
                 format: @"Error creating an XML buffer."];
    return nil;
  }

  writer = xmlNewTextWriterMemory(buf, 0);
  if (writer == NULL) {
    xmlBufferFree(buf);
    [NSException raise: @"XMLWriteError"
                 format: @"Error creating an XML writer."];
    return nil;
  }

  rc = xmlTextWriterStartDocument(writer, NULL, "utf-8", NULL);
  if (rc < 0) {
    xmlFreeTextWriter(writer);
    xmlBufferFree(buf);
    [NSException raise: @"XMLWriteError"
                 format: @"Error writing XML start document."];
    return nil;
  }

  NS_DURING
  {
    [self writeXMLElement: writer];
  }
  NS_HANDLER
  {
    xmlFreeTextWriter(writer);
    xmlBufferFree(buf);
    [localException raise];
  }
  NS_ENDHANDLER

  rc = xmlTextWriterEndDocument(writer);
  if (rc < 0) {
    xmlFreeTextWriter(writer);
    xmlBufferFree(buf);
    [NSException raise: @"XMLWriteError"
                 format: @"Error writing XML end document."];
    return nil;
  }

  xmlFreeTextWriter(writer);
  data = [NSData dataWithBytes: buf->content length: buf->use];
  xmlBufferFree(buf);
  return data;
}
@end /* implementation NEXUS_REST_APINS0NFCResourceResponse */

/**
 * Internal, private interface for JAXB reading and writing.
 */
@interface NEXUS_REST_APINS0NFCResourceResponse (JAXB) <JAXBReading, JAXBWriting, JAXBType, JAXBElement>

@end /*interface NEXUS_REST_APINS0NFCResourceResponse (JAXB)*/

/**
 * Internal, private implementation for JAXB reading and writing.
 */
@implementation NEXUS_REST_APINS0NFCResourceResponse (JAXB)

/**
 * Read an instance of NEXUS_REST_APINS0NFCResourceResponse from an XML reader.
 *
 * @param reader The reader.
 * @return An instance of NEXUS_REST_APINS0NFCResourceResponse defined by the XML reader.
 */
+ (id<JAXBType>) readXMLType: (xmlTextReaderPtr) reader
{
  NEXUS_REST_APINS0NFCResourceResponse *_nEXUS_REST_APINS0NFCResourceResponse = [[NEXUS_REST_APINS0NFCResourceResponse alloc] init];
  NS_DURING
  {
    [_nEXUS_REST_APINS0NFCResourceResponse initWithReader: reader];
  }
  NS_HANDLER
  {
    [_nEXUS_REST_APINS0NFCResourceResponse dealloc];
    _nEXUS_REST_APINS0NFCResourceResponse = nil;
    [localException raise];
  }
  NS_ENDHANDLER

  [_nEXUS_REST_APINS0NFCResourceResponse autorelease];
  return _nEXUS_REST_APINS0NFCResourceResponse;
}

/**
 * Initialize this instance of NEXUS_REST_APINS0NFCResourceResponse according to
 * the XML being read from the reader.
 *
 * @param reader The reader.
 */
- (id) initWithReader: (xmlTextReaderPtr) reader
{
  return [super initWithReader: reader];
}

/**
 * Write the XML for this instance of NEXUS_REST_APINS0NFCResourceResponse to the writer.
 * Note that since we're only writing the XML type,
 * No start/end element will be written.
 *
 * @param reader The reader.
 */
- (void) writeXMLType: (xmlTextWriterPtr) writer
{
  [super writeXMLType:writer];
}

/**
 * Reads a NEXUS_REST_APINS0NFCResourceResponse from an XML reader. The element to be read is
 * "nfc-info".
 *
 * @param reader The XML reader.
 * @return The NEXUS_REST_APINS0NFCResourceResponse.
 */
+ (id<JAXBElement>) readXMLElement: (xmlTextReaderPtr) reader {
  int status;
  NEXUS_REST_APINS0NFCResourceResponse *_nFCResourceResponse = nil;

  if (xmlTextReaderNodeType(reader) != XML_READER_TYPE_ELEMENT) {
    status = xmlTextReaderAdvanceToNextStartOrEndElement(reader);
    if (status < 1) {
      [NSException raise: @"XMLReadError"
                   format: @"Error advancing the reader to start element nfc-info."];
    }
  }

  if (xmlStrcmp(BAD_CAST "nfc-info", xmlTextReaderConstLocalName(reader)) == 0
      && xmlTextReaderConstNamespaceUri(reader) == NULL) {
#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read root element {}nfc-info.");
#endif
    _nFCResourceResponse = (NEXUS_REST_APINS0NFCResourceResponse *)[NEXUS_REST_APINS0NFCResourceResponse readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"Successfully read root element {}nfc-info.");
#endif
  }
  else {
    if (xmlTextReaderConstNamespaceUri(reader) == NULL) {
      [NSException raise: @"XMLReadError"
                   format: @"Unable to read NEXUS_REST_APINS0NFCResourceResponse. Expected element nfc-info. Current element: {}%s", xmlTextReaderConstLocalName(reader)];
    }
    else {
      [NSException raise: @"XMLReadError"
                   format: @"Unable to read NEXUS_REST_APINS0NFCResourceResponse. Expected element nfc-info. Current element: {%s}%s\n", xmlTextReaderConstNamespaceUri(reader), xmlTextReaderConstLocalName(reader)];
    }
  }

  return _nFCResourceResponse;
}

/**
 * Writes this NEXUS_REST_APINS0NFCResourceResponse to XML under element name "nfc-info".
 * The namespace declarations for the element will be written.
 *
 * @param writer The XML writer.
 * @param _nFCResourceResponse The NFCResourceResponse to write.
 * @return 1 if successful, 0 otherwise.
 */
- (void) writeXMLElement: (xmlTextWriterPtr) writer
{
  [self writeXMLElement: writer writeNamespaces: YES];
}

/**
 * Writes this NEXUS_REST_APINS0NFCResourceResponse to an XML writer.
 *
 * @param writer The writer.
 * @param writeNs Whether to write the namespaces for this element to the xml writer.
 */
- (void) writeXMLElement: (xmlTextWriterPtr) writer writeNamespaces: (BOOL) writeNs
{
  int rc = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "nfc-info", NULL);
  if (rc < 0) {
    [NSException raise: @"XMLWriteError"
                 format: @"Error writing start element {}nfc-info. XML writer status: %i\n", rc];
  }

#if DEBUG_ENUNCIATE > 1
  NSLog(@"writing type {}NFCResourceResponse for root element {}nfc-info...");
#endif
  [self writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
  NSLog(@"successfully wrote type {}NFCResourceResponse for root element {}nfc-info...");
#endif
  rc = xmlTextWriterEndElement(writer);
  if (rc < 0) {
    [NSException raise: @"XMLWriteError"
                 format: @"Error writing end element {}nfc-info. XML writer status: %i\n", rc];
  }
}

//documentation inherited.
- (BOOL) readJAXBAttribute: (xmlTextReaderPtr) reader
{
  void *_child_accessor;

  if ([super readJAXBAttribute: reader]) {
    return YES;
  }

  return NO;
}

//documentation inherited.
- (BOOL) readJAXBValue: (xmlTextReaderPtr) reader
{
  return [super readJAXBValue: reader];
}

//documentation inherited.
- (BOOL) readJAXBChildElement: (xmlTextReaderPtr) reader
{
  id __child;
  void *_child_accessor;
  int status, depth;

  if ([super readJAXBChildElement: reader]) {
    return YES;
  }
  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "data", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}data of type {}nfc-resource.");
#endif
    __child = [NEXUS_REST_APINS0NFCResource readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}data of type {}nfc-resource.");
#endif

    [self setData: __child];
    return YES;
  } //end "if choice"


  return NO;
}

//documentation inherited.
- (int) readUnknownJAXBChildElement: (xmlTextReaderPtr) reader
{
  return [super readUnknownJAXBChildElement: reader];
}

//documentation inherited.
- (void) readUnknownJAXBAttribute: (xmlTextReaderPtr) reader
{
  [super readUnknownJAXBAttribute: reader];
}

//documentation inherited.
- (void) writeJAXBAttributes: (xmlTextWriterPtr) writer
{
  int status;

  [super writeJAXBAttributes: writer];

}

//documentation inherited.
- (void) writeJAXBValue: (xmlTextWriterPtr) writer
{
  [super writeJAXBValue: writer];
}

/**
 * Method for writing the child elements.
 *
 * @param writer The writer.
 */
- (void) writeJAXBChildElements: (xmlTextWriterPtr) writer
{
  int status;
  id __item;
  NSEnumerator *__enumerator;

  [super writeJAXBChildElements: writer];

  if ([self data]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "data", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}data."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}data...");
#endif
    [[self data] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}data...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}data."];
    }
  }
}
@end /* implementation NEXUS_REST_APINS0NFCResourceResponse (JAXB) */

#endif /* DEF_NEXUS_REST_APINS0NFCResourceResponse_M */
#ifndef DEF_NEXUS_REST_APINS0NexusAuthenticationClientPermissions_M
#define DEF_NEXUS_REST_APINS0NexusAuthenticationClientPermissions_M

/**
 *  Permissions that are granted to the user.
 
 @version $Revision$ $Date$

 */
@implementation NEXUS_REST_APINS0NexusAuthenticationClientPermissions

- (void) dealloc
{
  [super dealloc];
}
@end /* implementation NEXUS_REST_APINS0NexusAuthenticationClientPermissions */

/**
 * Internal, private interface for JAXB reading and writing.
 */
@interface NEXUS_REST_APINS0NexusAuthenticationClientPermissions (JAXB) <JAXBReading, JAXBWriting, JAXBType>

@end /*interface NEXUS_REST_APINS0NexusAuthenticationClientPermissions (JAXB)*/

/**
 * Internal, private implementation for JAXB reading and writing.
 */
@implementation NEXUS_REST_APINS0NexusAuthenticationClientPermissions (JAXB)

/**
 * Read an instance of NEXUS_REST_APINS0NexusAuthenticationClientPermissions from an XML reader.
 *
 * @param reader The reader.
 * @return An instance of NEXUS_REST_APINS0NexusAuthenticationClientPermissions defined by the XML reader.
 */
+ (id<JAXBType>) readXMLType: (xmlTextReaderPtr) reader
{
  NEXUS_REST_APINS0NexusAuthenticationClientPermissions *_nEXUS_REST_APINS0NexusAuthenticationClientPermissions = [[NEXUS_REST_APINS0NexusAuthenticationClientPermissions alloc] init];
  NS_DURING
  {
    [_nEXUS_REST_APINS0NexusAuthenticationClientPermissions initWithReader: reader];
  }
  NS_HANDLER
  {
    [_nEXUS_REST_APINS0NexusAuthenticationClientPermissions dealloc];
    _nEXUS_REST_APINS0NexusAuthenticationClientPermissions = nil;
    [localException raise];
  }
  NS_ENDHANDLER

  [_nEXUS_REST_APINS0NexusAuthenticationClientPermissions autorelease];
  return _nEXUS_REST_APINS0NexusAuthenticationClientPermissions;
}

/**
 * Initialize this instance of NEXUS_REST_APINS0NexusAuthenticationClientPermissions according to
 * the XML being read from the reader.
 *
 * @param reader The reader.
 */
- (id) initWithReader: (xmlTextReaderPtr) reader
{
  return [super initWithReader: reader];
}

/**
 * Write the XML for this instance of NEXUS_REST_APINS0NexusAuthenticationClientPermissions to the writer.
 * Note that since we're only writing the XML type,
 * No start/end element will be written.
 *
 * @param reader The reader.
 */
- (void) writeXMLType: (xmlTextWriterPtr) writer
{
  [super writeXMLType:writer];
}

//documentation inherited.
- (BOOL) readJAXBAttribute: (xmlTextReaderPtr) reader
{
  void *_child_accessor;

  if ([super readJAXBAttribute: reader]) {
    return YES;
  }

  return NO;
}

//documentation inherited.
- (BOOL) readJAXBValue: (xmlTextReaderPtr) reader
{
  return [super readJAXBValue: reader];
}

//documentation inherited.
- (BOOL) readJAXBChildElement: (xmlTextReaderPtr) reader
{
  id __child;
  void *_child_accessor;
  int status, depth;

  if ([super readJAXBChildElement: reader]) {
    return YES;
  }

  return NO;
}

//documentation inherited.
- (int) readUnknownJAXBChildElement: (xmlTextReaderPtr) reader
{
  return [super readUnknownJAXBChildElement: reader];
}

//documentation inherited.
- (void) readUnknownJAXBAttribute: (xmlTextReaderPtr) reader
{
  [super readUnknownJAXBAttribute: reader];
}

//documentation inherited.
- (void) writeJAXBAttributes: (xmlTextWriterPtr) writer
{
  int status;

  [super writeJAXBAttributes: writer];

}

//documentation inherited.
- (void) writeJAXBValue: (xmlTextWriterPtr) writer
{
  [super writeJAXBValue: writer];
}

/**
 * Method for writing the child elements.
 *
 * @param writer The writer.
 */
- (void) writeJAXBChildElements: (xmlTextWriterPtr) writer
{
  int status;
  id __item;
  NSEnumerator *__enumerator;

  [super writeJAXBChildElements: writer];

}
@end /* implementation NEXUS_REST_APINS0NexusAuthenticationClientPermissions (JAXB) */

#endif /* DEF_NEXUS_REST_APINS0NexusAuthenticationClientPermissions_M */
#ifndef DEF_NEXUS_REST_APINS0MirrorStatusResourceListResponse_M
#define DEF_NEXUS_REST_APINS0MirrorStatusResourceListResponse_M

/**
 *  REST Response object for a list of mirror statuses associated
 with a repository, contains the typical 'data' parameter, which
 is the list of mirrors statuses.
 
 @version $Revision$ $Date$

 */
@implementation NEXUS_REST_APINS0MirrorStatusResourceListResponse

/**
 * Field data.
 */
- (NSArray *) data
{
  return _data;
}

/**
 * Field data.
 */
- (void) setData: (NSArray *) newData
{
  [newData retain];
  [_data release];
  _data = newData;
}

- (void) dealloc
{
  [self setData: nil];
  [super dealloc];
}

//documentation inherited.
+ (id<EnunciateXML>) readFromXML: (NSData *) xml
{
  NEXUS_REST_APINS0MirrorStatusResourceListResponse *_nEXUS_REST_APINS0MirrorStatusResourceListResponse;
  xmlTextReaderPtr reader = xmlReaderForMemory([xml bytes], [xml length], NULL, NULL, 0);
  if (reader == NULL) {
    [NSException raise: @"XMLReadError"
                 format: @"Error instantiating an XML reader."];
    return nil;
  }

  _nEXUS_REST_APINS0MirrorStatusResourceListResponse = (NEXUS_REST_APINS0MirrorStatusResourceListResponse *) [NEXUS_REST_APINS0MirrorStatusResourceListResponse readXMLElement: reader];
  xmlFreeTextReader(reader); //free the reader
  return _nEXUS_REST_APINS0MirrorStatusResourceListResponse;
}

//documentation inherited.
- (NSData *) writeToXML
{
  xmlBufferPtr buf;
  xmlTextWriterPtr writer;
  int rc;
  NSData *data;

  buf = xmlBufferCreate();
  if (buf == NULL) {
    [NSException raise: @"XMLWriteError"
                 format: @"Error creating an XML buffer."];
    return nil;
  }

  writer = xmlNewTextWriterMemory(buf, 0);
  if (writer == NULL) {
    xmlBufferFree(buf);
    [NSException raise: @"XMLWriteError"
                 format: @"Error creating an XML writer."];
    return nil;
  }

  rc = xmlTextWriterStartDocument(writer, NULL, "utf-8", NULL);
  if (rc < 0) {
    xmlFreeTextWriter(writer);
    xmlBufferFree(buf);
    [NSException raise: @"XMLWriteError"
                 format: @"Error writing XML start document."];
    return nil;
  }

  NS_DURING
  {
    [self writeXMLElement: writer];
  }
  NS_HANDLER
  {
    xmlFreeTextWriter(writer);
    xmlBufferFree(buf);
    [localException raise];
  }
  NS_ENDHANDLER

  rc = xmlTextWriterEndDocument(writer);
  if (rc < 0) {
    xmlFreeTextWriter(writer);
    xmlBufferFree(buf);
    [NSException raise: @"XMLWriteError"
                 format: @"Error writing XML end document."];
    return nil;
  }

  xmlFreeTextWriter(writer);
  data = [NSData dataWithBytes: buf->content length: buf->use];
  xmlBufferFree(buf);
  return data;
}
@end /* implementation NEXUS_REST_APINS0MirrorStatusResourceListResponse */

/**
 * Internal, private interface for JAXB reading and writing.
 */
@interface NEXUS_REST_APINS0MirrorStatusResourceListResponse (JAXB) <JAXBReading, JAXBWriting, JAXBType, JAXBElement>

@end /*interface NEXUS_REST_APINS0MirrorStatusResourceListResponse (JAXB)*/

/**
 * Internal, private implementation for JAXB reading and writing.
 */
@implementation NEXUS_REST_APINS0MirrorStatusResourceListResponse (JAXB)

/**
 * Read an instance of NEXUS_REST_APINS0MirrorStatusResourceListResponse from an XML reader.
 *
 * @param reader The reader.
 * @return An instance of NEXUS_REST_APINS0MirrorStatusResourceListResponse defined by the XML reader.
 */
+ (id<JAXBType>) readXMLType: (xmlTextReaderPtr) reader
{
  NEXUS_REST_APINS0MirrorStatusResourceListResponse *_nEXUS_REST_APINS0MirrorStatusResourceListResponse = [[NEXUS_REST_APINS0MirrorStatusResourceListResponse alloc] init];
  NS_DURING
  {
    [_nEXUS_REST_APINS0MirrorStatusResourceListResponse initWithReader: reader];
  }
  NS_HANDLER
  {
    [_nEXUS_REST_APINS0MirrorStatusResourceListResponse dealloc];
    _nEXUS_REST_APINS0MirrorStatusResourceListResponse = nil;
    [localException raise];
  }
  NS_ENDHANDLER

  [_nEXUS_REST_APINS0MirrorStatusResourceListResponse autorelease];
  return _nEXUS_REST_APINS0MirrorStatusResourceListResponse;
}

/**
 * Initialize this instance of NEXUS_REST_APINS0MirrorStatusResourceListResponse according to
 * the XML being read from the reader.
 *
 * @param reader The reader.
 */
- (id) initWithReader: (xmlTextReaderPtr) reader
{
  return [super initWithReader: reader];
}

/**
 * Write the XML for this instance of NEXUS_REST_APINS0MirrorStatusResourceListResponse to the writer.
 * Note that since we're only writing the XML type,
 * No start/end element will be written.
 *
 * @param reader The reader.
 */
- (void) writeXMLType: (xmlTextWriterPtr) writer
{
  [super writeXMLType:writer];
}

/**
 * Reads a NEXUS_REST_APINS0MirrorStatusResourceListResponse from an XML reader. The element to be read is
 * "mirror-status-list-response".
 *
 * @param reader The XML reader.
 * @return The NEXUS_REST_APINS0MirrorStatusResourceListResponse.
 */
+ (id<JAXBElement>) readXMLElement: (xmlTextReaderPtr) reader {
  int status;
  NEXUS_REST_APINS0MirrorStatusResourceListResponse *_mirrorStatusResourceListResponse = nil;

  if (xmlTextReaderNodeType(reader) != XML_READER_TYPE_ELEMENT) {
    status = xmlTextReaderAdvanceToNextStartOrEndElement(reader);
    if (status < 1) {
      [NSException raise: @"XMLReadError"
                   format: @"Error advancing the reader to start element mirror-status-list-response."];
    }
  }

  if (xmlStrcmp(BAD_CAST "mirror-status-list-response", xmlTextReaderConstLocalName(reader)) == 0
      && xmlTextReaderConstNamespaceUri(reader) == NULL) {
#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read root element {}mirror-status-list-response.");
#endif
    _mirrorStatusResourceListResponse = (NEXUS_REST_APINS0MirrorStatusResourceListResponse *)[NEXUS_REST_APINS0MirrorStatusResourceListResponse readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"Successfully read root element {}mirror-status-list-response.");
#endif
  }
  else {
    if (xmlTextReaderConstNamespaceUri(reader) == NULL) {
      [NSException raise: @"XMLReadError"
                   format: @"Unable to read NEXUS_REST_APINS0MirrorStatusResourceListResponse. Expected element mirror-status-list-response. Current element: {}%s", xmlTextReaderConstLocalName(reader)];
    }
    else {
      [NSException raise: @"XMLReadError"
                   format: @"Unable to read NEXUS_REST_APINS0MirrorStatusResourceListResponse. Expected element mirror-status-list-response. Current element: {%s}%s\n", xmlTextReaderConstNamespaceUri(reader), xmlTextReaderConstLocalName(reader)];
    }
  }

  return _mirrorStatusResourceListResponse;
}

/**
 * Writes this NEXUS_REST_APINS0MirrorStatusResourceListResponse to XML under element name "mirror-status-list-response".
 * The namespace declarations for the element will be written.
 *
 * @param writer The XML writer.
 * @param _mirrorStatusResourceListResponse The MirrorStatusResourceListResponse to write.
 * @return 1 if successful, 0 otherwise.
 */
- (void) writeXMLElement: (xmlTextWriterPtr) writer
{
  [self writeXMLElement: writer writeNamespaces: YES];
}

/**
 * Writes this NEXUS_REST_APINS0MirrorStatusResourceListResponse to an XML writer.
 *
 * @param writer The writer.
 * @param writeNs Whether to write the namespaces for this element to the xml writer.
 */
- (void) writeXMLElement: (xmlTextWriterPtr) writer writeNamespaces: (BOOL) writeNs
{
  int rc = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "mirror-status-list-response", NULL);
  if (rc < 0) {
    [NSException raise: @"XMLWriteError"
                 format: @"Error writing start element {}mirror-status-list-response. XML writer status: %i\n", rc];
  }

#if DEBUG_ENUNCIATE > 1
  NSLog(@"writing type {}mirrorStatusResourceListResponse for root element {}mirror-status-list-response...");
#endif
  [self writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
  NSLog(@"successfully wrote type {}mirrorStatusResourceListResponse for root element {}mirror-status-list-response...");
#endif
  rc = xmlTextWriterEndElement(writer);
  if (rc < 0) {
    [NSException raise: @"XMLWriteError"
                 format: @"Error writing end element {}mirror-status-list-response. XML writer status: %i\n", rc];
  }
}

//documentation inherited.
- (BOOL) readJAXBAttribute: (xmlTextReaderPtr) reader
{
  void *_child_accessor;

  if ([super readJAXBAttribute: reader]) {
    return YES;
  }

  return NO;
}

//documentation inherited.
- (BOOL) readJAXBValue: (xmlTextReaderPtr) reader
{
  return [super readJAXBValue: reader];
}

//documentation inherited.
- (BOOL) readJAXBChildElement: (xmlTextReaderPtr) reader
{
  id __child;
  void *_child_accessor;
  int status, depth;

  if ([super readJAXBChildElement: reader]) {
    return YES;
  }
  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "data", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

    if (xmlTextReaderIsEmptyElement(reader) == 0) {
#if DEBUG_ENUNCIATE > 1
      NSLog(@"Unwrapping wrapper element {}data...");
#endif
      //start wrapper element "{}data"
      depth = xmlTextReaderDepth(reader);
      status = xmlTextReaderAdvanceToNextStartOrEndElement(reader);
      while (xmlTextReaderDepth(reader) > depth) {
        if (status < 1) {
          //panic: XML read error.
          [self dealloc];
          [NSException raise: @"XMLReadError"
                       format: @"Failure to advance to next wrapped child element."];
        }
  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "mirrorResource", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}mirrorResource of type {}mirror-status-resource.");
#endif

    __child = [NEXUS_REST_APINS0MirrorStatusResource readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}mirrorResource of type {}mirror-status-resource.");
#endif

    if ([self data]) {
      [self setData: [[self data] arrayByAddingObject: __child]];
    }
    else {
      [self setData: [NSArray arrayWithObject: __child]];
    }
    continue; //continue "while in wrapper element" loop
  } //end "if choice"

        status = xmlTextReaderAdvanceToNextStartOrEndElement(reader);
#if DEBUG_ENUNCIATE > 1
        NSLog(@"successfully unwrapped wrapper element {}data...");
#endif
      } // end "while in wrapper element" loop

      if (status < 1) {
        //panic: XML read error.
        [self dealloc];
        [NSException raise: @"XMLReadError"
                     format: @"Failure to advance to end wrapper element."];
      }
      else {
        //end wrapper element "{}data"
        status = xmlTextReaderAdvanceToNextStartOrEndElement(reader);
      }
    } //end "if empty element" clause
    else {
      __child = [NSArray array];
      [self setData: (NSArray*) __child];
    }

    return YES;
  } // end "if wrapper element" clause

  return NO;
}

//documentation inherited.
- (int) readUnknownJAXBChildElement: (xmlTextReaderPtr) reader
{
  return [super readUnknownJAXBChildElement: reader];
}

//documentation inherited.
- (void) readUnknownJAXBAttribute: (xmlTextReaderPtr) reader
{
  [super readUnknownJAXBAttribute: reader];
}

//documentation inherited.
- (void) writeJAXBAttributes: (xmlTextWriterPtr) writer
{
  int status;

  [super writeJAXBAttributes: writer];

}

//documentation inherited.
- (void) writeJAXBValue: (xmlTextWriterPtr) writer
{
  [super writeJAXBValue: writer];
}

/**
 * Method for writing the child elements.
 *
 * @param writer The writer.
 */
- (void) writeJAXBChildElements: (xmlTextWriterPtr) writer
{
  int status;
  id __item;
  NSEnumerator *__enumerator;

  [super writeJAXBChildElements: writer];

  if ([self data]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "data", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start wrapper element {}data."];
    }
    __enumerator = [[self data] objectEnumerator];

    while ( (__item = [__enumerator nextObject]) ) {
      status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "mirrorResource", NULL);
      if (status < 0) {
        [NSException raise: @"XMLWriteError"
                     format: @"Error writing start child element {}mirrorResource."];
      }

#if DEBUG_ENUNCIATE > 1
      NSLog(@"writing element {}mirrorResource...");
#endif
      [__item writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
      NSLog(@"successfully wrote element {}mirrorResource...");
#endif

      status = xmlTextWriterEndElement(writer);
      if (status < 0) {
        [NSException raise: @"XMLWriteError"
                     format: @"Error writing end child element {}mirrorResource."];
      }
    } //end item iterator.

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end wrapper element {}data."];
    }
  }
}
@end /* implementation NEXUS_REST_APINS0MirrorStatusResourceListResponse (JAXB) */

#endif /* DEF_NEXUS_REST_APINS0MirrorStatusResourceListResponse_M */
#ifndef DEF_NEXUS_REST_APINS0MirrorResourceListResponse_M
#define DEF_NEXUS_REST_APINS0MirrorResourceListResponse_M

/**
 *  REST Response object for a list of mirrors associated with a
 repository, contains the typical 'data' parameter, which is the
 list of mirrors.
 
 @version $Revision$ $Date$

 */
@implementation NEXUS_REST_APINS0MirrorResourceListResponse

/**
 * Field data.
 */
- (NSArray *) data
{
  return _data;
}

/**
 * Field data.
 */
- (void) setData: (NSArray *) newData
{
  [newData retain];
  [_data release];
  _data = newData;
}

- (void) dealloc
{
  [self setData: nil];
  [super dealloc];
}

//documentation inherited.
+ (id<EnunciateXML>) readFromXML: (NSData *) xml
{
  NEXUS_REST_APINS0MirrorResourceListResponse *_nEXUS_REST_APINS0MirrorResourceListResponse;
  xmlTextReaderPtr reader = xmlReaderForMemory([xml bytes], [xml length], NULL, NULL, 0);
  if (reader == NULL) {
    [NSException raise: @"XMLReadError"
                 format: @"Error instantiating an XML reader."];
    return nil;
  }

  _nEXUS_REST_APINS0MirrorResourceListResponse = (NEXUS_REST_APINS0MirrorResourceListResponse *) [NEXUS_REST_APINS0MirrorResourceListResponse readXMLElement: reader];
  xmlFreeTextReader(reader); //free the reader
  return _nEXUS_REST_APINS0MirrorResourceListResponse;
}

//documentation inherited.
- (NSData *) writeToXML
{
  xmlBufferPtr buf;
  xmlTextWriterPtr writer;
  int rc;
  NSData *data;

  buf = xmlBufferCreate();
  if (buf == NULL) {
    [NSException raise: @"XMLWriteError"
                 format: @"Error creating an XML buffer."];
    return nil;
  }

  writer = xmlNewTextWriterMemory(buf, 0);
  if (writer == NULL) {
    xmlBufferFree(buf);
    [NSException raise: @"XMLWriteError"
                 format: @"Error creating an XML writer."];
    return nil;
  }

  rc = xmlTextWriterStartDocument(writer, NULL, "utf-8", NULL);
  if (rc < 0) {
    xmlFreeTextWriter(writer);
    xmlBufferFree(buf);
    [NSException raise: @"XMLWriteError"
                 format: @"Error writing XML start document."];
    return nil;
  }

  NS_DURING
  {
    [self writeXMLElement: writer];
  }
  NS_HANDLER
  {
    xmlFreeTextWriter(writer);
    xmlBufferFree(buf);
    [localException raise];
  }
  NS_ENDHANDLER

  rc = xmlTextWriterEndDocument(writer);
  if (rc < 0) {
    xmlFreeTextWriter(writer);
    xmlBufferFree(buf);
    [NSException raise: @"XMLWriteError"
                 format: @"Error writing XML end document."];
    return nil;
  }

  xmlFreeTextWriter(writer);
  data = [NSData dataWithBytes: buf->content length: buf->use];
  xmlBufferFree(buf);
  return data;
}
@end /* implementation NEXUS_REST_APINS0MirrorResourceListResponse */

/**
 * Internal, private interface for JAXB reading and writing.
 */
@interface NEXUS_REST_APINS0MirrorResourceListResponse (JAXB) <JAXBReading, JAXBWriting, JAXBType, JAXBElement>

@end /*interface NEXUS_REST_APINS0MirrorResourceListResponse (JAXB)*/

/**
 * Internal, private implementation for JAXB reading and writing.
 */
@implementation NEXUS_REST_APINS0MirrorResourceListResponse (JAXB)

/**
 * Read an instance of NEXUS_REST_APINS0MirrorResourceListResponse from an XML reader.
 *
 * @param reader The reader.
 * @return An instance of NEXUS_REST_APINS0MirrorResourceListResponse defined by the XML reader.
 */
+ (id<JAXBType>) readXMLType: (xmlTextReaderPtr) reader
{
  NEXUS_REST_APINS0MirrorResourceListResponse *_nEXUS_REST_APINS0MirrorResourceListResponse = [[NEXUS_REST_APINS0MirrorResourceListResponse alloc] init];
  NS_DURING
  {
    [_nEXUS_REST_APINS0MirrorResourceListResponse initWithReader: reader];
  }
  NS_HANDLER
  {
    [_nEXUS_REST_APINS0MirrorResourceListResponse dealloc];
    _nEXUS_REST_APINS0MirrorResourceListResponse = nil;
    [localException raise];
  }
  NS_ENDHANDLER

  [_nEXUS_REST_APINS0MirrorResourceListResponse autorelease];
  return _nEXUS_REST_APINS0MirrorResourceListResponse;
}

/**
 * Initialize this instance of NEXUS_REST_APINS0MirrorResourceListResponse according to
 * the XML being read from the reader.
 *
 * @param reader The reader.
 */
- (id) initWithReader: (xmlTextReaderPtr) reader
{
  return [super initWithReader: reader];
}

/**
 * Write the XML for this instance of NEXUS_REST_APINS0MirrorResourceListResponse to the writer.
 * Note that since we're only writing the XML type,
 * No start/end element will be written.
 *
 * @param reader The reader.
 */
- (void) writeXMLType: (xmlTextWriterPtr) writer
{
  [super writeXMLType:writer];
}

/**
 * Reads a NEXUS_REST_APINS0MirrorResourceListResponse from an XML reader. The element to be read is
 * "mirror-list-response".
 *
 * @param reader The XML reader.
 * @return The NEXUS_REST_APINS0MirrorResourceListResponse.
 */
+ (id<JAXBElement>) readXMLElement: (xmlTextReaderPtr) reader {
  int status;
  NEXUS_REST_APINS0MirrorResourceListResponse *_mirrorResourceListResponse = nil;

  if (xmlTextReaderNodeType(reader) != XML_READER_TYPE_ELEMENT) {
    status = xmlTextReaderAdvanceToNextStartOrEndElement(reader);
    if (status < 1) {
      [NSException raise: @"XMLReadError"
                   format: @"Error advancing the reader to start element mirror-list-response."];
    }
  }

  if (xmlStrcmp(BAD_CAST "mirror-list-response", xmlTextReaderConstLocalName(reader)) == 0
      && xmlTextReaderConstNamespaceUri(reader) == NULL) {
#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read root element {}mirror-list-response.");
#endif
    _mirrorResourceListResponse = (NEXUS_REST_APINS0MirrorResourceListResponse *)[NEXUS_REST_APINS0MirrorResourceListResponse readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"Successfully read root element {}mirror-list-response.");
#endif
  }
  else {
    if (xmlTextReaderConstNamespaceUri(reader) == NULL) {
      [NSException raise: @"XMLReadError"
                   format: @"Unable to read NEXUS_REST_APINS0MirrorResourceListResponse. Expected element mirror-list-response. Current element: {}%s", xmlTextReaderConstLocalName(reader)];
    }
    else {
      [NSException raise: @"XMLReadError"
                   format: @"Unable to read NEXUS_REST_APINS0MirrorResourceListResponse. Expected element mirror-list-response. Current element: {%s}%s\n", xmlTextReaderConstNamespaceUri(reader), xmlTextReaderConstLocalName(reader)];
    }
  }

  return _mirrorResourceListResponse;
}

/**
 * Writes this NEXUS_REST_APINS0MirrorResourceListResponse to XML under element name "mirror-list-response".
 * The namespace declarations for the element will be written.
 *
 * @param writer The XML writer.
 * @param _mirrorResourceListResponse The MirrorResourceListResponse to write.
 * @return 1 if successful, 0 otherwise.
 */
- (void) writeXMLElement: (xmlTextWriterPtr) writer
{
  [self writeXMLElement: writer writeNamespaces: YES];
}

/**
 * Writes this NEXUS_REST_APINS0MirrorResourceListResponse to an XML writer.
 *
 * @param writer The writer.
 * @param writeNs Whether to write the namespaces for this element to the xml writer.
 */
- (void) writeXMLElement: (xmlTextWriterPtr) writer writeNamespaces: (BOOL) writeNs
{
  int rc = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "mirror-list-response", NULL);
  if (rc < 0) {
    [NSException raise: @"XMLWriteError"
                 format: @"Error writing start element {}mirror-list-response. XML writer status: %i\n", rc];
  }

#if DEBUG_ENUNCIATE > 1
  NSLog(@"writing type {}mirrorResourceListResponse for root element {}mirror-list-response...");
#endif
  [self writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
  NSLog(@"successfully wrote type {}mirrorResourceListResponse for root element {}mirror-list-response...");
#endif
  rc = xmlTextWriterEndElement(writer);
  if (rc < 0) {
    [NSException raise: @"XMLWriteError"
                 format: @"Error writing end element {}mirror-list-response. XML writer status: %i\n", rc];
  }
}

//documentation inherited.
- (BOOL) readJAXBAttribute: (xmlTextReaderPtr) reader
{
  void *_child_accessor;

  if ([super readJAXBAttribute: reader]) {
    return YES;
  }

  return NO;
}

//documentation inherited.
- (BOOL) readJAXBValue: (xmlTextReaderPtr) reader
{
  return [super readJAXBValue: reader];
}

//documentation inherited.
- (BOOL) readJAXBChildElement: (xmlTextReaderPtr) reader
{
  id __child;
  void *_child_accessor;
  int status, depth;

  if ([super readJAXBChildElement: reader]) {
    return YES;
  }
  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "data", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

    if (xmlTextReaderIsEmptyElement(reader) == 0) {
#if DEBUG_ENUNCIATE > 1
      NSLog(@"Unwrapping wrapper element {}data...");
#endif
      //start wrapper element "{}data"
      depth = xmlTextReaderDepth(reader);
      status = xmlTextReaderAdvanceToNextStartOrEndElement(reader);
      while (xmlTextReaderDepth(reader) > depth) {
        if (status < 1) {
          //panic: XML read error.
          [self dealloc];
          [NSException raise: @"XMLReadError"
                       format: @"Failure to advance to next wrapped child element."];
        }
  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "mirrorResource", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}mirrorResource of type {}mirror-resource.");
#endif

    __child = [NEXUS_REST_APINS0MirrorResource readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}mirrorResource of type {}mirror-resource.");
#endif

    if ([self data]) {
      [self setData: [[self data] arrayByAddingObject: __child]];
    }
    else {
      [self setData: [NSArray arrayWithObject: __child]];
    }
    continue; //continue "while in wrapper element" loop
  } //end "if choice"

        status = xmlTextReaderAdvanceToNextStartOrEndElement(reader);
#if DEBUG_ENUNCIATE > 1
        NSLog(@"successfully unwrapped wrapper element {}data...");
#endif
      } // end "while in wrapper element" loop

      if (status < 1) {
        //panic: XML read error.
        [self dealloc];
        [NSException raise: @"XMLReadError"
                     format: @"Failure to advance to end wrapper element."];
      }
      else {
        //end wrapper element "{}data"
        status = xmlTextReaderAdvanceToNextStartOrEndElement(reader);
      }
    } //end "if empty element" clause
    else {
      __child = [NSArray array];
      [self setData: (NSArray*) __child];
    }

    return YES;
  } // end "if wrapper element" clause

  return NO;
}

//documentation inherited.
- (int) readUnknownJAXBChildElement: (xmlTextReaderPtr) reader
{
  return [super readUnknownJAXBChildElement: reader];
}

//documentation inherited.
- (void) readUnknownJAXBAttribute: (xmlTextReaderPtr) reader
{
  [super readUnknownJAXBAttribute: reader];
}

//documentation inherited.
- (void) writeJAXBAttributes: (xmlTextWriterPtr) writer
{
  int status;

  [super writeJAXBAttributes: writer];

}

//documentation inherited.
- (void) writeJAXBValue: (xmlTextWriterPtr) writer
{
  [super writeJAXBValue: writer];
}

/**
 * Method for writing the child elements.
 *
 * @param writer The writer.
 */
- (void) writeJAXBChildElements: (xmlTextWriterPtr) writer
{
  int status;
  id __item;
  NSEnumerator *__enumerator;

  [super writeJAXBChildElements: writer];

  if ([self data]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "data", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start wrapper element {}data."];
    }
    __enumerator = [[self data] objectEnumerator];

    while ( (__item = [__enumerator nextObject]) ) {
      status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "mirrorResource", NULL);
      if (status < 0) {
        [NSException raise: @"XMLWriteError"
                     format: @"Error writing start child element {}mirrorResource."];
      }

#if DEBUG_ENUNCIATE > 1
      NSLog(@"writing element {}mirrorResource...");
#endif
      [__item writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
      NSLog(@"successfully wrote element {}mirrorResource...");
#endif

      status = xmlTextWriterEndElement(writer);
      if (status < 0) {
        [NSException raise: @"XMLWriteError"
                     format: @"Error writing end child element {}mirrorResource."];
      }
    } //end item iterator.

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end wrapper element {}data."];
    }
  }
}
@end /* implementation NEXUS_REST_APINS0MirrorResourceListResponse (JAXB) */

#endif /* DEF_NEXUS_REST_APINS0MirrorResourceListResponse_M */
#ifndef DEF_NEXUS_REST_APINS0LogsListResourceResponse_M
#define DEF_NEXUS_REST_APINS0LogsListResourceResponse_M

/**
 *  REST Response object for a log list resource request, contains
 the typical 'data' parameter, which is a list of the log items
 requested.
 
 @version $Revision$ $Date$

 */
@implementation NEXUS_REST_APINS0LogsListResourceResponse

/**
 * Field data.
 */
- (NSArray *) data
{
  return _data;
}

/**
 * Field data.
 */
- (void) setData: (NSArray *) newData
{
  [newData retain];
  [_data release];
  _data = newData;
}

- (void) dealloc
{
  [self setData: nil];
  [super dealloc];
}

//documentation inherited.
+ (id<EnunciateXML>) readFromXML: (NSData *) xml
{
  NEXUS_REST_APINS0LogsListResourceResponse *_nEXUS_REST_APINS0LogsListResourceResponse;
  xmlTextReaderPtr reader = xmlReaderForMemory([xml bytes], [xml length], NULL, NULL, 0);
  if (reader == NULL) {
    [NSException raise: @"XMLReadError"
                 format: @"Error instantiating an XML reader."];
    return nil;
  }

  _nEXUS_REST_APINS0LogsListResourceResponse = (NEXUS_REST_APINS0LogsListResourceResponse *) [NEXUS_REST_APINS0LogsListResourceResponse readXMLElement: reader];
  xmlFreeTextReader(reader); //free the reader
  return _nEXUS_REST_APINS0LogsListResourceResponse;
}

//documentation inherited.
- (NSData *) writeToXML
{
  xmlBufferPtr buf;
  xmlTextWriterPtr writer;
  int rc;
  NSData *data;

  buf = xmlBufferCreate();
  if (buf == NULL) {
    [NSException raise: @"XMLWriteError"
                 format: @"Error creating an XML buffer."];
    return nil;
  }

  writer = xmlNewTextWriterMemory(buf, 0);
  if (writer == NULL) {
    xmlBufferFree(buf);
    [NSException raise: @"XMLWriteError"
                 format: @"Error creating an XML writer."];
    return nil;
  }

  rc = xmlTextWriterStartDocument(writer, NULL, "utf-8", NULL);
  if (rc < 0) {
    xmlFreeTextWriter(writer);
    xmlBufferFree(buf);
    [NSException raise: @"XMLWriteError"
                 format: @"Error writing XML start document."];
    return nil;
  }

  NS_DURING
  {
    [self writeXMLElement: writer];
  }
  NS_HANDLER
  {
    xmlFreeTextWriter(writer);
    xmlBufferFree(buf);
    [localException raise];
  }
  NS_ENDHANDLER

  rc = xmlTextWriterEndDocument(writer);
  if (rc < 0) {
    xmlFreeTextWriter(writer);
    xmlBufferFree(buf);
    [NSException raise: @"XMLWriteError"
                 format: @"Error writing XML end document."];
    return nil;
  }

  xmlFreeTextWriter(writer);
  data = [NSData dataWithBytes: buf->content length: buf->use];
  xmlBufferFree(buf);
  return data;
}
@end /* implementation NEXUS_REST_APINS0LogsListResourceResponse */

/**
 * Internal, private interface for JAXB reading and writing.
 */
@interface NEXUS_REST_APINS0LogsListResourceResponse (JAXB) <JAXBReading, JAXBWriting, JAXBType, JAXBElement>

@end /*interface NEXUS_REST_APINS0LogsListResourceResponse (JAXB)*/

/**
 * Internal, private implementation for JAXB reading and writing.
 */
@implementation NEXUS_REST_APINS0LogsListResourceResponse (JAXB)

/**
 * Read an instance of NEXUS_REST_APINS0LogsListResourceResponse from an XML reader.
 *
 * @param reader The reader.
 * @return An instance of NEXUS_REST_APINS0LogsListResourceResponse defined by the XML reader.
 */
+ (id<JAXBType>) readXMLType: (xmlTextReaderPtr) reader
{
  NEXUS_REST_APINS0LogsListResourceResponse *_nEXUS_REST_APINS0LogsListResourceResponse = [[NEXUS_REST_APINS0LogsListResourceResponse alloc] init];
  NS_DURING
  {
    [_nEXUS_REST_APINS0LogsListResourceResponse initWithReader: reader];
  }
  NS_HANDLER
  {
    [_nEXUS_REST_APINS0LogsListResourceResponse dealloc];
    _nEXUS_REST_APINS0LogsListResourceResponse = nil;
    [localException raise];
  }
  NS_ENDHANDLER

  [_nEXUS_REST_APINS0LogsListResourceResponse autorelease];
  return _nEXUS_REST_APINS0LogsListResourceResponse;
}

/**
 * Initialize this instance of NEXUS_REST_APINS0LogsListResourceResponse according to
 * the XML being read from the reader.
 *
 * @param reader The reader.
 */
- (id) initWithReader: (xmlTextReaderPtr) reader
{
  return [super initWithReader: reader];
}

/**
 * Write the XML for this instance of NEXUS_REST_APINS0LogsListResourceResponse to the writer.
 * Note that since we're only writing the XML type,
 * No start/end element will be written.
 *
 * @param reader The reader.
 */
- (void) writeXMLType: (xmlTextWriterPtr) writer
{
  [super writeXMLType:writer];
}

/**
 * Reads a NEXUS_REST_APINS0LogsListResourceResponse from an XML reader. The element to be read is
 * "logs-list".
 *
 * @param reader The XML reader.
 * @return The NEXUS_REST_APINS0LogsListResourceResponse.
 */
+ (id<JAXBElement>) readXMLElement: (xmlTextReaderPtr) reader {
  int status;
  NEXUS_REST_APINS0LogsListResourceResponse *_logsListResourceResponse = nil;

  if (xmlTextReaderNodeType(reader) != XML_READER_TYPE_ELEMENT) {
    status = xmlTextReaderAdvanceToNextStartOrEndElement(reader);
    if (status < 1) {
      [NSException raise: @"XMLReadError"
                   format: @"Error advancing the reader to start element logs-list."];
    }
  }

  if (xmlStrcmp(BAD_CAST "logs-list", xmlTextReaderConstLocalName(reader)) == 0
      && xmlTextReaderConstNamespaceUri(reader) == NULL) {
#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read root element {}logs-list.");
#endif
    _logsListResourceResponse = (NEXUS_REST_APINS0LogsListResourceResponse *)[NEXUS_REST_APINS0LogsListResourceResponse readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"Successfully read root element {}logs-list.");
#endif
  }
  else {
    if (xmlTextReaderConstNamespaceUri(reader) == NULL) {
      [NSException raise: @"XMLReadError"
                   format: @"Unable to read NEXUS_REST_APINS0LogsListResourceResponse. Expected element logs-list. Current element: {}%s", xmlTextReaderConstLocalName(reader)];
    }
    else {
      [NSException raise: @"XMLReadError"
                   format: @"Unable to read NEXUS_REST_APINS0LogsListResourceResponse. Expected element logs-list. Current element: {%s}%s\n", xmlTextReaderConstNamespaceUri(reader), xmlTextReaderConstLocalName(reader)];
    }
  }

  return _logsListResourceResponse;
}

/**
 * Writes this NEXUS_REST_APINS0LogsListResourceResponse to XML under element name "logs-list".
 * The namespace declarations for the element will be written.
 *
 * @param writer The XML writer.
 * @param _logsListResourceResponse The LogsListResourceResponse to write.
 * @return 1 if successful, 0 otherwise.
 */
- (void) writeXMLElement: (xmlTextWriterPtr) writer
{
  [self writeXMLElement: writer writeNamespaces: YES];
}

/**
 * Writes this NEXUS_REST_APINS0LogsListResourceResponse to an XML writer.
 *
 * @param writer The writer.
 * @param writeNs Whether to write the namespaces for this element to the xml writer.
 */
- (void) writeXMLElement: (xmlTextWriterPtr) writer writeNamespaces: (BOOL) writeNs
{
  int rc = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "logs-list", NULL);
  if (rc < 0) {
    [NSException raise: @"XMLWriteError"
                 format: @"Error writing start element {}logs-list. XML writer status: %i\n", rc];
  }

#if DEBUG_ENUNCIATE > 1
  NSLog(@"writing type {}logsListResourceResponse for root element {}logs-list...");
#endif
  [self writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
  NSLog(@"successfully wrote type {}logsListResourceResponse for root element {}logs-list...");
#endif
  rc = xmlTextWriterEndElement(writer);
  if (rc < 0) {
    [NSException raise: @"XMLWriteError"
                 format: @"Error writing end element {}logs-list. XML writer status: %i\n", rc];
  }
}

//documentation inherited.
- (BOOL) readJAXBAttribute: (xmlTextReaderPtr) reader
{
  void *_child_accessor;

  if ([super readJAXBAttribute: reader]) {
    return YES;
  }

  return NO;
}

//documentation inherited.
- (BOOL) readJAXBValue: (xmlTextReaderPtr) reader
{
  return [super readJAXBValue: reader];
}

//documentation inherited.
- (BOOL) readJAXBChildElement: (xmlTextReaderPtr) reader
{
  id __child;
  void *_child_accessor;
  int status, depth;

  if ([super readJAXBChildElement: reader]) {
    return YES;
  }
  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "data", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

    if (xmlTextReaderIsEmptyElement(reader) == 0) {
#if DEBUG_ENUNCIATE > 1
      NSLog(@"Unwrapping wrapper element {}data...");
#endif
      //start wrapper element "{}data"
      depth = xmlTextReaderDepth(reader);
      status = xmlTextReaderAdvanceToNextStartOrEndElement(reader);
      while (xmlTextReaderDepth(reader) > depth) {
        if (status < 1) {
          //panic: XML read error.
          [self dealloc];
          [NSException raise: @"XMLReadError"
                       format: @"Failure to advance to next wrapped child element."];
        }
  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "logs-list-item", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}logs-list-item of type {}logs-list-resource.");
#endif

    __child = [NEXUS_REST_APINS0LogsListResource readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}logs-list-item of type {}logs-list-resource.");
#endif

    if ([self data]) {
      [self setData: [[self data] arrayByAddingObject: __child]];
    }
    else {
      [self setData: [NSArray arrayWithObject: __child]];
    }
    continue; //continue "while in wrapper element" loop
  } //end "if choice"

        status = xmlTextReaderAdvanceToNextStartOrEndElement(reader);
#if DEBUG_ENUNCIATE > 1
        NSLog(@"successfully unwrapped wrapper element {}data...");
#endif
      } // end "while in wrapper element" loop

      if (status < 1) {
        //panic: XML read error.
        [self dealloc];
        [NSException raise: @"XMLReadError"
                     format: @"Failure to advance to end wrapper element."];
      }
      else {
        //end wrapper element "{}data"
        status = xmlTextReaderAdvanceToNextStartOrEndElement(reader);
      }
    } //end "if empty element" clause
    else {
      __child = [NSArray array];
      [self setData: (NSArray*) __child];
    }

    return YES;
  } // end "if wrapper element" clause

  return NO;
}

//documentation inherited.
- (int) readUnknownJAXBChildElement: (xmlTextReaderPtr) reader
{
  return [super readUnknownJAXBChildElement: reader];
}

//documentation inherited.
- (void) readUnknownJAXBAttribute: (xmlTextReaderPtr) reader
{
  [super readUnknownJAXBAttribute: reader];
}

//documentation inherited.
- (void) writeJAXBAttributes: (xmlTextWriterPtr) writer
{
  int status;

  [super writeJAXBAttributes: writer];

}

//documentation inherited.
- (void) writeJAXBValue: (xmlTextWriterPtr) writer
{
  [super writeJAXBValue: writer];
}

/**
 * Method for writing the child elements.
 *
 * @param writer The writer.
 */
- (void) writeJAXBChildElements: (xmlTextWriterPtr) writer
{
  int status;
  id __item;
  NSEnumerator *__enumerator;

  [super writeJAXBChildElements: writer];

  if ([self data]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "data", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start wrapper element {}data."];
    }
    __enumerator = [[self data] objectEnumerator];

    while ( (__item = [__enumerator nextObject]) ) {
      status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "logs-list-item", NULL);
      if (status < 0) {
        [NSException raise: @"XMLWriteError"
                     format: @"Error writing start child element {}logs-list-item."];
      }

#if DEBUG_ENUNCIATE > 1
      NSLog(@"writing element {}logs-list-item...");
#endif
      [__item writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
      NSLog(@"successfully wrote element {}logs-list-item...");
#endif

      status = xmlTextWriterEndElement(writer);
      if (status < 0) {
        [NSException raise: @"XMLWriteError"
                     format: @"Error writing end child element {}logs-list-item."];
      }
    } //end item iterator.

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end wrapper element {}data."];
    }
  }
}
@end /* implementation NEXUS_REST_APINS0LogsListResourceResponse (JAXB) */

#endif /* DEF_NEXUS_REST_APINS0LogsListResourceResponse_M */
#ifndef DEF_NEXUS_REST_APINS0FeedListResourceResponse_M
#define DEF_NEXUS_REST_APINS0FeedListResourceResponse_M

/**
 *  REST Response object for a list of Nexus feed items, contains
 the typical 'data' parameter, which is a list of the feed items.
 
 @version $Revision$ $Date$

 */
@implementation NEXUS_REST_APINS0FeedListResourceResponse

/**
 * Field data.
 */
- (NSArray *) data
{
  return _data;
}

/**
 * Field data.
 */
- (void) setData: (NSArray *) newData
{
  [newData retain];
  [_data release];
  _data = newData;
}

- (void) dealloc
{
  [self setData: nil];
  [super dealloc];
}

//documentation inherited.
+ (id<EnunciateXML>) readFromXML: (NSData *) xml
{
  NEXUS_REST_APINS0FeedListResourceResponse *_nEXUS_REST_APINS0FeedListResourceResponse;
  xmlTextReaderPtr reader = xmlReaderForMemory([xml bytes], [xml length], NULL, NULL, 0);
  if (reader == NULL) {
    [NSException raise: @"XMLReadError"
                 format: @"Error instantiating an XML reader."];
    return nil;
  }

  _nEXUS_REST_APINS0FeedListResourceResponse = (NEXUS_REST_APINS0FeedListResourceResponse *) [NEXUS_REST_APINS0FeedListResourceResponse readXMLElement: reader];
  xmlFreeTextReader(reader); //free the reader
  return _nEXUS_REST_APINS0FeedListResourceResponse;
}

//documentation inherited.
- (NSData *) writeToXML
{
  xmlBufferPtr buf;
  xmlTextWriterPtr writer;
  int rc;
  NSData *data;

  buf = xmlBufferCreate();
  if (buf == NULL) {
    [NSException raise: @"XMLWriteError"
                 format: @"Error creating an XML buffer."];
    return nil;
  }

  writer = xmlNewTextWriterMemory(buf, 0);
  if (writer == NULL) {
    xmlBufferFree(buf);
    [NSException raise: @"XMLWriteError"
                 format: @"Error creating an XML writer."];
    return nil;
  }

  rc = xmlTextWriterStartDocument(writer, NULL, "utf-8", NULL);
  if (rc < 0) {
    xmlFreeTextWriter(writer);
    xmlBufferFree(buf);
    [NSException raise: @"XMLWriteError"
                 format: @"Error writing XML start document."];
    return nil;
  }

  NS_DURING
  {
    [self writeXMLElement: writer];
  }
  NS_HANDLER
  {
    xmlFreeTextWriter(writer);
    xmlBufferFree(buf);
    [localException raise];
  }
  NS_ENDHANDLER

  rc = xmlTextWriterEndDocument(writer);
  if (rc < 0) {
    xmlFreeTextWriter(writer);
    xmlBufferFree(buf);
    [NSException raise: @"XMLWriteError"
                 format: @"Error writing XML end document."];
    return nil;
  }

  xmlFreeTextWriter(writer);
  data = [NSData dataWithBytes: buf->content length: buf->use];
  xmlBufferFree(buf);
  return data;
}
@end /* implementation NEXUS_REST_APINS0FeedListResourceResponse */

/**
 * Internal, private interface for JAXB reading and writing.
 */
@interface NEXUS_REST_APINS0FeedListResourceResponse (JAXB) <JAXBReading, JAXBWriting, JAXBType, JAXBElement>

@end /*interface NEXUS_REST_APINS0FeedListResourceResponse (JAXB)*/

/**
 * Internal, private implementation for JAXB reading and writing.
 */
@implementation NEXUS_REST_APINS0FeedListResourceResponse (JAXB)

/**
 * Read an instance of NEXUS_REST_APINS0FeedListResourceResponse from an XML reader.
 *
 * @param reader The reader.
 * @return An instance of NEXUS_REST_APINS0FeedListResourceResponse defined by the XML reader.
 */
+ (id<JAXBType>) readXMLType: (xmlTextReaderPtr) reader
{
  NEXUS_REST_APINS0FeedListResourceResponse *_nEXUS_REST_APINS0FeedListResourceResponse = [[NEXUS_REST_APINS0FeedListResourceResponse alloc] init];
  NS_DURING
  {
    [_nEXUS_REST_APINS0FeedListResourceResponse initWithReader: reader];
  }
  NS_HANDLER
  {
    [_nEXUS_REST_APINS0FeedListResourceResponse dealloc];
    _nEXUS_REST_APINS0FeedListResourceResponse = nil;
    [localException raise];
  }
  NS_ENDHANDLER

  [_nEXUS_REST_APINS0FeedListResourceResponse autorelease];
  return _nEXUS_REST_APINS0FeedListResourceResponse;
}

/**
 * Initialize this instance of NEXUS_REST_APINS0FeedListResourceResponse according to
 * the XML being read from the reader.
 *
 * @param reader The reader.
 */
- (id) initWithReader: (xmlTextReaderPtr) reader
{
  return [super initWithReader: reader];
}

/**
 * Write the XML for this instance of NEXUS_REST_APINS0FeedListResourceResponse to the writer.
 * Note that since we're only writing the XML type,
 * No start/end element will be written.
 *
 * @param reader The reader.
 */
- (void) writeXMLType: (xmlTextWriterPtr) writer
{
  [super writeXMLType:writer];
}

/**
 * Reads a NEXUS_REST_APINS0FeedListResourceResponse from an XML reader. The element to be read is
 * "feeds-list".
 *
 * @param reader The XML reader.
 * @return The NEXUS_REST_APINS0FeedListResourceResponse.
 */
+ (id<JAXBElement>) readXMLElement: (xmlTextReaderPtr) reader {
  int status;
  NEXUS_REST_APINS0FeedListResourceResponse *_feedListResourceResponse = nil;

  if (xmlTextReaderNodeType(reader) != XML_READER_TYPE_ELEMENT) {
    status = xmlTextReaderAdvanceToNextStartOrEndElement(reader);
    if (status < 1) {
      [NSException raise: @"XMLReadError"
                   format: @"Error advancing the reader to start element feeds-list."];
    }
  }

  if (xmlStrcmp(BAD_CAST "feeds-list", xmlTextReaderConstLocalName(reader)) == 0
      && xmlTextReaderConstNamespaceUri(reader) == NULL) {
#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read root element {}feeds-list.");
#endif
    _feedListResourceResponse = (NEXUS_REST_APINS0FeedListResourceResponse *)[NEXUS_REST_APINS0FeedListResourceResponse readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"Successfully read root element {}feeds-list.");
#endif
  }
  else {
    if (xmlTextReaderConstNamespaceUri(reader) == NULL) {
      [NSException raise: @"XMLReadError"
                   format: @"Unable to read NEXUS_REST_APINS0FeedListResourceResponse. Expected element feeds-list. Current element: {}%s", xmlTextReaderConstLocalName(reader)];
    }
    else {
      [NSException raise: @"XMLReadError"
                   format: @"Unable to read NEXUS_REST_APINS0FeedListResourceResponse. Expected element feeds-list. Current element: {%s}%s\n", xmlTextReaderConstNamespaceUri(reader), xmlTextReaderConstLocalName(reader)];
    }
  }

  return _feedListResourceResponse;
}

/**
 * Writes this NEXUS_REST_APINS0FeedListResourceResponse to XML under element name "feeds-list".
 * The namespace declarations for the element will be written.
 *
 * @param writer The XML writer.
 * @param _feedListResourceResponse The FeedListResourceResponse to write.
 * @return 1 if successful, 0 otherwise.
 */
- (void) writeXMLElement: (xmlTextWriterPtr) writer
{
  [self writeXMLElement: writer writeNamespaces: YES];
}

/**
 * Writes this NEXUS_REST_APINS0FeedListResourceResponse to an XML writer.
 *
 * @param writer The writer.
 * @param writeNs Whether to write the namespaces for this element to the xml writer.
 */
- (void) writeXMLElement: (xmlTextWriterPtr) writer writeNamespaces: (BOOL) writeNs
{
  int rc = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "feeds-list", NULL);
  if (rc < 0) {
    [NSException raise: @"XMLWriteError"
                 format: @"Error writing start element {}feeds-list. XML writer status: %i\n", rc];
  }

#if DEBUG_ENUNCIATE > 1
  NSLog(@"writing type {}feedListResourceResponse for root element {}feeds-list...");
#endif
  [self writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
  NSLog(@"successfully wrote type {}feedListResourceResponse for root element {}feeds-list...");
#endif
  rc = xmlTextWriterEndElement(writer);
  if (rc < 0) {
    [NSException raise: @"XMLWriteError"
                 format: @"Error writing end element {}feeds-list. XML writer status: %i\n", rc];
  }
}

//documentation inherited.
- (BOOL) readJAXBAttribute: (xmlTextReaderPtr) reader
{
  void *_child_accessor;

  if ([super readJAXBAttribute: reader]) {
    return YES;
  }

  return NO;
}

//documentation inherited.
- (BOOL) readJAXBValue: (xmlTextReaderPtr) reader
{
  return [super readJAXBValue: reader];
}

//documentation inherited.
- (BOOL) readJAXBChildElement: (xmlTextReaderPtr) reader
{
  id __child;
  void *_child_accessor;
  int status, depth;

  if ([super readJAXBChildElement: reader]) {
    return YES;
  }
  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "data", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

    if (xmlTextReaderIsEmptyElement(reader) == 0) {
#if DEBUG_ENUNCIATE > 1
      NSLog(@"Unwrapping wrapper element {}data...");
#endif
      //start wrapper element "{}data"
      depth = xmlTextReaderDepth(reader);
      status = xmlTextReaderAdvanceToNextStartOrEndElement(reader);
      while (xmlTextReaderDepth(reader) > depth) {
        if (status < 1) {
          //panic: XML read error.
          [self dealloc];
          [NSException raise: @"XMLReadError"
                       format: @"Failure to advance to next wrapped child element."];
        }
  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "feeds-list-item", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}feeds-list-item of type {}feed-list-resource.");
#endif

    __child = [NEXUS_REST_APINS0FeedListResource readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}feeds-list-item of type {}feed-list-resource.");
#endif

    if ([self data]) {
      [self setData: [[self data] arrayByAddingObject: __child]];
    }
    else {
      [self setData: [NSArray arrayWithObject: __child]];
    }
    continue; //continue "while in wrapper element" loop
  } //end "if choice"

        status = xmlTextReaderAdvanceToNextStartOrEndElement(reader);
#if DEBUG_ENUNCIATE > 1
        NSLog(@"successfully unwrapped wrapper element {}data...");
#endif
      } // end "while in wrapper element" loop

      if (status < 1) {
        //panic: XML read error.
        [self dealloc];
        [NSException raise: @"XMLReadError"
                     format: @"Failure to advance to end wrapper element."];
      }
      else {
        //end wrapper element "{}data"
        status = xmlTextReaderAdvanceToNextStartOrEndElement(reader);
      }
    } //end "if empty element" clause
    else {
      __child = [NSArray array];
      [self setData: (NSArray*) __child];
    }

    return YES;
  } // end "if wrapper element" clause

  return NO;
}

//documentation inherited.
- (int) readUnknownJAXBChildElement: (xmlTextReaderPtr) reader
{
  return [super readUnknownJAXBChildElement: reader];
}

//documentation inherited.
- (void) readUnknownJAXBAttribute: (xmlTextReaderPtr) reader
{
  [super readUnknownJAXBAttribute: reader];
}

//documentation inherited.
- (void) writeJAXBAttributes: (xmlTextWriterPtr) writer
{
  int status;

  [super writeJAXBAttributes: writer];

}

//documentation inherited.
- (void) writeJAXBValue: (xmlTextWriterPtr) writer
{
  [super writeJAXBValue: writer];
}

/**
 * Method for writing the child elements.
 *
 * @param writer The writer.
 */
- (void) writeJAXBChildElements: (xmlTextWriterPtr) writer
{
  int status;
  id __item;
  NSEnumerator *__enumerator;

  [super writeJAXBChildElements: writer];

  if ([self data]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "data", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start wrapper element {}data."];
    }
    __enumerator = [[self data] objectEnumerator];

    while ( (__item = [__enumerator nextObject]) ) {
      status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "feeds-list-item", NULL);
      if (status < 0) {
        [NSException raise: @"XMLWriteError"
                     format: @"Error writing start child element {}feeds-list-item."];
      }

#if DEBUG_ENUNCIATE > 1
      NSLog(@"writing element {}feeds-list-item...");
#endif
      [__item writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
      NSLog(@"successfully wrote element {}feeds-list-item...");
#endif

      status = xmlTextWriterEndElement(writer);
      if (status < 0) {
        [NSException raise: @"XMLWriteError"
                     format: @"Error writing end child element {}feeds-list-item."];
      }
    } //end item iterator.

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end wrapper element {}data."];
    }
  }
}
@end /* implementation NEXUS_REST_APINS0FeedListResourceResponse (JAXB) */

#endif /* DEF_NEXUS_REST_APINS0FeedListResourceResponse_M */
#ifndef DEF_NEXUS_REST_APINS0GlobalConfigurationListResourceResponse_M
#define DEF_NEXUS_REST_APINS0GlobalConfigurationListResourceResponse_M

/**
 *  REST Response object for a global configuration list request,
 contains the typical 'data' parameter, which is a list of the
 global configuration items requested.
 
 @version $Revision$ $Date$

 */
@implementation NEXUS_REST_APINS0GlobalConfigurationListResourceResponse

/**
 * Field data.
 */
- (NSArray *) data
{
  return _data;
}

/**
 * Field data.
 */
- (void) setData: (NSArray *) newData
{
  [newData retain];
  [_data release];
  _data = newData;
}

- (void) dealloc
{
  [self setData: nil];
  [super dealloc];
}

//documentation inherited.
+ (id<EnunciateXML>) readFromXML: (NSData *) xml
{
  NEXUS_REST_APINS0GlobalConfigurationListResourceResponse *_nEXUS_REST_APINS0GlobalConfigurationListResourceResponse;
  xmlTextReaderPtr reader = xmlReaderForMemory([xml bytes], [xml length], NULL, NULL, 0);
  if (reader == NULL) {
    [NSException raise: @"XMLReadError"
                 format: @"Error instantiating an XML reader."];
    return nil;
  }

  _nEXUS_REST_APINS0GlobalConfigurationListResourceResponse = (NEXUS_REST_APINS0GlobalConfigurationListResourceResponse *) [NEXUS_REST_APINS0GlobalConfigurationListResourceResponse readXMLElement: reader];
  xmlFreeTextReader(reader); //free the reader
  return _nEXUS_REST_APINS0GlobalConfigurationListResourceResponse;
}

//documentation inherited.
- (NSData *) writeToXML
{
  xmlBufferPtr buf;
  xmlTextWriterPtr writer;
  int rc;
  NSData *data;

  buf = xmlBufferCreate();
  if (buf == NULL) {
    [NSException raise: @"XMLWriteError"
                 format: @"Error creating an XML buffer."];
    return nil;
  }

  writer = xmlNewTextWriterMemory(buf, 0);
  if (writer == NULL) {
    xmlBufferFree(buf);
    [NSException raise: @"XMLWriteError"
                 format: @"Error creating an XML writer."];
    return nil;
  }

  rc = xmlTextWriterStartDocument(writer, NULL, "utf-8", NULL);
  if (rc < 0) {
    xmlFreeTextWriter(writer);
    xmlBufferFree(buf);
    [NSException raise: @"XMLWriteError"
                 format: @"Error writing XML start document."];
    return nil;
  }

  NS_DURING
  {
    [self writeXMLElement: writer];
  }
  NS_HANDLER
  {
    xmlFreeTextWriter(writer);
    xmlBufferFree(buf);
    [localException raise];
  }
  NS_ENDHANDLER

  rc = xmlTextWriterEndDocument(writer);
  if (rc < 0) {
    xmlFreeTextWriter(writer);
    xmlBufferFree(buf);
    [NSException raise: @"XMLWriteError"
                 format: @"Error writing XML end document."];
    return nil;
  }

  xmlFreeTextWriter(writer);
  data = [NSData dataWithBytes: buf->content length: buf->use];
  xmlBufferFree(buf);
  return data;
}
@end /* implementation NEXUS_REST_APINS0GlobalConfigurationListResourceResponse */

/**
 * Internal, private interface for JAXB reading and writing.
 */
@interface NEXUS_REST_APINS0GlobalConfigurationListResourceResponse (JAXB) <JAXBReading, JAXBWriting, JAXBType, JAXBElement>

@end /*interface NEXUS_REST_APINS0GlobalConfigurationListResourceResponse (JAXB)*/

/**
 * Internal, private implementation for JAXB reading and writing.
 */
@implementation NEXUS_REST_APINS0GlobalConfigurationListResourceResponse (JAXB)

/**
 * Read an instance of NEXUS_REST_APINS0GlobalConfigurationListResourceResponse from an XML reader.
 *
 * @param reader The reader.
 * @return An instance of NEXUS_REST_APINS0GlobalConfigurationListResourceResponse defined by the XML reader.
 */
+ (id<JAXBType>) readXMLType: (xmlTextReaderPtr) reader
{
  NEXUS_REST_APINS0GlobalConfigurationListResourceResponse *_nEXUS_REST_APINS0GlobalConfigurationListResourceResponse = [[NEXUS_REST_APINS0GlobalConfigurationListResourceResponse alloc] init];
  NS_DURING
  {
    [_nEXUS_REST_APINS0GlobalConfigurationListResourceResponse initWithReader: reader];
  }
  NS_HANDLER
  {
    [_nEXUS_REST_APINS0GlobalConfigurationListResourceResponse dealloc];
    _nEXUS_REST_APINS0GlobalConfigurationListResourceResponse = nil;
    [localException raise];
  }
  NS_ENDHANDLER

  [_nEXUS_REST_APINS0GlobalConfigurationListResourceResponse autorelease];
  return _nEXUS_REST_APINS0GlobalConfigurationListResourceResponse;
}

/**
 * Initialize this instance of NEXUS_REST_APINS0GlobalConfigurationListResourceResponse according to
 * the XML being read from the reader.
 *
 * @param reader The reader.
 */
- (id) initWithReader: (xmlTextReaderPtr) reader
{
  return [super initWithReader: reader];
}

/**
 * Write the XML for this instance of NEXUS_REST_APINS0GlobalConfigurationListResourceResponse to the writer.
 * Note that since we're only writing the XML type,
 * No start/end element will be written.
 *
 * @param reader The reader.
 */
- (void) writeXMLType: (xmlTextWriterPtr) writer
{
  [super writeXMLType:writer];
}

/**
 * Reads a NEXUS_REST_APINS0GlobalConfigurationListResourceResponse from an XML reader. The element to be read is
 * "global-settings-list".
 *
 * @param reader The XML reader.
 * @return The NEXUS_REST_APINS0GlobalConfigurationListResourceResponse.
 */
+ (id<JAXBElement>) readXMLElement: (xmlTextReaderPtr) reader {
  int status;
  NEXUS_REST_APINS0GlobalConfigurationListResourceResponse *_globalConfigurationListResourceResponse = nil;

  if (xmlTextReaderNodeType(reader) != XML_READER_TYPE_ELEMENT) {
    status = xmlTextReaderAdvanceToNextStartOrEndElement(reader);
    if (status < 1) {
      [NSException raise: @"XMLReadError"
                   format: @"Error advancing the reader to start element global-settings-list."];
    }
  }

  if (xmlStrcmp(BAD_CAST "global-settings-list", xmlTextReaderConstLocalName(reader)) == 0
      && xmlTextReaderConstNamespaceUri(reader) == NULL) {
#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read root element {}global-settings-list.");
#endif
    _globalConfigurationListResourceResponse = (NEXUS_REST_APINS0GlobalConfigurationListResourceResponse *)[NEXUS_REST_APINS0GlobalConfigurationListResourceResponse readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"Successfully read root element {}global-settings-list.");
#endif
  }
  else {
    if (xmlTextReaderConstNamespaceUri(reader) == NULL) {
      [NSException raise: @"XMLReadError"
                   format: @"Unable to read NEXUS_REST_APINS0GlobalConfigurationListResourceResponse. Expected element global-settings-list. Current element: {}%s", xmlTextReaderConstLocalName(reader)];
    }
    else {
      [NSException raise: @"XMLReadError"
                   format: @"Unable to read NEXUS_REST_APINS0GlobalConfigurationListResourceResponse. Expected element global-settings-list. Current element: {%s}%s\n", xmlTextReaderConstNamespaceUri(reader), xmlTextReaderConstLocalName(reader)];
    }
  }

  return _globalConfigurationListResourceResponse;
}

/**
 * Writes this NEXUS_REST_APINS0GlobalConfigurationListResourceResponse to XML under element name "global-settings-list".
 * The namespace declarations for the element will be written.
 *
 * @param writer The XML writer.
 * @param _globalConfigurationListResourceResponse The GlobalConfigurationListResourceResponse to write.
 * @return 1 if successful, 0 otherwise.
 */
- (void) writeXMLElement: (xmlTextWriterPtr) writer
{
  [self writeXMLElement: writer writeNamespaces: YES];
}

/**
 * Writes this NEXUS_REST_APINS0GlobalConfigurationListResourceResponse to an XML writer.
 *
 * @param writer The writer.
 * @param writeNs Whether to write the namespaces for this element to the xml writer.
 */
- (void) writeXMLElement: (xmlTextWriterPtr) writer writeNamespaces: (BOOL) writeNs
{
  int rc = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "global-settings-list", NULL);
  if (rc < 0) {
    [NSException raise: @"XMLWriteError"
                 format: @"Error writing start element {}global-settings-list. XML writer status: %i\n", rc];
  }

#if DEBUG_ENUNCIATE > 1
  NSLog(@"writing type {}globalConfigurationListResourceResponse for root element {}global-settings-list...");
#endif
  [self writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
  NSLog(@"successfully wrote type {}globalConfigurationListResourceResponse for root element {}global-settings-list...");
#endif
  rc = xmlTextWriterEndElement(writer);
  if (rc < 0) {
    [NSException raise: @"XMLWriteError"
                 format: @"Error writing end element {}global-settings-list. XML writer status: %i\n", rc];
  }
}

//documentation inherited.
- (BOOL) readJAXBAttribute: (xmlTextReaderPtr) reader
{
  void *_child_accessor;

  if ([super readJAXBAttribute: reader]) {
    return YES;
  }

  return NO;
}

//documentation inherited.
- (BOOL) readJAXBValue: (xmlTextReaderPtr) reader
{
  return [super readJAXBValue: reader];
}

//documentation inherited.
- (BOOL) readJAXBChildElement: (xmlTextReaderPtr) reader
{
  id __child;
  void *_child_accessor;
  int status, depth;

  if ([super readJAXBChildElement: reader]) {
    return YES;
  }
  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "data", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

    if (xmlTextReaderIsEmptyElement(reader) == 0) {
#if DEBUG_ENUNCIATE > 1
      NSLog(@"Unwrapping wrapper element {}data...");
#endif
      //start wrapper element "{}data"
      depth = xmlTextReaderDepth(reader);
      status = xmlTextReaderAdvanceToNextStartOrEndElement(reader);
      while (xmlTextReaderDepth(reader) > depth) {
        if (status < 1) {
          //panic: XML read error.
          [self dealloc];
          [NSException raise: @"XMLReadError"
                       format: @"Failure to advance to next wrapped child element."];
        }
  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "global-settings-list-item", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}global-settings-list-item of type {}global-configuration-list-item.");
#endif

    __child = [NEXUS_REST_APINS0GlobalConfigurationListResource readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}global-settings-list-item of type {}global-configuration-list-item.");
#endif

    if ([self data]) {
      [self setData: [[self data] arrayByAddingObject: __child]];
    }
    else {
      [self setData: [NSArray arrayWithObject: __child]];
    }
    continue; //continue "while in wrapper element" loop
  } //end "if choice"

        status = xmlTextReaderAdvanceToNextStartOrEndElement(reader);
#if DEBUG_ENUNCIATE > 1
        NSLog(@"successfully unwrapped wrapper element {}data...");
#endif
      } // end "while in wrapper element" loop

      if (status < 1) {
        //panic: XML read error.
        [self dealloc];
        [NSException raise: @"XMLReadError"
                     format: @"Failure to advance to end wrapper element."];
      }
      else {
        //end wrapper element "{}data"
        status = xmlTextReaderAdvanceToNextStartOrEndElement(reader);
      }
    } //end "if empty element" clause
    else {
      __child = [NSArray array];
      [self setData: (NSArray*) __child];
    }

    return YES;
  } // end "if wrapper element" clause

  return NO;
}

//documentation inherited.
- (int) readUnknownJAXBChildElement: (xmlTextReaderPtr) reader
{
  return [super readUnknownJAXBChildElement: reader];
}

//documentation inherited.
- (void) readUnknownJAXBAttribute: (xmlTextReaderPtr) reader
{
  [super readUnknownJAXBAttribute: reader];
}

//documentation inherited.
- (void) writeJAXBAttributes: (xmlTextWriterPtr) writer
{
  int status;

  [super writeJAXBAttributes: writer];

}

//documentation inherited.
- (void) writeJAXBValue: (xmlTextWriterPtr) writer
{
  [super writeJAXBValue: writer];
}

/**
 * Method for writing the child elements.
 *
 * @param writer The writer.
 */
- (void) writeJAXBChildElements: (xmlTextWriterPtr) writer
{
  int status;
  id __item;
  NSEnumerator *__enumerator;

  [super writeJAXBChildElements: writer];

  if ([self data]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "data", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start wrapper element {}data."];
    }
    __enumerator = [[self data] objectEnumerator];

    while ( (__item = [__enumerator nextObject]) ) {
      status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "global-settings-list-item", NULL);
      if (status < 0) {
        [NSException raise: @"XMLWriteError"
                     format: @"Error writing start child element {}global-settings-list-item."];
      }

#if DEBUG_ENUNCIATE > 1
      NSLog(@"writing element {}global-settings-list-item...");
#endif
      [__item writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
      NSLog(@"successfully wrote element {}global-settings-list-item...");
#endif

      status = xmlTextWriterEndElement(writer);
      if (status < 0) {
        [NSException raise: @"XMLWriteError"
                     format: @"Error writing end child element {}global-settings-list-item."];
      }
    } //end item iterator.

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end wrapper element {}data."];
    }
  }
}
@end /* implementation NEXUS_REST_APINS0GlobalConfigurationListResourceResponse (JAXB) */

#endif /* DEF_NEXUS_REST_APINS0GlobalConfigurationListResourceResponse_M */
#ifndef DEF_NEXUS_REST_APINS0LogConfigResourceResponse_M
#define DEF_NEXUS_REST_APINS0LogConfigResourceResponse_M

/**
 *  REST Response object for the log config request, contains the
 typical 'data' parameter, which is the log configuration.
 
 @version $Revision$ $Date$

 */
@implementation NEXUS_REST_APINS0LogConfigResourceResponse

/**
 * The log configuration parameters.
 */
- (NEXUS_REST_APINS0LogConfigResource *) data
{
  return _data;
}

/**
 * The log configuration parameters.
 */
- (void) setData: (NEXUS_REST_APINS0LogConfigResource *) newData
{
  [newData retain];
  [_data release];
  _data = newData;
}

- (void) dealloc
{
  [self setData: nil];
  [super dealloc];
}

//documentation inherited.
+ (id<EnunciateXML>) readFromXML: (NSData *) xml
{
  NEXUS_REST_APINS0LogConfigResourceResponse *_nEXUS_REST_APINS0LogConfigResourceResponse;
  xmlTextReaderPtr reader = xmlReaderForMemory([xml bytes], [xml length], NULL, NULL, 0);
  if (reader == NULL) {
    [NSException raise: @"XMLReadError"
                 format: @"Error instantiating an XML reader."];
    return nil;
  }

  _nEXUS_REST_APINS0LogConfigResourceResponse = (NEXUS_REST_APINS0LogConfigResourceResponse *) [NEXUS_REST_APINS0LogConfigResourceResponse readXMLElement: reader];
  xmlFreeTextReader(reader); //free the reader
  return _nEXUS_REST_APINS0LogConfigResourceResponse;
}

//documentation inherited.
- (NSData *) writeToXML
{
  xmlBufferPtr buf;
  xmlTextWriterPtr writer;
  int rc;
  NSData *data;

  buf = xmlBufferCreate();
  if (buf == NULL) {
    [NSException raise: @"XMLWriteError"
                 format: @"Error creating an XML buffer."];
    return nil;
  }

  writer = xmlNewTextWriterMemory(buf, 0);
  if (writer == NULL) {
    xmlBufferFree(buf);
    [NSException raise: @"XMLWriteError"
                 format: @"Error creating an XML writer."];
    return nil;
  }

  rc = xmlTextWriterStartDocument(writer, NULL, "utf-8", NULL);
  if (rc < 0) {
    xmlFreeTextWriter(writer);
    xmlBufferFree(buf);
    [NSException raise: @"XMLWriteError"
                 format: @"Error writing XML start document."];
    return nil;
  }

  NS_DURING
  {
    [self writeXMLElement: writer];
  }
  NS_HANDLER
  {
    xmlFreeTextWriter(writer);
    xmlBufferFree(buf);
    [localException raise];
  }
  NS_ENDHANDLER

  rc = xmlTextWriterEndDocument(writer);
  if (rc < 0) {
    xmlFreeTextWriter(writer);
    xmlBufferFree(buf);
    [NSException raise: @"XMLWriteError"
                 format: @"Error writing XML end document."];
    return nil;
  }

  xmlFreeTextWriter(writer);
  data = [NSData dataWithBytes: buf->content length: buf->use];
  xmlBufferFree(buf);
  return data;
}
@end /* implementation NEXUS_REST_APINS0LogConfigResourceResponse */

/**
 * Internal, private interface for JAXB reading and writing.
 */
@interface NEXUS_REST_APINS0LogConfigResourceResponse (JAXB) <JAXBReading, JAXBWriting, JAXBType, JAXBElement>

@end /*interface NEXUS_REST_APINS0LogConfigResourceResponse (JAXB)*/

/**
 * Internal, private implementation for JAXB reading and writing.
 */
@implementation NEXUS_REST_APINS0LogConfigResourceResponse (JAXB)

/**
 * Read an instance of NEXUS_REST_APINS0LogConfigResourceResponse from an XML reader.
 *
 * @param reader The reader.
 * @return An instance of NEXUS_REST_APINS0LogConfigResourceResponse defined by the XML reader.
 */
+ (id<JAXBType>) readXMLType: (xmlTextReaderPtr) reader
{
  NEXUS_REST_APINS0LogConfigResourceResponse *_nEXUS_REST_APINS0LogConfigResourceResponse = [[NEXUS_REST_APINS0LogConfigResourceResponse alloc] init];
  NS_DURING
  {
    [_nEXUS_REST_APINS0LogConfigResourceResponse initWithReader: reader];
  }
  NS_HANDLER
  {
    [_nEXUS_REST_APINS0LogConfigResourceResponse dealloc];
    _nEXUS_REST_APINS0LogConfigResourceResponse = nil;
    [localException raise];
  }
  NS_ENDHANDLER

  [_nEXUS_REST_APINS0LogConfigResourceResponse autorelease];
  return _nEXUS_REST_APINS0LogConfigResourceResponse;
}

/**
 * Initialize this instance of NEXUS_REST_APINS0LogConfigResourceResponse according to
 * the XML being read from the reader.
 *
 * @param reader The reader.
 */
- (id) initWithReader: (xmlTextReaderPtr) reader
{
  return [super initWithReader: reader];
}

/**
 * Write the XML for this instance of NEXUS_REST_APINS0LogConfigResourceResponse to the writer.
 * Note that since we're only writing the XML type,
 * No start/end element will be written.
 *
 * @param reader The reader.
 */
- (void) writeXMLType: (xmlTextWriterPtr) writer
{
  [super writeXMLType:writer];
}

/**
 * Reads a NEXUS_REST_APINS0LogConfigResourceResponse from an XML reader. The element to be read is
 * "log-config".
 *
 * @param reader The XML reader.
 * @return The NEXUS_REST_APINS0LogConfigResourceResponse.
 */
+ (id<JAXBElement>) readXMLElement: (xmlTextReaderPtr) reader {
  int status;
  NEXUS_REST_APINS0LogConfigResourceResponse *_logConfigResourceResponse = nil;

  if (xmlTextReaderNodeType(reader) != XML_READER_TYPE_ELEMENT) {
    status = xmlTextReaderAdvanceToNextStartOrEndElement(reader);
    if (status < 1) {
      [NSException raise: @"XMLReadError"
                   format: @"Error advancing the reader to start element log-config."];
    }
  }

  if (xmlStrcmp(BAD_CAST "log-config", xmlTextReaderConstLocalName(reader)) == 0
      && xmlTextReaderConstNamespaceUri(reader) == NULL) {
#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read root element {}log-config.");
#endif
    _logConfigResourceResponse = (NEXUS_REST_APINS0LogConfigResourceResponse *)[NEXUS_REST_APINS0LogConfigResourceResponse readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"Successfully read root element {}log-config.");
#endif
  }
  else {
    if (xmlTextReaderConstNamespaceUri(reader) == NULL) {
      [NSException raise: @"XMLReadError"
                   format: @"Unable to read NEXUS_REST_APINS0LogConfigResourceResponse. Expected element log-config. Current element: {}%s", xmlTextReaderConstLocalName(reader)];
    }
    else {
      [NSException raise: @"XMLReadError"
                   format: @"Unable to read NEXUS_REST_APINS0LogConfigResourceResponse. Expected element log-config. Current element: {%s}%s\n", xmlTextReaderConstNamespaceUri(reader), xmlTextReaderConstLocalName(reader)];
    }
  }

  return _logConfigResourceResponse;
}

/**
 * Writes this NEXUS_REST_APINS0LogConfigResourceResponse to XML under element name "log-config".
 * The namespace declarations for the element will be written.
 *
 * @param writer The XML writer.
 * @param _logConfigResourceResponse The LogConfigResourceResponse to write.
 * @return 1 if successful, 0 otherwise.
 */
- (void) writeXMLElement: (xmlTextWriterPtr) writer
{
  [self writeXMLElement: writer writeNamespaces: YES];
}

/**
 * Writes this NEXUS_REST_APINS0LogConfigResourceResponse to an XML writer.
 *
 * @param writer The writer.
 * @param writeNs Whether to write the namespaces for this element to the xml writer.
 */
- (void) writeXMLElement: (xmlTextWriterPtr) writer writeNamespaces: (BOOL) writeNs
{
  int rc = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "log-config", NULL);
  if (rc < 0) {
    [NSException raise: @"XMLWriteError"
                 format: @"Error writing start element {}log-config. XML writer status: %i\n", rc];
  }

#if DEBUG_ENUNCIATE > 1
  NSLog(@"writing type {}logConfigResourceResponse for root element {}log-config...");
#endif
  [self writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
  NSLog(@"successfully wrote type {}logConfigResourceResponse for root element {}log-config...");
#endif
  rc = xmlTextWriterEndElement(writer);
  if (rc < 0) {
    [NSException raise: @"XMLWriteError"
                 format: @"Error writing end element {}log-config. XML writer status: %i\n", rc];
  }
}

//documentation inherited.
- (BOOL) readJAXBAttribute: (xmlTextReaderPtr) reader
{
  void *_child_accessor;

  if ([super readJAXBAttribute: reader]) {
    return YES;
  }

  return NO;
}

//documentation inherited.
- (BOOL) readJAXBValue: (xmlTextReaderPtr) reader
{
  return [super readJAXBValue: reader];
}

//documentation inherited.
- (BOOL) readJAXBChildElement: (xmlTextReaderPtr) reader
{
  id __child;
  void *_child_accessor;
  int status, depth;

  if ([super readJAXBChildElement: reader]) {
    return YES;
  }
  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "data", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}data of type {}log-config-resource.");
#endif
    __child = [NEXUS_REST_APINS0LogConfigResource readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}data of type {}log-config-resource.");
#endif

    [self setData: __child];
    return YES;
  } //end "if choice"


  return NO;
}

//documentation inherited.
- (int) readUnknownJAXBChildElement: (xmlTextReaderPtr) reader
{
  return [super readUnknownJAXBChildElement: reader];
}

//documentation inherited.
- (void) readUnknownJAXBAttribute: (xmlTextReaderPtr) reader
{
  [super readUnknownJAXBAttribute: reader];
}

//documentation inherited.
- (void) writeJAXBAttributes: (xmlTextWriterPtr) writer
{
  int status;

  [super writeJAXBAttributes: writer];

}

//documentation inherited.
- (void) writeJAXBValue: (xmlTextWriterPtr) writer
{
  [super writeJAXBValue: writer];
}

/**
 * Method for writing the child elements.
 *
 * @param writer The writer.
 */
- (void) writeJAXBChildElements: (xmlTextWriterPtr) writer
{
  int status;
  id __item;
  NSEnumerator *__enumerator;

  [super writeJAXBChildElements: writer];

  if ([self data]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "data", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}data."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}data...");
#endif
    [[self data] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}data...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}data."];
    }
  }
}
@end /* implementation NEXUS_REST_APINS0LogConfigResourceResponse (JAXB) */

#endif /* DEF_NEXUS_REST_APINS0LogConfigResourceResponse_M */
#ifndef DEF_NEXUS_REST_APINS0GlobalConfigurationResourceResponse_M
#define DEF_NEXUS_REST_APINS0GlobalConfigurationResourceResponse_M

/**
 *  REST Response object for a global configuration request,
 contains the typical 'data' parameter, which is the global
 configuration item requested.
 
 @version $Revision$ $Date$

 */
@implementation NEXUS_REST_APINS0GlobalConfigurationResourceResponse

/**
 * The global configuration details.
 */
- (NEXUS_REST_APINS0GlobalConfigurationResource *) data
{
  return _data;
}

/**
 * The global configuration details.
 */
- (void) setData: (NEXUS_REST_APINS0GlobalConfigurationResource *) newData
{
  [newData retain];
  [_data release];
  _data = newData;
}

- (void) dealloc
{
  [self setData: nil];
  [super dealloc];
}

//documentation inherited.
+ (id<EnunciateXML>) readFromXML: (NSData *) xml
{
  NEXUS_REST_APINS0GlobalConfigurationResourceResponse *_nEXUS_REST_APINS0GlobalConfigurationResourceResponse;
  xmlTextReaderPtr reader = xmlReaderForMemory([xml bytes], [xml length], NULL, NULL, 0);
  if (reader == NULL) {
    [NSException raise: @"XMLReadError"
                 format: @"Error instantiating an XML reader."];
    return nil;
  }

  _nEXUS_REST_APINS0GlobalConfigurationResourceResponse = (NEXUS_REST_APINS0GlobalConfigurationResourceResponse *) [NEXUS_REST_APINS0GlobalConfigurationResourceResponse readXMLElement: reader];
  xmlFreeTextReader(reader); //free the reader
  return _nEXUS_REST_APINS0GlobalConfigurationResourceResponse;
}

//documentation inherited.
- (NSData *) writeToXML
{
  xmlBufferPtr buf;
  xmlTextWriterPtr writer;
  int rc;
  NSData *data;

  buf = xmlBufferCreate();
  if (buf == NULL) {
    [NSException raise: @"XMLWriteError"
                 format: @"Error creating an XML buffer."];
    return nil;
  }

  writer = xmlNewTextWriterMemory(buf, 0);
  if (writer == NULL) {
    xmlBufferFree(buf);
    [NSException raise: @"XMLWriteError"
                 format: @"Error creating an XML writer."];
    return nil;
  }

  rc = xmlTextWriterStartDocument(writer, NULL, "utf-8", NULL);
  if (rc < 0) {
    xmlFreeTextWriter(writer);
    xmlBufferFree(buf);
    [NSException raise: @"XMLWriteError"
                 format: @"Error writing XML start document."];
    return nil;
  }

  NS_DURING
  {
    [self writeXMLElement: writer];
  }
  NS_HANDLER
  {
    xmlFreeTextWriter(writer);
    xmlBufferFree(buf);
    [localException raise];
  }
  NS_ENDHANDLER

  rc = xmlTextWriterEndDocument(writer);
  if (rc < 0) {
    xmlFreeTextWriter(writer);
    xmlBufferFree(buf);
    [NSException raise: @"XMLWriteError"
                 format: @"Error writing XML end document."];
    return nil;
  }

  xmlFreeTextWriter(writer);
  data = [NSData dataWithBytes: buf->content length: buf->use];
  xmlBufferFree(buf);
  return data;
}
@end /* implementation NEXUS_REST_APINS0GlobalConfigurationResourceResponse */

/**
 * Internal, private interface for JAXB reading and writing.
 */
@interface NEXUS_REST_APINS0GlobalConfigurationResourceResponse (JAXB) <JAXBReading, JAXBWriting, JAXBType, JAXBElement>

@end /*interface NEXUS_REST_APINS0GlobalConfigurationResourceResponse (JAXB)*/

/**
 * Internal, private implementation for JAXB reading and writing.
 */
@implementation NEXUS_REST_APINS0GlobalConfigurationResourceResponse (JAXB)

/**
 * Read an instance of NEXUS_REST_APINS0GlobalConfigurationResourceResponse from an XML reader.
 *
 * @param reader The reader.
 * @return An instance of NEXUS_REST_APINS0GlobalConfigurationResourceResponse defined by the XML reader.
 */
+ (id<JAXBType>) readXMLType: (xmlTextReaderPtr) reader
{
  NEXUS_REST_APINS0GlobalConfigurationResourceResponse *_nEXUS_REST_APINS0GlobalConfigurationResourceResponse = [[NEXUS_REST_APINS0GlobalConfigurationResourceResponse alloc] init];
  NS_DURING
  {
    [_nEXUS_REST_APINS0GlobalConfigurationResourceResponse initWithReader: reader];
  }
  NS_HANDLER
  {
    [_nEXUS_REST_APINS0GlobalConfigurationResourceResponse dealloc];
    _nEXUS_REST_APINS0GlobalConfigurationResourceResponse = nil;
    [localException raise];
  }
  NS_ENDHANDLER

  [_nEXUS_REST_APINS0GlobalConfigurationResourceResponse autorelease];
  return _nEXUS_REST_APINS0GlobalConfigurationResourceResponse;
}

/**
 * Initialize this instance of NEXUS_REST_APINS0GlobalConfigurationResourceResponse according to
 * the XML being read from the reader.
 *
 * @param reader The reader.
 */
- (id) initWithReader: (xmlTextReaderPtr) reader
{
  return [super initWithReader: reader];
}

/**
 * Write the XML for this instance of NEXUS_REST_APINS0GlobalConfigurationResourceResponse to the writer.
 * Note that since we're only writing the XML type,
 * No start/end element will be written.
 *
 * @param reader The reader.
 */
- (void) writeXMLType: (xmlTextWriterPtr) writer
{
  [super writeXMLType:writer];
}

/**
 * Reads a NEXUS_REST_APINS0GlobalConfigurationResourceResponse from an XML reader. The element to be read is
 * "global-settings".
 *
 * @param reader The XML reader.
 * @return The NEXUS_REST_APINS0GlobalConfigurationResourceResponse.
 */
+ (id<JAXBElement>) readXMLElement: (xmlTextReaderPtr) reader {
  int status;
  NEXUS_REST_APINS0GlobalConfigurationResourceResponse *_globalConfigurationResourceResponse = nil;

  if (xmlTextReaderNodeType(reader) != XML_READER_TYPE_ELEMENT) {
    status = xmlTextReaderAdvanceToNextStartOrEndElement(reader);
    if (status < 1) {
      [NSException raise: @"XMLReadError"
                   format: @"Error advancing the reader to start element global-settings."];
    }
  }

  if (xmlStrcmp(BAD_CAST "global-settings", xmlTextReaderConstLocalName(reader)) == 0
      && xmlTextReaderConstNamespaceUri(reader) == NULL) {
#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read root element {}global-settings.");
#endif
    _globalConfigurationResourceResponse = (NEXUS_REST_APINS0GlobalConfigurationResourceResponse *)[NEXUS_REST_APINS0GlobalConfigurationResourceResponse readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"Successfully read root element {}global-settings.");
#endif
  }
  else {
    if (xmlTextReaderConstNamespaceUri(reader) == NULL) {
      [NSException raise: @"XMLReadError"
                   format: @"Unable to read NEXUS_REST_APINS0GlobalConfigurationResourceResponse. Expected element global-settings. Current element: {}%s", xmlTextReaderConstLocalName(reader)];
    }
    else {
      [NSException raise: @"XMLReadError"
                   format: @"Unable to read NEXUS_REST_APINS0GlobalConfigurationResourceResponse. Expected element global-settings. Current element: {%s}%s\n", xmlTextReaderConstNamespaceUri(reader), xmlTextReaderConstLocalName(reader)];
    }
  }

  return _globalConfigurationResourceResponse;
}

/**
 * Writes this NEXUS_REST_APINS0GlobalConfigurationResourceResponse to XML under element name "global-settings".
 * The namespace declarations for the element will be written.
 *
 * @param writer The XML writer.
 * @param _globalConfigurationResourceResponse The GlobalConfigurationResourceResponse to write.
 * @return 1 if successful, 0 otherwise.
 */
- (void) writeXMLElement: (xmlTextWriterPtr) writer
{
  [self writeXMLElement: writer writeNamespaces: YES];
}

/**
 * Writes this NEXUS_REST_APINS0GlobalConfigurationResourceResponse to an XML writer.
 *
 * @param writer The writer.
 * @param writeNs Whether to write the namespaces for this element to the xml writer.
 */
- (void) writeXMLElement: (xmlTextWriterPtr) writer writeNamespaces: (BOOL) writeNs
{
  int rc = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "global-settings", NULL);
  if (rc < 0) {
    [NSException raise: @"XMLWriteError"
                 format: @"Error writing start element {}global-settings. XML writer status: %i\n", rc];
  }

#if DEBUG_ENUNCIATE > 1
  NSLog(@"writing type {}globalConfigurationResourceResponse for root element {}global-settings...");
#endif
  [self writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
  NSLog(@"successfully wrote type {}globalConfigurationResourceResponse for root element {}global-settings...");
#endif
  rc = xmlTextWriterEndElement(writer);
  if (rc < 0) {
    [NSException raise: @"XMLWriteError"
                 format: @"Error writing end element {}global-settings. XML writer status: %i\n", rc];
  }
}

//documentation inherited.
- (BOOL) readJAXBAttribute: (xmlTextReaderPtr) reader
{
  void *_child_accessor;

  if ([super readJAXBAttribute: reader]) {
    return YES;
  }

  return NO;
}

//documentation inherited.
- (BOOL) readJAXBValue: (xmlTextReaderPtr) reader
{
  return [super readJAXBValue: reader];
}

//documentation inherited.
- (BOOL) readJAXBChildElement: (xmlTextReaderPtr) reader
{
  id __child;
  void *_child_accessor;
  int status, depth;

  if ([super readJAXBChildElement: reader]) {
    return YES;
  }
  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "data", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}data of type {}global-settings-item.");
#endif
    __child = [NEXUS_REST_APINS0GlobalConfigurationResource readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}data of type {}global-settings-item.");
#endif

    [self setData: __child];
    return YES;
  } //end "if choice"


  return NO;
}

//documentation inherited.
- (int) readUnknownJAXBChildElement: (xmlTextReaderPtr) reader
{
  return [super readUnknownJAXBChildElement: reader];
}

//documentation inherited.
- (void) readUnknownJAXBAttribute: (xmlTextReaderPtr) reader
{
  [super readUnknownJAXBAttribute: reader];
}

//documentation inherited.
- (void) writeJAXBAttributes: (xmlTextWriterPtr) writer
{
  int status;

  [super writeJAXBAttributes: writer];

}

//documentation inherited.
- (void) writeJAXBValue: (xmlTextWriterPtr) writer
{
  [super writeJAXBValue: writer];
}

/**
 * Method for writing the child elements.
 *
 * @param writer The writer.
 */
- (void) writeJAXBChildElements: (xmlTextWriterPtr) writer
{
  int status;
  id __item;
  NSEnumerator *__enumerator;

  [super writeJAXBChildElements: writer];

  if ([self data]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "data", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}data."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}data...");
#endif
    [[self data] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}data...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}data."];
    }
  }
}
@end /* implementation NEXUS_REST_APINS0GlobalConfigurationResourceResponse (JAXB) */

#endif /* DEF_NEXUS_REST_APINS0GlobalConfigurationResourceResponse_M */
#ifndef DEF_NEXUS_REST_APINS0ContentListResourceResponse_M
#define DEF_NEXUS_REST_APINS0ContentListResourceResponse_M

/**
 *  REST Response object for a content resource request, contains
 the typical 'data' parameter, which is a list of the content
 items requested.
 
 @version $Revision$ $Date$

 */
@implementation NEXUS_REST_APINS0ContentListResourceResponse

/**
 * Field data.
 */
- (NSArray *) data
{
  return _data;
}

/**
 * Field data.
 */
- (void) setData: (NSArray *) newData
{
  [newData retain];
  [_data release];
  _data = newData;
}

- (void) dealloc
{
  [self setData: nil];
  [super dealloc];
}

//documentation inherited.
+ (id<EnunciateXML>) readFromXML: (NSData *) xml
{
  NEXUS_REST_APINS0ContentListResourceResponse *_nEXUS_REST_APINS0ContentListResourceResponse;
  xmlTextReaderPtr reader = xmlReaderForMemory([xml bytes], [xml length], NULL, NULL, 0);
  if (reader == NULL) {
    [NSException raise: @"XMLReadError"
                 format: @"Error instantiating an XML reader."];
    return nil;
  }

  _nEXUS_REST_APINS0ContentListResourceResponse = (NEXUS_REST_APINS0ContentListResourceResponse *) [NEXUS_REST_APINS0ContentListResourceResponse readXMLElement: reader];
  xmlFreeTextReader(reader); //free the reader
  return _nEXUS_REST_APINS0ContentListResourceResponse;
}

//documentation inherited.
- (NSData *) writeToXML
{
  xmlBufferPtr buf;
  xmlTextWriterPtr writer;
  int rc;
  NSData *data;

  buf = xmlBufferCreate();
  if (buf == NULL) {
    [NSException raise: @"XMLWriteError"
                 format: @"Error creating an XML buffer."];
    return nil;
  }

  writer = xmlNewTextWriterMemory(buf, 0);
  if (writer == NULL) {
    xmlBufferFree(buf);
    [NSException raise: @"XMLWriteError"
                 format: @"Error creating an XML writer."];
    return nil;
  }

  rc = xmlTextWriterStartDocument(writer, NULL, "utf-8", NULL);
  if (rc < 0) {
    xmlFreeTextWriter(writer);
    xmlBufferFree(buf);
    [NSException raise: @"XMLWriteError"
                 format: @"Error writing XML start document."];
    return nil;
  }

  NS_DURING
  {
    [self writeXMLElement: writer];
  }
  NS_HANDLER
  {
    xmlFreeTextWriter(writer);
    xmlBufferFree(buf);
    [localException raise];
  }
  NS_ENDHANDLER

  rc = xmlTextWriterEndDocument(writer);
  if (rc < 0) {
    xmlFreeTextWriter(writer);
    xmlBufferFree(buf);
    [NSException raise: @"XMLWriteError"
                 format: @"Error writing XML end document."];
    return nil;
  }

  xmlFreeTextWriter(writer);
  data = [NSData dataWithBytes: buf->content length: buf->use];
  xmlBufferFree(buf);
  return data;
}
@end /* implementation NEXUS_REST_APINS0ContentListResourceResponse */

/**
 * Internal, private interface for JAXB reading and writing.
 */
@interface NEXUS_REST_APINS0ContentListResourceResponse (JAXB) <JAXBReading, JAXBWriting, JAXBType, JAXBElement>

@end /*interface NEXUS_REST_APINS0ContentListResourceResponse (JAXB)*/

/**
 * Internal, private implementation for JAXB reading and writing.
 */
@implementation NEXUS_REST_APINS0ContentListResourceResponse (JAXB)

/**
 * Read an instance of NEXUS_REST_APINS0ContentListResourceResponse from an XML reader.
 *
 * @param reader The reader.
 * @return An instance of NEXUS_REST_APINS0ContentListResourceResponse defined by the XML reader.
 */
+ (id<JAXBType>) readXMLType: (xmlTextReaderPtr) reader
{
  NEXUS_REST_APINS0ContentListResourceResponse *_nEXUS_REST_APINS0ContentListResourceResponse = [[NEXUS_REST_APINS0ContentListResourceResponse alloc] init];
  NS_DURING
  {
    [_nEXUS_REST_APINS0ContentListResourceResponse initWithReader: reader];
  }
  NS_HANDLER
  {
    [_nEXUS_REST_APINS0ContentListResourceResponse dealloc];
    _nEXUS_REST_APINS0ContentListResourceResponse = nil;
    [localException raise];
  }
  NS_ENDHANDLER

  [_nEXUS_REST_APINS0ContentListResourceResponse autorelease];
  return _nEXUS_REST_APINS0ContentListResourceResponse;
}

/**
 * Initialize this instance of NEXUS_REST_APINS0ContentListResourceResponse according to
 * the XML being read from the reader.
 *
 * @param reader The reader.
 */
- (id) initWithReader: (xmlTextReaderPtr) reader
{
  return [super initWithReader: reader];
}

/**
 * Write the XML for this instance of NEXUS_REST_APINS0ContentListResourceResponse to the writer.
 * Note that since we're only writing the XML type,
 * No start/end element will be written.
 *
 * @param reader The reader.
 */
- (void) writeXMLType: (xmlTextWriterPtr) writer
{
  [super writeXMLType:writer];
}

/**
 * Reads a NEXUS_REST_APINS0ContentListResourceResponse from an XML reader. The element to be read is
 * "content".
 *
 * @param reader The XML reader.
 * @return The NEXUS_REST_APINS0ContentListResourceResponse.
 */
+ (id<JAXBElement>) readXMLElement: (xmlTextReaderPtr) reader {
  int status;
  NEXUS_REST_APINS0ContentListResourceResponse *_contentListResourceResponse = nil;

  if (xmlTextReaderNodeType(reader) != XML_READER_TYPE_ELEMENT) {
    status = xmlTextReaderAdvanceToNextStartOrEndElement(reader);
    if (status < 1) {
      [NSException raise: @"XMLReadError"
                   format: @"Error advancing the reader to start element content."];
    }
  }

  if (xmlStrcmp(BAD_CAST "content", xmlTextReaderConstLocalName(reader)) == 0
      && xmlTextReaderConstNamespaceUri(reader) == NULL) {
#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read root element {}content.");
#endif
    _contentListResourceResponse = (NEXUS_REST_APINS0ContentListResourceResponse *)[NEXUS_REST_APINS0ContentListResourceResponse readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"Successfully read root element {}content.");
#endif
  }
  else {
    if (xmlTextReaderConstNamespaceUri(reader) == NULL) {
      [NSException raise: @"XMLReadError"
                   format: @"Unable to read NEXUS_REST_APINS0ContentListResourceResponse. Expected element content. Current element: {}%s", xmlTextReaderConstLocalName(reader)];
    }
    else {
      [NSException raise: @"XMLReadError"
                   format: @"Unable to read NEXUS_REST_APINS0ContentListResourceResponse. Expected element content. Current element: {%s}%s\n", xmlTextReaderConstNamespaceUri(reader), xmlTextReaderConstLocalName(reader)];
    }
  }

  return _contentListResourceResponse;
}

/**
 * Writes this NEXUS_REST_APINS0ContentListResourceResponse to XML under element name "content".
 * The namespace declarations for the element will be written.
 *
 * @param writer The XML writer.
 * @param _contentListResourceResponse The ContentListResourceResponse to write.
 * @return 1 if successful, 0 otherwise.
 */
- (void) writeXMLElement: (xmlTextWriterPtr) writer
{
  [self writeXMLElement: writer writeNamespaces: YES];
}

/**
 * Writes this NEXUS_REST_APINS0ContentListResourceResponse to an XML writer.
 *
 * @param writer The writer.
 * @param writeNs Whether to write the namespaces for this element to the xml writer.
 */
- (void) writeXMLElement: (xmlTextWriterPtr) writer writeNamespaces: (BOOL) writeNs
{
  int rc = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "content", NULL);
  if (rc < 0) {
    [NSException raise: @"XMLWriteError"
                 format: @"Error writing start element {}content. XML writer status: %i\n", rc];
  }

#if DEBUG_ENUNCIATE > 1
  NSLog(@"writing type {}contentListResourceResponse for root element {}content...");
#endif
  [self writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
  NSLog(@"successfully wrote type {}contentListResourceResponse for root element {}content...");
#endif
  rc = xmlTextWriterEndElement(writer);
  if (rc < 0) {
    [NSException raise: @"XMLWriteError"
                 format: @"Error writing end element {}content. XML writer status: %i\n", rc];
  }
}

//documentation inherited.
- (BOOL) readJAXBAttribute: (xmlTextReaderPtr) reader
{
  void *_child_accessor;

  if ([super readJAXBAttribute: reader]) {
    return YES;
  }

  return NO;
}

//documentation inherited.
- (BOOL) readJAXBValue: (xmlTextReaderPtr) reader
{
  return [super readJAXBValue: reader];
}

//documentation inherited.
- (BOOL) readJAXBChildElement: (xmlTextReaderPtr) reader
{
  id __child;
  void *_child_accessor;
  int status, depth;

  if ([super readJAXBChildElement: reader]) {
    return YES;
  }
  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "data", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

    if (xmlTextReaderIsEmptyElement(reader) == 0) {
#if DEBUG_ENUNCIATE > 1
      NSLog(@"Unwrapping wrapper element {}data...");
#endif
      //start wrapper element "{}data"
      depth = xmlTextReaderDepth(reader);
      status = xmlTextReaderAdvanceToNextStartOrEndElement(reader);
      while (xmlTextReaderDepth(reader) > depth) {
        if (status < 1) {
          //panic: XML read error.
          [self dealloc];
          [NSException raise: @"XMLReadError"
                       format: @"Failure to advance to next wrapped child element."];
        }
  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "content-item", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}content-item of type {}content-list-resource.");
#endif

    __child = [NEXUS_REST_APINS0ContentListResource readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}content-item of type {}content-list-resource.");
#endif

    if ([self data]) {
      [self setData: [[self data] arrayByAddingObject: __child]];
    }
    else {
      [self setData: [NSArray arrayWithObject: __child]];
    }
    continue; //continue "while in wrapper element" loop
  } //end "if choice"

        status = xmlTextReaderAdvanceToNextStartOrEndElement(reader);
#if DEBUG_ENUNCIATE > 1
        NSLog(@"successfully unwrapped wrapper element {}data...");
#endif
      } // end "while in wrapper element" loop

      if (status < 1) {
        //panic: XML read error.
        [self dealloc];
        [NSException raise: @"XMLReadError"
                     format: @"Failure to advance to end wrapper element."];
      }
      else {
        //end wrapper element "{}data"
        status = xmlTextReaderAdvanceToNextStartOrEndElement(reader);
      }
    } //end "if empty element" clause
    else {
      __child = [NSArray array];
      [self setData: (NSArray*) __child];
    }

    return YES;
  } // end "if wrapper element" clause

  return NO;
}

//documentation inherited.
- (int) readUnknownJAXBChildElement: (xmlTextReaderPtr) reader
{
  return [super readUnknownJAXBChildElement: reader];
}

//documentation inherited.
- (void) readUnknownJAXBAttribute: (xmlTextReaderPtr) reader
{
  [super readUnknownJAXBAttribute: reader];
}

//documentation inherited.
- (void) writeJAXBAttributes: (xmlTextWriterPtr) writer
{
  int status;

  [super writeJAXBAttributes: writer];

}

//documentation inherited.
- (void) writeJAXBValue: (xmlTextWriterPtr) writer
{
  [super writeJAXBValue: writer];
}

/**
 * Method for writing the child elements.
 *
 * @param writer The writer.
 */
- (void) writeJAXBChildElements: (xmlTextWriterPtr) writer
{
  int status;
  id __item;
  NSEnumerator *__enumerator;

  [super writeJAXBChildElements: writer];

  if ([self data]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "data", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start wrapper element {}data."];
    }
    __enumerator = [[self data] objectEnumerator];

    while ( (__item = [__enumerator nextObject]) ) {
      status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "content-item", NULL);
      if (status < 0) {
        [NSException raise: @"XMLWriteError"
                     format: @"Error writing start child element {}content-item."];
      }

#if DEBUG_ENUNCIATE > 1
      NSLog(@"writing element {}content-item...");
#endif
      [__item writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
      NSLog(@"successfully wrote element {}content-item...");
#endif

      status = xmlTextWriterEndElement(writer);
      if (status < 0) {
        [NSException raise: @"XMLWriteError"
                     format: @"Error writing end child element {}content-item."];
      }
    } //end item iterator.

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end wrapper element {}data."];
    }
  }
}
@end /* implementation NEXUS_REST_APINS0ContentListResourceResponse (JAXB) */

#endif /* DEF_NEXUS_REST_APINS0ContentListResourceResponse_M */
#ifndef DEF_NEXUS_REST_APINS0ContentListDescribeResourceResponse_M
#define DEF_NEXUS_REST_APINS0ContentListDescribeResourceResponse_M

/**
 *  REST Response object for a content resource request, contains
 the typical 'data' parameter, which is a list of the content
 items requested.
 
 @version $Revision$ $Date$

 */
@implementation NEXUS_REST_APINS0ContentListDescribeResourceResponse

/**
 * List of describe items, that will contain useful information
about the retrieved data.
 */
- (NEXUS_REST_APINS0ContentListDescribeResource *) data
{
  return _data;
}

/**
 * List of describe items, that will contain useful information
about the retrieved data.
 */
- (void) setData: (NEXUS_REST_APINS0ContentListDescribeResource *) newData
{
  [newData retain];
  [_data release];
  _data = newData;
}

- (void) dealloc
{
  [self setData: nil];
  [super dealloc];
}

//documentation inherited.
+ (id<EnunciateXML>) readFromXML: (NSData *) xml
{
  NEXUS_REST_APINS0ContentListDescribeResourceResponse *_nEXUS_REST_APINS0ContentListDescribeResourceResponse;
  xmlTextReaderPtr reader = xmlReaderForMemory([xml bytes], [xml length], NULL, NULL, 0);
  if (reader == NULL) {
    [NSException raise: @"XMLReadError"
                 format: @"Error instantiating an XML reader."];
    return nil;
  }

  _nEXUS_REST_APINS0ContentListDescribeResourceResponse = (NEXUS_REST_APINS0ContentListDescribeResourceResponse *) [NEXUS_REST_APINS0ContentListDescribeResourceResponse readXMLElement: reader];
  xmlFreeTextReader(reader); //free the reader
  return _nEXUS_REST_APINS0ContentListDescribeResourceResponse;
}

//documentation inherited.
- (NSData *) writeToXML
{
  xmlBufferPtr buf;
  xmlTextWriterPtr writer;
  int rc;
  NSData *data;

  buf = xmlBufferCreate();
  if (buf == NULL) {
    [NSException raise: @"XMLWriteError"
                 format: @"Error creating an XML buffer."];
    return nil;
  }

  writer = xmlNewTextWriterMemory(buf, 0);
  if (writer == NULL) {
    xmlBufferFree(buf);
    [NSException raise: @"XMLWriteError"
                 format: @"Error creating an XML writer."];
    return nil;
  }

  rc = xmlTextWriterStartDocument(writer, NULL, "utf-8", NULL);
  if (rc < 0) {
    xmlFreeTextWriter(writer);
    xmlBufferFree(buf);
    [NSException raise: @"XMLWriteError"
                 format: @"Error writing XML start document."];
    return nil;
  }

  NS_DURING
  {
    [self writeXMLElement: writer];
  }
  NS_HANDLER
  {
    xmlFreeTextWriter(writer);
    xmlBufferFree(buf);
    [localException raise];
  }
  NS_ENDHANDLER

  rc = xmlTextWriterEndDocument(writer);
  if (rc < 0) {
    xmlFreeTextWriter(writer);
    xmlBufferFree(buf);
    [NSException raise: @"XMLWriteError"
                 format: @"Error writing XML end document."];
    return nil;
  }

  xmlFreeTextWriter(writer);
  data = [NSData dataWithBytes: buf->content length: buf->use];
  xmlBufferFree(buf);
  return data;
}
@end /* implementation NEXUS_REST_APINS0ContentListDescribeResourceResponse */

/**
 * Internal, private interface for JAXB reading and writing.
 */
@interface NEXUS_REST_APINS0ContentListDescribeResourceResponse (JAXB) <JAXBReading, JAXBWriting, JAXBType, JAXBElement>

@end /*interface NEXUS_REST_APINS0ContentListDescribeResourceResponse (JAXB)*/

/**
 * Internal, private implementation for JAXB reading and writing.
 */
@implementation NEXUS_REST_APINS0ContentListDescribeResourceResponse (JAXB)

/**
 * Read an instance of NEXUS_REST_APINS0ContentListDescribeResourceResponse from an XML reader.
 *
 * @param reader The reader.
 * @return An instance of NEXUS_REST_APINS0ContentListDescribeResourceResponse defined by the XML reader.
 */
+ (id<JAXBType>) readXMLType: (xmlTextReaderPtr) reader
{
  NEXUS_REST_APINS0ContentListDescribeResourceResponse *_nEXUS_REST_APINS0ContentListDescribeResourceResponse = [[NEXUS_REST_APINS0ContentListDescribeResourceResponse alloc] init];
  NS_DURING
  {
    [_nEXUS_REST_APINS0ContentListDescribeResourceResponse initWithReader: reader];
  }
  NS_HANDLER
  {
    [_nEXUS_REST_APINS0ContentListDescribeResourceResponse dealloc];
    _nEXUS_REST_APINS0ContentListDescribeResourceResponse = nil;
    [localException raise];
  }
  NS_ENDHANDLER

  [_nEXUS_REST_APINS0ContentListDescribeResourceResponse autorelease];
  return _nEXUS_REST_APINS0ContentListDescribeResourceResponse;
}

/**
 * Initialize this instance of NEXUS_REST_APINS0ContentListDescribeResourceResponse according to
 * the XML being read from the reader.
 *
 * @param reader The reader.
 */
- (id) initWithReader: (xmlTextReaderPtr) reader
{
  return [super initWithReader: reader];
}

/**
 * Write the XML for this instance of NEXUS_REST_APINS0ContentListDescribeResourceResponse to the writer.
 * Note that since we're only writing the XML type,
 * No start/end element will be written.
 *
 * @param reader The reader.
 */
- (void) writeXMLType: (xmlTextWriterPtr) writer
{
  [super writeXMLType:writer];
}

/**
 * Reads a NEXUS_REST_APINS0ContentListDescribeResourceResponse from an XML reader. The element to be read is
 * "contentDescribe".
 *
 * @param reader The XML reader.
 * @return The NEXUS_REST_APINS0ContentListDescribeResourceResponse.
 */
+ (id<JAXBElement>) readXMLElement: (xmlTextReaderPtr) reader {
  int status;
  NEXUS_REST_APINS0ContentListDescribeResourceResponse *_contentListDescribeResourceResponse = nil;

  if (xmlTextReaderNodeType(reader) != XML_READER_TYPE_ELEMENT) {
    status = xmlTextReaderAdvanceToNextStartOrEndElement(reader);
    if (status < 1) {
      [NSException raise: @"XMLReadError"
                   format: @"Error advancing the reader to start element contentDescribe."];
    }
  }

  if (xmlStrcmp(BAD_CAST "contentDescribe", xmlTextReaderConstLocalName(reader)) == 0
      && xmlTextReaderConstNamespaceUri(reader) == NULL) {
#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read root element {}contentDescribe.");
#endif
    _contentListDescribeResourceResponse = (NEXUS_REST_APINS0ContentListDescribeResourceResponse *)[NEXUS_REST_APINS0ContentListDescribeResourceResponse readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"Successfully read root element {}contentDescribe.");
#endif
  }
  else {
    if (xmlTextReaderConstNamespaceUri(reader) == NULL) {
      [NSException raise: @"XMLReadError"
                   format: @"Unable to read NEXUS_REST_APINS0ContentListDescribeResourceResponse. Expected element contentDescribe. Current element: {}%s", xmlTextReaderConstLocalName(reader)];
    }
    else {
      [NSException raise: @"XMLReadError"
                   format: @"Unable to read NEXUS_REST_APINS0ContentListDescribeResourceResponse. Expected element contentDescribe. Current element: {%s}%s\n", xmlTextReaderConstNamespaceUri(reader), xmlTextReaderConstLocalName(reader)];
    }
  }

  return _contentListDescribeResourceResponse;
}

/**
 * Writes this NEXUS_REST_APINS0ContentListDescribeResourceResponse to XML under element name "contentDescribe".
 * The namespace declarations for the element will be written.
 *
 * @param writer The XML writer.
 * @param _contentListDescribeResourceResponse The ContentListDescribeResourceResponse to write.
 * @return 1 if successful, 0 otherwise.
 */
- (void) writeXMLElement: (xmlTextWriterPtr) writer
{
  [self writeXMLElement: writer writeNamespaces: YES];
}

/**
 * Writes this NEXUS_REST_APINS0ContentListDescribeResourceResponse to an XML writer.
 *
 * @param writer The writer.
 * @param writeNs Whether to write the namespaces for this element to the xml writer.
 */
- (void) writeXMLElement: (xmlTextWriterPtr) writer writeNamespaces: (BOOL) writeNs
{
  int rc = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "contentDescribe", NULL);
  if (rc < 0) {
    [NSException raise: @"XMLWriteError"
                 format: @"Error writing start element {}contentDescribe. XML writer status: %i\n", rc];
  }

#if DEBUG_ENUNCIATE > 1
  NSLog(@"writing type {}contentListDescribeResourceResponse for root element {}contentDescribe...");
#endif
  [self writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
  NSLog(@"successfully wrote type {}contentListDescribeResourceResponse for root element {}contentDescribe...");
#endif
  rc = xmlTextWriterEndElement(writer);
  if (rc < 0) {
    [NSException raise: @"XMLWriteError"
                 format: @"Error writing end element {}contentDescribe. XML writer status: %i\n", rc];
  }
}

//documentation inherited.
- (BOOL) readJAXBAttribute: (xmlTextReaderPtr) reader
{
  void *_child_accessor;

  if ([super readJAXBAttribute: reader]) {
    return YES;
  }

  return NO;
}

//documentation inherited.
- (BOOL) readJAXBValue: (xmlTextReaderPtr) reader
{
  return [super readJAXBValue: reader];
}

//documentation inherited.
- (BOOL) readJAXBChildElement: (xmlTextReaderPtr) reader
{
  id __child;
  void *_child_accessor;
  int status, depth;

  if ([super readJAXBChildElement: reader]) {
    return YES;
  }
  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "data", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}data of type {}content-list-describe-resource.");
#endif
    __child = [NEXUS_REST_APINS0ContentListDescribeResource readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}data of type {}content-list-describe-resource.");
#endif

    [self setData: __child];
    return YES;
  } //end "if choice"


  return NO;
}

//documentation inherited.
- (int) readUnknownJAXBChildElement: (xmlTextReaderPtr) reader
{
  return [super readUnknownJAXBChildElement: reader];
}

//documentation inherited.
- (void) readUnknownJAXBAttribute: (xmlTextReaderPtr) reader
{
  [super readUnknownJAXBAttribute: reader];
}

//documentation inherited.
- (void) writeJAXBAttributes: (xmlTextWriterPtr) writer
{
  int status;

  [super writeJAXBAttributes: writer];

}

//documentation inherited.
- (void) writeJAXBValue: (xmlTextWriterPtr) writer
{
  [super writeJAXBValue: writer];
}

/**
 * Method for writing the child elements.
 *
 * @param writer The writer.
 */
- (void) writeJAXBChildElements: (xmlTextWriterPtr) writer
{
  int status;
  id __item;
  NSEnumerator *__enumerator;

  [super writeJAXBChildElements: writer];

  if ([self data]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "data", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}data."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}data...");
#endif
    [[self data] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}data...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}data."];
    }
  }
}
@end /* implementation NEXUS_REST_APINS0ContentListDescribeResourceResponse (JAXB) */

#endif /* DEF_NEXUS_REST_APINS0ContentListDescribeResourceResponse_M */
#ifndef DEF_NEXUS_REST_APINS0ConfigurationsListResourceResponse_M
#define DEF_NEXUS_REST_APINS0ConfigurationsListResourceResponse_M

/**
 *  REST Response object for a list of Nexus configuration objects,
 contains the typical 'data' parameter, which is a list of the
 configuration items.
 
 @version $Revision$ $Date$

 */
@implementation NEXUS_REST_APINS0ConfigurationsListResourceResponse

/**
 * Field data.
 */
- (NSArray *) data
{
  return _data;
}

/**
 * Field data.
 */
- (void) setData: (NSArray *) newData
{
  [newData retain];
  [_data release];
  _data = newData;
}

- (void) dealloc
{
  [self setData: nil];
  [super dealloc];
}

//documentation inherited.
+ (id<EnunciateXML>) readFromXML: (NSData *) xml
{
  NEXUS_REST_APINS0ConfigurationsListResourceResponse *_nEXUS_REST_APINS0ConfigurationsListResourceResponse;
  xmlTextReaderPtr reader = xmlReaderForMemory([xml bytes], [xml length], NULL, NULL, 0);
  if (reader == NULL) {
    [NSException raise: @"XMLReadError"
                 format: @"Error instantiating an XML reader."];
    return nil;
  }

  _nEXUS_REST_APINS0ConfigurationsListResourceResponse = (NEXUS_REST_APINS0ConfigurationsListResourceResponse *) [NEXUS_REST_APINS0ConfigurationsListResourceResponse readXMLElement: reader];
  xmlFreeTextReader(reader); //free the reader
  return _nEXUS_REST_APINS0ConfigurationsListResourceResponse;
}

//documentation inherited.
- (NSData *) writeToXML
{
  xmlBufferPtr buf;
  xmlTextWriterPtr writer;
  int rc;
  NSData *data;

  buf = xmlBufferCreate();
  if (buf == NULL) {
    [NSException raise: @"XMLWriteError"
                 format: @"Error creating an XML buffer."];
    return nil;
  }

  writer = xmlNewTextWriterMemory(buf, 0);
  if (writer == NULL) {
    xmlBufferFree(buf);
    [NSException raise: @"XMLWriteError"
                 format: @"Error creating an XML writer."];
    return nil;
  }

  rc = xmlTextWriterStartDocument(writer, NULL, "utf-8", NULL);
  if (rc < 0) {
    xmlFreeTextWriter(writer);
    xmlBufferFree(buf);
    [NSException raise: @"XMLWriteError"
                 format: @"Error writing XML start document."];
    return nil;
  }

  NS_DURING
  {
    [self writeXMLElement: writer];
  }
  NS_HANDLER
  {
    xmlFreeTextWriter(writer);
    xmlBufferFree(buf);
    [localException raise];
  }
  NS_ENDHANDLER

  rc = xmlTextWriterEndDocument(writer);
  if (rc < 0) {
    xmlFreeTextWriter(writer);
    xmlBufferFree(buf);
    [NSException raise: @"XMLWriteError"
                 format: @"Error writing XML end document."];
    return nil;
  }

  xmlFreeTextWriter(writer);
  data = [NSData dataWithBytes: buf->content length: buf->use];
  xmlBufferFree(buf);
  return data;
}
@end /* implementation NEXUS_REST_APINS0ConfigurationsListResourceResponse */

/**
 * Internal, private interface for JAXB reading and writing.
 */
@interface NEXUS_REST_APINS0ConfigurationsListResourceResponse (JAXB) <JAXBReading, JAXBWriting, JAXBType, JAXBElement>

@end /*interface NEXUS_REST_APINS0ConfigurationsListResourceResponse (JAXB)*/

/**
 * Internal, private implementation for JAXB reading and writing.
 */
@implementation NEXUS_REST_APINS0ConfigurationsListResourceResponse (JAXB)

/**
 * Read an instance of NEXUS_REST_APINS0ConfigurationsListResourceResponse from an XML reader.
 *
 * @param reader The reader.
 * @return An instance of NEXUS_REST_APINS0ConfigurationsListResourceResponse defined by the XML reader.
 */
+ (id<JAXBType>) readXMLType: (xmlTextReaderPtr) reader
{
  NEXUS_REST_APINS0ConfigurationsListResourceResponse *_nEXUS_REST_APINS0ConfigurationsListResourceResponse = [[NEXUS_REST_APINS0ConfigurationsListResourceResponse alloc] init];
  NS_DURING
  {
    [_nEXUS_REST_APINS0ConfigurationsListResourceResponse initWithReader: reader];
  }
  NS_HANDLER
  {
    [_nEXUS_REST_APINS0ConfigurationsListResourceResponse dealloc];
    _nEXUS_REST_APINS0ConfigurationsListResourceResponse = nil;
    [localException raise];
  }
  NS_ENDHANDLER

  [_nEXUS_REST_APINS0ConfigurationsListResourceResponse autorelease];
  return _nEXUS_REST_APINS0ConfigurationsListResourceResponse;
}

/**
 * Initialize this instance of NEXUS_REST_APINS0ConfigurationsListResourceResponse according to
 * the XML being read from the reader.
 *
 * @param reader The reader.
 */
- (id) initWithReader: (xmlTextReaderPtr) reader
{
  return [super initWithReader: reader];
}

/**
 * Write the XML for this instance of NEXUS_REST_APINS0ConfigurationsListResourceResponse to the writer.
 * Note that since we're only writing the XML type,
 * No start/end element will be written.
 *
 * @param reader The reader.
 */
- (void) writeXMLType: (xmlTextWriterPtr) writer
{
  [super writeXMLType:writer];
}

/**
 * Reads a NEXUS_REST_APINS0ConfigurationsListResourceResponse from an XML reader. The element to be read is
 * "configs-list".
 *
 * @param reader The XML reader.
 * @return The NEXUS_REST_APINS0ConfigurationsListResourceResponse.
 */
+ (id<JAXBElement>) readXMLElement: (xmlTextReaderPtr) reader {
  int status;
  NEXUS_REST_APINS0ConfigurationsListResourceResponse *_configurationsListResourceResponse = nil;

  if (xmlTextReaderNodeType(reader) != XML_READER_TYPE_ELEMENT) {
    status = xmlTextReaderAdvanceToNextStartOrEndElement(reader);
    if (status < 1) {
      [NSException raise: @"XMLReadError"
                   format: @"Error advancing the reader to start element configs-list."];
    }
  }

  if (xmlStrcmp(BAD_CAST "configs-list", xmlTextReaderConstLocalName(reader)) == 0
      && xmlTextReaderConstNamespaceUri(reader) == NULL) {
#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read root element {}configs-list.");
#endif
    _configurationsListResourceResponse = (NEXUS_REST_APINS0ConfigurationsListResourceResponse *)[NEXUS_REST_APINS0ConfigurationsListResourceResponse readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"Successfully read root element {}configs-list.");
#endif
  }
  else {
    if (xmlTextReaderConstNamespaceUri(reader) == NULL) {
      [NSException raise: @"XMLReadError"
                   format: @"Unable to read NEXUS_REST_APINS0ConfigurationsListResourceResponse. Expected element configs-list. Current element: {}%s", xmlTextReaderConstLocalName(reader)];
    }
    else {
      [NSException raise: @"XMLReadError"
                   format: @"Unable to read NEXUS_REST_APINS0ConfigurationsListResourceResponse. Expected element configs-list. Current element: {%s}%s\n", xmlTextReaderConstNamespaceUri(reader), xmlTextReaderConstLocalName(reader)];
    }
  }

  return _configurationsListResourceResponse;
}

/**
 * Writes this NEXUS_REST_APINS0ConfigurationsListResourceResponse to XML under element name "configs-list".
 * The namespace declarations for the element will be written.
 *
 * @param writer The XML writer.
 * @param _configurationsListResourceResponse The ConfigurationsListResourceResponse to write.
 * @return 1 if successful, 0 otherwise.
 */
- (void) writeXMLElement: (xmlTextWriterPtr) writer
{
  [self writeXMLElement: writer writeNamespaces: YES];
}

/**
 * Writes this NEXUS_REST_APINS0ConfigurationsListResourceResponse to an XML writer.
 *
 * @param writer The writer.
 * @param writeNs Whether to write the namespaces for this element to the xml writer.
 */
- (void) writeXMLElement: (xmlTextWriterPtr) writer writeNamespaces: (BOOL) writeNs
{
  int rc = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "configs-list", NULL);
  if (rc < 0) {
    [NSException raise: @"XMLWriteError"
                 format: @"Error writing start element {}configs-list. XML writer status: %i\n", rc];
  }

#if DEBUG_ENUNCIATE > 1
  NSLog(@"writing type {}configurationsListResourceResponse for root element {}configs-list...");
#endif
  [self writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
  NSLog(@"successfully wrote type {}configurationsListResourceResponse for root element {}configs-list...");
#endif
  rc = xmlTextWriterEndElement(writer);
  if (rc < 0) {
    [NSException raise: @"XMLWriteError"
                 format: @"Error writing end element {}configs-list. XML writer status: %i\n", rc];
  }
}

//documentation inherited.
- (BOOL) readJAXBAttribute: (xmlTextReaderPtr) reader
{
  void *_child_accessor;

  if ([super readJAXBAttribute: reader]) {
    return YES;
  }

  return NO;
}

//documentation inherited.
- (BOOL) readJAXBValue: (xmlTextReaderPtr) reader
{
  return [super readJAXBValue: reader];
}

//documentation inherited.
- (BOOL) readJAXBChildElement: (xmlTextReaderPtr) reader
{
  id __child;
  void *_child_accessor;
  int status, depth;

  if ([super readJAXBChildElement: reader]) {
    return YES;
  }
  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "data", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

    if (xmlTextReaderIsEmptyElement(reader) == 0) {
#if DEBUG_ENUNCIATE > 1
      NSLog(@"Unwrapping wrapper element {}data...");
#endif
      //start wrapper element "{}data"
      depth = xmlTextReaderDepth(reader);
      status = xmlTextReaderAdvanceToNextStartOrEndElement(reader);
      while (xmlTextReaderDepth(reader) > depth) {
        if (status < 1) {
          //panic: XML read error.
          [self dealloc];
          [NSException raise: @"XMLReadError"
                       format: @"Failure to advance to next wrapped child element."];
        }
  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "configs-list-item", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}configs-list-item of type {}configs-list-item.");
#endif

    __child = [NEXUS_REST_APINS0ConfigurationsListResource readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}configs-list-item of type {}configs-list-item.");
#endif

    if ([self data]) {
      [self setData: [[self data] arrayByAddingObject: __child]];
    }
    else {
      [self setData: [NSArray arrayWithObject: __child]];
    }
    continue; //continue "while in wrapper element" loop
  } //end "if choice"

        status = xmlTextReaderAdvanceToNextStartOrEndElement(reader);
#if DEBUG_ENUNCIATE > 1
        NSLog(@"successfully unwrapped wrapper element {}data...");
#endif
      } // end "while in wrapper element" loop

      if (status < 1) {
        //panic: XML read error.
        [self dealloc];
        [NSException raise: @"XMLReadError"
                     format: @"Failure to advance to end wrapper element."];
      }
      else {
        //end wrapper element "{}data"
        status = xmlTextReaderAdvanceToNextStartOrEndElement(reader);
      }
    } //end "if empty element" clause
    else {
      __child = [NSArray array];
      [self setData: (NSArray*) __child];
    }

    return YES;
  } // end "if wrapper element" clause

  return NO;
}

//documentation inherited.
- (int) readUnknownJAXBChildElement: (xmlTextReaderPtr) reader
{
  return [super readUnknownJAXBChildElement: reader];
}

//documentation inherited.
- (void) readUnknownJAXBAttribute: (xmlTextReaderPtr) reader
{
  [super readUnknownJAXBAttribute: reader];
}

//documentation inherited.
- (void) writeJAXBAttributes: (xmlTextWriterPtr) writer
{
  int status;

  [super writeJAXBAttributes: writer];

}

//documentation inherited.
- (void) writeJAXBValue: (xmlTextWriterPtr) writer
{
  [super writeJAXBValue: writer];
}

/**
 * Method for writing the child elements.
 *
 * @param writer The writer.
 */
- (void) writeJAXBChildElements: (xmlTextWriterPtr) writer
{
  int status;
  id __item;
  NSEnumerator *__enumerator;

  [super writeJAXBChildElements: writer];

  if ([self data]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "data", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start wrapper element {}data."];
    }
    __enumerator = [[self data] objectEnumerator];

    while ( (__item = [__enumerator nextObject]) ) {
      status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "configs-list-item", NULL);
      if (status < 0) {
        [NSException raise: @"XMLWriteError"
                     format: @"Error writing start child element {}configs-list-item."];
      }

#if DEBUG_ENUNCIATE > 1
      NSLog(@"writing element {}configs-list-item...");
#endif
      [__item writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
      NSLog(@"successfully wrote element {}configs-list-item...");
#endif

      status = xmlTextWriterEndElement(writer);
      if (status < 0) {
        [NSException raise: @"XMLWriteError"
                     format: @"Error writing end child element {}configs-list-item."];
      }
    } //end item iterator.

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end wrapper element {}data."];
    }
  }
}
@end /* implementation NEXUS_REST_APINS0ConfigurationsListResourceResponse (JAXB) */

#endif /* DEF_NEXUS_REST_APINS0ConfigurationsListResourceResponse_M */
